/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_d0hd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (d0|hd) integrals */

void d12hrr_order_d0hd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][7][11] = int_stack + 0;
 Libderiv->deriv_classes[2][7][10] = int_stack + 216;
 Libderiv->deriv_classes[2][7][9] = int_stack + 432;
 Libderiv->deriv_classes[2][7][8] = int_stack + 648;
 Libderiv->deriv_classes[2][7][7] = int_stack + 864;
 Libderiv->dvrr_classes[2][6] = int_stack + 1080;
 Libderiv->deriv_classes[2][7][6] = int_stack + 1248;
 Libderiv->deriv_classes[2][7][2] = int_stack + 1464;
 Libderiv->deriv_classes[2][7][1] = int_stack + 1680;
 Libderiv->deriv_classes[2][7][0] = int_stack + 1896;
 Libderiv->deriv2_classes[2][5][143] = int_stack + 2112;
 Libderiv->deriv2_classes[2][6][143] = int_stack + 2238;
 Libderiv->deriv2_classes[2][7][143] = int_stack + 2406;
 Libderiv->deriv2_classes[2][5][131] = int_stack + 2622;
 Libderiv->deriv2_classes[2][6][131] = int_stack + 2748;
 Libderiv->deriv2_classes[2][7][131] = int_stack + 2916;
 Libderiv->deriv2_classes[2][5][130] = int_stack + 3132;
 Libderiv->deriv2_classes[2][6][130] = int_stack + 3258;
 Libderiv->deriv2_classes[2][7][130] = int_stack + 3426;
 Libderiv->deriv2_classes[2][5][119] = int_stack + 3642;
 Libderiv->deriv2_classes[2][6][119] = int_stack + 3768;
 Libderiv->deriv2_classes[2][7][119] = int_stack + 3936;
 Libderiv->deriv2_classes[2][5][118] = int_stack + 4152;
 Libderiv->deriv2_classes[2][6][118] = int_stack + 4278;
 Libderiv->deriv2_classes[2][7][118] = int_stack + 4446;
 Libderiv->deriv2_classes[2][5][117] = int_stack + 4662;
 Libderiv->deriv2_classes[2][6][117] = int_stack + 4788;
 Libderiv->deriv2_classes[2][7][117] = int_stack + 4956;
 Libderiv->deriv2_classes[2][5][107] = int_stack + 5172;
 Libderiv->deriv2_classes[2][6][107] = int_stack + 5298;
 Libderiv->deriv2_classes[2][7][107] = int_stack + 5466;
 Libderiv->deriv2_classes[2][5][106] = int_stack + 5682;
 Libderiv->deriv2_classes[2][6][106] = int_stack + 5808;
 Libderiv->deriv2_classes[2][7][106] = int_stack + 5976;
 Libderiv->deriv2_classes[2][5][105] = int_stack + 6192;
 Libderiv->deriv2_classes[2][6][105] = int_stack + 6318;
 Libderiv->deriv2_classes[2][7][105] = int_stack + 6486;
 Libderiv->deriv2_classes[2][5][104] = int_stack + 6702;
 Libderiv->deriv2_classes[2][6][104] = int_stack + 6828;
 Libderiv->deriv2_classes[2][7][104] = int_stack + 6996;
 Libderiv->deriv2_classes[2][5][95] = int_stack + 7212;
 Libderiv->deriv2_classes[2][6][95] = int_stack + 7338;
 Libderiv->deriv2_classes[2][7][95] = int_stack + 7506;
 Libderiv->deriv2_classes[2][5][94] = int_stack + 7722;
 Libderiv->deriv2_classes[2][6][94] = int_stack + 7848;
 Libderiv->deriv2_classes[2][7][94] = int_stack + 8016;
 Libderiv->deriv2_classes[2][5][93] = int_stack + 8232;
 Libderiv->deriv2_classes[2][6][93] = int_stack + 8358;
 Libderiv->deriv2_classes[2][7][93] = int_stack + 8526;
 Libderiv->deriv2_classes[2][5][92] = int_stack + 8742;
 Libderiv->deriv2_classes[2][6][92] = int_stack + 8868;
 Libderiv->deriv2_classes[2][7][92] = int_stack + 9036;
 Libderiv->deriv2_classes[2][5][91] = int_stack + 9252;
 Libderiv->deriv2_classes[2][6][91] = int_stack + 9378;
 Libderiv->deriv2_classes[2][7][91] = int_stack + 9546;
 Libderiv->deriv_classes[2][5][11] = int_stack + 9762;
 Libderiv->deriv2_classes[2][5][83] = int_stack + 9888;
 Libderiv->deriv_classes[2][6][11] = int_stack + 10014;
 Libderiv->deriv2_classes[2][6][83] = int_stack + 10182;
 Libderiv->deriv2_classes[2][7][83] = int_stack + 10350;
 Libderiv->deriv_classes[2][5][10] = int_stack + 10566;
 Libderiv->deriv2_classes[2][5][82] = int_stack + 10692;
 Libderiv->deriv_classes[2][6][10] = int_stack + 10818;
 Libderiv->deriv2_classes[2][6][82] = int_stack + 10986;
 Libderiv->deriv2_classes[2][7][82] = int_stack + 11154;
 Libderiv->deriv_classes[2][5][9] = int_stack + 11370;
 Libderiv->deriv2_classes[2][5][81] = int_stack + 11496;
 Libderiv->deriv_classes[2][6][9] = int_stack + 11622;
 Libderiv->deriv2_classes[2][6][81] = int_stack + 11790;
 Libderiv->deriv2_classes[2][7][81] = int_stack + 11958;
 Libderiv->deriv_classes[2][5][8] = int_stack + 12174;
 Libderiv->deriv2_classes[2][5][80] = int_stack + 12300;
 Libderiv->deriv_classes[2][6][8] = int_stack + 12426;
 Libderiv->deriv2_classes[2][6][80] = int_stack + 12594;
 Libderiv->deriv2_classes[2][7][80] = int_stack + 12762;
 Libderiv->deriv_classes[2][5][7] = int_stack + 12978;
 Libderiv->deriv2_classes[2][5][79] = int_stack + 13104;
 Libderiv->deriv_classes[2][6][7] = int_stack + 13230;
 Libderiv->deriv2_classes[2][6][79] = int_stack + 13398;
 Libderiv->deriv2_classes[2][7][79] = int_stack + 13566;
 Libderiv->dvrr_classes[2][5] = int_stack + 13782;
 Libderiv->deriv_classes[2][5][6] = int_stack + 13908;
 Libderiv->deriv2_classes[2][5][78] = int_stack + 14034;
 Libderiv->deriv_classes[2][6][6] = int_stack + 14160;
 Libderiv->deriv2_classes[2][6][78] = int_stack + 14328;
 Libderiv->deriv2_classes[2][7][78] = int_stack + 14496;
 Libderiv->deriv2_classes[2][5][35] = int_stack + 14712;
 Libderiv->deriv2_classes[2][6][35] = int_stack + 14838;
 Libderiv->deriv2_classes[2][7][35] = int_stack + 15006;
 Libderiv->deriv2_classes[2][5][34] = int_stack + 15222;
 Libderiv->deriv2_classes[2][6][34] = int_stack + 15348;
 Libderiv->deriv2_classes[2][7][34] = int_stack + 15516;
 Libderiv->deriv2_classes[2][5][33] = int_stack + 15732;
 Libderiv->deriv2_classes[2][6][33] = int_stack + 15858;
 Libderiv->deriv2_classes[2][7][33] = int_stack + 16026;
 Libderiv->deriv2_classes[2][5][32] = int_stack + 16242;
 Libderiv->deriv2_classes[2][6][32] = int_stack + 16368;
 Libderiv->deriv2_classes[2][7][32] = int_stack + 16536;
 Libderiv->deriv2_classes[2][5][31] = int_stack + 16752;
 Libderiv->deriv2_classes[2][6][31] = int_stack + 16878;
 Libderiv->deriv2_classes[2][7][31] = int_stack + 17046;
 Libderiv->deriv_classes[2][5][2] = int_stack + 17262;
 Libderiv->deriv2_classes[2][5][30] = int_stack + 17388;
 Libderiv->deriv_classes[2][6][2] = int_stack + 17514;
 Libderiv->deriv2_classes[2][6][30] = int_stack + 17682;
 Libderiv->deriv2_classes[2][7][30] = int_stack + 17850;
 Libderiv->deriv2_classes[2][5][26] = int_stack + 18066;
 Libderiv->deriv2_classes[2][6][26] = int_stack + 18192;
 Libderiv->deriv2_classes[2][7][26] = int_stack + 18360;
 Libderiv->deriv2_classes[2][5][23] = int_stack + 18576;
 Libderiv->deriv2_classes[2][6][23] = int_stack + 18702;
 Libderiv->deriv2_classes[2][7][23] = int_stack + 18870;
 Libderiv->deriv2_classes[2][5][22] = int_stack + 19086;
 Libderiv->deriv2_classes[2][6][22] = int_stack + 19212;
 Libderiv->deriv2_classes[2][7][22] = int_stack + 19380;
 Libderiv->deriv2_classes[2][5][21] = int_stack + 19596;
 Libderiv->deriv2_classes[2][6][21] = int_stack + 19722;
 Libderiv->deriv2_classes[2][7][21] = int_stack + 19890;
 Libderiv->deriv2_classes[2][5][20] = int_stack + 20106;
 Libderiv->deriv2_classes[2][6][20] = int_stack + 20232;
 Libderiv->deriv2_classes[2][7][20] = int_stack + 20400;
 Libderiv->deriv2_classes[2][5][19] = int_stack + 20616;
 Libderiv->deriv2_classes[2][6][19] = int_stack + 20742;
 Libderiv->deriv2_classes[2][7][19] = int_stack + 20910;
 Libderiv->deriv_classes[2][5][1] = int_stack + 21126;
 Libderiv->deriv2_classes[2][5][18] = int_stack + 21252;
 Libderiv->deriv_classes[2][6][1] = int_stack + 21378;
 Libderiv->deriv2_classes[2][6][18] = int_stack + 21546;
 Libderiv->deriv2_classes[2][7][18] = int_stack + 21714;
 Libderiv->deriv2_classes[2][5][14] = int_stack + 21930;
 Libderiv->deriv2_classes[2][6][14] = int_stack + 22056;
 Libderiv->deriv2_classes[2][7][14] = int_stack + 22224;
 Libderiv->deriv2_classes[2][5][13] = int_stack + 22440;
 Libderiv->deriv2_classes[2][6][13] = int_stack + 22566;
 Libderiv->deriv2_classes[2][7][13] = int_stack + 22734;
 Libderiv->deriv2_classes[2][5][11] = int_stack + 22950;
 Libderiv->deriv2_classes[2][6][11] = int_stack + 23076;
 Libderiv->deriv2_classes[2][7][11] = int_stack + 23244;
 Libderiv->deriv2_classes[2][5][10] = int_stack + 23460;
 Libderiv->deriv2_classes[2][6][10] = int_stack + 23586;
 Libderiv->deriv2_classes[2][7][10] = int_stack + 23754;
 Libderiv->deriv2_classes[2][5][9] = int_stack + 23970;
 Libderiv->deriv2_classes[2][6][9] = int_stack + 24096;
 Libderiv->deriv2_classes[2][7][9] = int_stack + 24264;
 Libderiv->deriv2_classes[2][5][8] = int_stack + 24480;
 Libderiv->deriv2_classes[2][6][8] = int_stack + 24606;
 Libderiv->deriv2_classes[2][7][8] = int_stack + 24774;
 Libderiv->deriv2_classes[2][5][7] = int_stack + 24990;
 Libderiv->deriv2_classes[2][6][7] = int_stack + 25116;
 Libderiv->deriv2_classes[2][7][7] = int_stack + 25284;
 Libderiv->deriv_classes[2][5][0] = int_stack + 25500;
 Libderiv->deriv2_classes[2][5][6] = int_stack + 25626;
 Libderiv->deriv_classes[2][6][0] = int_stack + 25752;
 Libderiv->deriv2_classes[2][6][6] = int_stack + 25920;
 Libderiv->deriv2_classes[2][7][6] = int_stack + 26088;
 Libderiv->deriv2_classes[2][5][2] = int_stack + 26304;
 Libderiv->deriv2_classes[2][6][2] = int_stack + 26430;
 Libderiv->deriv2_classes[2][7][2] = int_stack + 26598;
 Libderiv->deriv2_classes[2][5][1] = int_stack + 26814;
 Libderiv->deriv2_classes[2][6][1] = int_stack + 26940;
 Libderiv->deriv2_classes[2][7][1] = int_stack + 27108;
 Libderiv->deriv2_classes[2][5][0] = int_stack + 27324;
 Libderiv->deriv2_classes[2][6][0] = int_stack + 27450;
 Libderiv->deriv2_classes[2][7][0] = int_stack + 27618;
 memset(int_stack,0,222672);

 Libderiv->dvrr_stack = int_stack + 52530;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_d0hd(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+27834,int_stack+1080,int_stack+13782,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28212,int_stack+10014,int_stack+9762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13782,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28590,int_stack+0,int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29094,int_stack+10818,int_stack+10566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13782, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29472,int_stack+216,int_stack+10818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+11622,int_stack+11370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13782, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29976,int_stack+432,int_stack+11622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30480,int_stack+12426,int_stack+12174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30858,int_stack+648,int_stack+12426, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+378,int_stack+13230,int_stack+12978, 0.0, zero_stack, 1.0, int_stack+13782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31362,int_stack+864,int_stack+13230, 0.0, zero_stack, 1.0, int_stack+1080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31866,int_stack+14160,int_stack+13908, 1.0, int_stack+13782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32244,int_stack+1248,int_stack+14160, 1.0, int_stack+1080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+756,int_stack+17514,int_stack+17262,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+32748,int_stack+1464,int_stack+17514,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1134,int_stack+21378,int_stack+21126,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+33252,int_stack+1680,int_stack+21378,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1512,int_stack+25752,int_stack+25500,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+33756,int_stack+1896,int_stack+25752,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34260,int_stack+2238,int_stack+2112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+9762,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34638,int_stack+2406,int_stack+2238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+10014,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+2748,int_stack+2622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9762, 1.0, int_stack+10566,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35142,int_stack+2916,int_stack+2748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10014, 1.0, int_stack+10818,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+3258,int_stack+3132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+10566, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2646,int_stack+3426,int_stack+3258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+10818, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+3768,int_stack+3642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9762, 0.0, zero_stack, 1.0, int_stack+11370,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35646,int_stack+3936,int_stack+3768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10014, 0.0, zero_stack, 1.0, int_stack+11622,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528,int_stack+4278,int_stack+4152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10566, 1.0, int_stack+11370, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+36150,int_stack+4446,int_stack+4278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10818, 1.0, int_stack+11622, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3906,int_stack+4788,int_stack+4662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+11370, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4284,int_stack+4956,int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+11622, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4788,int_stack+5298,int_stack+5172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12174,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+36654,int_stack+5466,int_stack+5298, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12426,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5166,int_stack+5808,int_stack+5682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10566, 0.0, zero_stack, 1.0, int_stack+12174, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37158,int_stack+5976,int_stack+5808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10818, 0.0, zero_stack, 1.0, int_stack+12426, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5544,int_stack+6318,int_stack+6192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11370, 1.0, int_stack+12174, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37662,int_stack+6486,int_stack+6318, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11622, 1.0, int_stack+12426, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5922,int_stack+6828,int_stack+6702, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+12174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6300,int_stack+6996,int_stack+6828, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+12426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6804,int_stack+7338,int_stack+7212, 0.0, zero_stack, 1.0, int_stack+9762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12978,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38166,int_stack+7506,int_stack+7338, 0.0, zero_stack, 1.0, int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13230,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+7848,int_stack+7722, 0.0, zero_stack, 1.0, int_stack+10566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12978, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38670,int_stack+8016,int_stack+7848, 0.0, zero_stack, 1.0, int_stack+10818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13230, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7560,int_stack+8358,int_stack+8232, 0.0, zero_stack, 1.0, int_stack+11370, 0.0, zero_stack, 1.0, int_stack+12978, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39174,int_stack+8526,int_stack+8358, 0.0, zero_stack, 1.0, int_stack+11622, 0.0, zero_stack, 1.0, int_stack+13230, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7938,int_stack+8868,int_stack+8742, 0.0, zero_stack, 1.0, int_stack+12174, 1.0, int_stack+12978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8316,int_stack+9036,int_stack+8868, 0.0, zero_stack, 1.0, int_stack+12426, 1.0, int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8820,int_stack+9378,int_stack+9252, 0.0, zero_stack, 2.0, int_stack+12978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39678,int_stack+9546,int_stack+9378, 0.0, zero_stack, 2.0, int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9198,int_stack+10182,int_stack+9888, 1.0, int_stack+9762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13908,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40182,int_stack+10350,int_stack+10182, 1.0, int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14160,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9576,int_stack+10986,int_stack+10692, 1.0, int_stack+10566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13908, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9954,int_stack+11154,int_stack+10986, 1.0, int_stack+10818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14160, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10458,int_stack+11790,int_stack+11496, 1.0, int_stack+11370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13908, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10836,int_stack+11958,int_stack+11790, 1.0, int_stack+11622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14160, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11340,int_stack+12594,int_stack+12300, 1.0, int_stack+12174, 0.0, zero_stack, 1.0, int_stack+13908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11718,int_stack+12762,int_stack+12594, 1.0, int_stack+12426, 0.0, zero_stack, 1.0, int_stack+14160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12222,int_stack+13398,int_stack+13104, 1.0, int_stack+12978, 1.0, int_stack+13908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+13566,int_stack+13398, 1.0, int_stack+13230, 1.0, int_stack+14160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13104,int_stack+14328,int_stack+14034, 2.0, int_stack+13908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13482,int_stack+14496,int_stack+14328, 2.0, int_stack+14160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13986,int_stack+14838,int_stack+14712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17262,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40686,int_stack+15006,int_stack+14838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17514,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14364,int_stack+15348,int_stack+15222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17262, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14742,int_stack+15516,int_stack+15348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17514, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15246,int_stack+15858,int_stack+15732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17262, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41190,int_stack+16026,int_stack+15858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17514, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15624,int_stack+16368,int_stack+16242, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41694,int_stack+16536,int_stack+16368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16002,int_stack+16878,int_stack+16752, 0.0, zero_stack, 1.0, int_stack+17262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42198,int_stack+17046,int_stack+16878, 0.0, zero_stack, 1.0, int_stack+17514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16380,int_stack+17682,int_stack+17388, 1.0, int_stack+17262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16758,int_stack+17850,int_stack+17682, 1.0, int_stack+17514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+17262,int_stack+18192,int_stack+18066,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+17640,int_stack+18360,int_stack+18192,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18144,int_stack+18702,int_stack+18576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21126,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42702,int_stack+18870,int_stack+18702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21378,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18522,int_stack+19212,int_stack+19086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21126, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43206,int_stack+19380,int_stack+19212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21378, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+19722,int_stack+19596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21126, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43710,int_stack+19890,int_stack+19722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21378, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19278,int_stack+20232,int_stack+20106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19656,int_stack+20400,int_stack+20232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20160,int_stack+20742,int_stack+20616, 0.0, zero_stack, 1.0, int_stack+21126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+44214,int_stack+20910,int_stack+20742, 0.0, zero_stack, 1.0, int_stack+21378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20538,int_stack+21546,int_stack+21252, 1.0, int_stack+21126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+44718,int_stack+21714,int_stack+21546, 1.0, int_stack+21378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+20916,int_stack+22056,int_stack+21930,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+21294,int_stack+22224,int_stack+22056,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+21798,int_stack+22566,int_stack+22440,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+45222,int_stack+22734,int_stack+22566,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22176,int_stack+23076,int_stack+22950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25500,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+22554,int_stack+23244,int_stack+23076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25752,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23058,int_stack+23586,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25500, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+45726,int_stack+23754,int_stack+23586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25752, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23436,int_stack+24096,int_stack+23970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25500, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+46230,int_stack+24264,int_stack+24096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25752, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23814,int_stack+24606,int_stack+24480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+46734,int_stack+24774,int_stack+24606, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24192,int_stack+25116,int_stack+24990, 0.0, zero_stack, 1.0, int_stack+25500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+24570,int_stack+25284,int_stack+25116, 0.0, zero_stack, 1.0, int_stack+25752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25074,int_stack+25920,int_stack+25626, 1.0, int_stack+25500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+47238,int_stack+26088,int_stack+25920, 1.0, int_stack+25752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+25452,int_stack+26430,int_stack+26304,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+25830,int_stack+26598,int_stack+26430,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+26334,int_stack+26940,int_stack+26814,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+47742,int_stack+27108,int_stack+26940,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+26712,int_stack+27450,int_stack+27324,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+48246,int_stack+27618,int_stack+27450,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48750,int_stack+28590,int_stack+28212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27834,6);
     Libderiv->ABCD[11] = int_stack + 48750;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49506,int_stack+29472,int_stack+29094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27834, 0.0, zero_stack,6);
     Libderiv->ABCD[10] = int_stack + 49506;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50262,int_stack+29976,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27834, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[9] = int_stack + 50262;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29472,int_stack+30858,int_stack+30480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[8] = int_stack + 29472;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51018,int_stack+31362,int_stack+378, 0.0, zero_stack, 1.0, int_stack+27834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[7] = int_stack + 51018;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30858,int_stack+32244,int_stack+31866, 1.0, int_stack+27834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[6] = int_stack + 30858;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+27090,int_stack+32748,int_stack+756,6);
     Libderiv->ABCD[2] = int_stack + 27090;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+32244,int_stack+33252,int_stack+1134,6);
     Libderiv->ABCD[1] = int_stack + 32244;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+33000,int_stack+33756,int_stack+1512,6);
     Libderiv->ABCD[0] = int_stack + 33000;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51774,int_stack+34638,int_stack+34260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+28212,6);
     Libderiv->ABCD[155] = int_stack + 51774;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33756,int_stack+35142,int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28212, 1.0, int_stack+29094,6);
     Libderiv->ABCD[143] = int_stack + 33756;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34512,int_stack+2646,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+29094, 0.0, zero_stack,6);
     Libderiv->ABCD[142] = int_stack + 34512;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1890,int_stack+35646,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28212, 0.0, zero_stack, 1.0, int_stack+0,6);
     Libderiv->ABCD[131] = int_stack + 1890;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2646,int_stack+36150,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29094, 1.0, int_stack+0, 0.0, zero_stack,6);
     Libderiv->ABCD[130] = int_stack + 2646;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35268,int_stack+4284,int_stack+3906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[129] = int_stack + 35268;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3402,int_stack+36654,int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30480,6);
     Libderiv->ABCD[119] = int_stack + 3402;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4158,int_stack+37158,int_stack+5166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29094, 0.0, zero_stack, 1.0, int_stack+30480, 0.0, zero_stack,6);
     Libderiv->ABCD[118] = int_stack + 4158;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36024,int_stack+37662,int_stack+5544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+30480, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[117] = int_stack + 36024;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4914,int_stack+6300,int_stack+5922, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+30480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[116] = int_stack + 4914;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5670,int_stack+38166,int_stack+6804, 0.0, zero_stack, 1.0, int_stack+28212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378,6);
     Libderiv->ABCD[107] = int_stack + 5670;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6426,int_stack+38670,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+29094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378, 0.0, zero_stack,6);
     Libderiv->ABCD[106] = int_stack + 6426;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36780,int_stack+39174,int_stack+7560, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+378, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[105] = int_stack + 36780;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+8316,int_stack+7938, 0.0, zero_stack, 1.0, int_stack+30480, 1.0, int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[104] = int_stack + 7182;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7938,int_stack+39678,int_stack+8820, 0.0, zero_stack, 2.0, int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[103] = int_stack + 7938;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37536,int_stack+40182,int_stack+9198, 1.0, int_stack+28212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31866,6);
     Libderiv->ABCD[95] = int_stack + 37536;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8694,int_stack+9954,int_stack+9576, 1.0, int_stack+29094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31866, 0.0, zero_stack,6);
     Libderiv->ABCD[94] = int_stack + 8694;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+10836,int_stack+10458, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31866, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[93] = int_stack + 9450;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10206,int_stack+11718,int_stack+11340, 1.0, int_stack+30480, 0.0, zero_stack, 1.0, int_stack+31866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[92] = int_stack + 10206;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10962,int_stack+12600,int_stack+12222, 1.0, int_stack+378, 1.0, int_stack+31866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[91] = int_stack + 10962;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+13482,int_stack+13104, 2.0, int_stack+31866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[90] = int_stack + 0;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11718,int_stack+40686,int_stack+13986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756,6);
     Libderiv->ABCD[47] = int_stack + 11718;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12474,int_stack+14742,int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756, 0.0, zero_stack,6);
     Libderiv->ABCD[46] = int_stack + 12474;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13230,int_stack+41190,int_stack+15246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[45] = int_stack + 13230;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13986,int_stack+41694,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[44] = int_stack + 13986;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14742,int_stack+42198,int_stack+16002, 0.0, zero_stack, 1.0, int_stack+756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[43] = int_stack + 14742;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15498,int_stack+16758,int_stack+16380, 1.0, int_stack+756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[42] = int_stack + 15498;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+16254,int_stack+17640,int_stack+17262,6);
     Libderiv->ABCD[38] = int_stack + 16254;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17010,int_stack+42702,int_stack+18144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1134,6);
     Libderiv->ABCD[35] = int_stack + 17010;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17766,int_stack+43206,int_stack+18522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1134, 0.0, zero_stack,6);
     Libderiv->ABCD[34] = int_stack + 17766;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38292,int_stack+43710,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1134, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[33] = int_stack + 38292;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18522,int_stack+19656,int_stack+19278, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[32] = int_stack + 18522;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19278,int_stack+44214,int_stack+20160, 0.0, zero_stack, 1.0, int_stack+1134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[31] = int_stack + 19278;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39048,int_stack+44718,int_stack+20538, 1.0, int_stack+1134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[30] = int_stack + 39048;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+756,int_stack+21294,int_stack+20916,6);
     Libderiv->ABCD[26] = int_stack + 756;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+20034,int_stack+45222,int_stack+21798,6);
     Libderiv->ABCD[25] = int_stack + 20034;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20790,int_stack+22554,int_stack+22176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1512,6);
     Libderiv->ABCD[23] = int_stack + 20790;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21546,int_stack+45726,int_stack+23058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1512, 0.0, zero_stack,6);
     Libderiv->ABCD[22] = int_stack + 21546;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22302,int_stack+46230,int_stack+23436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1512, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[21] = int_stack + 22302;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23058,int_stack+46734,int_stack+23814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[20] = int_stack + 23058;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39804,int_stack+24570,int_stack+24192, 0.0, zero_stack, 1.0, int_stack+1512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[19] = int_stack + 39804;
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23814,int_stack+47238,int_stack+25074, 1.0, int_stack+1512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[18] = int_stack + 23814;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+24570,int_stack+25830,int_stack+25452,6);
     Libderiv->ABCD[14] = int_stack + 24570;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+25326,int_stack+47742,int_stack+26334,6);
     Libderiv->ABCD[13] = int_stack + 25326;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40560,int_stack+48246,int_stack+26712,6);
     Libderiv->ABCD[12] = int_stack + 40560;

}
