/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_p0hp(Libderiv_t *, prim_data *);

  /* Computes derivatives of (p0|hp) integrals */

void d12hrr_order_p0hp(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][6][11] = int_stack + 0;
 Libderiv->deriv_classes[1][6][10] = int_stack + 84;
 Libderiv->deriv_classes[1][6][9] = int_stack + 168;
 Libderiv->deriv_classes[1][6][8] = int_stack + 252;
 Libderiv->deriv_classes[1][6][7] = int_stack + 336;
 Libderiv->dvrr_classes[1][5] = int_stack + 420;
 Libderiv->deriv_classes[1][6][6] = int_stack + 483;
 Libderiv->deriv_classes[1][6][2] = int_stack + 567;
 Libderiv->deriv_classes[1][6][1] = int_stack + 651;
 Libderiv->deriv_classes[1][6][0] = int_stack + 735;
 Libderiv->deriv2_classes[1][5][143] = int_stack + 819;
 Libderiv->deriv2_classes[1][6][143] = int_stack + 882;
 Libderiv->deriv2_classes[1][5][131] = int_stack + 966;
 Libderiv->deriv2_classes[1][6][131] = int_stack + 1029;
 Libderiv->deriv2_classes[1][5][130] = int_stack + 1113;
 Libderiv->deriv2_classes[1][6][130] = int_stack + 1176;
 Libderiv->deriv2_classes[1][5][119] = int_stack + 1260;
 Libderiv->deriv2_classes[1][6][119] = int_stack + 1323;
 Libderiv->deriv2_classes[1][5][118] = int_stack + 1407;
 Libderiv->deriv2_classes[1][6][118] = int_stack + 1470;
 Libderiv->deriv2_classes[1][5][117] = int_stack + 1554;
 Libderiv->deriv2_classes[1][6][117] = int_stack + 1617;
 Libderiv->deriv2_classes[1][5][107] = int_stack + 1701;
 Libderiv->deriv2_classes[1][6][107] = int_stack + 1764;
 Libderiv->deriv2_classes[1][5][106] = int_stack + 1848;
 Libderiv->deriv2_classes[1][6][106] = int_stack + 1911;
 Libderiv->deriv2_classes[1][5][105] = int_stack + 1995;
 Libderiv->deriv2_classes[1][6][105] = int_stack + 2058;
 Libderiv->deriv2_classes[1][5][104] = int_stack + 2142;
 Libderiv->deriv2_classes[1][6][104] = int_stack + 2205;
 Libderiv->deriv2_classes[1][5][95] = int_stack + 2289;
 Libderiv->deriv2_classes[1][6][95] = int_stack + 2352;
 Libderiv->deriv2_classes[1][5][94] = int_stack + 2436;
 Libderiv->deriv2_classes[1][6][94] = int_stack + 2499;
 Libderiv->deriv2_classes[1][5][93] = int_stack + 2583;
 Libderiv->deriv2_classes[1][6][93] = int_stack + 2646;
 Libderiv->deriv2_classes[1][5][92] = int_stack + 2730;
 Libderiv->deriv2_classes[1][6][92] = int_stack + 2793;
 Libderiv->deriv2_classes[1][5][91] = int_stack + 2877;
 Libderiv->deriv2_classes[1][6][91] = int_stack + 2940;
 Libderiv->deriv_classes[1][5][11] = int_stack + 3024;
 Libderiv->deriv2_classes[1][5][83] = int_stack + 3087;
 Libderiv->deriv2_classes[1][6][83] = int_stack + 3150;
 Libderiv->deriv_classes[1][5][10] = int_stack + 3234;
 Libderiv->deriv2_classes[1][5][82] = int_stack + 3297;
 Libderiv->deriv2_classes[1][6][82] = int_stack + 3360;
 Libderiv->deriv_classes[1][5][9] = int_stack + 3444;
 Libderiv->deriv2_classes[1][5][81] = int_stack + 3507;
 Libderiv->deriv2_classes[1][6][81] = int_stack + 3570;
 Libderiv->deriv_classes[1][5][8] = int_stack + 3654;
 Libderiv->deriv2_classes[1][5][80] = int_stack + 3717;
 Libderiv->deriv2_classes[1][6][80] = int_stack + 3780;
 Libderiv->deriv_classes[1][5][7] = int_stack + 3864;
 Libderiv->deriv2_classes[1][5][79] = int_stack + 3927;
 Libderiv->deriv2_classes[1][6][79] = int_stack + 3990;
 Libderiv->deriv_classes[1][5][6] = int_stack + 4074;
 Libderiv->deriv2_classes[1][5][78] = int_stack + 4137;
 Libderiv->deriv2_classes[1][6][78] = int_stack + 4200;
 Libderiv->deriv2_classes[1][5][35] = int_stack + 4284;
 Libderiv->deriv2_classes[1][6][35] = int_stack + 4347;
 Libderiv->deriv2_classes[1][5][34] = int_stack + 4431;
 Libderiv->deriv2_classes[1][6][34] = int_stack + 4494;
 Libderiv->deriv2_classes[1][5][33] = int_stack + 4578;
 Libderiv->deriv2_classes[1][6][33] = int_stack + 4641;
 Libderiv->deriv2_classes[1][5][32] = int_stack + 4725;
 Libderiv->deriv2_classes[1][6][32] = int_stack + 4788;
 Libderiv->deriv2_classes[1][5][31] = int_stack + 4872;
 Libderiv->deriv2_classes[1][6][31] = int_stack + 4935;
 Libderiv->deriv_classes[1][5][2] = int_stack + 5019;
 Libderiv->deriv2_classes[1][5][30] = int_stack + 5082;
 Libderiv->deriv2_classes[1][6][30] = int_stack + 5145;
 Libderiv->deriv2_classes[1][5][26] = int_stack + 5229;
 Libderiv->deriv2_classes[1][6][26] = int_stack + 5292;
 Libderiv->deriv2_classes[1][5][23] = int_stack + 5376;
 Libderiv->deriv2_classes[1][6][23] = int_stack + 5439;
 Libderiv->deriv2_classes[1][5][22] = int_stack + 5523;
 Libderiv->deriv2_classes[1][6][22] = int_stack + 5586;
 Libderiv->deriv2_classes[1][5][21] = int_stack + 5670;
 Libderiv->deriv2_classes[1][6][21] = int_stack + 5733;
 Libderiv->deriv2_classes[1][5][20] = int_stack + 5817;
 Libderiv->deriv2_classes[1][6][20] = int_stack + 5880;
 Libderiv->deriv2_classes[1][5][19] = int_stack + 5964;
 Libderiv->deriv2_classes[1][6][19] = int_stack + 6027;
 Libderiv->deriv_classes[1][5][1] = int_stack + 6111;
 Libderiv->deriv2_classes[1][5][18] = int_stack + 6174;
 Libderiv->deriv2_classes[1][6][18] = int_stack + 6237;
 Libderiv->deriv2_classes[1][5][14] = int_stack + 6321;
 Libderiv->deriv2_classes[1][6][14] = int_stack + 6384;
 Libderiv->deriv2_classes[1][5][13] = int_stack + 6468;
 Libderiv->deriv2_classes[1][6][13] = int_stack + 6531;
 Libderiv->deriv2_classes[1][5][11] = int_stack + 6615;
 Libderiv->deriv2_classes[1][6][11] = int_stack + 6678;
 Libderiv->deriv2_classes[1][5][10] = int_stack + 6762;
 Libderiv->deriv2_classes[1][6][10] = int_stack + 6825;
 Libderiv->deriv2_classes[1][5][9] = int_stack + 6909;
 Libderiv->deriv2_classes[1][6][9] = int_stack + 6972;
 Libderiv->deriv2_classes[1][5][8] = int_stack + 7056;
 Libderiv->deriv2_classes[1][6][8] = int_stack + 7119;
 Libderiv->deriv2_classes[1][5][7] = int_stack + 7203;
 Libderiv->deriv2_classes[1][6][7] = int_stack + 7266;
 Libderiv->deriv_classes[1][5][0] = int_stack + 7350;
 Libderiv->deriv2_classes[1][5][6] = int_stack + 7413;
 Libderiv->deriv2_classes[1][6][6] = int_stack + 7476;
 Libderiv->deriv2_classes[1][5][2] = int_stack + 7560;
 Libderiv->deriv2_classes[1][6][2] = int_stack + 7623;
 Libderiv->deriv2_classes[1][5][1] = int_stack + 7707;
 Libderiv->deriv2_classes[1][6][1] = int_stack + 7770;
 Libderiv->deriv2_classes[1][5][0] = int_stack + 7854;
 Libderiv->deriv2_classes[1][6][0] = int_stack + 7917;
 memset(int_stack,0,64008);

 Libderiv->dvrr_stack = int_stack + 10458;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_p0hp(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8001,int_stack+0,int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420,3);
     Libderiv->ABCD[11] = int_stack + 8001;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8190,int_stack+84,int_stack+3234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420, 0.0, zero_stack,3);
     Libderiv->ABCD[10] = int_stack + 8190;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8379,int_stack+168,int_stack+3444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[9] = int_stack + 8379;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+252,int_stack+3654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8568,int_stack+336,int_stack+3864, 0.0, zero_stack, 1.0, int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[7] = int_stack + 8568;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+189,int_stack+483,int_stack+4074, 1.0, int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[6] = int_stack + 189;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+378,int_stack+567,int_stack+5019,3);
     Libderiv->ABCD[2] = int_stack + 378;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8757,int_stack+651,int_stack+6111,3);
     Libderiv->ABCD[1] = int_stack + 8757;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8946,int_stack+735,int_stack+7350,3);
     Libderiv->ABCD[0] = int_stack + 8946;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+567,int_stack+882,int_stack+819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3024,3);
     Libderiv->ABCD[155] = int_stack + 567;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+756,int_stack+1029,int_stack+966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 1.0, int_stack+3234,3);
     Libderiv->ABCD[143] = int_stack + 756;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9135,int_stack+1176,int_stack+1113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3234, 0.0, zero_stack,3);
     Libderiv->ABCD[142] = int_stack + 9135;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+945,int_stack+1323,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 1.0, int_stack+3444,3);
     Libderiv->ABCD[131] = int_stack + 945;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1134,int_stack+1470,int_stack+1407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3234, 1.0, int_stack+3444, 0.0, zero_stack,3);
     Libderiv->ABCD[130] = int_stack + 1134;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1323,int_stack+1617,int_stack+1554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3444, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[129] = int_stack + 1323;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1512,int_stack+1764,int_stack+1701, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3654,3);
     Libderiv->ABCD[119] = int_stack + 1512;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9324,int_stack+1911,int_stack+1848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3234, 0.0, zero_stack, 1.0, int_stack+3654, 0.0, zero_stack,3);
     Libderiv->ABCD[118] = int_stack + 9324;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1701,int_stack+2058,int_stack+1995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3444, 1.0, int_stack+3654, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[117] = int_stack + 1701;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+2205,int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[116] = int_stack + 1890;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2079,int_stack+2352,int_stack+2289, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3864,3);
     Libderiv->ABCD[107] = int_stack + 2079;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9513,int_stack+2499,int_stack+2436, 0.0, zero_stack, 1.0, int_stack+3234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3864, 0.0, zero_stack,3);
     Libderiv->ABCD[106] = int_stack + 9513;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+2646,int_stack+2583, 0.0, zero_stack, 1.0, int_stack+3444, 0.0, zero_stack, 1.0, int_stack+3864, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[105] = int_stack + 2268;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2457,int_stack+2793,int_stack+2730, 0.0, zero_stack, 1.0, int_stack+3654, 1.0, int_stack+3864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[104] = int_stack + 2457;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2646,int_stack+2940,int_stack+2877, 0.0, zero_stack, 2.0, int_stack+3864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[103] = int_stack + 2646;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2835,int_stack+3150,int_stack+3087, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4074,3);
     Libderiv->ABCD[95] = int_stack + 2835;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3024,int_stack+3360,int_stack+3297, 1.0, int_stack+3234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4074, 0.0, zero_stack,3);
     Libderiv->ABCD[94] = int_stack + 3024;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3213,int_stack+3570,int_stack+3507, 1.0, int_stack+3444, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4074, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[93] = int_stack + 3213;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3402,int_stack+3780,int_stack+3717, 1.0, int_stack+3654, 0.0, zero_stack, 1.0, int_stack+4074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[92] = int_stack + 3402;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3591,int_stack+3990,int_stack+3927, 1.0, int_stack+3864, 1.0, int_stack+4074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[91] = int_stack + 3591;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+4200,int_stack+4137, 2.0, int_stack+4074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[90] = int_stack + 3780;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3969,int_stack+4347,int_stack+4284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5019,3);
     Libderiv->ABCD[47] = int_stack + 3969;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4158,int_stack+4494,int_stack+4431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5019, 0.0, zero_stack,3);
     Libderiv->ABCD[46] = int_stack + 4158;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4347,int_stack+4641,int_stack+4578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5019, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[45] = int_stack + 4347;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4536,int_stack+4788,int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[44] = int_stack + 4536;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9702,int_stack+4935,int_stack+4872, 0.0, zero_stack, 1.0, int_stack+5019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[43] = int_stack + 9702;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725,int_stack+5145,int_stack+5082, 1.0, int_stack+5019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[42] = int_stack + 4725;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4914,int_stack+5292,int_stack+5229,3);
     Libderiv->ABCD[38] = int_stack + 4914;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5103,int_stack+5439,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6111,3);
     Libderiv->ABCD[35] = int_stack + 5103;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+5586,int_stack+5523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6111, 0.0, zero_stack,3);
     Libderiv->ABCD[34] = int_stack + 5292;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5481,int_stack+5733,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6111, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[33] = int_stack + 5481;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9891,int_stack+5880,int_stack+5817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[32] = int_stack + 9891;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+6027,int_stack+5964, 0.0, zero_stack, 1.0, int_stack+6111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[31] = int_stack + 5670;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5859,int_stack+6237,int_stack+6174, 1.0, int_stack+6111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[30] = int_stack + 5859;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6048,int_stack+6384,int_stack+6321,3);
     Libderiv->ABCD[26] = int_stack + 6048;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6237,int_stack+6531,int_stack+6468,3);
     Libderiv->ABCD[25] = int_stack + 6237;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6426,int_stack+6678,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7350,3);
     Libderiv->ABCD[23] = int_stack + 6426;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10080,int_stack+6825,int_stack+6762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7350, 0.0, zero_stack,3);
     Libderiv->ABCD[22] = int_stack + 10080;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+6972,int_stack+6909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7350, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[21] = int_stack + 6615;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6804,int_stack+7119,int_stack+7056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[20] = int_stack + 6804;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6993,int_stack+7266,int_stack+7203, 0.0, zero_stack, 1.0, int_stack+7350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[19] = int_stack + 6993;
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10269,int_stack+7476,int_stack+7413, 1.0, int_stack+7350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[18] = int_stack + 10269;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+7623,int_stack+7560,3);
     Libderiv->ABCD[14] = int_stack + 7182;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7371,int_stack+7770,int_stack+7707,3);
     Libderiv->ABCD[13] = int_stack + 7371;
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7560,int_stack+7917,int_stack+7854,3);
     Libderiv->ABCD[12] = int_stack + 7560;

}
