/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_d0hh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (d0|hh) integrals */

void d1hrr_order_d0hh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][5][11] = int_stack + 0;
 Libderiv->deriv_classes[2][6][11] = int_stack + 126;
 Libderiv->deriv_classes[2][7][11] = int_stack + 294;
 Libderiv->deriv_classes[2][8][11] = int_stack + 510;
 Libderiv->deriv_classes[2][9][11] = int_stack + 780;
 Libderiv->deriv_classes[2][10][11] = int_stack + 1110;
 Libderiv->deriv_classes[2][5][10] = int_stack + 1506;
 Libderiv->deriv_classes[2][6][10] = int_stack + 1632;
 Libderiv->deriv_classes[2][7][10] = int_stack + 1800;
 Libderiv->deriv_classes[2][8][10] = int_stack + 2016;
 Libderiv->deriv_classes[2][9][10] = int_stack + 2286;
 Libderiv->deriv_classes[2][10][10] = int_stack + 2616;
 Libderiv->deriv_classes[2][5][9] = int_stack + 3012;
 Libderiv->deriv_classes[2][6][9] = int_stack + 3138;
 Libderiv->deriv_classes[2][7][9] = int_stack + 3306;
 Libderiv->deriv_classes[2][8][9] = int_stack + 3522;
 Libderiv->deriv_classes[2][9][9] = int_stack + 3792;
 Libderiv->deriv_classes[2][10][9] = int_stack + 4122;
 Libderiv->deriv_classes[2][5][8] = int_stack + 4518;
 Libderiv->deriv_classes[2][6][8] = int_stack + 4644;
 Libderiv->deriv_classes[2][7][8] = int_stack + 4812;
 Libderiv->deriv_classes[2][8][8] = int_stack + 5028;
 Libderiv->deriv_classes[2][9][8] = int_stack + 5298;
 Libderiv->deriv_classes[2][10][8] = int_stack + 5628;
 Libderiv->deriv_classes[2][5][7] = int_stack + 6024;
 Libderiv->deriv_classes[2][6][7] = int_stack + 6150;
 Libderiv->deriv_classes[2][7][7] = int_stack + 6318;
 Libderiv->deriv_classes[2][8][7] = int_stack + 6534;
 Libderiv->deriv_classes[2][9][7] = int_stack + 6804;
 Libderiv->deriv_classes[2][10][7] = int_stack + 7134;
 Libderiv->dvrr_classes[2][5] = int_stack + 7530;
 Libderiv->deriv_classes[2][5][6] = int_stack + 7656;
 Libderiv->dvrr_classes[2][6] = int_stack + 7782;
 Libderiv->deriv_classes[2][6][6] = int_stack + 7950;
 Libderiv->dvrr_classes[2][7] = int_stack + 8118;
 Libderiv->deriv_classes[2][7][6] = int_stack + 8334;
 Libderiv->dvrr_classes[2][8] = int_stack + 8550;
 Libderiv->deriv_classes[2][8][6] = int_stack + 8820;
 Libderiv->dvrr_classes[2][9] = int_stack + 9090;
 Libderiv->deriv_classes[2][9][6] = int_stack + 9420;
 Libderiv->deriv_classes[2][10][6] = int_stack + 9750;
 Libderiv->deriv_classes[2][5][2] = int_stack + 10146;
 Libderiv->deriv_classes[2][6][2] = int_stack + 10272;
 Libderiv->deriv_classes[2][7][2] = int_stack + 10440;
 Libderiv->deriv_classes[2][8][2] = int_stack + 10656;
 Libderiv->deriv_classes[2][9][2] = int_stack + 10926;
 Libderiv->deriv_classes[2][10][2] = int_stack + 11256;
 Libderiv->deriv_classes[2][5][1] = int_stack + 11652;
 Libderiv->deriv_classes[2][6][1] = int_stack + 11778;
 Libderiv->deriv_classes[2][7][1] = int_stack + 11946;
 Libderiv->deriv_classes[2][8][1] = int_stack + 12162;
 Libderiv->deriv_classes[2][9][1] = int_stack + 12432;
 Libderiv->deriv_classes[2][10][1] = int_stack + 12762;
 Libderiv->deriv_classes[2][5][0] = int_stack + 13158;
 Libderiv->deriv_classes[2][6][0] = int_stack + 13284;
 Libderiv->deriv_classes[2][7][0] = int_stack + 13452;
 Libderiv->deriv_classes[2][8][0] = int_stack + 13668;
 Libderiv->deriv_classes[2][9][0] = int_stack + 13938;
 Libderiv->deriv_classes[2][10][0] = int_stack + 14268;
 memset(int_stack,0,117312);

 Libderiv->dvrr_stack = int_stack + 51918;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_d0hh(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+14664,int_stack+7782,int_stack+7530,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+15042,int_stack+8118,int_stack+7782,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+15546,int_stack+15042,int_stack+14664,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16302,int_stack+8550,int_stack+8118,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+16950,int_stack+16302,int_stack+15042,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+17958,int_stack+16950,int_stack+15546,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+19218,int_stack+9090,int_stack+8550,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+20028,int_stack+19218,int_stack+16302,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+21324,int_stack+20028,int_stack+16950,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+23004,int_stack+21324,int_stack+17958,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24894,int_stack+126,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7530,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+25272,int_stack+294,int_stack+126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7782,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25776,int_stack+25272,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14664,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26532,int_stack+510,int_stack+294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8118,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27180,int_stack+26532,int_stack+25272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15042,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28188,int_stack+27180,int_stack+25776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15546,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+780,int_stack+510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8550,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+29448,int_stack+24894,int_stack+26532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16302,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+30744,int_stack+29448,int_stack+27180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16950,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+25704,int_stack+30744,int_stack+28188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17958,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+27594,int_stack+1110,int_stack+780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9090,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+32424,int_stack+27594,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19218,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+34044,int_stack+32424,int_stack+29448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20028,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+27594,int_stack+34044,int_stack+30744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21324,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24894,int_stack+1632,int_stack+1506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7530, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30114,int_stack+1800,int_stack+1632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7782, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30618,int_stack+30114,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14664, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24894,int_stack+2016,int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8118, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31374,int_stack+24894,int_stack+30114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15042, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32382,int_stack+31374,int_stack+30618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15546, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+30114,int_stack+2286,int_stack+2016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8550, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33642,int_stack+30114,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16302, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34938,int_stack+33642,int_stack+31374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16950, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+34938,int_stack+32382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17958, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30924,int_stack+2616,int_stack+2286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9090, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31914,int_stack+30924,int_stack+30114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19218, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+36618,int_stack+31914,int_stack+33642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20028, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+30114,int_stack+36618,int_stack+34938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21324, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32634,int_stack+3138,int_stack+3012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7530, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33012,int_stack+3306,int_stack+3138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7782, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33516,int_stack+33012,int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14664, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+34272,int_stack+3522,int_stack+3306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8118, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34920,int_stack+34272,int_stack+33012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15042, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+35928,int_stack+34920,int_stack+33516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15546, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+3792,int_stack+3522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8550, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32634,int_stack+24894,int_stack+34272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16302, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+37188,int_stack+32634,int_stack+34920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16950, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+33930,int_stack+37188,int_stack+35928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17958, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+35820,int_stack+4122,int_stack+3792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9090, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1890,int_stack+35820,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19218, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+38868,int_stack+1890,int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20028, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1890,int_stack+38868,int_stack+37188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21324, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32634,int_stack+4644,int_stack+4518, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33012,int_stack+4812,int_stack+4644, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24894,int_stack+33012,int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+35820,int_stack+5028,int_stack+4812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+36468,int_stack+35820,int_stack+33012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32634,int_stack+36468,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+5298,int_stack+5028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+37476,int_stack+24894,int_stack+35820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+38772,int_stack+37476,int_stack+36468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+40452,int_stack+38772,int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+32634,int_stack+5628,int_stack+5298, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+35820,int_stack+32634,int_stack+24894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+42342,int_stack+35820,int_stack+37476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+35820,int_stack+42342,int_stack+38772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42342,int_stack+6150,int_stack+6024, 0.0, zero_stack, 1.0, int_stack+7530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42720,int_stack+6318,int_stack+6150, 0.0, zero_stack, 1.0, int_stack+7782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+43224,int_stack+42720,int_stack+42342, 0.0, zero_stack, 1.0, int_stack+14664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+43980,int_stack+6534,int_stack+6318, 0.0, zero_stack, 1.0, int_stack+8118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38340,int_stack+43980,int_stack+42720, 0.0, zero_stack, 1.0, int_stack+15042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32634,int_stack+38340,int_stack+43224, 0.0, zero_stack, 1.0, int_stack+15546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+6804,int_stack+6534, 0.0, zero_stack, 1.0, int_stack+8550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+42342,int_stack+24894,int_stack+43980, 0.0, zero_stack, 1.0, int_stack+16302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4410,int_stack+42342,int_stack+38340, 0.0, zero_stack, 1.0, int_stack+16950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+38340,int_stack+4410,int_stack+32634, 0.0, zero_stack, 1.0, int_stack+17958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+32634,int_stack+7134,int_stack+6804, 0.0, zero_stack, 1.0, int_stack+9090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43638,int_stack+32634,int_stack+24894, 0.0, zero_stack, 1.0, int_stack+19218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+45258,int_stack+43638,int_stack+42342, 0.0, zero_stack, 1.0, int_stack+20028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+42342,int_stack+45258,int_stack+4410, 0.0, zero_stack, 1.0, int_stack+21324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4410,int_stack+7950,int_stack+7656, 1.0, int_stack+7530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4788,int_stack+8334,int_stack+7950, 1.0, int_stack+7782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5292,int_stack+4788,int_stack+4410, 1.0, int_stack+14664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6048,int_stack+8820,int_stack+8334, 1.0, int_stack+8118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6696,int_stack+6048,int_stack+4788, 1.0, int_stack+15042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44862,int_stack+6696,int_stack+5292, 1.0, int_stack+15546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+9420,int_stack+8820, 1.0, int_stack+8550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32634,int_stack+24894,int_stack+6048, 1.0, int_stack+16302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14664,int_stack+32634,int_stack+6696, 1.0, int_stack+16950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4410,int_stack+14664,int_stack+44862, 1.0, int_stack+17958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+44862,int_stack+9750,int_stack+9420, 1.0, int_stack+9090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+45852,int_stack+44862,int_stack+24894, 1.0, int_stack+19218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+16344,int_stack+45852,int_stack+32634, 1.0, int_stack+20028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+44862,int_stack+16344,int_stack+14664, 1.0, int_stack+21324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+14664,int_stack+10272,int_stack+10146,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+15042,int_stack+10440,int_stack+10272,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+15546,int_stack+15042,int_stack+14664,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16302,int_stack+10656,int_stack+10440,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+16950,int_stack+16302,int_stack+15042,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+17958,int_stack+16950,int_stack+15546,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+10926,int_stack+10656,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+32634,int_stack+24894,int_stack+16302,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+14664,int_stack+32634,int_stack+16950,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+19218,int_stack+14664,int_stack+17958,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+16344,int_stack+11256,int_stack+10926,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+17334,int_stack+16344,int_stack+24894,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6300,int_stack+17334,int_stack+32634,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+16344,int_stack+6300,int_stack+14664,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+14664,int_stack+11778,int_stack+11652,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+15042,int_stack+11946,int_stack+11778,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+15546,int_stack+15042,int_stack+14664,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6300,int_stack+12162,int_stack+11946,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6948,int_stack+6300,int_stack+15042,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7956,int_stack+6948,int_stack+15546,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+12432,int_stack+12162,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+32634,int_stack+24894,int_stack+6300,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+14664,int_stack+32634,int_stack+6948,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9216,int_stack+14664,int_stack+7956,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6300,int_stack+12762,int_stack+12432,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7290,int_stack+6300,int_stack+24894,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+47382,int_stack+7290,int_stack+32634,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6300,int_stack+47382,int_stack+14664,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+14664,int_stack+13284,int_stack+13158,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+15042,int_stack+13452,int_stack+13284,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+15546,int_stack+15042,int_stack+14664,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+47382,int_stack+13668,int_stack+13452,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+48030,int_stack+47382,int_stack+15042,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+32634,int_stack+48030,int_stack+15546,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+24894,int_stack+13938,int_stack+13668,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+14664,int_stack+24894,int_stack+47382,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+11106,int_stack+14664,int_stack+48030,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+47382,int_stack+11106,int_stack+32634,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+32634,int_stack+14268,int_stack+13938,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+12786,int_stack+32634,int_stack+24894,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+49272,int_stack+12786,int_stack+14664,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+12786,int_stack+49272,int_stack+11106,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+49272,int_stack+27594,int_stack+25704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23004,6);
     Libderiv->ABCD[11] = int_stack + 49272;
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+24894,int_stack+30114,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23004, 0.0, zero_stack,6);
     Libderiv->ABCD[10] = int_stack + 24894;
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+27540,int_stack+1890,int_stack+33930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23004, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[9] = int_stack + 27540;
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+0,int_stack+35820,int_stack+40452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+30186,int_stack+42342,int_stack+38340, 0.0, zero_stack, 1.0, int_stack+23004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[7] = int_stack + 30186;
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+32832,int_stack+44862,int_stack+4410, 1.0, int_stack+23004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[6] = int_stack + 32832;
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2646,int_stack+16344,int_stack+19218,6);
     Libderiv->ABCD[2] = int_stack + 2646;
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+15306,int_stack+6300,int_stack+9216,6);
     Libderiv->ABCD[1] = int_stack + 15306;
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+5292,int_stack+12786,int_stack+47382,6);
     Libderiv->ABCD[0] = int_stack + 5292;

}
