/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ffig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ff|ig) integrals */

void d1hrr_order_ffig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][11] = int_stack + 280;
 Libderiv->deriv_classes[3][8][11] = int_stack + 640;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1090;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1640;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2300;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2720;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3260;
 Libderiv->deriv_classes[4][9][11] = int_stack + 3935;
 Libderiv->deriv_classes[4][10][11] = int_stack + 4760;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5750;
 Libderiv->deriv_classes[5][7][11] = int_stack + 6338;
 Libderiv->deriv_classes[5][8][11] = int_stack + 7094;
 Libderiv->deriv_classes[5][9][11] = int_stack + 8039;
 Libderiv->deriv_classes[5][10][11] = int_stack + 9194;
 Libderiv->deriv_classes[6][6][11] = int_stack + 10580;
 Libderiv->deriv_classes[6][7][11] = int_stack + 11364;
 Libderiv->deriv_classes[6][8][11] = int_stack + 12372;
 Libderiv->deriv_classes[6][9][11] = int_stack + 13632;
 Libderiv->deriv_classes[6][10][11] = int_stack + 15172;
 Libderiv->deriv_classes[3][6][10] = int_stack + 17020;
 Libderiv->deriv_classes[3][7][10] = int_stack + 17300;
 Libderiv->deriv_classes[3][8][10] = int_stack + 17660;
 Libderiv->deriv_classes[3][9][10] = int_stack + 18110;
 Libderiv->deriv_classes[3][10][10] = int_stack + 18660;
 Libderiv->deriv_classes[4][6][10] = int_stack + 19320;
 Libderiv->deriv_classes[4][7][10] = int_stack + 19740;
 Libderiv->deriv_classes[4][8][10] = int_stack + 20280;
 Libderiv->deriv_classes[4][9][10] = int_stack + 20955;
 Libderiv->deriv_classes[4][10][10] = int_stack + 21780;
 Libderiv->deriv_classes[5][6][10] = int_stack + 22770;
 Libderiv->deriv_classes[5][7][10] = int_stack + 23358;
 Libderiv->deriv_classes[5][8][10] = int_stack + 24114;
 Libderiv->deriv_classes[5][9][10] = int_stack + 25059;
 Libderiv->deriv_classes[5][10][10] = int_stack + 26214;
 Libderiv->deriv_classes[6][6][10] = int_stack + 27600;
 Libderiv->deriv_classes[6][7][10] = int_stack + 28384;
 Libderiv->deriv_classes[6][8][10] = int_stack + 29392;
 Libderiv->deriv_classes[6][9][10] = int_stack + 30652;
 Libderiv->deriv_classes[6][10][10] = int_stack + 32192;
 Libderiv->deriv_classes[3][6][9] = int_stack + 34040;
 Libderiv->deriv_classes[3][7][9] = int_stack + 34320;
 Libderiv->deriv_classes[3][8][9] = int_stack + 34680;
 Libderiv->deriv_classes[3][9][9] = int_stack + 35130;
 Libderiv->deriv_classes[3][10][9] = int_stack + 35680;
 Libderiv->deriv_classes[4][6][9] = int_stack + 36340;
 Libderiv->deriv_classes[4][7][9] = int_stack + 36760;
 Libderiv->deriv_classes[4][8][9] = int_stack + 37300;
 Libderiv->deriv_classes[4][9][9] = int_stack + 37975;
 Libderiv->deriv_classes[4][10][9] = int_stack + 38800;
 Libderiv->deriv_classes[5][6][9] = int_stack + 39790;
 Libderiv->deriv_classes[5][7][9] = int_stack + 40378;
 Libderiv->deriv_classes[5][8][9] = int_stack + 41134;
 Libderiv->deriv_classes[5][9][9] = int_stack + 42079;
 Libderiv->deriv_classes[5][10][9] = int_stack + 43234;
 Libderiv->deriv_classes[6][6][9] = int_stack + 44620;
 Libderiv->deriv_classes[6][7][9] = int_stack + 45404;
 Libderiv->deriv_classes[6][8][9] = int_stack + 46412;
 Libderiv->deriv_classes[6][9][9] = int_stack + 47672;
 Libderiv->deriv_classes[6][10][9] = int_stack + 49212;
 Libderiv->deriv_classes[3][6][8] = int_stack + 51060;
 Libderiv->deriv_classes[3][7][8] = int_stack + 51340;
 Libderiv->deriv_classes[3][8][8] = int_stack + 51700;
 Libderiv->deriv_classes[3][9][8] = int_stack + 52150;
 Libderiv->deriv_classes[3][10][8] = int_stack + 52700;
 Libderiv->deriv_classes[4][6][8] = int_stack + 53360;
 Libderiv->deriv_classes[4][7][8] = int_stack + 53780;
 Libderiv->deriv_classes[4][8][8] = int_stack + 54320;
 Libderiv->deriv_classes[4][9][8] = int_stack + 54995;
 Libderiv->deriv_classes[4][10][8] = int_stack + 55820;
 Libderiv->deriv_classes[5][6][8] = int_stack + 56810;
 Libderiv->deriv_classes[5][7][8] = int_stack + 57398;
 Libderiv->deriv_classes[5][8][8] = int_stack + 58154;
 Libderiv->deriv_classes[5][9][8] = int_stack + 59099;
 Libderiv->deriv_classes[5][10][8] = int_stack + 60254;
 Libderiv->deriv_classes[6][6][8] = int_stack + 61640;
 Libderiv->deriv_classes[6][7][8] = int_stack + 62424;
 Libderiv->deriv_classes[6][8][8] = int_stack + 63432;
 Libderiv->deriv_classes[6][9][8] = int_stack + 64692;
 Libderiv->deriv_classes[6][10][8] = int_stack + 66232;
 Libderiv->deriv_classes[3][6][7] = int_stack + 68080;
 Libderiv->deriv_classes[3][7][7] = int_stack + 68360;
 Libderiv->deriv_classes[3][8][7] = int_stack + 68720;
 Libderiv->deriv_classes[3][9][7] = int_stack + 69170;
 Libderiv->deriv_classes[3][10][7] = int_stack + 69720;
 Libderiv->deriv_classes[4][6][7] = int_stack + 70380;
 Libderiv->deriv_classes[4][7][7] = int_stack + 70800;
 Libderiv->deriv_classes[4][8][7] = int_stack + 71340;
 Libderiv->deriv_classes[4][9][7] = int_stack + 72015;
 Libderiv->deriv_classes[4][10][7] = int_stack + 72840;
 Libderiv->deriv_classes[5][6][7] = int_stack + 73830;
 Libderiv->deriv_classes[5][7][7] = int_stack + 74418;
 Libderiv->deriv_classes[5][8][7] = int_stack + 75174;
 Libderiv->deriv_classes[5][9][7] = int_stack + 76119;
 Libderiv->deriv_classes[5][10][7] = int_stack + 77274;
 Libderiv->deriv_classes[6][6][7] = int_stack + 78660;
 Libderiv->deriv_classes[6][7][7] = int_stack + 79444;
 Libderiv->deriv_classes[6][8][7] = int_stack + 80452;
 Libderiv->deriv_classes[6][9][7] = int_stack + 81712;
 Libderiv->deriv_classes[6][10][7] = int_stack + 83252;
 Libderiv->deriv_classes[3][6][6] = int_stack + 85100;
 Libderiv->deriv_classes[3][7][6] = int_stack + 85380;
 Libderiv->deriv_classes[3][8][6] = int_stack + 85740;
 Libderiv->deriv_classes[3][9][6] = int_stack + 86190;
 Libderiv->deriv_classes[3][10][6] = int_stack + 86740;
 Libderiv->deriv_classes[4][6][6] = int_stack + 87400;
 Libderiv->deriv_classes[4][7][6] = int_stack + 87820;
 Libderiv->deriv_classes[4][8][6] = int_stack + 88360;
 Libderiv->deriv_classes[4][9][6] = int_stack + 89035;
 Libderiv->deriv_classes[4][10][6] = int_stack + 89860;
 Libderiv->deriv_classes[5][6][6] = int_stack + 90850;
 Libderiv->deriv_classes[5][7][6] = int_stack + 91438;
 Libderiv->deriv_classes[5][8][6] = int_stack + 92194;
 Libderiv->deriv_classes[5][9][6] = int_stack + 93139;
 Libderiv->deriv_classes[5][10][6] = int_stack + 94294;
 Libderiv->dvrr_classes[6][6] = int_stack + 95680;
 Libderiv->deriv_classes[6][6][6] = int_stack + 96464;
 Libderiv->dvrr_classes[6][7] = int_stack + 97248;
 Libderiv->deriv_classes[6][7][6] = int_stack + 98256;
 Libderiv->dvrr_classes[6][8] = int_stack + 99264;
 Libderiv->deriv_classes[6][8][6] = int_stack + 100524;
 Libderiv->dvrr_classes[6][9] = int_stack + 101784;
 Libderiv->deriv_classes[6][9][6] = int_stack + 103324;
 Libderiv->deriv_classes[6][10][6] = int_stack + 104864;
 Libderiv->deriv_classes[3][6][2] = int_stack + 106712;
 Libderiv->deriv_classes[3][7][2] = int_stack + 106992;
 Libderiv->deriv_classes[3][8][2] = int_stack + 107352;
 Libderiv->deriv_classes[3][9][2] = int_stack + 107802;
 Libderiv->deriv_classes[3][10][2] = int_stack + 108352;
 Libderiv->deriv_classes[4][6][2] = int_stack + 109012;
 Libderiv->deriv_classes[4][7][2] = int_stack + 109432;
 Libderiv->deriv_classes[4][8][2] = int_stack + 109972;
 Libderiv->deriv_classes[4][9][2] = int_stack + 110647;
 Libderiv->deriv_classes[4][10][2] = int_stack + 111472;
 Libderiv->deriv_classes[5][6][2] = int_stack + 112462;
 Libderiv->deriv_classes[5][7][2] = int_stack + 113050;
 Libderiv->deriv_classes[5][8][2] = int_stack + 113806;
 Libderiv->deriv_classes[5][9][2] = int_stack + 114751;
 Libderiv->deriv_classes[5][10][2] = int_stack + 115906;
 Libderiv->deriv_classes[6][6][2] = int_stack + 117292;
 Libderiv->deriv_classes[6][7][2] = int_stack + 118076;
 Libderiv->deriv_classes[6][8][2] = int_stack + 119084;
 Libderiv->deriv_classes[6][9][2] = int_stack + 120344;
 Libderiv->deriv_classes[6][10][2] = int_stack + 121884;
 Libderiv->deriv_classes[3][6][1] = int_stack + 123732;
 Libderiv->deriv_classes[3][7][1] = int_stack + 124012;
 Libderiv->deriv_classes[3][8][1] = int_stack + 124372;
 Libderiv->deriv_classes[3][9][1] = int_stack + 124822;
 Libderiv->deriv_classes[3][10][1] = int_stack + 125372;
 Libderiv->deriv_classes[4][6][1] = int_stack + 126032;
 Libderiv->deriv_classes[4][7][1] = int_stack + 126452;
 Libderiv->deriv_classes[4][8][1] = int_stack + 126992;
 Libderiv->deriv_classes[4][9][1] = int_stack + 127667;
 Libderiv->deriv_classes[4][10][1] = int_stack + 128492;
 Libderiv->deriv_classes[5][6][1] = int_stack + 129482;
 Libderiv->deriv_classes[5][7][1] = int_stack + 130070;
 Libderiv->deriv_classes[5][8][1] = int_stack + 130826;
 Libderiv->deriv_classes[5][9][1] = int_stack + 131771;
 Libderiv->deriv_classes[5][10][1] = int_stack + 132926;
 Libderiv->deriv_classes[6][6][1] = int_stack + 134312;
 Libderiv->deriv_classes[6][7][1] = int_stack + 135096;
 Libderiv->deriv_classes[6][8][1] = int_stack + 136104;
 Libderiv->deriv_classes[6][9][1] = int_stack + 137364;
 Libderiv->deriv_classes[6][10][1] = int_stack + 138904;
 Libderiv->dvrr_classes[3][6] = int_stack + 140752;
 Libderiv->dvrr_classes[3][7] = int_stack + 141032;
 Libderiv->dvrr_classes[3][8] = int_stack + 141392;
 Libderiv->dvrr_classes[3][9] = int_stack + 141842;
 Libderiv->dvrr_classes[3][10] = int_stack + 142392;
 Libderiv->deriv_classes[3][6][0] = int_stack + 143052;
 Libderiv->deriv_classes[3][7][0] = int_stack + 143332;
 Libderiv->deriv_classes[3][8][0] = int_stack + 143692;
 Libderiv->deriv_classes[3][9][0] = int_stack + 144142;
 Libderiv->deriv_classes[3][10][0] = int_stack + 144692;
 Libderiv->dvrr_classes[4][6] = int_stack + 145352;
 Libderiv->dvrr_classes[4][7] = int_stack + 145772;
 Libderiv->dvrr_classes[4][8] = int_stack + 146312;
 Libderiv->dvrr_classes[4][9] = int_stack + 146987;
 Libderiv->dvrr_classes[4][10] = int_stack + 147812;
 Libderiv->deriv_classes[4][6][0] = int_stack + 148802;
 Libderiv->deriv_classes[4][7][0] = int_stack + 149222;
 Libderiv->deriv_classes[4][8][0] = int_stack + 149762;
 Libderiv->deriv_classes[4][9][0] = int_stack + 150437;
 Libderiv->deriv_classes[4][10][0] = int_stack + 151262;
 Libderiv->dvrr_classes[5][6] = int_stack + 152252;
 Libderiv->dvrr_classes[5][7] = int_stack + 152840;
 Libderiv->dvrr_classes[5][8] = int_stack + 153596;
 Libderiv->dvrr_classes[5][9] = int_stack + 154541;
 Libderiv->dvrr_classes[5][10] = int_stack + 155696;
 Libderiv->deriv_classes[5][6][0] = int_stack + 157082;
 Libderiv->deriv_classes[5][7][0] = int_stack + 157670;
 Libderiv->deriv_classes[5][8][0] = int_stack + 158426;
 Libderiv->deriv_classes[5][9][0] = int_stack + 159371;
 Libderiv->deriv_classes[5][10][0] = int_stack + 160526;
 Libderiv->deriv_classes[6][6][0] = int_stack + 161912;
 Libderiv->deriv_classes[6][7][0] = int_stack + 162696;
 Libderiv->deriv_classes[6][8][0] = int_stack + 163704;
 Libderiv->deriv_classes[6][9][0] = int_stack + 164964;
 Libderiv->deriv_classes[6][10][0] = int_stack + 166504;
 memset(int_stack,0,1346816);

 Libderiv->dvrr_stack = int_stack + 799588;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ffig(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+168352,int_stack+141032,int_stack+140752,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+169192,int_stack+141392,int_stack+141032,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+170272,int_stack+169192,int_stack+168352,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+171952,int_stack+141842,int_stack+141392,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+173302,int_stack+171952,int_stack+169192,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+175462,int_stack+173302,int_stack+170272,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+178262,int_stack+280,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140752,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+179102,int_stack+640,int_stack+280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141032,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+180182,int_stack+179102,int_stack+178262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168352,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+181862,int_stack+1090,int_stack+640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141392,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+183212,int_stack+181862,int_stack+179102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169192,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185372,int_stack+183212,int_stack+180182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170272,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+178262,int_stack+1640,int_stack+1090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141842,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+188172,int_stack+178262,int_stack+181862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171952,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+178262,int_stack+188172,int_stack+183212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173302,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+188172,int_stack+178262,int_stack+185372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175462,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+178262,int_stack+145772,int_stack+145352,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+179522,int_stack+146312,int_stack+145772,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+181142,int_stack+179522,int_stack+178262,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+183662,int_stack+146987,int_stack+146312,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+192372,int_stack+183662,int_stack+179522,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+195612,int_stack+192372,int_stack+181142,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+185687,int_stack+2720,int_stack+2300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+3260,int_stack+2720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145772,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+199812,int_stack+0,int_stack+185687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178262,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+185687,int_stack+3935,int_stack+3260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146312,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+202332,int_stack+185687,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179522,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+205572,int_stack+202332,int_stack+199812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181142,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+199812,int_stack+4760,int_stack+3935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146987,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+199812,int_stack+185687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183662,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+209772,int_stack+0,int_stack+202332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192372,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+215172,int_stack+209772,int_stack+205572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195612,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+199812,int_stack+215172,int_stack+188172,420);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+152840,int_stack+152252,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+153596,int_stack+152840,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+185687,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+189215,int_stack+154541,int_stack+153596,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+221472,int_stack+189215,int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+226008,int_stack+221472,int_stack+185687,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+212412,int_stack+6338,int_stack+5750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152252,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4032,int_stack+7094,int_stack+6338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152840,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+231888,int_stack+4032,int_stack+212412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+235416,int_stack+8039,int_stack+7094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153596,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+238251,int_stack+235416,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+242787,int_stack+238251,int_stack+231888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185687,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+231888,int_stack+9194,int_stack+8039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154541,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4032,int_stack+231888,int_stack+235416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189215,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+248667,int_stack+4032,int_stack+238251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221472,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+231888,int_stack+248667,int_stack+242787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226008,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+240708,int_stack+231888,int_stack+215172,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+259608,int_stack+240708,int_stack+199812,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+199812,int_stack+97248,int_stack+95680,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+202164,int_stack+99264,int_stack+97248,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+205188,int_stack+202164,int_stack+199812,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+209892,int_stack+101784,int_stack+99264,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+213672,int_stack+209892,int_stack+202164,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+284808,int_stack+213672,int_stack+205188,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+11364,int_stack+10580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95680,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6384,int_stack+12372,int_stack+11364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97248,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+292648,int_stack+6384,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199812,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+297352,int_stack+13632,int_stack+12372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99264,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+301132,int_stack+297352,int_stack+6384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202164,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4032,int_stack+301132,int_stack+292648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205188,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+292648,int_stack+15172,int_stack+13632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101784,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+307180,int_stack+292648,int_stack+297352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209892,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+314740,int_stack+307180,int_stack+301132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213672,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+292648,int_stack+314740,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284808,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+304408,int_stack+292648,int_stack+231888,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+330868,int_stack+304408,int_stack+240708,420);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231888,int_stack+17300,int_stack+17020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140752, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+232728,int_stack+17660,int_stack+17300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141032, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+233808,int_stack+232728,int_stack+231888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168352, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+235488,int_stack+18110,int_stack+17660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141392, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+236838,int_stack+235488,int_stack+232728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169192, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+238998,int_stack+236838,int_stack+233808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170272, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+231888,int_stack+18660,int_stack+18110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141842, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+241798,int_stack+231888,int_stack+235488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171952, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+231888,int_stack+241798,int_stack+236838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173302, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+241798,int_stack+231888,int_stack+238998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175462, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231888,int_stack+19740,int_stack+19320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+233148,int_stack+20280,int_stack+19740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145772, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+234768,int_stack+233148,int_stack+231888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178262, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+237288,int_stack+20955,int_stack+20280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146312, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+245998,int_stack+237288,int_stack+233148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179522, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+249238,int_stack+245998,int_stack+234768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181142, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+231888,int_stack+21780,int_stack+20955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146987, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+253438,int_stack+231888,int_stack+237288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183662, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+231888,int_stack+253438,int_stack+245998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192372, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+292648,int_stack+231888,int_stack+249238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195612, 0.0, zero_stack,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+245998,int_stack+292648,int_stack+241798,420);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231888,int_stack+23358,int_stack+22770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152252, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+233652,int_stack+24114,int_stack+23358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152840, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+235920,int_stack+233652,int_stack+231888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+239448,int_stack+25059,int_stack+24114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153596, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+298948,int_stack+239448,int_stack+233652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+303484,int_stack+298948,int_stack+235920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185687, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+231888,int_stack+26214,int_stack+25059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154541, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+309364,int_stack+231888,int_stack+239448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189215, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+231888,int_stack+309364,int_stack+298948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221472, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+309364,int_stack+231888,int_stack+303484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226008, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4032,int_stack+309364,int_stack+292648,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+368668,int_stack+4032,int_stack+245998,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+292648,int_stack+28384,int_stack+27600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95680, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+295000,int_stack+29392,int_stack+28384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97248, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+298024,int_stack+295000,int_stack+292648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199812, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+302728,int_stack+30652,int_stack+29392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99264, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+231888,int_stack+302728,int_stack+295000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202164, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+237936,int_stack+231888,int_stack+298024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205188, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+292648,int_stack+32192,int_stack+30652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101784, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+245776,int_stack+292648,int_stack+302728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209892, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+292648,int_stack+245776,int_stack+231888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213672, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+245776,int_stack+292648,int_stack+237936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284808, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+393868,int_stack+245776,int_stack+309364,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+292648,int_stack+393868,int_stack+4032,420);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+34320,int_stack+34040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140752, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4872,int_stack+34680,int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141032, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5952,int_stack+4872,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7632,int_stack+35130,int_stack+34680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141392, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8982,int_stack+7632,int_stack+4872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169192, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11142,int_stack+8982,int_stack+5952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170272, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4032,int_stack+35680,int_stack+35130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141842, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13942,int_stack+4032,int_stack+7632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171952, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4032,int_stack+13942,int_stack+8982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173302, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13942,int_stack+4032,int_stack+11142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175462, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+36760,int_stack+36340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5292,int_stack+37300,int_stack+36760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145772, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6912,int_stack+5292,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178262, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9432,int_stack+37975,int_stack+37300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146312, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+18142,int_stack+9432,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179522, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+21382,int_stack+18142,int_stack+6912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181142, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4032,int_stack+38800,int_stack+37975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146987, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+25582,int_stack+4032,int_stack+9432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183662, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4032,int_stack+25582,int_stack+18142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192372, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+25582,int_stack+4032,int_stack+21382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195612, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+393868,int_stack+25582,int_stack+13942,420);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+40378,int_stack+39790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152252, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+41134,int_stack+40378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152840, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8064,int_stack+5796,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11592,int_stack+42079,int_stack+41134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153596, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14427,int_stack+11592,int_stack+5796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+18963,int_stack+14427,int_stack+8064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185687, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4032,int_stack+43234,int_stack+42079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154541, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31882,int_stack+4032,int_stack+11592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189215, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4032,int_stack+31882,int_stack+14427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221472, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+31882,int_stack+4032,int_stack+18963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226008, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4032,int_stack+31882,int_stack+25582,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+231888,int_stack+4032,int_stack+393868,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+393868,int_stack+45404,int_stack+44620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95680, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+396220,int_stack+46412,int_stack+45404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97248, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+399244,int_stack+396220,int_stack+393868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199812, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+403948,int_stack+47672,int_stack+46412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99264, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+407728,int_stack+403948,int_stack+396220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202164, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+22932,int_stack+407728,int_stack+399244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205188, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+393868,int_stack+49212,int_stack+47672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101784, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+40702,int_stack+393868,int_stack+403948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209892, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+393868,int_stack+40702,int_stack+407728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213672, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+403948,int_stack+393868,int_stack+22932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+415708,int_stack+403948,int_stack+31882,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+442168,int_stack+415708,int_stack+4032,420);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+51340,int_stack+51060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4872,int_stack+51700,int_stack+51340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5952,int_stack+4872,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7632,int_stack+52150,int_stack+51700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8982,int_stack+7632,int_stack+4872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11142,int_stack+8982,int_stack+5952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4032,int_stack+52700,int_stack+52150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13942,int_stack+4032,int_stack+7632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4032,int_stack+13942,int_stack+8982, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13942,int_stack+4032,int_stack+11142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+53780,int_stack+53360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5292,int_stack+54320,int_stack+53780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+257088,int_stack+5292,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6912,int_stack+54995,int_stack+54320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8937,int_stack+6912,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+18142,int_stack+8937,int_stack+257088, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+257088,int_stack+55820,int_stack+54995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+22342,int_stack+257088,int_stack+6912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+26392,int_stack+22342,int_stack+8937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4032,int_stack+26392,int_stack+18142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+18142,int_stack+4032,int_stack+13942,420);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30742,int_stack+57398,int_stack+56810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+32506,int_stack+58154,int_stack+57398, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34774,int_stack+32506,int_stack+30742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+38302,int_stack+59099,int_stack+58154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41137,int_stack+38302,int_stack+32506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+45673,int_stack+41137,int_stack+34774, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30742,int_stack+60254,int_stack+59099, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51553,int_stack+30742,int_stack+38302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30742,int_stack+51553,int_stack+41137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+51553,int_stack+30742,int_stack+45673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+30742,int_stack+51553,int_stack+4032,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+393868,int_stack+30742,int_stack+18142,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+62424,int_stack+61640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6384,int_stack+63432,int_stack+62424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9408,int_stack+6384,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+14112,int_stack+64692,int_stack+63432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+17892,int_stack+14112,int_stack+6384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+419068,int_stack+17892,int_stack+9408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4032,int_stack+66232,int_stack+64692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+60373,int_stack+4032,int_stack+14112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4032,int_stack+60373,int_stack+17892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+14112,int_stack+4032,int_stack+419068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+479968,int_stack+14112,int_stack+51553,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+506428,int_stack+479968,int_stack+30742,420);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+479968,int_stack+68360,int_stack+68080, 0.0, zero_stack, 1.0, int_stack+140752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+480808,int_stack+68720,int_stack+68360, 0.0, zero_stack, 1.0, int_stack+141032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+481888,int_stack+480808,int_stack+479968, 0.0, zero_stack, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+483568,int_stack+69170,int_stack+68720, 0.0, zero_stack, 1.0, int_stack+141392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+484918,int_stack+483568,int_stack+480808, 0.0, zero_stack, 1.0, int_stack+169192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+487078,int_stack+484918,int_stack+481888, 0.0, zero_stack, 1.0, int_stack+170272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+479968,int_stack+69720,int_stack+69170, 0.0, zero_stack, 1.0, int_stack+141842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+489878,int_stack+479968,int_stack+483568, 0.0, zero_stack, 1.0, int_stack+171952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+479968,int_stack+489878,int_stack+484918, 0.0, zero_stack, 1.0, int_stack+173302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+489878,int_stack+479968,int_stack+487078, 0.0, zero_stack, 1.0, int_stack+175462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+479968,int_stack+70800,int_stack+70380, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+481228,int_stack+71340,int_stack+70800, 0.0, zero_stack, 1.0, int_stack+145772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+257088,int_stack+481228,int_stack+479968, 0.0, zero_stack, 1.0, int_stack+178262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+482848,int_stack+72015,int_stack+71340, 0.0, zero_stack, 1.0, int_stack+146312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+484873,int_stack+482848,int_stack+481228, 0.0, zero_stack, 1.0, int_stack+179522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+494078,int_stack+484873,int_stack+257088, 0.0, zero_stack, 1.0, int_stack+181142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+257088,int_stack+72840,int_stack+72015, 0.0, zero_stack, 1.0, int_stack+146987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+498278,int_stack+257088,int_stack+482848, 0.0, zero_stack, 1.0, int_stack+183662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+419068,int_stack+498278,int_stack+484873, 0.0, zero_stack, 1.0, int_stack+192372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+498278,int_stack+419068,int_stack+494078, 0.0, zero_stack, 1.0, int_stack+195612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+419068,int_stack+498278,int_stack+489878,420);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+431668,int_stack+74418,int_stack+73830, 0.0, zero_stack, 1.0, int_stack+152252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+433432,int_stack+75174,int_stack+74418, 0.0, zero_stack, 1.0, int_stack+152840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+435700,int_stack+433432,int_stack+431668, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+439228,int_stack+76119,int_stack+75174, 0.0, zero_stack, 1.0, int_stack+153596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+479968,int_stack+439228,int_stack+433432, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+484504,int_stack+479968,int_stack+435700, 0.0, zero_stack, 1.0, int_stack+185687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+431668,int_stack+77274,int_stack+76119, 0.0, zero_stack, 1.0, int_stack+154541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+490384,int_stack+431668,int_stack+439228, 0.0, zero_stack, 1.0, int_stack+189215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+431668,int_stack+490384,int_stack+479968, 0.0, zero_stack, 1.0, int_stack+221472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4032,int_stack+431668,int_stack+484504, 0.0, zero_stack, 1.0, int_stack+226008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+12852,int_stack+4032,int_stack+498278,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+479968,int_stack+12852,int_stack+419068,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+419068,int_stack+79444,int_stack+78660, 0.0, zero_stack, 1.0, int_stack+95680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+421420,int_stack+80452,int_stack+79444, 0.0, zero_stack, 1.0, int_stack+97248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+424444,int_stack+421420,int_stack+419068, 0.0, zero_stack, 1.0, int_stack+199812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+429148,int_stack+81712,int_stack+80452, 0.0, zero_stack, 1.0, int_stack+99264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+432928,int_stack+429148,int_stack+421420, 0.0, zero_stack, 1.0, int_stack+202164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+31752,int_stack+432928,int_stack+424444, 0.0, zero_stack, 1.0, int_stack+205188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+419068,int_stack+83252,int_stack+81712, 0.0, zero_stack, 1.0, int_stack+101784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+39592,int_stack+419068,int_stack+429148, 0.0, zero_stack, 1.0, int_stack+209892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+419068,int_stack+39592,int_stack+432928, 0.0, zero_stack, 1.0, int_stack+213672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+39592,int_stack+419068,int_stack+31752, 0.0, zero_stack, 1.0, int_stack+284808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+51352,int_stack+39592,int_stack+4032,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+544228,int_stack+51352,int_stack+12852,420);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+85380,int_stack+85100, 1.0, int_stack+140752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4872,int_stack+85740,int_stack+85380, 1.0, int_stack+141032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5952,int_stack+4872,int_stack+4032, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7632,int_stack+86190,int_stack+85740, 1.0, int_stack+141392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8982,int_stack+7632,int_stack+4872, 1.0, int_stack+169192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11142,int_stack+8982,int_stack+5952, 1.0, int_stack+170272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+168352,int_stack+86740,int_stack+86190, 1.0, int_stack+141842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4032,int_stack+168352,int_stack+7632, 1.0, int_stack+171952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+168352,int_stack+4032,int_stack+8982, 1.0, int_stack+173302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4032,int_stack+168352,int_stack+11142, 1.0, int_stack+175462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505168,int_stack+87820,int_stack+87400, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+168352,int_stack+88360,int_stack+87820, 1.0, int_stack+145772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+257088,int_stack+168352,int_stack+505168, 1.0, int_stack+178262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8232,int_stack+89035,int_stack+88360, 1.0, int_stack+146312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10257,int_stack+8232,int_stack+168352, 1.0, int_stack+179522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13497,int_stack+10257,int_stack+257088, 1.0, int_stack+181142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+257088,int_stack+89860,int_stack+89035, 1.0, int_stack+146987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+178262,int_stack+257088,int_stack+8232, 1.0, int_stack+183662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+17697,int_stack+178262,int_stack+10257, 1.0, int_stack+192372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+23097,int_stack+17697,int_stack+13497, 1.0, int_stack+195612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+8232,int_stack+23097,int_stack+4032,420);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+91438,int_stack+90850, 1.0, int_stack+152252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+92194,int_stack+91438, 1.0, int_stack+152840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+178262,int_stack+5796,int_stack+4032, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+168352,int_stack+93139,int_stack+92194, 1.0, int_stack+153596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+29397,int_stack+168352,int_stack+5796, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+29397,int_stack+178262, 1.0, int_stack+185687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+185687,int_stack+94294,int_stack+93139, 1.0, int_stack+154541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+33933,int_stack+185687,int_stack+168352, 1.0, int_stack+189215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+39603,int_stack+33933,int_stack+29397, 1.0, int_stack+221472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29397,int_stack+39603,int_stack+0, 1.0, int_stack+226008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+38217,int_stack+29397,int_stack+23097,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+57117,int_stack+38217,int_stack+8232,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+98256,int_stack+96464, 1.0, int_stack+95680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+100524,int_stack+98256, 1.0, int_stack+97248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 1.0, int_stack+199812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+103324,int_stack+100524, 1.0, int_stack+99264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13860,int_stack+10080,int_stack+2352, 1.0, int_stack+202164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+19908,int_stack+13860,int_stack+5376, 1.0, int_stack+205188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+199812,int_stack+104864,int_stack+103324, 1.0, int_stack+101784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+199812,int_stack+10080, 1.0, int_stack+209892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+199812,int_stack+0,int_stack+13860, 1.0, int_stack+213672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+199812,int_stack+19908, 1.0, int_stack+284808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+582028,int_stack+0,int_stack+29397,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+582028,int_stack+38217,420);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+582028,int_stack+142392,int_stack+141842,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+583678,int_stack+582028,int_stack+171952,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+586378,int_stack+583678,int_stack+173302,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+582028,int_stack+586378,int_stack+175462,10);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+586228,int_stack+147812,int_stack+146987,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+588703,int_stack+586228,int_stack+183662,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+592753,int_stack+588703,int_stack+192372,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+586228,int_stack+592753,int_stack+195612,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+592528,int_stack+586228,int_stack+582028,420);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+605128,int_stack+155696,int_stack+154541,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+37800,int_stack+605128,int_stack+189215,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+43470,int_stack+37800,int_stack+221472,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+82317,int_stack+43470,int_stack+226008,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+37800,int_stack+82317,int_stack+586228,420);
 /*--- compute (fd|ig) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+168352,int_stack+37800,int_stack+592528,420);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+605128,int_stack+106992,int_stack+106712,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+605968,int_stack+107352,int_stack+106992,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+607048,int_stack+605968,int_stack+605128,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+284808,int_stack+107802,int_stack+107352,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+286158,int_stack+284808,int_stack+605968,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+288318,int_stack+286158,int_stack+607048,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+605128,int_stack+108352,int_stack+107802,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+91137,int_stack+605128,int_stack+284808,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+605128,int_stack+91137,int_stack+286158,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+91137,int_stack+605128,int_stack+288318,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505168,int_stack+109432,int_stack+109012,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+605128,int_stack+109972,int_stack+109432,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+257088,int_stack+605128,int_stack+505168,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+606748,int_stack+110647,int_stack+109972,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+95337,int_stack+606748,int_stack+605128,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+98577,int_stack+95337,int_stack+257088,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+257088,int_stack+111472,int_stack+110647,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+102777,int_stack+257088,int_stack+606748,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+106827,int_stack+102777,int_stack+95337,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+284808,int_stack+106827,int_stack+98577,15);
 /*--- compute (fp|ig) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+95337,int_stack+284808,int_stack+91137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+91137,int_stack+113050,int_stack+112462,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+92901,int_stack+113806,int_stack+113050,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+107937,int_stack+92901,int_stack+91137,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+605128,int_stack+114751,int_stack+113806,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+193552,int_stack+605128,int_stack+92901,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+198088,int_stack+193552,int_stack+107937,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+107937,int_stack+115906,int_stack+114751,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+111402,int_stack+107937,int_stack+605128,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+203968,int_stack+111402,int_stack+193552,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+107937,int_stack+203968,int_stack+198088,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+193552,int_stack+107937,int_stack+284808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (fd|ig) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+605128,int_stack+193552,int_stack+95337, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+592528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+284808,int_stack+118076,int_stack+117292,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+287160,int_stack+119084,int_stack+118076,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+212452,int_stack+287160,int_stack+284808,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+217156,int_stack+120344,int_stack+119084,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+220936,int_stack+217156,int_stack+287160,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+284808,int_stack+220936,int_stack+212452,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+212452,int_stack+121884,int_stack+120344,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+91137,int_stack+212452,int_stack+217156,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+419068,int_stack+91137,int_stack+220936,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+91137,int_stack+419068,int_stack+284808,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+630328,int_stack+91137,int_stack+107937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+656788,int_stack+630328,int_stack+193552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+193552,int_stack+124012,int_stack+123732,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+194392,int_stack+124372,int_stack+124012,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+195472,int_stack+194392,int_stack+193552,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+197152,int_stack+124822,int_stack+124372,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+198502,int_stack+197152,int_stack+194392,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+200662,int_stack+198502,int_stack+195472,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+193552,int_stack+125372,int_stack+124822,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+203462,int_stack+193552,int_stack+197152,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+193552,int_stack+203462,int_stack+198502,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+203462,int_stack+193552,int_stack+200662,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505168,int_stack+126452,int_stack+126032,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+193552,int_stack+126992,int_stack+126452,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+257088,int_stack+193552,int_stack+505168,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+195172,int_stack+127667,int_stack+126992,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+197197,int_stack+195172,int_stack+193552,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+207662,int_stack+197197,int_stack+257088,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+257088,int_stack+128492,int_stack+127667,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+211862,int_stack+257088,int_stack+195172,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+215912,int_stack+211862,int_stack+197197,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+193552,int_stack+215912,int_stack+207662,15);
 /*--- compute (fp|ig) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+207662,int_stack+193552,int_stack+203462, 0.0, zero_stack, 1.0, int_stack+582028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+220262,int_stack+130070,int_stack+129482,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+222026,int_stack+130826,int_stack+130070,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+224294,int_stack+222026,int_stack+220262,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+227822,int_stack+131771,int_stack+130826,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+199852,int_stack+227822,int_stack+222026,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+630328,int_stack+199852,int_stack+224294,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+220262,int_stack+132926,int_stack+131771,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+636208,int_stack+220262,int_stack+227822,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+220262,int_stack+636208,int_stack+199852,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+636208,int_stack+220262,int_stack+630328,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+91137,int_stack+636208,int_stack+193552, 0.0, zero_stack, 1.0, int_stack+586228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (fd|ig) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+694588,int_stack+91137,int_stack+207662, 0.0, zero_stack, 1.0, int_stack+592528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+193552,int_stack+135096,int_stack+134312,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+195904,int_stack+136104,int_stack+135096,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+198928,int_stack+195904,int_stack+193552,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+203632,int_stack+137364,int_stack+136104,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+207412,int_stack+203632,int_stack+195904,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+284808,int_stack+207412,int_stack+198928,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+193552,int_stack+138904,int_stack+137364,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+213460,int_stack+193552,int_stack+203632,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+193552,int_stack+213460,int_stack+207412,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+645028,int_stack+193552,int_stack+284808,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+193552,int_stack+645028,int_stack+636208, 0.0, zero_stack, 1.0, int_stack+82317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+719788,int_stack+193552,int_stack+91137, 0.0, zero_stack, 1.0, int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+91137,int_stack+143332,int_stack+143052,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+91977,int_stack+143692,int_stack+143332,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+93057,int_stack+91977,int_stack+91137,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+94737,int_stack+144142,int_stack+143692,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+96087,int_stack+94737,int_stack+91977,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+98247,int_stack+96087,int_stack+93057,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+91137,int_stack+144692,int_stack+144142,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+101047,int_stack+91137,int_stack+94737,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+91137,int_stack+101047,int_stack+96087,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+101047,int_stack+91137,int_stack+98247,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505168,int_stack+149222,int_stack+148802,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+91137,int_stack+149762,int_stack+149222,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+257088,int_stack+91137,int_stack+505168,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+92757,int_stack+150437,int_stack+149762,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+94782,int_stack+92757,int_stack+91137,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+105247,int_stack+94782,int_stack+257088,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+257088,int_stack+151262,int_stack+150437,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+109447,int_stack+257088,int_stack+92757,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+113497,int_stack+109447,int_stack+94782,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+91137,int_stack+113497,int_stack+105247,15);
 /*--- compute (fp|ig) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+105247,int_stack+91137,int_stack+101047, 1.0, int_stack+582028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+582028,int_stack+157670,int_stack+157082,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+583792,int_stack+158426,int_stack+157670,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+117847,int_stack+583792,int_stack+582028,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+121375,int_stack+159371,int_stack+158426,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+124210,int_stack+121375,int_stack+583792,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+128746,int_stack+124210,int_stack+117847,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+117847,int_stack+160526,int_stack+159371,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+134626,int_stack+117847,int_stack+121375,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+140296,int_stack+134626,int_stack+124210,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+117847,int_stack+140296,int_stack+128746,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+126667,int_stack+117847,int_stack+91137, 1.0, int_stack+586228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (fd|ig) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+193552,int_stack+126667,int_stack+105247, 1.0, int_stack+592528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+91137,int_stack+162696,int_stack+161912,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+93489,int_stack+163704,int_stack+162696,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+96513,int_stack+93489,int_stack+91137,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+101217,int_stack+164964,int_stack+163704,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+104997,int_stack+101217,int_stack+93489,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+284808,int_stack+104997,int_stack+96513,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+91137,int_stack+166504,int_stack+164964,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+145567,int_stack+91137,int_stack+101217,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+91137,int_stack+145567,int_stack+104997,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+145567,int_stack+91137,int_stack+284808,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+630328,int_stack+145567,int_stack+117847, 1.0, int_stack+82317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+82317,int_stack+630328,int_stack+126667, 1.0, int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (ff|ig) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+120117,int_stack+330868,int_stack+259608,420);
     Libderiv->ABCD[11] = int_stack + 120117;
 /*--- compute (ff|ig) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+757588,int_stack+292648,int_stack+368668,420);
     Libderiv->ABCD[10] = int_stack + 757588;
 /*--- compute (ff|ig) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+257088,int_stack+442168,int_stack+231888,420);
     Libderiv->ABCD[9] = int_stack + 257088;
 /*--- compute (ff|ig) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+299088,int_stack+506428,int_stack+393868,420);
     Libderiv->ABCD[8] = int_stack + 299088;
 /*--- compute (ff|ig) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+341088,int_stack+544228,int_stack+479968,420);
     Libderiv->ABCD[7] = int_stack + 341088;
 /*--- compute (ff|ig) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+383088,int_stack+0,int_stack+57117,420);
     Libderiv->ABCD[6] = int_stack + 383088;
 /*--- compute (ff|ig) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+0,int_stack+656788,int_stack+605128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 0;
 /*--- compute (ff|ig) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+425088,int_stack+719788,int_stack+694588, 0.0, zero_stack, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 425088;
 /*--- compute (ff|ig) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+467088,int_stack+82317,int_stack+193552, 1.0, int_stack+168352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 467088;

}
