/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fphh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fp|hh) integrals */

void d1hrr_order_fphh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[3][8][11] = int_stack + 850;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1300;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1850;
 Libderiv->deriv_classes[4][5][11] = int_stack + 2510;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2825;
 Libderiv->deriv_classes[4][7][11] = int_stack + 3245;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3785;
 Libderiv->deriv_classes[4][9][11] = int_stack + 4460;
 Libderiv->deriv_classes[4][10][11] = int_stack + 5285;
 Libderiv->deriv_classes[3][5][10] = int_stack + 6275;
 Libderiv->deriv_classes[3][6][10] = int_stack + 6485;
 Libderiv->deriv_classes[3][7][10] = int_stack + 6765;
 Libderiv->deriv_classes[3][8][10] = int_stack + 7125;
 Libderiv->deriv_classes[3][9][10] = int_stack + 7575;
 Libderiv->deriv_classes[3][10][10] = int_stack + 8125;
 Libderiv->deriv_classes[4][5][10] = int_stack + 8785;
 Libderiv->deriv_classes[4][6][10] = int_stack + 9100;
 Libderiv->deriv_classes[4][7][10] = int_stack + 9520;
 Libderiv->deriv_classes[4][8][10] = int_stack + 10060;
 Libderiv->deriv_classes[4][9][10] = int_stack + 10735;
 Libderiv->deriv_classes[4][10][10] = int_stack + 11560;
 Libderiv->deriv_classes[3][5][9] = int_stack + 12550;
 Libderiv->deriv_classes[3][6][9] = int_stack + 12760;
 Libderiv->deriv_classes[3][7][9] = int_stack + 13040;
 Libderiv->deriv_classes[3][8][9] = int_stack + 13400;
 Libderiv->deriv_classes[3][9][9] = int_stack + 13850;
 Libderiv->deriv_classes[3][10][9] = int_stack + 14400;
 Libderiv->deriv_classes[4][5][9] = int_stack + 15060;
 Libderiv->deriv_classes[4][6][9] = int_stack + 15375;
 Libderiv->deriv_classes[4][7][9] = int_stack + 15795;
 Libderiv->deriv_classes[4][8][9] = int_stack + 16335;
 Libderiv->deriv_classes[4][9][9] = int_stack + 17010;
 Libderiv->deriv_classes[4][10][9] = int_stack + 17835;
 Libderiv->deriv_classes[3][5][8] = int_stack + 18825;
 Libderiv->deriv_classes[3][6][8] = int_stack + 19035;
 Libderiv->deriv_classes[3][7][8] = int_stack + 19315;
 Libderiv->deriv_classes[3][8][8] = int_stack + 19675;
 Libderiv->deriv_classes[3][9][8] = int_stack + 20125;
 Libderiv->deriv_classes[3][10][8] = int_stack + 20675;
 Libderiv->deriv_classes[4][5][8] = int_stack + 21335;
 Libderiv->deriv_classes[4][6][8] = int_stack + 21650;
 Libderiv->deriv_classes[4][7][8] = int_stack + 22070;
 Libderiv->deriv_classes[4][8][8] = int_stack + 22610;
 Libderiv->deriv_classes[4][9][8] = int_stack + 23285;
 Libderiv->deriv_classes[4][10][8] = int_stack + 24110;
 Libderiv->deriv_classes[3][5][7] = int_stack + 25100;
 Libderiv->deriv_classes[3][6][7] = int_stack + 25310;
 Libderiv->deriv_classes[3][7][7] = int_stack + 25590;
 Libderiv->deriv_classes[3][8][7] = int_stack + 25950;
 Libderiv->deriv_classes[3][9][7] = int_stack + 26400;
 Libderiv->deriv_classes[3][10][7] = int_stack + 26950;
 Libderiv->deriv_classes[4][5][7] = int_stack + 27610;
 Libderiv->deriv_classes[4][6][7] = int_stack + 27925;
 Libderiv->deriv_classes[4][7][7] = int_stack + 28345;
 Libderiv->deriv_classes[4][8][7] = int_stack + 28885;
 Libderiv->deriv_classes[4][9][7] = int_stack + 29560;
 Libderiv->deriv_classes[4][10][7] = int_stack + 30385;
 Libderiv->deriv_classes[3][5][6] = int_stack + 31375;
 Libderiv->deriv_classes[3][6][6] = int_stack + 31585;
 Libderiv->deriv_classes[3][7][6] = int_stack + 31865;
 Libderiv->deriv_classes[3][8][6] = int_stack + 32225;
 Libderiv->deriv_classes[3][9][6] = int_stack + 32675;
 Libderiv->deriv_classes[3][10][6] = int_stack + 33225;
 Libderiv->dvrr_classes[4][5] = int_stack + 33885;
 Libderiv->deriv_classes[4][5][6] = int_stack + 34200;
 Libderiv->dvrr_classes[4][6] = int_stack + 34515;
 Libderiv->deriv_classes[4][6][6] = int_stack + 34935;
 Libderiv->dvrr_classes[4][7] = int_stack + 35355;
 Libderiv->deriv_classes[4][7][6] = int_stack + 35895;
 Libderiv->dvrr_classes[4][8] = int_stack + 36435;
 Libderiv->deriv_classes[4][8][6] = int_stack + 37110;
 Libderiv->dvrr_classes[4][9] = int_stack + 37785;
 Libderiv->deriv_classes[4][9][6] = int_stack + 38610;
 Libderiv->deriv_classes[4][10][6] = int_stack + 39435;
 Libderiv->deriv_classes[3][5][2] = int_stack + 40425;
 Libderiv->deriv_classes[3][6][2] = int_stack + 40635;
 Libderiv->deriv_classes[3][7][2] = int_stack + 40915;
 Libderiv->deriv_classes[3][8][2] = int_stack + 41275;
 Libderiv->deriv_classes[3][9][2] = int_stack + 41725;
 Libderiv->deriv_classes[3][10][2] = int_stack + 42275;
 Libderiv->deriv_classes[4][5][2] = int_stack + 42935;
 Libderiv->deriv_classes[4][6][2] = int_stack + 43250;
 Libderiv->deriv_classes[4][7][2] = int_stack + 43670;
 Libderiv->deriv_classes[4][8][2] = int_stack + 44210;
 Libderiv->deriv_classes[4][9][2] = int_stack + 44885;
 Libderiv->deriv_classes[4][10][2] = int_stack + 45710;
 Libderiv->deriv_classes[3][5][1] = int_stack + 46700;
 Libderiv->deriv_classes[3][6][1] = int_stack + 46910;
 Libderiv->deriv_classes[3][7][1] = int_stack + 47190;
 Libderiv->deriv_classes[3][8][1] = int_stack + 47550;
 Libderiv->deriv_classes[3][9][1] = int_stack + 48000;
 Libderiv->deriv_classes[3][10][1] = int_stack + 48550;
 Libderiv->deriv_classes[4][5][1] = int_stack + 49210;
 Libderiv->deriv_classes[4][6][1] = int_stack + 49525;
 Libderiv->deriv_classes[4][7][1] = int_stack + 49945;
 Libderiv->deriv_classes[4][8][1] = int_stack + 50485;
 Libderiv->deriv_classes[4][9][1] = int_stack + 51160;
 Libderiv->deriv_classes[4][10][1] = int_stack + 51985;
 Libderiv->dvrr_classes[3][5] = int_stack + 52975;
 Libderiv->dvrr_classes[3][6] = int_stack + 53185;
 Libderiv->dvrr_classes[3][7] = int_stack + 53465;
 Libderiv->dvrr_classes[3][8] = int_stack + 53825;
 Libderiv->dvrr_classes[3][9] = int_stack + 54275;
 Libderiv->dvrr_classes[3][10] = int_stack + 54825;
 Libderiv->deriv_classes[3][5][0] = int_stack + 55485;
 Libderiv->deriv_classes[3][6][0] = int_stack + 55695;
 Libderiv->deriv_classes[3][7][0] = int_stack + 55975;
 Libderiv->deriv_classes[3][8][0] = int_stack + 56335;
 Libderiv->deriv_classes[3][9][0] = int_stack + 56785;
 Libderiv->deriv_classes[3][10][0] = int_stack + 57335;
 Libderiv->deriv_classes[4][5][0] = int_stack + 57995;
 Libderiv->deriv_classes[4][6][0] = int_stack + 58310;
 Libderiv->deriv_classes[4][7][0] = int_stack + 58730;
 Libderiv->deriv_classes[4][8][0] = int_stack + 59270;
 Libderiv->deriv_classes[4][9][0] = int_stack + 59945;
 Libderiv->deriv_classes[4][10][0] = int_stack + 60770;
 memset(int_stack,0,494080);

 Libderiv->dvrr_stack = int_stack + 186255;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fphh(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61760,int_stack+53185,int_stack+52975,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+62390,int_stack+53465,int_stack+53185,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+63230,int_stack+62390,int_stack+61760,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+64490,int_stack+53825,int_stack+53465,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65570,int_stack+64490,int_stack+62390,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+67250,int_stack+65570,int_stack+63230,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+69350,int_stack+54275,int_stack+53825,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+70700,int_stack+69350,int_stack+64490,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+72860,int_stack+70700,int_stack+65570,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+75660,int_stack+72860,int_stack+67250,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+78810,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52975,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+79440,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53185,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+80280,int_stack+79440,int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61760,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+81540,int_stack+850,int_stack+490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53465,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+82620,int_stack+81540,int_stack+79440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62390,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+84300,int_stack+82620,int_stack+80280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63230,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+78810,int_stack+1300,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53825,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+86400,int_stack+78810,int_stack+81540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64490,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+88560,int_stack+86400,int_stack+82620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65570,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+80160,int_stack+88560,int_stack+84300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67250,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+83310,int_stack+1850,int_stack+1300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54275,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+91360,int_stack+83310,int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69350,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+94060,int_stack+91360,int_stack+86400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+83310,int_stack+94060,int_stack+88560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72860,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+87510,int_stack+83310,int_stack+80160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75660,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+78810,int_stack+34515,int_stack+33885,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+79755,int_stack+35355,int_stack+34515,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+81015,int_stack+79755,int_stack+78810,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+82905,int_stack+36435,int_stack+35355,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+84525,int_stack+82905,int_stack+79755,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+91920,int_stack+84525,int_stack+81015,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+95070,int_stack+37785,int_stack+36435,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+97095,int_stack+95070,int_stack+82905,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+100335,int_stack+97095,int_stack+84525,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+104535,int_stack+100335,int_stack+91920,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+2825,int_stack+2510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33885,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+3245,int_stack+2825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34515,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+109260,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+111150,int_stack+3785,int_stack+3245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35355,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+112770,int_stack+111150,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79755,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+112770,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81015,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+115290,int_stack+4460,int_stack+3785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36435,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+117315,int_stack+115290,int_stack+111150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82905,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+120555,int_stack+117315,int_stack+112770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84525,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+109260,int_stack+120555,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91920,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+5285,int_stack+4460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37785,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+124755,int_stack+0,int_stack+115290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95070,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+124755,int_stack+117315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97095,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+113985,int_stack+0,int_stack+120555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100335,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+120285,int_stack+113985,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104535,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109260,int_stack+6485,int_stack+6275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52975, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109890,int_stack+6765,int_stack+6485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53185, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+110730,int_stack+109890,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61760, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+111990,int_stack+7125,int_stack+6765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53465, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+113070,int_stack+111990,int_stack+109890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62390, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+114750,int_stack+113070,int_stack+110730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63230, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+109260,int_stack+7575,int_stack+7125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53825, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+116850,int_stack+109260,int_stack+111990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64490, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+116850,int_stack+113070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65570, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+110610,int_stack+0,int_stack+114750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67250, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+113760,int_stack+8125,int_stack+7575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54275, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2800,int_stack+113760,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69350, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+126900,int_stack+2800,int_stack+116850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2800,int_stack+126900,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72860, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+113760,int_stack+2800,int_stack+110610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75660, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+9100,int_stack+8785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33885, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+9520,int_stack+9100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34515, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2205,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4095,int_stack+10060,int_stack+9520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35355, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5715,int_stack+4095,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79755, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+126900,int_stack+5715,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81015, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+10735,int_stack+10060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36435, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+109260,int_stack+0,int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82905, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+130050,int_stack+109260,int_stack+5715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84525, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2025,int_stack+130050,int_stack+126900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91920, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+126900,int_stack+11560,int_stack+10735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37785, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6750,int_stack+126900,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95070, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+134250,int_stack+6750,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97095, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+139650,int_stack+134250,int_stack+130050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100335, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+126900,int_stack+139650,int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104535, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109260,int_stack+12760,int_stack+12550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52975, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109890,int_stack+13040,int_stack+12760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53185, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+110730,int_stack+109890,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61760, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+111990,int_stack+13400,int_stack+13040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53465, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+111990,int_stack+109890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62390, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1680,int_stack+0,int_stack+110730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63230, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+109260,int_stack+13850,int_stack+13400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53825, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3780,int_stack+109260,int_stack+111990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64490, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+110610,int_stack+3780,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65570, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5940,int_stack+110610,int_stack+1680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+14400,int_stack+13850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54275, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9090,int_stack+0,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69350, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+9090,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9090,int_stack+0,int_stack+110610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72860, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+0,int_stack+9090,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75660, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4410,int_stack+15375,int_stack+15060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33885, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5355,int_stack+15795,int_stack+15375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34515, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6615,int_stack+5355,int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8505,int_stack+16335,int_stack+15795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35355, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10125,int_stack+8505,int_stack+5355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12645,int_stack+10125,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81015, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4410,int_stack+17010,int_stack+16335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36435, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+109260,int_stack+4410,int_stack+8505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82905, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+133515,int_stack+109260,int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84525, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6435,int_stack+133515,int_stack+12645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91920, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11160,int_stack+17835,int_stack+17010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37785, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13635,int_stack+11160,int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95070, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+137715,int_stack+13635,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97095, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11160,int_stack+137715,int_stack+133515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100335, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+133515,int_stack+11160,int_stack+6435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104535, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+140130,int_stack+19035,int_stack+18825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+140760,int_stack+19315,int_stack+19035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+141600,int_stack+140760,int_stack+140130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+142860,int_stack+19675,int_stack+19315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+143940,int_stack+142860,int_stack+140760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+109260,int_stack+143940,int_stack+141600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+140130,int_stack+20125,int_stack+19675, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111360,int_stack+140130,int_stack+142860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4410,int_stack+111360,int_stack+143940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+141480,int_stack+4410,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+109260,int_stack+20675,int_stack+20125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7210,int_stack+109260,int_stack+140130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9910,int_stack+7210,int_stack+111360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+109260,int_stack+9910,int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4410,int_stack+109260,int_stack+141480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109260,int_stack+21650,int_stack+21335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+110205,int_stack+22070,int_stack+21650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111465,int_stack+110205,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8820,int_stack+22610,int_stack+22070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10440,int_stack+8820,int_stack+110205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12960,int_stack+10440,int_stack+111465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+109260,int_stack+23285,int_stack+22610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16110,int_stack+109260,int_stack+8820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+140130,int_stack+16110,int_stack+10440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+144330,int_stack+140130,int_stack+12960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+111285,int_stack+24110,int_stack+23285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8820,int_stack+111285,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+19350,int_stack+8820,int_stack+16110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8820,int_stack+19350,int_stack+140130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+15120,int_stack+8820,int_stack+144330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8820,int_stack+25310,int_stack+25100, 0.0, zero_stack, 1.0, int_stack+52975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+25590,int_stack+25310, 0.0, zero_stack, 1.0, int_stack+53185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10290,int_stack+9450,int_stack+8820, 0.0, zero_stack, 1.0, int_stack+61760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11550,int_stack+25950,int_stack+25590, 0.0, zero_stack, 1.0, int_stack+53465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12630,int_stack+11550,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+62390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+140130,int_stack+12630,int_stack+10290, 0.0, zero_stack, 1.0, int_stack+63230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8820,int_stack+26400,int_stack+25950, 0.0, zero_stack, 1.0, int_stack+53825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+142230,int_stack+8820,int_stack+11550, 0.0, zero_stack, 1.0, int_stack+64490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+144390,int_stack+142230,int_stack+12630, 0.0, zero_stack, 1.0, int_stack+65570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10170,int_stack+144390,int_stack+140130, 0.0, zero_stack, 1.0, int_stack+67250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+140130,int_stack+26950,int_stack+26400, 0.0, zero_stack, 1.0, int_stack+54275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+147190,int_stack+140130,int_stack+8820, 0.0, zero_stack, 1.0, int_stack+69350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+21735,int_stack+147190,int_stack+142230, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+140130,int_stack+21735,int_stack+144390, 0.0, zero_stack, 1.0, int_stack+72860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+21735,int_stack+140130,int_stack+10170, 0.0, zero_stack, 1.0, int_stack+75660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+140130,int_stack+27925,int_stack+27610, 0.0, zero_stack, 1.0, int_stack+33885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+141075,int_stack+28345,int_stack+27925, 0.0, zero_stack, 1.0, int_stack+34515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+142335,int_stack+141075,int_stack+140130, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+144225,int_stack+28885,int_stack+28345, 0.0, zero_stack, 1.0, int_stack+35355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+145845,int_stack+144225,int_stack+141075, 0.0, zero_stack, 1.0, int_stack+79755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8820,int_stack+145845,int_stack+142335, 0.0, zero_stack, 1.0, int_stack+81015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+140130,int_stack+29560,int_stack+28885, 0.0, zero_stack, 1.0, int_stack+36435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+26145,int_stack+140130,int_stack+144225, 0.0, zero_stack, 1.0, int_stack+82905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+109260,int_stack+26145,int_stack+145845, 0.0, zero_stack, 1.0, int_stack+84525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+142155,int_stack+109260,int_stack+8820, 0.0, zero_stack, 1.0, int_stack+91920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8820,int_stack+30385,int_stack+29560, 0.0, zero_stack, 1.0, int_stack+37785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+146880,int_stack+8820,int_stack+140130, 0.0, zero_stack, 1.0, int_stack+95070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8820,int_stack+146880,int_stack+26145, 0.0, zero_stack, 1.0, int_stack+97095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+146880,int_stack+8820,int_stack+109260, 0.0, zero_stack, 1.0, int_stack+100335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+153180,int_stack+146880,int_stack+142155, 0.0, zero_stack, 1.0, int_stack+104535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109260,int_stack+31585,int_stack+31375, 1.0, int_stack+52975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109890,int_stack+31865,int_stack+31585, 1.0, int_stack+53185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+110730,int_stack+109890,int_stack+109260, 1.0, int_stack+61760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+111990,int_stack+32225,int_stack+31865, 1.0, int_stack+53465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8820,int_stack+111990,int_stack+109890, 1.0, int_stack+62390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10500,int_stack+8820,int_stack+110730, 1.0, int_stack+63230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+61760,int_stack+32675,int_stack+32225, 1.0, int_stack+53825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+109260,int_stack+61760,int_stack+111990, 1.0, int_stack+64490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+26145,int_stack+109260,int_stack+8820, 1.0, int_stack+65570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+63110,int_stack+26145,int_stack+10500, 1.0, int_stack+67250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8820,int_stack+33225,int_stack+32675, 1.0, int_stack+54275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10470,int_stack+8820,int_stack+61760, 1.0, int_stack+69350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+28945,int_stack+10470,int_stack+109260, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+109260,int_stack+28945,int_stack+26145, 1.0, int_stack+72860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+26145,int_stack+109260,int_stack+63110, 1.0, int_stack+75660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109260,int_stack+34935,int_stack+34200, 1.0, int_stack+33885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+110205,int_stack+35895,int_stack+34935, 1.0, int_stack+34515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111465,int_stack+110205,int_stack+109260, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30555,int_stack+37110,int_stack+35895, 1.0, int_stack+35355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32175,int_stack+30555,int_stack+110205, 1.0, int_stack+79755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+61760,int_stack+32175,int_stack+111465, 1.0, int_stack+81015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+78810,int_stack+38610,int_stack+37110, 1.0, int_stack+36435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+109260,int_stack+78810,int_stack+30555, 1.0, int_stack+82905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+64910,int_stack+109260,int_stack+32175, 1.0, int_stack+84525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+30555,int_stack+64910,int_stack+61760, 1.0, int_stack+91920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+91920,int_stack+39435,int_stack+38610, 1.0, int_stack+37785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+35280,int_stack+91920,int_stack+78810, 1.0, int_stack+95070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+78810,int_stack+35280,int_stack+109260, 1.0, int_stack+97095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8820,int_stack+78810,int_stack+64910, 1.0, int_stack+100335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+78810,int_stack+8820,int_stack+30555, 1.0, int_stack+104535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+30555,int_stack+54825,int_stack+54275,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+32205,int_stack+30555,int_stack+69350,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+34905,int_stack+32205,int_stack+70700,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+30555,int_stack+34905,int_stack+72860,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+34755,int_stack+30555,int_stack+75660,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+30555,int_stack+40635,int_stack+40425,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+31185,int_stack+40915,int_stack+40635,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+32025,int_stack+31185,int_stack+30555,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+33285,int_stack+41275,int_stack+40915,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+39165,int_stack+33285,int_stack+31185,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8820,int_stack+39165,int_stack+32025,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+30555,int_stack+41725,int_stack+41275,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+10920,int_stack+30555,int_stack+33285,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+31905,int_stack+10920,int_stack+39165,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+91920,int_stack+31905,int_stack+8820,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8820,int_stack+42275,int_stack+41725,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+39165,int_stack+8820,int_stack+30555,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+95070,int_stack+39165,int_stack+10920,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8820,int_stack+95070,int_stack+31905,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+95070,int_stack+8820,int_stack+91920,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+91920,int_stack+43250,int_stack+42935,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+92865,int_stack+43670,int_stack+43250,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8820,int_stack+92865,int_stack+91920,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+10710,int_stack+44210,int_stack+43670,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+12330,int_stack+10710,int_stack+92865,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+91920,int_stack+12330,int_stack+8820,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+99480,int_stack+44885,int_stack+44210,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+101505,int_stack+99480,int_stack+10710,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+30555,int_stack+101505,int_stack+12330,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8820,int_stack+30555,int_stack+91920,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+91920,int_stack+45710,int_stack+44885,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+104745,int_stack+91920,int_stack+99480,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+39165,int_stack+104745,int_stack+101505,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+99480,int_stack+39165,int_stack+30555,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+39165,int_stack+99480,int_stack+8820,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8820,int_stack+46910,int_stack+46700,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+47190,int_stack+46910,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10290,int_stack+9450,int_stack+8820,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+11550,int_stack+47550,int_stack+47190,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+12630,int_stack+11550,int_stack+9450,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+99480,int_stack+12630,int_stack+10290,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+8820,int_stack+48000,int_stack+47550,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+101580,int_stack+8820,int_stack+11550,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+103740,int_stack+101580,int_stack+12630,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+91920,int_stack+103740,int_stack+99480,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+99480,int_stack+48550,int_stack+48000,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+10170,int_stack+99480,int_stack+8820,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+106540,int_stack+10170,int_stack+101580,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+30555,int_stack+106540,int_stack+103740,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8820,int_stack+30555,int_stack+91920,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+91920,int_stack+49525,int_stack+49210,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+92865,int_stack+49945,int_stack+49525,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13230,int_stack+92865,int_stack+91920,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+30555,int_stack+50485,int_stack+49945,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+32175,int_stack+30555,int_stack+92865,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+91920,int_stack+32175,int_stack+13230,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+99480,int_stack+51160,int_stack+50485,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+101505,int_stack+99480,int_stack+30555,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+104745,int_stack+101505,int_stack+32175,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+108945,int_stack+104745,int_stack+91920,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+91920,int_stack+51985,int_stack+51160,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+30555,int_stack+91920,int_stack+99480,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+45780,int_stack+30555,int_stack+101505,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+61760,int_stack+45780,int_stack+104745,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+45780,int_stack+61760,int_stack+108945,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61760,int_stack+55695,int_stack+55485,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+62390,int_stack+55975,int_stack+55695,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+63230,int_stack+62390,int_stack+61760,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+64490,int_stack+56335,int_stack+55975,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65570,int_stack+64490,int_stack+62390,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+67250,int_stack+65570,int_stack+63230,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+61760,int_stack+56785,int_stack+56335,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+69350,int_stack+61760,int_stack+64490,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+71510,int_stack+69350,int_stack+65570,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+91920,int_stack+71510,int_stack+67250,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+63110,int_stack+57335,int_stack+56785,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+64760,int_stack+63110,int_stack+61760,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+74310,int_stack+64760,int_stack+69350,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+30555,int_stack+74310,int_stack+71510,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+61760,int_stack+30555,int_stack+91920,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+91920,int_stack+58310,int_stack+57995,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+92865,int_stack+58730,int_stack+58310,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13230,int_stack+92865,int_stack+91920,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+30555,int_stack+59270,int_stack+58730,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+32175,int_stack+30555,int_stack+92865,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+91920,int_stack+32175,int_stack+13230,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+66170,int_stack+59945,int_stack+59270,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+68195,int_stack+66170,int_stack+30555,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+71435,int_stack+68195,int_stack+32175,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+52395,int_stack+71435,int_stack+91920,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+91920,int_stack+60770,int_stack+59945,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+30555,int_stack+91920,int_stack+66170,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+99480,int_stack+30555,int_stack+68195,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+104880,int_stack+99480,int_stack+71435,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+66170,int_stack+104880,int_stack+52395,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+99480,int_stack+120285,int_stack+87510,441);
     Libderiv->ABCD[11] = int_stack + 99480;
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+159795,int_stack+126900,int_stack+113760,441);
     Libderiv->ABCD[10] = int_stack + 159795;
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+112710,int_stack+133515,int_stack+0,441);
     Libderiv->ABCD[9] = int_stack + 112710;
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+125940,int_stack+15120,int_stack+4410,441);
     Libderiv->ABCD[8] = int_stack + 125940;
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+139170,int_stack+153180,int_stack+21735,441);
     Libderiv->ABCD[7] = int_stack + 139170;
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+173025,int_stack+78810,int_stack+26145,441);
     Libderiv->ABCD[6] = int_stack + 173025;
 /*--- compute (fp|hh) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+72785,int_stack+39165,int_stack+95070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 72785;
 /*--- compute (fp|hh) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+86015,int_stack+45780,int_stack+8820, 0.0, zero_stack, 1.0, int_stack+34755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 86015;
 /*--- compute (fp|hh) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39165,int_stack+66170,int_stack+61760, 1.0, int_stack+34755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 39165;

}
