/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_i0ii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (i0|ii) integrals */

void d1hrr_order_i0ii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[6][10][11] = int_stack + 4592;
 Libderiv->deriv_classes[6][11][11] = int_stack + 6440;
 Libderiv->deriv_classes[6][12][11] = int_stack + 8624;
 Libderiv->deriv_classes[6][6][10] = int_stack + 11172;
 Libderiv->deriv_classes[6][7][10] = int_stack + 11956;
 Libderiv->deriv_classes[6][8][10] = int_stack + 12964;
 Libderiv->deriv_classes[6][9][10] = int_stack + 14224;
 Libderiv->deriv_classes[6][10][10] = int_stack + 15764;
 Libderiv->deriv_classes[6][11][10] = int_stack + 17612;
 Libderiv->deriv_classes[6][12][10] = int_stack + 19796;
 Libderiv->deriv_classes[6][6][9] = int_stack + 22344;
 Libderiv->deriv_classes[6][7][9] = int_stack + 23128;
 Libderiv->deriv_classes[6][8][9] = int_stack + 24136;
 Libderiv->deriv_classes[6][9][9] = int_stack + 25396;
 Libderiv->deriv_classes[6][10][9] = int_stack + 26936;
 Libderiv->deriv_classes[6][11][9] = int_stack + 28784;
 Libderiv->deriv_classes[6][12][9] = int_stack + 30968;
 Libderiv->deriv_classes[6][6][8] = int_stack + 33516;
 Libderiv->deriv_classes[6][7][8] = int_stack + 34300;
 Libderiv->deriv_classes[6][8][8] = int_stack + 35308;
 Libderiv->deriv_classes[6][9][8] = int_stack + 36568;
 Libderiv->deriv_classes[6][10][8] = int_stack + 38108;
 Libderiv->deriv_classes[6][11][8] = int_stack + 39956;
 Libderiv->deriv_classes[6][12][8] = int_stack + 42140;
 Libderiv->deriv_classes[6][6][7] = int_stack + 44688;
 Libderiv->deriv_classes[6][7][7] = int_stack + 45472;
 Libderiv->deriv_classes[6][8][7] = int_stack + 46480;
 Libderiv->deriv_classes[6][9][7] = int_stack + 47740;
 Libderiv->deriv_classes[6][10][7] = int_stack + 49280;
 Libderiv->deriv_classes[6][11][7] = int_stack + 51128;
 Libderiv->deriv_classes[6][12][7] = int_stack + 53312;
 Libderiv->dvrr_classes[6][6] = int_stack + 55860;
 Libderiv->deriv_classes[6][6][6] = int_stack + 56644;
 Libderiv->dvrr_classes[6][7] = int_stack + 57428;
 Libderiv->deriv_classes[6][7][6] = int_stack + 58436;
 Libderiv->dvrr_classes[6][8] = int_stack + 59444;
 Libderiv->deriv_classes[6][8][6] = int_stack + 60704;
 Libderiv->dvrr_classes[6][9] = int_stack + 61964;
 Libderiv->deriv_classes[6][9][6] = int_stack + 63504;
 Libderiv->dvrr_classes[6][10] = int_stack + 65044;
 Libderiv->deriv_classes[6][10][6] = int_stack + 66892;
 Libderiv->dvrr_classes[6][11] = int_stack + 68740;
 Libderiv->deriv_classes[6][11][6] = int_stack + 70924;
 Libderiv->deriv_classes[6][12][6] = int_stack + 73108;
 Libderiv->deriv_classes[6][6][2] = int_stack + 75656;
 Libderiv->deriv_classes[6][7][2] = int_stack + 76440;
 Libderiv->deriv_classes[6][8][2] = int_stack + 77448;
 Libderiv->deriv_classes[6][9][2] = int_stack + 78708;
 Libderiv->deriv_classes[6][10][2] = int_stack + 80248;
 Libderiv->deriv_classes[6][11][2] = int_stack + 82096;
 Libderiv->deriv_classes[6][12][2] = int_stack + 84280;
 Libderiv->deriv_classes[6][6][1] = int_stack + 86828;
 Libderiv->deriv_classes[6][7][1] = int_stack + 87612;
 Libderiv->deriv_classes[6][8][1] = int_stack + 88620;
 Libderiv->deriv_classes[6][9][1] = int_stack + 89880;
 Libderiv->deriv_classes[6][10][1] = int_stack + 91420;
 Libderiv->deriv_classes[6][11][1] = int_stack + 93268;
 Libderiv->deriv_classes[6][12][1] = int_stack + 95452;
 Libderiv->deriv_classes[6][6][0] = int_stack + 98000;
 Libderiv->deriv_classes[6][7][0] = int_stack + 98784;
 Libderiv->deriv_classes[6][8][0] = int_stack + 99792;
 Libderiv->deriv_classes[6][9][0] = int_stack + 101052;
 Libderiv->deriv_classes[6][10][0] = int_stack + 102592;
 Libderiv->deriv_classes[6][11][0] = int_stack + 104440;
 Libderiv->deriv_classes[6][12][0] = int_stack + 106624;
 memset(int_stack,0,873376);

 Libderiv->dvrr_stack = int_stack + 456316;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_i0ii(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+109172,int_stack+57428,int_stack+55860,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+111524,int_stack+59444,int_stack+57428,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+114548,int_stack+111524,int_stack+109172,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+119252,int_stack+61964,int_stack+59444,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+123032,int_stack+119252,int_stack+111524,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+129080,int_stack+123032,int_stack+114548,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+136920,int_stack+65044,int_stack+61964,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+141540,int_stack+136920,int_stack+119252,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+149100,int_stack+141540,int_stack+123032,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+159180,int_stack+149100,int_stack+129080,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+170940,int_stack+68740,int_stack+65044,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+176484,int_stack+170940,int_stack+136920,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+185724,int_stack+176484,int_stack+141540,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+198324,int_stack+185724,int_stack+149100,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+213444,int_stack+198324,int_stack+159180,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+229908,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55860,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+232260,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57428,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+235284,int_stack+232260,int_stack+229908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109172,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+239988,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59444,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+243768,int_stack+239988,int_stack+232260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111524,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+249816,int_stack+243768,int_stack+235284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114548,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+229908,int_stack+4592,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61964,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+257656,int_stack+229908,int_stack+239988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119252,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+265216,int_stack+257656,int_stack+243768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123032,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+234528,int_stack+265216,int_stack+249816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129080,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+246288,int_stack+6440,int_stack+4592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65044,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+275296,int_stack+246288,int_stack+229908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136920,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+284536,int_stack+275296,int_stack+257656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141540,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+297136,int_stack+284536,int_stack+265216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149100,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+251832,int_stack+297136,int_stack+234528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159180,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+229908,int_stack+8624,int_stack+6440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68740,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+229908,int_stack+246288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170940,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+229908,int_stack+0,int_stack+275296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176484,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+312256,int_stack+229908,int_stack+284536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185724,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+229908,int_stack+312256,int_stack+297136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198324,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+11956,int_stack+11172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55860, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+12964,int_stack+11956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57428, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109172, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+268296,int_stack+14224,int_stack+12964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59444, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272076,int_stack+268296,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111524, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+278124,int_stack+272076,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114548, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+15764,int_stack+14224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61964, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4620,int_stack+0,int_stack+268296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119252, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+285964,int_stack+4620,int_stack+272076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123032, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+296044,int_stack+285964,int_stack+278124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129080, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+268296,int_stack+17612,int_stack+15764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65044, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+273840,int_stack+268296,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136920, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+307804,int_stack+273840,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141540, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+307804,int_stack+285964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149100, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+320404,int_stack+0,int_stack+296044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159180, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+283080,int_stack+19796,int_stack+17612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68740, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+289632,int_stack+283080,int_stack+268296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170940, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+336868,int_stack+289632,int_stack+273840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176484, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+268296,int_stack+336868,int_stack+307804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185724, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+287196,int_stack+268296,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198324, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+23128,int_stack+22344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55860, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+24136,int_stack+23128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57428, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+25396,int_stack+24136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59444, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13860,int_stack+10080,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111524, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+268296,int_stack+13860,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114548, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+26936,int_stack+25396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61964, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+276136,int_stack+0,int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119252, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+336868,int_stack+276136,int_stack+13860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123032, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4620,int_stack+336868,int_stack+268296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129080, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+268296,int_stack+28784,int_stack+26936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65044, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+16380,int_stack+268296,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+346948,int_stack+16380,int_stack+276136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141540, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+359548,int_stack+346948,int_stack+336868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149100, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+374668,int_stack+359548,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159180, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+336868,int_stack+30968,int_stack+28784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68740, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+336868,int_stack+268296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170940, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+268296,int_stack+0,int_stack+16380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176484, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+0,int_stack+268296,int_stack+346948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185724, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+336868,int_stack+0,int_stack+359548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198324, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+34300,int_stack+33516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+35308,int_stack+34300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+36568,int_stack+35308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13860,int_stack+10080,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+19908,int_stack+13860,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+38108,int_stack+36568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+27748,int_stack+0,int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+268296,int_stack+27748,int_stack+13860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4620,int_stack+268296,int_stack+19908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+16380,int_stack+39956,int_stack+38108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+358036,int_stack+16380,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+391132,int_stack+358036,int_stack+27748, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+21924,int_stack+391132,int_stack+268296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+268296,int_stack+21924,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+0,int_stack+42140,int_stack+39956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+308364,int_stack+0,int_stack+16380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+0,int_stack+308364,int_stack+358036, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+403732,int_stack+0,int_stack+391132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+0,int_stack+403732,int_stack+21924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+391132,int_stack+45472,int_stack+44688, 0.0, zero_stack, 1.0, int_stack+55860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+393484,int_stack+46480,int_stack+45472, 0.0, zero_stack, 1.0, int_stack+57428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+396508,int_stack+393484,int_stack+391132, 0.0, zero_stack, 1.0, int_stack+109172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+401212,int_stack+47740,int_stack+46480, 0.0, zero_stack, 1.0, int_stack+59444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+404992,int_stack+401212,int_stack+393484, 0.0, zero_stack, 1.0, int_stack+111524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+411040,int_stack+404992,int_stack+396508, 0.0, zero_stack, 1.0, int_stack+114548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+391132,int_stack+49280,int_stack+47740, 0.0, zero_stack, 1.0, int_stack+61964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21168,int_stack+391132,int_stack+401212, 0.0, zero_stack, 1.0, int_stack+119252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+28728,int_stack+21168,int_stack+404992, 0.0, zero_stack, 1.0, int_stack+123032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+395752,int_stack+28728,int_stack+411040, 0.0, zero_stack, 1.0, int_stack+129080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+407512,int_stack+51128,int_stack+49280, 0.0, zero_stack, 1.0, int_stack+65044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+413056,int_stack+407512,int_stack+391132, 0.0, zero_stack, 1.0, int_stack+136920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+358036,int_stack+413056,int_stack+21168, 0.0, zero_stack, 1.0, int_stack+141540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+422296,int_stack+358036,int_stack+28728, 0.0, zero_stack, 1.0, int_stack+149100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+21168,int_stack+422296,int_stack+395752, 0.0, zero_stack, 1.0, int_stack+159180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+37632,int_stack+53312,int_stack+51128, 0.0, zero_stack, 1.0, int_stack+68740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+44184,int_stack+37632,int_stack+407512, 0.0, zero_stack, 1.0, int_stack+170940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+391132,int_stack+44184,int_stack+413056, 0.0, zero_stack, 1.0, int_stack+176484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+437416,int_stack+391132,int_stack+358036, 0.0, zero_stack, 1.0, int_stack+185724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+391132,int_stack+437416,int_stack+422296, 0.0, zero_stack, 1.0, int_stack+198324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+358036,int_stack+58436,int_stack+56644, 1.0, int_stack+55860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+360388,int_stack+60704,int_stack+58436, 1.0, int_stack+57428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+363412,int_stack+360388,int_stack+358036, 1.0, int_stack+109172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+368116,int_stack+63504,int_stack+60704, 1.0, int_stack+59444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+412300,int_stack+368116,int_stack+360388, 1.0, int_stack+111524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+418348,int_stack+412300,int_stack+363412, 1.0, int_stack+114548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+109172,int_stack+66892,int_stack+63504, 1.0, int_stack+61964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+358036,int_stack+109172,int_stack+368116, 1.0, int_stack+119252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+426188,int_stack+358036,int_stack+412300, 1.0, int_stack+123032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+113792,int_stack+426188,int_stack+418348, 1.0, int_stack+129080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+412300,int_stack+70924,int_stack+66892, 1.0, int_stack+65044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+125552,int_stack+412300,int_stack+109172, 1.0, int_stack+136920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+436268,int_stack+125552,int_stack+358036, 1.0, int_stack+141540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+358036,int_stack+436268,int_stack+426188, 1.0, int_stack+149100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+417844,int_stack+358036,int_stack+113792, 1.0, int_stack+159180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+109172,int_stack+73108,int_stack+70924, 1.0, int_stack+68740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+134792,int_stack+109172,int_stack+412300, 1.0, int_stack+170940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+109172,int_stack+134792,int_stack+125552, 1.0, int_stack+176484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+124572,int_stack+109172,int_stack+436268, 1.0, int_stack+185724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+143472,int_stack+124572,int_stack+358036, 1.0, int_stack+198324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+358036,int_stack+76440,int_stack+75656,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+360388,int_stack+77448,int_stack+76440,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+363412,int_stack+360388,int_stack+358036,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+368116,int_stack+78708,int_stack+77448,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+109172,int_stack+368116,int_stack+360388,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+115220,int_stack+109172,int_stack+363412,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+358036,int_stack+80248,int_stack+78708,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+123060,int_stack+358036,int_stack+368116,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+362656,int_stack+123060,int_stack+109172,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+130620,int_stack+362656,int_stack+115220,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+412300,int_stack+82096,int_stack+80248,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+109172,int_stack+412300,int_stack+358036,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+164640,int_stack+109172,int_stack+123060,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+177240,int_stack+164640,int_stack+362656,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+358036,int_stack+177240,int_stack+130620,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+118412,int_stack+84280,int_stack+82096,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+124964,int_stack+118412,int_stack+412300,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+192360,int_stack+124964,int_stack+109172,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+109172,int_stack+192360,int_stack+164640,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+434308,int_stack+109172,int_stack+177240,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+109172,int_stack+87612,int_stack+86828,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+111524,int_stack+88620,int_stack+87612,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+114548,int_stack+111524,int_stack+109172,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+119252,int_stack+89880,int_stack+88620,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+123032,int_stack+119252,int_stack+111524,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+129080,int_stack+123032,int_stack+114548,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+109172,int_stack+91420,int_stack+89880,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+164640,int_stack+109172,int_stack+119252,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+172200,int_stack+164640,int_stack+123032,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+113792,int_stack+172200,int_stack+129080,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+412300,int_stack+93268,int_stack+91420,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+125552,int_stack+412300,int_stack+109172,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+182280,int_stack+125552,int_stack+164640,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+194880,int_stack+182280,int_stack+172200,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+164640,int_stack+194880,int_stack+113792,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+109172,int_stack+95452,int_stack+93268,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+37632,int_stack+109172,int_stack+412300,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+109172,int_stack+37632,int_stack+125552,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+124572,int_stack+109172,int_stack+182280,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+37632,int_stack+124572,int_stack+194880,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+109172,int_stack+98784,int_stack+98000,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+111524,int_stack+99792,int_stack+98784,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+114548,int_stack+111524,int_stack+109172,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+119252,int_stack+101052,int_stack+99792,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+123032,int_stack+119252,int_stack+111524,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+129080,int_stack+123032,int_stack+114548,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+109172,int_stack+102592,int_stack+101052,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+58800,int_stack+109172,int_stack+119252,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+66360,int_stack+58800,int_stack+123032,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+113792,int_stack+66360,int_stack+129080,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+412300,int_stack+104440,int_stack+102592,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+125552,int_stack+412300,int_stack+109172,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+76440,int_stack+125552,int_stack+58800,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+89040,int_stack+76440,int_stack+66360,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+58800,int_stack+89040,int_stack+113792,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+109172,int_stack+106624,int_stack+104440,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+181104,int_stack+109172,int_stack+412300,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+104160,int_stack+181104,int_stack+125552,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+181104,int_stack+104160,int_stack+76440,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+104160,int_stack+181104,int_stack+89040,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+181104,int_stack+229908,int_stack+251832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213444,28);
     Libderiv->ABCD[11] = int_stack + 181104;
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+229908,int_stack+287196,int_stack+320404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213444, 0.0, zero_stack,28);
     Libderiv->ABCD[10] = int_stack + 229908;
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+75264,int_stack+336868,int_stack+374668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213444, 0.0, zero_stack, 0.0, zero_stack,28);
     Libderiv->ABCD[9] = int_stack + 75264;
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+284760,int_stack+0,int_stack+268296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
     Libderiv->ABCD[8] = int_stack + 284760;
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+251860,int_stack+391132,int_stack+21168, 0.0, zero_stack, 1.0, int_stack+213444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
     Libderiv->ABCD[7] = int_stack + 251860;
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+0,int_stack+143472,int_stack+417844, 1.0, int_stack+213444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+203056,int_stack+434308,int_stack+358036,28);
     Libderiv->ABCD[2] = int_stack + 203056;
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+125328,int_stack+37632,int_stack+164640,28);
     Libderiv->ABCD[1] = int_stack + 125328;
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+21952,int_stack+104160,int_stack+58800,28);
     Libderiv->ABCD[0] = int_stack + 21952;

}
