/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include "libint.h"
#include "hrr_header.h"

extern void vrr_order_dpkh(Libint_t*, prim_data*);

  /* Computes quartets of (dp|kh) integrals */

REALTYPE *hrr_order_dpkh(Libint_t *Libint, int num_prim_comb)
{
 prim_data *Data = Libint->PrimQuartet;
 REALTYPE *int_stack = Libint->int_stack;
 int i;

 Libint->vrr_classes[2][7] = int_stack + 0;
 Libint->vrr_classes[2][8] = int_stack + 216;
 Libint->vrr_classes[2][9] = int_stack + 486;
 Libint->vrr_classes[2][10] = int_stack + 816;
 Libint->vrr_classes[2][11] = int_stack + 1212;
 Libint->vrr_classes[2][12] = int_stack + 1680;
 Libint->vrr_classes[3][7] = int_stack + 2226;
 Libint->vrr_classes[3][8] = int_stack + 2586;
 Libint->vrr_classes[3][9] = int_stack + 3036;
 Libint->vrr_classes[3][10] = int_stack + 3586;
 Libint->vrr_classes[3][11] = int_stack + 4246;
 Libint->vrr_classes[3][12] = int_stack + 5026;
 memset(int_stack,0,5936*sizeof(REALTYPE));

 Libint->vrr_stack = int_stack + 5936;
 for(i=0;i<num_prim_comb;i++) {
   vrr_order_dpkh(Libint, Data);
   Data++;
 }
 /*--- compute (d0|kp) ---*/
 hrr3_build_kp(Libint->CD,int_stack+5936,int_stack+216,int_stack+0,6);
 /*--- compute (d0|lp) ---*/
 hrr3_build_lp(Libint->CD,int_stack+6584,int_stack+486,int_stack+216,6);
 /*--- compute (d0|kd) ---*/
 hrr3_build_kd(Libint->CD,int_stack+7394,int_stack+6584,int_stack+5936,6);
 /*--- compute (d0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+8690,int_stack+816,int_stack+486,6);
 /*--- compute (d0|ld) ---*/
 hrr3_build_ld(Libint->CD,int_stack+9680,int_stack+8690,int_stack+6584,6);
 /*--- compute (d0|kf) ---*/
 hrr3_build_kf(Libint->CD,int_stack+11300,int_stack+9680,int_stack+7394,6);
 /*--- compute (d0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+5936,int_stack+1212,int_stack+816,6);
 /*--- compute (d0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+13460,int_stack+5936,int_stack+8690,6);
 /*--- compute (d0|lf) ---*/
 hrr3_build_lf(Libint->CD,int_stack+15440,int_stack+13460,int_stack+9680,6);
 /*--- compute (d0|kg) ---*/
 hrr3_build_kg(Libint->CD,int_stack+7124,int_stack+15440,int_stack+11300,6);
 /*--- compute (d0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+10364,int_stack+1680,int_stack+1212,6);
 /*--- compute (d0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+18140,int_stack+10364,int_stack+5936,6);
 /*--- compute (d0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+20516,int_stack+18140,int_stack+13460,6);
 /*--- compute (d0|lg) ---*/
 hrr3_build_lg(Libint->CD,int_stack+10364,int_stack+20516,int_stack+15440,6);
 /*--- compute (d0|kh) ---*/
 hrr3_build_kh(Libint->CD,int_stack+14414,int_stack+10364,int_stack+7124,6);
 /*--- compute (f0|kp) ---*/
 hrr3_build_kp(Libint->CD,int_stack+5936,int_stack+2586,int_stack+2226,10);
 /*--- compute (f0|lp) ---*/
 hrr3_build_lp(Libint->CD,int_stack+7016,int_stack+3036,int_stack+2586,10);
 /*--- compute (f0|kd) ---*/
 hrr3_build_kd(Libint->CD,int_stack+8366,int_stack+7016,int_stack+5936,10);
 /*--- compute (f0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+10526,int_stack+3586,int_stack+3036,10);
 /*--- compute (f0|ld) ---*/
 hrr3_build_ld(Libint->CD,int_stack+18950,int_stack+10526,int_stack+7016,10);
 /*--- compute (f0|kf) ---*/
 hrr3_build_kf(Libint->CD,int_stack+21650,int_stack+18950,int_stack+8366,10);
 /*--- compute (f0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+5936,int_stack+4246,int_stack+3586,10);
 /*--- compute (f0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+0,int_stack+5936,int_stack+10526,10);
 /*--- compute (f0|lf) ---*/
 hrr3_build_lf(Libint->CD,int_stack+7916,int_stack+0,int_stack+18950,10);
 /*--- compute (f0|kg) ---*/
 hrr3_build_kg(Libint->CD,int_stack+25250,int_stack+7916,int_stack+21650,10);
 /*--- compute (f0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+18950,int_stack+5026,int_stack+4246,10);
 /*--- compute (f0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+21290,int_stack+18950,int_stack+5936,10);
 /*--- compute (f0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+30650,int_stack+21290,int_stack+0,10);
 /*--- compute (f0|lg) ---*/
 hrr3_build_lg(Libint->CD,int_stack+0,int_stack+30650,int_stack+7916,10);
 /*--- compute (f0|kh) ---*/
 hrr3_build_kh(Libint->CD,int_stack+6750,int_stack+0,int_stack+25250,10);
 /*--- compute (dp|kh) ---*/
 hrr1_build_dp(Libint->AB,int_stack+18950,int_stack+6750,int_stack+14414,756);
 return int_stack+18950;}
