/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_d0hd(Libr12_t *, prim_data *);

  /* Computes (d0|hd) integrals for linear R12-methods */

void hrr_grt_order_d0hd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 210;
 Libr12->gvrr_classes[3][6] = int_stack + 336;
 Libr12->t2vrr_classes[2][6] = int_stack + 616;
 Libr12->t2vrr_classes[2][7] = int_stack + 784;
 Libr12->t1vrr_classes[2][5] = int_stack + 1000;
 Libr12->t1vrr_classes[2][6] = int_stack + 1126;
 Libr12->t1vrr_classes[2][7] = int_stack + 1294;
 Libr12->rvrr_classes[2][5] = int_stack + 1510;
 Libr12->rvrr_classes[2][6] = int_stack + 1636;
 Libr12->rvrr_classes[2][7] = int_stack + 1804;
 Libr12->gvrr_classes[2][5] = int_stack + 2020;
 Libr12->gvrr_classes[2][6] = int_stack + 2146;
 Libr12->gvrr_classes[2][7] = int_stack + 2314;
 memset(int_stack,0,2530*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 2530;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_d0hd(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2530, int_stack+2146, int_stack+2020, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2908, int_stack+336, int_stack+0, 10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3538, int_stack+2314, int_stack+2146, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4042, int_stack+616, int_stack+210, int_stack+2146, int_stack+0, int_stack+2020, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4420, int_stack+784, int_stack+616, int_stack+2314, int_stack+336, int_stack+2146, 2, 0);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2020, int_stack+1126, int_stack+1000, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1294, int_stack+1126, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+504, int_stack+1636, int_stack+1510, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+882, int_stack+1804, int_stack+1636, 6);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4924, int_stack+4420, int_stack+4042, int_stack+3538, int_stack+2908, int_stack+2530, 2, 0);
     Libr12->te_ptr[3] = int_stack + 4924;
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4042, int_stack+0, int_stack+2020, 6);
     Libr12->te_ptr[2] = int_stack + 4042;
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1386, int_stack+882, int_stack+504, 6);
     Libr12->te_ptr[1] = int_stack + 1386;
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3538, int_stack+2530, 6);
     Libr12->te_ptr[0] = int_stack + 0;

}
