/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dpfp(Libr12_t *, prim_data *);

  /* Computes (dp|fp) integrals for linear R12-methods */

void hrr_grt_order_dpfp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][3] = int_stack + 0;
 Libr12->t2vrr_classes[2][4] = int_stack + 60;
 Libr12->gvrr_classes[4][3] = int_stack + 150;
 Libr12->t2vrr_classes[3][3] = int_stack + 300;
 Libr12->t2vrr_classes[3][4] = int_stack + 400;
 Libr12->gvrr_classes[2][5] = int_stack + 550;
 Libr12->t1vrr_classes[2][3] = int_stack + 676;
 Libr12->t1vrr_classes[2][4] = int_stack + 736;
 Libr12->t1vrr_classes[3][3] = int_stack + 826;
 Libr12->t1vrr_classes[3][4] = int_stack + 926;
 Libr12->rvrr_classes[2][3] = int_stack + 1076;
 Libr12->rvrr_classes[2][4] = int_stack + 1136;
 Libr12->rvrr_classes[3][3] = int_stack + 1226;
 Libr12->rvrr_classes[3][4] = int_stack + 1326;
 Libr12->gvrr_classes[2][3] = int_stack + 1476;
 Libr12->gvrr_classes[2][4] = int_stack + 1536;
 Libr12->gvrr_classes[3][3] = int_stack + 1626;
 Libr12->gvrr_classes[3][4] = int_stack + 1726;
 memset(int_stack,0,1876*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1876;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dpfp(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1876, int_stack+60, int_stack+0, int_stack+1536, int_stack+1626, int_stack+1476, 2, 0);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2056, int_stack+400, int_stack+300, int_stack+1726, int_stack+150, int_stack+1626, 3, 0);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1536, int_stack+1476, 6);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+180, int_stack+550, int_stack+1536, 6);
 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2356, int_stack+1726, int_stack+1626, 10);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1476, int_stack+736, int_stack+676, 6);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+926, int_stack+826, 10);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1656, int_stack+1136, int_stack+1076, 6);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+750, int_stack+1326, int_stack+1226, 10);
 /*--- compute (dp|[r12,T2]|fp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+2656, int_stack+2056, int_stack+1876, 30);
     Libr12->te_ptr[3] = int_stack + 2656;
 /*--- compute (dp|[r12,T1]|fp) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+3196, int_stack+450, int_stack+1476, int_stack+2356, int_stack+180, int_stack+0, 3, 1);
     Libr12->te_ptr[2] = int_stack + 3196;
 /*--- compute (dp||fp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+180, int_stack+750, int_stack+1656, 30);
     Libr12->te_ptr[1] = int_stack + 180;
 /*--- compute (dp|fp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+720, int_stack+2356, int_stack+0, 30);
     Libr12->te_ptr[0] = int_stack + 720;

}
