/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_f0ff(Libr12_t *, prim_data *);

  /* Computes (f0|ff) integrals for linear R12-methods */

void hrr_grt_order_f0ff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[4][3] = int_stack + 0;
 Libr12->t2vrr_classes[3][3] = int_stack + 150;
 Libr12->gvrr_classes[4][4] = int_stack + 250;
 Libr12->t2vrr_classes[3][4] = int_stack + 475;
 Libr12->gvrr_classes[4][5] = int_stack + 625;
 Libr12->t2vrr_classes[3][5] = int_stack + 940;
 Libr12->t2vrr_classes[3][6] = int_stack + 1150;
 Libr12->t1vrr_classes[3][3] = int_stack + 1430;
 Libr12->t1vrr_classes[3][4] = int_stack + 1530;
 Libr12->t1vrr_classes[3][5] = int_stack + 1680;
 Libr12->t1vrr_classes[3][6] = int_stack + 1890;
 Libr12->rvrr_classes[3][3] = int_stack + 2170;
 Libr12->rvrr_classes[3][4] = int_stack + 2270;
 Libr12->rvrr_classes[3][5] = int_stack + 2420;
 Libr12->rvrr_classes[3][6] = int_stack + 2630;
 Libr12->gvrr_classes[3][3] = int_stack + 2910;
 Libr12->gvrr_classes[3][4] = int_stack + 3010;
 Libr12->gvrr_classes[3][5] = int_stack + 3160;
 Libr12->gvrr_classes[3][6] = int_stack + 3370;
 memset(int_stack,0,3650*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 3650;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_f0ff(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+3650, int_stack+3010, int_stack+2910, 10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3950, int_stack+3160, int_stack+3010, 10);
 /*--- compute (f0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+4400, int_stack+3950, int_stack+3650, 10);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+5000, int_stack+250, int_stack+0, 15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5450, int_stack+625, int_stack+250, 15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+6125, int_stack+5450, int_stack+5000, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7025, int_stack+3370, int_stack+3160, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7655, int_stack+7025, int_stack+3950, 10);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8555, int_stack+475, int_stack+150, int_stack+3010, int_stack+0, int_stack+2910, 3, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8855, int_stack+940, int_stack+475, int_stack+3160, int_stack+250, int_stack+3010, 3, 0);
 /*--- compute (f0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+8855, int_stack+8555, int_stack+3950, int_stack+5000, int_stack+3650, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9305, int_stack+1150, int_stack+940, int_stack+3370, int_stack+625, int_stack+3160, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2910, int_stack+9305, int_stack+8855, int_stack+7025, int_stack+5450, int_stack+3950, 3, 0);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+7025, int_stack+1530, int_stack+1430, 10);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5000, int_stack+1680, int_stack+1530, 10);
 /*--- compute (f0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+5450, int_stack+5000, int_stack+7025, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7025, int_stack+1890, int_stack+1680, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8555, int_stack+7025, int_stack+5000, 10);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+5000, int_stack+2270, int_stack+2170, 10);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7025, int_stack+2420, int_stack+2270, 10);
 /*--- compute (f0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+600, int_stack+7025, int_stack+5000, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1200, int_stack+2630, int_stack+2420, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1830, int_stack+1200, int_stack+7025, 10);
 /*--- compute (f0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9455, int_stack+2910, int_stack+0, int_stack+7655, int_stack+6125, int_stack+4400, 3, 0);
     Libr12->te_ptr[3] = int_stack + 9455;
 /*--- compute (f0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+6050, int_stack+8555, int_stack+5450, 10);
     Libr12->te_ptr[2] = int_stack + 6050;
 /*--- compute (f0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+5000, int_stack+1830, int_stack+600, 10);
     Libr12->te_ptr[1] = int_stack + 5000;
 /*--- compute (f0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7655, int_stack+4400, 10);
     Libr12->te_ptr[0] = int_stack + 0;

}
