/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ffgf(Libr12_t *, prim_data *);

  /* Computes (ff|gf) integrals for linear R12-methods */

void hrr_grt_order_ffgf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->t2vrr_classes[3][7] = int_stack + 640;
 Libr12->t2vrr_classes[4][4] = int_stack + 1000;
 Libr12->t2vrr_classes[4][5] = int_stack + 1225;
 Libr12->t2vrr_classes[4][6] = int_stack + 1540;
 Libr12->t2vrr_classes[4][7] = int_stack + 1960;
 Libr12->t2vrr_classes[5][4] = int_stack + 2500;
 Libr12->t2vrr_classes[5][5] = int_stack + 2815;
 Libr12->t2vrr_classes[5][6] = int_stack + 3256;
 Libr12->t2vrr_classes[5][7] = int_stack + 3844;
 Libr12->gvrr_classes[7][4] = int_stack + 4600;
 Libr12->t2vrr_classes[6][4] = int_stack + 5140;
 Libr12->gvrr_classes[7][5] = int_stack + 5560;
 Libr12->t2vrr_classes[6][5] = int_stack + 6316;
 Libr12->gvrr_classes[7][6] = int_stack + 6904;
 Libr12->t2vrr_classes[6][6] = int_stack + 7912;
 Libr12->t2vrr_classes[6][7] = int_stack + 8696;
 Libr12->gvrr_classes[3][8] = int_stack + 9704;
 Libr12->t1vrr_classes[3][4] = int_stack + 10154;
 Libr12->t1vrr_classes[3][5] = int_stack + 10304;
 Libr12->t1vrr_classes[3][6] = int_stack + 10514;
 Libr12->t1vrr_classes[3][7] = int_stack + 10794;
 Libr12->gvrr_classes[4][8] = int_stack + 11154;
 Libr12->t1vrr_classes[4][4] = int_stack + 11829;
 Libr12->t1vrr_classes[4][5] = int_stack + 12054;
 Libr12->t1vrr_classes[4][6] = int_stack + 12369;
 Libr12->t1vrr_classes[4][7] = int_stack + 12789;
 Libr12->gvrr_classes[5][8] = int_stack + 13329;
 Libr12->t1vrr_classes[5][4] = int_stack + 14274;
 Libr12->t1vrr_classes[5][5] = int_stack + 14589;
 Libr12->t1vrr_classes[5][6] = int_stack + 15030;
 Libr12->t1vrr_classes[5][7] = int_stack + 15618;
 Libr12->t1vrr_classes[6][4] = int_stack + 16374;
 Libr12->t1vrr_classes[6][5] = int_stack + 16794;
 Libr12->t1vrr_classes[6][6] = int_stack + 17382;
 Libr12->t1vrr_classes[6][7] = int_stack + 18166;
 Libr12->rvrr_classes[3][4] = int_stack + 19174;
 Libr12->rvrr_classes[3][5] = int_stack + 19324;
 Libr12->rvrr_classes[3][6] = int_stack + 19534;
 Libr12->rvrr_classes[3][7] = int_stack + 19814;
 Libr12->rvrr_classes[4][4] = int_stack + 20174;
 Libr12->rvrr_classes[4][5] = int_stack + 20399;
 Libr12->rvrr_classes[4][6] = int_stack + 20714;
 Libr12->rvrr_classes[4][7] = int_stack + 21134;
 Libr12->rvrr_classes[5][4] = int_stack + 21674;
 Libr12->rvrr_classes[5][5] = int_stack + 21989;
 Libr12->rvrr_classes[5][6] = int_stack + 22430;
 Libr12->rvrr_classes[5][7] = int_stack + 23018;
 Libr12->rvrr_classes[6][4] = int_stack + 23774;
 Libr12->rvrr_classes[6][5] = int_stack + 24194;
 Libr12->rvrr_classes[6][6] = int_stack + 24782;
 Libr12->rvrr_classes[6][7] = int_stack + 25566;
 Libr12->gvrr_classes[3][4] = int_stack + 26574;
 Libr12->gvrr_classes[3][5] = int_stack + 26724;
 Libr12->gvrr_classes[3][6] = int_stack + 26934;
 Libr12->gvrr_classes[3][7] = int_stack + 27214;
 Libr12->gvrr_classes[4][4] = int_stack + 27574;
 Libr12->gvrr_classes[4][5] = int_stack + 27799;
 Libr12->gvrr_classes[4][6] = int_stack + 28114;
 Libr12->gvrr_classes[4][7] = int_stack + 28534;
 Libr12->gvrr_classes[5][4] = int_stack + 29074;
 Libr12->gvrr_classes[5][5] = int_stack + 29389;
 Libr12->gvrr_classes[5][6] = int_stack + 29830;
 Libr12->gvrr_classes[5][7] = int_stack + 30418;
 Libr12->gvrr_classes[6][4] = int_stack + 31174;
 Libr12->gvrr_classes[6][5] = int_stack + 31594;
 Libr12->gvrr_classes[6][6] = int_stack + 32182;
 Libr12->gvrr_classes[6][7] = int_stack + 32966;
 memset(int_stack,0,33974*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 33974;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ffgf(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+33974, int_stack+26724, int_stack+26574, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+34424, int_stack+26934, int_stack+26724, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+35054, int_stack+34424, int_stack+33974, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+35954, int_stack+27799, int_stack+27574, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+36629, int_stack+28114, int_stack+27799, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+37574, int_stack+36629, int_stack+35954, 15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+38924, int_stack+27214, int_stack+26934, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+39764, int_stack+38924, int_stack+34424, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41024, int_stack+150, int_stack+0, int_stack+26724, int_stack+27574, int_stack+26574, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41474, int_stack+360, int_stack+150, int_stack+26934, int_stack+27799, int_stack+26724, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42104, int_stack+41474, int_stack+41024, int_stack+34424, int_stack+35954, int_stack+33974, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+43004, int_stack+640, int_stack+360, int_stack+27214, int_stack+28114, int_stack+26934, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+43844, int_stack+43004, int_stack+41474, int_stack+38924, int_stack+36629, int_stack+34424, 3, 0);
 /*--- compute (f0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+45104, int_stack+43844, int_stack+42104, int_stack+39764, int_stack+37574, int_stack+35054, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+33974, int_stack+29389, int_stack+29074, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41024, int_stack+29830, int_stack+29389, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+42347, int_stack+41024, int_stack+33974, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+46604, int_stack+28534, int_stack+28114, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+47864, int_stack+46604, int_stack+36629, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44237, int_stack+1225, int_stack+1000, int_stack+27799, int_stack+29074, int_stack+27574, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1540, int_stack+1225, int_stack+28114, int_stack+29389, int_stack+27799, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49754, int_stack+0, int_stack+44237, int_stack+36629, int_stack+33974, int_stack+35954, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51104, int_stack+1960, int_stack+1540, int_stack+28534, int_stack+29830, int_stack+28114, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+52364, int_stack+51104, int_stack+0, int_stack+46604, int_stack+41024, int_stack+36629, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+52364, int_stack+49754, int_stack+47864, int_stack+42347, int_stack+37574, 4, 0);
 /*--- compute (fp|[r12,T2]|gf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+49754, int_stack+0, int_stack+45104, 150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+35954, int_stack+31594, int_stack+31174, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+44237, int_stack+32182, int_stack+31594, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+54254, int_stack+44237, int_stack+35954, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+56774, int_stack+30418, int_stack+29830, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+58538, int_stack+56774, int_stack+41024, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+27574, int_stack+2815, int_stack+2500, int_stack+29389, int_stack+31174, int_stack+29074, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+61184, int_stack+3256, int_stack+2815, int_stack+29830, int_stack+31594, int_stack+29389, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+62507, int_stack+61184, int_stack+27574, int_stack+41024, int_stack+35954, int_stack+33974, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+64397, int_stack+3844, int_stack+3256, int_stack+30418, int_stack+32182, int_stack+29830, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66161, int_stack+64397, int_stack+61184, int_stack+56774, int_stack+44237, int_stack+41024, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68807, int_stack+66161, int_stack+62507, int_stack+58538, int_stack+54254, int_stack+42347, 5, 0);
 /*--- compute (gp|[r12,T2]|gf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+61184, int_stack+68807, int_stack+0, 150);
 /*--- compute (fd|[r12,T2]|gf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+71957, int_stack+61184, int_stack+49754, 150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+49754, int_stack+5560, int_stack+4600, 36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+51374, int_stack+6904, int_stack+5560, 36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+51374, int_stack+49754, 36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+80957, int_stack+32966, int_stack+32182, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+83309, int_stack+80957, int_stack+44237, 28);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3240, int_stack+6316, int_stack+5140, int_stack+31594, int_stack+4600, int_stack+31174, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+86837, int_stack+7912, int_stack+6316, int_stack+32182, int_stack+5560, int_stack+31594, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+88601, int_stack+86837, int_stack+3240, int_stack+44237, int_stack+49754, int_stack+35954, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3240, int_stack+8696, int_stack+7912, int_stack+32966, int_stack+6904, int_stack+32182, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5592, int_stack+3240, int_stack+86837, int_stack+80957, int_stack+51374, int_stack+44237, 6, 0);
 /*--- compute (i0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49754, int_stack+5592, int_stack+88601, int_stack+83309, int_stack+0, int_stack+54254, 6, 0);
 /*--- compute (hp|[r12,T2]|gf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+49754, int_stack+68807, 150);
 /*--- compute (gd|[r12,T2]|gf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+86837, int_stack+0, int_stack+61184, 150);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+61184, int_stack+39764, int_stack+35054, 10);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+62684, int_stack+47864, int_stack+37574, 15);
 /*--- compute (fp|gf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+49754, int_stack+62684, int_stack+61184, 150);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+64934, int_stack+58538, int_stack+42347, 21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+64934, int_stack+62684, 150);
 /*--- compute (fd|gf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+100337, int_stack+0, int_stack+49754, 150);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+68084, int_stack+9704, int_stack+27214, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+69164, int_stack+68084, int_stack+38924, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+69164, int_stack+39764, 10);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+68084, int_stack+11154, int_stack+28534, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+31174, int_stack+68084, int_stack+46604, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+68084, int_stack+31174, int_stack+47864, 15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+31174, int_stack+68084, int_stack+6750, 210);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+37474, int_stack+13329, int_stack+30418, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+39742, int_stack+37474, int_stack+56774, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+43270, int_stack+39742, int_stack+58538, 21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+109337, int_stack+43270, int_stack+68084, 210);
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+118787, int_stack+109337, int_stack+31174, 210);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+56774, int_stack+83309, int_stack+54254, 28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+131387, int_stack+56774, int_stack+64934, 150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+140837, int_stack+131387, int_stack+0, 150);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+54254, int_stack+10304, int_stack+10154, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+54704, int_stack+10514, int_stack+10304, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+55334, int_stack+54704, int_stack+54254, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+37474, int_stack+10794, int_stack+10514, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+38314, int_stack+37474, int_stack+54704, 10);
 /*--- compute (f0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+39574, int_stack+38314, int_stack+55334, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+37474, int_stack+12054, int_stack+11829, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13329, int_stack+12369, int_stack+12054, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+38149, int_stack+13329, int_stack+37474, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+54254, int_stack+12789, int_stack+12369, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+41074, int_stack+54254, int_stack+13329, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+54254, int_stack+41074, int_stack+38149, 15);
 /*--- compute (fp|[r12,T1]|gf) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+8850, int_stack+54254, int_stack+39574, int_stack+62684, int_stack+6750, int_stack+61184, 4, 3);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+14589, int_stack+14274, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+37474, int_stack+15030, int_stack+14589, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+38797, int_stack+37474, int_stack+6750, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+15618, int_stack+15030, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13350, int_stack+6750, int_stack+37474, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+80957, int_stack+13350, int_stack+38797, 21);
 /*--- compute (gp|[r12,T1]|gf) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+154337, int_stack+80957, int_stack+54254, int_stack+64934, int_stack+68084, int_stack+62684, 4, 3);
 /*--- compute (fd|[r12,T1]|gf) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+161087, int_stack+154337, int_stack+8850, int_stack+0, int_stack+31174, int_stack+49754, 4, 3);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+68084, int_stack+16794, int_stack+16374, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+69344, int_stack+17382, int_stack+16794, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+69344, int_stack+68084, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9270, int_stack+18166, int_stack+17382, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+11622, int_stack+9270, int_stack+69344, 28);
 /*--- compute (i0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+47680, int_stack+11622, int_stack+6750, 28);
 /*--- compute (hp|[r12,T1]|gf) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+6750, int_stack+47680, int_stack+80957, int_stack+56774, int_stack+43270, int_stack+64934, 4, 3);
 /*--- compute (gd|[r12,T1]|gf) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+26574, int_stack+6750, int_stack+154337, int_stack+131387, int_stack+109337, int_stack+0, 4, 3);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+19324, int_stack+19174, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+19534, int_stack+19324, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1080, int_stack+450, int_stack+0, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1980, int_stack+19814, int_stack+19534, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2820, int_stack+1980, int_stack+450, 10);
 /*--- compute (f0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+4080, int_stack+2820, int_stack+1080, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+20399, int_stack+20174, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+675, int_stack+20714, int_stack+20399, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1620, int_stack+675, int_stack+0, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5580, int_stack+21134, int_stack+20714, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6840, int_stack+5580, int_stack+675, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+8730, int_stack+6840, int_stack+1620, 15);
 /*--- compute (fp||gf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+10980, int_stack+8730, int_stack+4080, 150);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+21989, int_stack+21674, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+945, int_stack+22430, int_stack+21989, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+945, int_stack+0, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+4158, int_stack+23018, int_stack+22430, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5922, int_stack+4158, int_stack+945, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+15480, int_stack+5922, int_stack+2268, 21);
 /*--- compute (gp||gf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+154337, int_stack+15480, int_stack+8730, 150);
 /*--- compute (fd||gf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+154337, int_stack+10980, 150);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9000, int_stack+24194, int_stack+23774, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10260, int_stack+24782, int_stack+24194, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12024, int_stack+10260, int_stack+9000, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+18630, int_stack+25566, int_stack+24782, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20982, int_stack+18630, int_stack+10260, 28);
 /*--- compute (i0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+109337, int_stack+20982, int_stack+12024, 28);
 /*--- compute (hp||gf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+131387, int_stack+109337, int_stack+15480, 150);
 /*--- compute (gd||gf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+9000, int_stack+131387, int_stack+154337, 150);
 /*--- compute (ff|[r12,T2]|gf) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+40074, int_stack+86837, int_stack+71957, 150);
     Libr12->te_ptr[3] = int_stack + 40074;
 /*--- compute (ff|[r12,T1]|gf) ---*/
   t1hrr1_build_ff(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+55074, int_stack+26574, int_stack+161087, int_stack+140837, int_stack+118787, int_stack+100337, 4, 3);
     Libr12->te_ptr[2] = int_stack + 55074;
 /*--- compute (ff||gf) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+154337, int_stack+9000, int_stack+0, 150);
     Libr12->te_ptr[1] = int_stack + 154337;
 /*--- compute (ff|gf) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+0, int_stack+140837, int_stack+100337, 150);
     Libr12->te_ptr[0] = int_stack + 0;

}
