/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fpgd(Libr12_t *, prim_data *);

  /* Computes (fp|gd) integrals for linear R12-methods */

void hrr_grt_order_fpgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->gvrr_classes[5][4] = int_stack + 640;
 Libr12->t2vrr_classes[4][4] = int_stack + 955;
 Libr12->gvrr_classes[5][5] = int_stack + 1180;
 Libr12->t2vrr_classes[4][5] = int_stack + 1621;
 Libr12->t2vrr_classes[4][6] = int_stack + 1936;
 Libr12->gvrr_classes[3][7] = int_stack + 2356;
 Libr12->t1vrr_classes[3][4] = int_stack + 2716;
 Libr12->t1vrr_classes[3][5] = int_stack + 2866;
 Libr12->t1vrr_classes[3][6] = int_stack + 3076;
 Libr12->t1vrr_classes[4][4] = int_stack + 3356;
 Libr12->t1vrr_classes[4][5] = int_stack + 3581;
 Libr12->t1vrr_classes[4][6] = int_stack + 3896;
 Libr12->rvrr_classes[3][4] = int_stack + 4316;
 Libr12->rvrr_classes[3][5] = int_stack + 4466;
 Libr12->rvrr_classes[3][6] = int_stack + 4676;
 Libr12->rvrr_classes[4][4] = int_stack + 4956;
 Libr12->rvrr_classes[4][5] = int_stack + 5181;
 Libr12->rvrr_classes[4][6] = int_stack + 5496;
 Libr12->gvrr_classes[3][4] = int_stack + 5916;
 Libr12->gvrr_classes[3][5] = int_stack + 6066;
 Libr12->gvrr_classes[3][6] = int_stack + 6276;
 Libr12->gvrr_classes[4][4] = int_stack + 6556;
 Libr12->gvrr_classes[4][5] = int_stack + 6781;
 Libr12->gvrr_classes[4][6] = int_stack + 7096;
 memset(int_stack,0,7516*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 7516;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fpgd(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7516, int_stack+6066, int_stack+5916, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7966, int_stack+6781, int_stack+6556, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8641, int_stack+6276, int_stack+6066, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9271, int_stack+150, int_stack+0, int_stack+6066, int_stack+6556, int_stack+5916, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9721, int_stack+360, int_stack+150, int_stack+6276, int_stack+6781, int_stack+6066, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10351, int_stack+9721, int_stack+9271, int_stack+8641, int_stack+7966, int_stack+7516, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9271, int_stack+1180, int_stack+640, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11251, int_stack+7096, int_stack+6781, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12196, int_stack+1621, int_stack+955, int_stack+6781, int_stack+640, int_stack+6556, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1936, int_stack+1621, int_stack+7096, int_stack+1180, int_stack+6781, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+945, int_stack+0, int_stack+12196, int_stack+11251, int_stack+9271, int_stack+7966, 4, 0);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+9271, int_stack+8641, int_stack+7516, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2356, int_stack+6276, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5916, int_stack+0, int_stack+8641, 10);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12196, int_stack+11251, int_stack+7966, 15);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11251, int_stack+2866, int_stack+2716, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3076, int_stack+2866, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7176, int_stack+0, int_stack+11251, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11251, int_stack+3581, int_stack+3356, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3896, int_stack+3581, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2295, int_stack+0, int_stack+11251, 15);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11251, int_stack+4466, int_stack+4316, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4676, int_stack+4466, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8076, int_stack+0, int_stack+11251, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11251, int_stack+5181, int_stack+4956, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+5496, int_stack+5181, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3645, int_stack+0, int_stack+11251, 15);
 /*--- compute (fp|[r12,T2]|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+13546, int_stack+945, int_stack+10351, 90);
     Libr12->te_ptr[3] = int_stack + 13546;
 /*--- compute (fp|[r12,T1]|gd) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+16246, int_stack+2295, int_stack+7176, int_stack+12196, int_stack+5916, int_stack+9271, 4, 2);
     Libr12->te_ptr[2] = int_stack + 16246;
 /*--- compute (fp||gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+3645, int_stack+8076, 90);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+2700, int_stack+12196, int_stack+9271, 90);
     Libr12->te_ptr[0] = int_stack + 2700;

}
