/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gpgg(Libr12_t *, prim_data *);

  /* Computes (gp|gg) integrals for linear R12-methods */

void hrr_grt_order_gpgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][4] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 225;
 Libr12->t2vrr_classes[4][6] = int_stack + 540;
 Libr12->t2vrr_classes[4][7] = int_stack + 960;
 Libr12->t2vrr_classes[4][8] = int_stack + 1500;
 Libr12->gvrr_classes[6][4] = int_stack + 2175;
 Libr12->t2vrr_classes[5][4] = int_stack + 2595;
 Libr12->gvrr_classes[6][5] = int_stack + 2910;
 Libr12->t2vrr_classes[5][5] = int_stack + 3498;
 Libr12->gvrr_classes[6][6] = int_stack + 3939;
 Libr12->t2vrr_classes[5][6] = int_stack + 4723;
 Libr12->gvrr_classes[6][7] = int_stack + 5311;
 Libr12->t2vrr_classes[5][7] = int_stack + 6319;
 Libr12->t2vrr_classes[5][8] = int_stack + 7075;
 Libr12->gvrr_classes[4][9] = int_stack + 8020;
 Libr12->t1vrr_classes[4][4] = int_stack + 8845;
 Libr12->t1vrr_classes[4][5] = int_stack + 9070;
 Libr12->t1vrr_classes[4][6] = int_stack + 9385;
 Libr12->t1vrr_classes[4][7] = int_stack + 9805;
 Libr12->t1vrr_classes[4][8] = int_stack + 10345;
 Libr12->t1vrr_classes[5][4] = int_stack + 11020;
 Libr12->t1vrr_classes[5][5] = int_stack + 11335;
 Libr12->t1vrr_classes[5][6] = int_stack + 11776;
 Libr12->t1vrr_classes[5][7] = int_stack + 12364;
 Libr12->t1vrr_classes[5][8] = int_stack + 13120;
 Libr12->rvrr_classes[4][4] = int_stack + 14065;
 Libr12->rvrr_classes[4][5] = int_stack + 14290;
 Libr12->rvrr_classes[4][6] = int_stack + 14605;
 Libr12->rvrr_classes[4][7] = int_stack + 15025;
 Libr12->rvrr_classes[4][8] = int_stack + 15565;
 Libr12->rvrr_classes[5][4] = int_stack + 16240;
 Libr12->rvrr_classes[5][5] = int_stack + 16555;
 Libr12->rvrr_classes[5][6] = int_stack + 16996;
 Libr12->rvrr_classes[5][7] = int_stack + 17584;
 Libr12->rvrr_classes[5][8] = int_stack + 18340;
 Libr12->gvrr_classes[4][4] = int_stack + 19285;
 Libr12->gvrr_classes[4][5] = int_stack + 19510;
 Libr12->gvrr_classes[4][6] = int_stack + 19825;
 Libr12->gvrr_classes[4][7] = int_stack + 20245;
 Libr12->gvrr_classes[4][8] = int_stack + 20785;
 Libr12->gvrr_classes[5][4] = int_stack + 21460;
 Libr12->gvrr_classes[5][5] = int_stack + 21775;
 Libr12->gvrr_classes[5][6] = int_stack + 22216;
 Libr12->gvrr_classes[5][7] = int_stack + 22804;
 Libr12->gvrr_classes[5][8] = int_stack + 23560;
 memset(int_stack,0,24505*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 24505;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gpgg(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24505, int_stack+19510, int_stack+19285, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25180, int_stack+19825, int_stack+19510, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+26125, int_stack+25180, int_stack+24505, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+27475, int_stack+20245, int_stack+19825, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+28735, int_stack+27475, int_stack+25180, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+30625, int_stack+28735, int_stack+26125, 15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+32875, int_stack+21775, int_stack+21460, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+33820, int_stack+22216, int_stack+21775, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+35143, int_stack+33820, int_stack+32875, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+37033, int_stack+22804, int_stack+22216, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+38797, int_stack+37033, int_stack+33820, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+41443, int_stack+38797, int_stack+35143, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+44593, int_stack+20785, int_stack+20245, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+46213, int_stack+44593, int_stack+27475, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+48733, int_stack+46213, int_stack+28735, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51883, int_stack+225, int_stack+0, int_stack+19510, int_stack+21460, int_stack+19285, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+52558, int_stack+540, int_stack+225, int_stack+19825, int_stack+21775, int_stack+19510, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53503, int_stack+52558, int_stack+51883, int_stack+25180, int_stack+32875, int_stack+24505, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54853, int_stack+960, int_stack+540, int_stack+20245, int_stack+22216, int_stack+19825, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56113, int_stack+54853, int_stack+52558, int_stack+27475, int_stack+33820, int_stack+25180, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+58003, int_stack+56113, int_stack+53503, int_stack+28735, int_stack+35143, int_stack+26125, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24505, int_stack+1500, int_stack+960, int_stack+20785, int_stack+22804, int_stack+20245, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51883, int_stack+24505, int_stack+54853, int_stack+44593, int_stack+37033, int_stack+27475, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24505, int_stack+51883, int_stack+56113, int_stack+46213, int_stack+38797, int_stack+28735, 4, 0);
 /*--- compute (g0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51883, int_stack+24505, int_stack+58003, int_stack+48733, int_stack+41443, int_stack+30625, 4, 0);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24505, int_stack+2910, int_stack+2175, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25765, int_stack+3939, int_stack+2910, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+27529, int_stack+25765, int_stack+24505, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+55258, int_stack+5311, int_stack+3939, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+57610, int_stack+55258, int_stack+25765, 28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+61138, int_stack+57610, int_stack+27529, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+65338, int_stack+23560, int_stack+22804, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+67606, int_stack+65338, int_stack+37033, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+71134, int_stack+67606, int_stack+38797, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19285, int_stack+3498, int_stack+2595, int_stack+21775, int_stack+2175, int_stack+21460, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4723, int_stack+3498, int_stack+22216, int_stack+2910, int_stack+21775, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1323, int_stack+0, int_stack+19285, int_stack+33820, int_stack+24505, int_stack+32875, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+75544, int_stack+6319, int_stack+4723, int_stack+22804, int_stack+3939, int_stack+22216, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+77308, int_stack+75544, int_stack+0, int_stack+37033, int_stack+25765, int_stack+33820, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+79954, int_stack+77308, int_stack+1323, int_stack+38797, int_stack+27529, int_stack+35143, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+7075, int_stack+6319, int_stack+23560, int_stack+5311, int_stack+22804, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2268, int_stack+0, int_stack+75544, int_stack+65338, int_stack+55258, int_stack+37033, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32875, int_stack+2268, int_stack+77308, int_stack+67606, int_stack+57610, int_stack+38797, 5, 0);
 /*--- compute (h0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+55258, int_stack+32875, int_stack+79954, int_stack+71134, int_stack+61138, int_stack+41443, 5, 0);
 /*--- compute (g0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+32875, int_stack+48733, int_stack+30625, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+36250, int_stack+8020, int_stack+20785, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+59983, int_stack+36250, int_stack+44593, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+36250, int_stack+59983, int_stack+46213, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+59983, int_stack+36250, int_stack+48733, 15);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+36250, int_stack+71134, int_stack+41443, 21);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+9070, int_stack+8845, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41650, int_stack+9385, int_stack+9070, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+42595, int_stack+41650, int_stack+40975, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+43945, int_stack+9805, int_stack+9385, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+45205, int_stack+43945, int_stack+41650, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+47095, int_stack+45205, int_stack+42595, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+10345, int_stack+9805, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+49345, int_stack+40975, int_stack+43945, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+49345, int_stack+45205, 15);
 /*--- compute (g0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+64708, int_stack+40975, int_stack+47095, 15);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+11335, int_stack+11020, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41920, int_stack+11776, int_stack+11335, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+43243, int_stack+41920, int_stack+40975, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+45133, int_stack+12364, int_stack+11776, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+46897, int_stack+45133, int_stack+41920, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+68083, int_stack+46897, int_stack+43243, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+13120, int_stack+12364, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+71233, int_stack+40975, int_stack+45133, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+71233, int_stack+46897, 21);
 /*--- compute (h0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+71233, int_stack+40975, int_stack+68083, 21);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+68083, int_stack+14290, int_stack+14065, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+68758, int_stack+14605, int_stack+14290, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+69703, int_stack+68758, int_stack+68083, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+15025, int_stack+14605, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+42235, int_stack+40975, int_stack+68758, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+44125, int_stack+42235, int_stack+69703, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+68083, int_stack+15565, int_stack+15025, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+46375, int_stack+68083, int_stack+40975, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+68083, int_stack+46375, int_stack+42235, 15);
 /*--- compute (g0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+46375, int_stack+68083, int_stack+44125, 15);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+68083, int_stack+16555, int_stack+16240, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+69028, int_stack+16996, int_stack+16555, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+49750, int_stack+69028, int_stack+68083, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+17584, int_stack+16996, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+42739, int_stack+40975, int_stack+69028, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+68083, int_stack+42739, int_stack+49750, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+75958, int_stack+18340, int_stack+17584, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+78226, int_stack+75958, int_stack+40975, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+78226, int_stack+42739, 21);
 /*--- compute (h0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+40975, int_stack+0, int_stack+68083, 21);
 /*--- compute (gp|[r12,T2]|gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+55258, int_stack+51883, 225);
     Libr12->te_ptr[3] = int_stack + 0;
 /*--- compute (gp|[r12,T1]|gg) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+10125, int_stack+71233, int_stack+64708, int_stack+36250, int_stack+59983, int_stack+32875, 4, 4);
     Libr12->te_ptr[2] = int_stack + 10125;
 /*--- compute (gp||gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+20250, int_stack+40975, int_stack+46375, 225);
     Libr12->te_ptr[1] = int_stack + 20250;
 /*--- compute (gp|gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+40975, int_stack+36250, int_stack+32875, 225);
     Libr12->te_ptr[0] = int_stack + 40975;

}
