/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_ddff(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+2);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (p0|00)^2 ---*/
 _BUILD_p000(Data,r12vrr_stack+111, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+114, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+3);

 /*--- compute (d0|p0)^1 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+123, r12vrr_stack+6, r12vrr_stack+114, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+111);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+141, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+144, r12vrr_stack+30, r12vrr_stack+141, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+150, r12vrr_stack+33, r12vrr_stack+144, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+39, r12vrr_stack+150, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+114);

 /*--- compute (f0|d0)^0 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+75, r12vrr_stack+168, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+123);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+33, r12vrr_stack+144, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+284, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+33);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+314, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+314, r12vrr_stack+274, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+354, r12vrr_stack+141, r12vrr_stack+3, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+360, r12vrr_stack+144, r12vrr_stack+354, r12vrr_stack+30, r12vrr_stack+141, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+370, r12vrr_stack+264, r12vrr_stack+360, NULL, NULL, r12vrr_stack+144);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+400, r12vrr_stack+284, r12vrr_stack+370, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+150);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+324, r12vrr_stack+284, r12vrr_stack+314, r12vrr_stack+274, r12vrr_stack+39);
 tmp = r12vrr_stack + 460;
 target_ptr = Libr12->gvrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+520, r12vrr_stack+460, r12vrr_stack+400, r12vrr_stack+324, r12vrr_stack+284, r12vrr_stack+168);
 tmp = r12vrr_stack + 520;
 target_ptr = Libr12->gvrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+620, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+635, r12vrr_stack+314, r12vrr_stack+274, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+650, r12vrr_stack+264, r12vrr_stack+360, r12vrr_stack+33, r12vrr_stack+144, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+665, r12vrr_stack+620, r12vrr_stack+650, NULL, NULL, r12vrr_stack+264);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+710, r12vrr_stack+635, r12vrr_stack+620, NULL, NULL, r12vrr_stack+274);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+755, r12vrr_stack+710, r12vrr_stack+665, r12vrr_stack+635, r12vrr_stack+620, r12vrr_stack+284);
 tmp = r12vrr_stack + 755;
 target_ptr = Libr12->gvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+845, r12vrr_stack+3, r12vrr_stack+15, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+851, r12vrr_stack+354, r12vrr_stack+845, r12vrr_stack+141, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+861, r12vrr_stack+360, r12vrr_stack+851, r12vrr_stack+144, r12vrr_stack+354, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+876, r12vrr_stack+650, r12vrr_stack+861, NULL, NULL, r12vrr_stack+360);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+921, r12vrr_stack+665, r12vrr_stack+876, r12vrr_stack+620, r12vrr_stack+650, r12vrr_stack+370);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1011, r12vrr_stack+755, r12vrr_stack+921, r12vrr_stack+710, r12vrr_stack+665, r12vrr_stack+400);
 tmp = r12vrr_stack + 1011;
 target_ptr = Libr12->gvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1161, r12vrr_stack+620, r12vrr_stack+650, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1182, r12vrr_stack+635, r12vrr_stack+620, r12vrr_stack+314, r12vrr_stack+274, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1203, r12vrr_stack+650, r12vrr_stack+861, r12vrr_stack+264, r12vrr_stack+360, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1224, r12vrr_stack+1161, r12vrr_stack+1203, NULL, NULL, r12vrr_stack+650);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1287, r12vrr_stack+1182, r12vrr_stack+1161, NULL, NULL, r12vrr_stack+620);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1350, r12vrr_stack+1287, r12vrr_stack+1224, r12vrr_stack+1182, r12vrr_stack+1161, r12vrr_stack+665);
 tmp = r12vrr_stack + 1350;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+18, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+274, r12vrr_stack+15, r12vrr_stack+18, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1476, r12vrr_stack+845, r12vrr_stack+274, r12vrr_stack+3, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1486, r12vrr_stack+851, r12vrr_stack+1476, r12vrr_stack+354, r12vrr_stack+845, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1501, r12vrr_stack+861, r12vrr_stack+1486, r12vrr_stack+360, r12vrr_stack+851, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1522, r12vrr_stack+1203, r12vrr_stack+1501, NULL, NULL, r12vrr_stack+861);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1585, r12vrr_stack+1224, r12vrr_stack+1522, r12vrr_stack+1161, r12vrr_stack+1203, r12vrr_stack+876);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1711, r12vrr_stack+1350, r12vrr_stack+1585, r12vrr_stack+1287, r12vrr_stack+1224, r12vrr_stack+921);
 tmp = r12vrr_stack + 1711;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1921, r12vrr_stack+1161, r12vrr_stack+1203, r12vrr_stack+620, r12vrr_stack+650, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1949, r12vrr_stack+1182, r12vrr_stack+1161, r12vrr_stack+635, r12vrr_stack+620, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1977, r12vrr_stack+1203, r12vrr_stack+1501, r12vrr_stack+650, r12vrr_stack+861, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2005, r12vrr_stack+1921, r12vrr_stack+1977, NULL, NULL, r12vrr_stack+1203);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2089, r12vrr_stack+1949, r12vrr_stack+1921, NULL, NULL, r12vrr_stack+1161);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2173, r12vrr_stack+2089, r12vrr_stack+2005, r12vrr_stack+1949, r12vrr_stack+1921, r12vrr_stack+1224);
 tmp = r12vrr_stack + 2173;
 target_ptr = Libr12->gvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+620, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+623, r12vrr_stack+18, r12vrr_stack+620, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2341, r12vrr_stack+274, r12vrr_stack+623, r12vrr_stack+15, r12vrr_stack+18, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2351, r12vrr_stack+1476, r12vrr_stack+2341, r12vrr_stack+845, r12vrr_stack+274, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2366, r12vrr_stack+1486, r12vrr_stack+2351, r12vrr_stack+851, r12vrr_stack+1476, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2387, r12vrr_stack+1501, r12vrr_stack+2366, r12vrr_stack+861, r12vrr_stack+1486, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2415, r12vrr_stack+1977, r12vrr_stack+2387, NULL, NULL, r12vrr_stack+1501);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2499, r12vrr_stack+2005, r12vrr_stack+2415, r12vrr_stack+1921, r12vrr_stack+1977, r12vrr_stack+1522);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2667, r12vrr_stack+2173, r12vrr_stack+2499, r12vrr_stack+2089, r12vrr_stack+2005, r12vrr_stack+1585);
 tmp = r12vrr_stack + 2667;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2947, r12vrr_stack+1921, r12vrr_stack+1977, r12vrr_stack+1161, r12vrr_stack+1203, NULL);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2983, r12vrr_stack+1949, r12vrr_stack+1921, r12vrr_stack+1182, r12vrr_stack+1161, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3019, r12vrr_stack+1977, r12vrr_stack+2387, r12vrr_stack+1203, r12vrr_stack+1501, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3055, r12vrr_stack+2947, r12vrr_stack+3019, NULL, NULL, r12vrr_stack+1977);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3163, r12vrr_stack+2983, r12vrr_stack+2947, NULL, NULL, r12vrr_stack+1921);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3271, r12vrr_stack+3163, r12vrr_stack+3055, r12vrr_stack+2983, r12vrr_stack+2947, r12vrr_stack+2005);
 tmp = r12vrr_stack + 3271;
 target_ptr = Libr12->gvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+15, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (d0|00)^2 ---*/
 _BUILD_d000(Data,r12vrr_stack+629, r12vrr_stack+111, r12vrr_stack+15, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+2983, r12vrr_stack+30, r12vrr_stack+141, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2992, r12vrr_stack+114, r12vrr_stack+2983, r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+15);

 /*--- compute (f0|p0)^1 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+3487, r12vrr_stack+123, r12vrr_stack+2992, r12vrr_stack+6, r12vrr_stack+114, r12vrr_stack+629);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1921, r12vrr_stack+144, r12vrr_stack+354, NULL, NULL, r12vrr_stack+141);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+3517, r12vrr_stack+150, r12vrr_stack+1921, r12vrr_stack+33, r12vrr_stack+144, r12vrr_stack+2983);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+3553, r12vrr_stack+168, r12vrr_stack+3517, r12vrr_stack+39, r12vrr_stack+150, r12vrr_stack+2992);

 /*--- compute (g0|d0)^0 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+3613, r12vrr_stack+204, r12vrr_stack+3553, r12vrr_stack+75, r12vrr_stack+168, r12vrr_stack+3487);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+3703, r12vrr_stack+360, r12vrr_stack+851, NULL, NULL, r12vrr_stack+354);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3733, r12vrr_stack+370, r12vrr_stack+3703, r12vrr_stack+264, r12vrr_stack+360, r12vrr_stack+1921);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+3793, r12vrr_stack+400, r12vrr_stack+3733, r12vrr_stack+284, r12vrr_stack+370, r12vrr_stack+3517);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+3893, r12vrr_stack+520, r12vrr_stack+3793, r12vrr_stack+460, r12vrr_stack+400, r12vrr_stack+3553);
 tmp = r12vrr_stack + 3893;
 target_ptr = Libr12->gvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+4043, r12vrr_stack+861, r12vrr_stack+1486, NULL, NULL, r12vrr_stack+851);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+4088, r12vrr_stack+876, r12vrr_stack+4043, r12vrr_stack+650, r12vrr_stack+861, r12vrr_stack+3703);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+4178, r12vrr_stack+921, r12vrr_stack+4088, r12vrr_stack+665, r12vrr_stack+876, r12vrr_stack+3733);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+4328, r12vrr_stack+1011, r12vrr_stack+4178, r12vrr_stack+755, r12vrr_stack+921, r12vrr_stack+3793);
 tmp = r12vrr_stack + 4328;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4553, r12vrr_stack+1501, r12vrr_stack+2366, NULL, NULL, r12vrr_stack+1486);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4616, r12vrr_stack+1522, r12vrr_stack+4553, r12vrr_stack+1203, r12vrr_stack+1501, r12vrr_stack+4043);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4742, r12vrr_stack+1585, r12vrr_stack+4616, r12vrr_stack+1224, r12vrr_stack+1522, r12vrr_stack+4088);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4952, r12vrr_stack+1711, r12vrr_stack+4742, r12vrr_stack+1350, r12vrr_stack+1585, r12vrr_stack+4178);
 tmp = r12vrr_stack + 4952;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1203, r12vrr_stack+620, r12vrr_stack+0, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+623, r12vrr_stack+1203, r12vrr_stack+18, r12vrr_stack+620, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1209, r12vrr_stack+2341, r12vrr_stack+264, r12vrr_stack+274, r12vrr_stack+623, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1161, r12vrr_stack+2351, r12vrr_stack+1209, r12vrr_stack+1476, r12vrr_stack+2341, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+274, r12vrr_stack+2366, r12vrr_stack+1161, r12vrr_stack+1486, r12vrr_stack+2351, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5267, r12vrr_stack+2387, r12vrr_stack+274, NULL, NULL, r12vrr_stack+2366);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5351, r12vrr_stack+2415, r12vrr_stack+5267, r12vrr_stack+1977, r12vrr_stack+2387, r12vrr_stack+4553);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5519, r12vrr_stack+2499, r12vrr_stack+5351, r12vrr_stack+2005, r12vrr_stack+2415, r12vrr_stack+4616);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5799, r12vrr_stack+2667, r12vrr_stack+5519, r12vrr_stack+2173, r12vrr_stack+2499, r12vrr_stack+4742);
 tmp = r12vrr_stack + 5799;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1977, r12vrr_stack+2387, r12vrr_stack+274, r12vrr_stack+1501, r12vrr_stack+2366, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6219, r12vrr_stack+3019, r12vrr_stack+1977, NULL, NULL, r12vrr_stack+2387);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6327, r12vrr_stack+3055, r12vrr_stack+6219, r12vrr_stack+2947, r12vrr_stack+3019, r12vrr_stack+2415);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6543, r12vrr_stack+3271, r12vrr_stack+6327, r12vrr_stack+3163, r12vrr_stack+3055, r12vrr_stack+2499);
 tmp = r12vrr_stack + 6543;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+18, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+2947, r12vrr_stack+15, r12vrr_stack+18, Data->F+3, Data->F+4, NULL);

 /*--- compute (f0|00)^2 ---*/
 _BUILD_f000(Data,r12vrr_stack+1939, r12vrr_stack+629, r12vrr_stack+2947, r12vrr_stack+111, r12vrr_stack+15, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+3010, r12vrr_stack+141, r12vrr_stack+3, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2953, r12vrr_stack+2983, r12vrr_stack+3010, r12vrr_stack+30, r12vrr_stack+141, r12vrr_stack+18);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+2013, r12vrr_stack+2992, r12vrr_stack+2953, r12vrr_stack+114, r12vrr_stack+2983, r12vrr_stack+2947);

 /*--- compute (g0|p0)^1 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+2043, r12vrr_stack+3487, r12vrr_stack+2013, r12vrr_stack+123, r12vrr_stack+2992, r12vrr_stack+1939);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+3487, r12vrr_stack+354, r12vrr_stack+845, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+2971, r12vrr_stack+1921, r12vrr_stack+3487, r12vrr_stack+144, r12vrr_stack+354, r12vrr_stack+3010);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+650, r12vrr_stack+3517, r12vrr_stack+2971, r12vrr_stack+150, r12vrr_stack+1921, r12vrr_stack+2953);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+6903, r12vrr_stack+3553, r12vrr_stack+650, r12vrr_stack+168, r12vrr_stack+3517, r12vrr_stack+2013);

 /*--- compute (h0|d0)^0 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+6993, r12vrr_stack+3613, r12vrr_stack+6903, r12vrr_stack+204, r12vrr_stack+3553, r12vrr_stack+2043);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+2013, r12vrr_stack+851, r12vrr_stack+1476, NULL, NULL, r12vrr_stack+845);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3505, r12vrr_stack+3703, r12vrr_stack+2013, r12vrr_stack+360, r12vrr_stack+851, r12vrr_stack+3487);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+7119, r12vrr_stack+3733, r12vrr_stack+3505, r12vrr_stack+370, r12vrr_stack+3703, r12vrr_stack+2971);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+7219, r12vrr_stack+3793, r12vrr_stack+7119, r12vrr_stack+400, r12vrr_stack+3733, r12vrr_stack+650);

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+7369, r12vrr_stack+3893, r12vrr_stack+7219, r12vrr_stack+520, r12vrr_stack+3793, r12vrr_stack+6903);
 tmp = r12vrr_stack + 7369;
 target_ptr = Libr12->gvrr_classes[5][3];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+6903, r12vrr_stack+1486, r12vrr_stack+2351, NULL, NULL, r12vrr_stack+1476);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3703, r12vrr_stack+4043, r12vrr_stack+6903, r12vrr_stack+861, r12vrr_stack+1486, r12vrr_stack+2013);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+7579, r12vrr_stack+4088, r12vrr_stack+3703, r12vrr_stack+876, r12vrr_stack+4043, r12vrr_stack+3505);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+7729, r12vrr_stack+4178, r12vrr_stack+7579, r12vrr_stack+921, r12vrr_stack+4088, r12vrr_stack+7119);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+7954, r12vrr_stack+4328, r12vrr_stack+7729, r12vrr_stack+1011, r12vrr_stack+4178, r12vrr_stack+7219);
 tmp = r12vrr_stack + 7954;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1224, r12vrr_stack+2366, r12vrr_stack+1161, NULL, NULL, r12vrr_stack+2351);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3487, r12vrr_stack+4553, r12vrr_stack+1224, r12vrr_stack+1501, r12vrr_stack+2366, r12vrr_stack+6903);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+7119, r12vrr_stack+4616, r12vrr_stack+3487, r12vrr_stack+1522, r12vrr_stack+4553, r12vrr_stack+3703);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+8269, r12vrr_stack+4742, r12vrr_stack+7119, r12vrr_stack+1585, r12vrr_stack+4616, r12vrr_stack+7579);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+8584, r12vrr_stack+4952, r12vrr_stack+8269, r12vrr_stack+1711, r12vrr_stack+4742, r12vrr_stack+7729);
 tmp = r12vrr_stack + 8584;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+7579, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+629, r12vrr_stack+0, r12vrr_stack+7579, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+7579, r12vrr_stack+1203, r12vrr_stack+629, r12vrr_stack+620, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+264, r12vrr_stack+7579, r12vrr_stack+623, r12vrr_stack+1203, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+7579, r12vrr_stack+1209, r12vrr_stack+0, r12vrr_stack+2341, r12vrr_stack+264, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1921, r12vrr_stack+1161, r12vrr_stack+7579, r12vrr_stack+2351, r12vrr_stack+1209, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7579, r12vrr_stack+274, r12vrr_stack+1921, NULL, NULL, r12vrr_stack+1161);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7663, r12vrr_stack+5267, r12vrr_stack+7579, r12vrr_stack+2387, r12vrr_stack+274, r12vrr_stack+1224);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4553, r12vrr_stack+5351, r12vrr_stack+7663, r12vrr_stack+2415, r12vrr_stack+5267, r12vrr_stack+3487);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+9025, r12vrr_stack+5519, r12vrr_stack+4553, r12vrr_stack+2499, r12vrr_stack+5351, r12vrr_stack+7119);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+9445, r12vrr_stack+5799, r12vrr_stack+9025, r12vrr_stack+2667, r12vrr_stack+5519, r12vrr_stack+8269);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8269, r12vrr_stack+274, r12vrr_stack+1921, r12vrr_stack+2366, r12vrr_stack+1161, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8305, r12vrr_stack+1977, r12vrr_stack+8269, NULL, NULL, r12vrr_stack+274);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9025, r12vrr_stack+6219, r12vrr_stack+8305, r12vrr_stack+3019, r12vrr_stack+1977, r12vrr_stack+5267);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4553, r12vrr_stack+6327, r12vrr_stack+9025, r12vrr_stack+3055, r12vrr_stack+6219, r12vrr_stack+5351);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10033, r12vrr_stack+6543, r12vrr_stack+4553, r12vrr_stack+3271, r12vrr_stack+6327, r12vrr_stack+5519);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+4553, &(Data->ss_r12_ss), NULL, r12vrr_stack+21, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+4556, r12vrr_stack+4553, &(Data->ss_r12_ss), r12vrr_stack+24, r12vrr_stack+21, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+4562, r12vrr_stack+4556, r12vrr_stack+4553, r12vrr_stack+314, r12vrr_stack+24, r12vrr_stack+21, NULL);

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+4572, r12vrr_stack+4562, NULL, r12vrr_stack+324, r12vrr_stack+314, NULL, r12vrr_stack+24);

 /*--- compute (d0||f0)^0 ---*/
 _R_BUILD_d0f0(Data,r12vrr_stack+650, r12vrr_stack+4572, r12vrr_stack+4562, r12vrr_stack+460, r12vrr_stack+324, r12vrr_stack+314, r12vrr_stack+57);
 tmp = r12vrr_stack + 650;
 target_ptr = Libr12->rvrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||f0)^0 ---*/
 _R_BUILD_f0f0(Data,r12vrr_stack+4602, r12vrr_stack+650, r12vrr_stack+4572, r12vrr_stack+520, r12vrr_stack+460, r12vrr_stack+324, r12vrr_stack+75);
 tmp = r12vrr_stack + 4602;
 target_ptr = Libr12->rvrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+620, r12vrr_stack+4562, r12vrr_stack+4556, r12vrr_stack+635, r12vrr_stack+314, r12vrr_stack+24, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+4702, r12vrr_stack+620, NULL, r12vrr_stack+710, r12vrr_stack+635, NULL, r12vrr_stack+314);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+6903, r12vrr_stack+4702, r12vrr_stack+620, r12vrr_stack+755, r12vrr_stack+710, r12vrr_stack+635, r12vrr_stack+324);
 tmp = r12vrr_stack + 6903;
 target_ptr = Libr12->rvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+4747, r12vrr_stack+6903, r12vrr_stack+4702, r12vrr_stack+1011, r12vrr_stack+755, r12vrr_stack+710, r12vrr_stack+460);
 tmp = r12vrr_stack + 4747;
 target_ptr = Libr12->rvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+1161, r12vrr_stack+620, r12vrr_stack+4562, r12vrr_stack+1182, r12vrr_stack+635, r12vrr_stack+314, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+6219, r12vrr_stack+1161, NULL, r12vrr_stack+1287, r12vrr_stack+1182, NULL, r12vrr_stack+635);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+3487, r12vrr_stack+6219, r12vrr_stack+1161, r12vrr_stack+1350, r12vrr_stack+1287, r12vrr_stack+1182, r12vrr_stack+710);
 tmp = r12vrr_stack + 3487;
 target_ptr = Libr12->rvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+6282, r12vrr_stack+3487, r12vrr_stack+6219, r12vrr_stack+1711, r12vrr_stack+1350, r12vrr_stack+1287, r12vrr_stack+755);
 tmp = r12vrr_stack + 6282;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+1921, r12vrr_stack+1161, r12vrr_stack+620, r12vrr_stack+1949, r12vrr_stack+1182, r12vrr_stack+635, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+1203, r12vrr_stack+1921, NULL, r12vrr_stack+2089, r12vrr_stack+1949, NULL, r12vrr_stack+1182);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+9025, r12vrr_stack+1203, r12vrr_stack+1921, r12vrr_stack+2173, r12vrr_stack+2089, r12vrr_stack+1949, r12vrr_stack+1287);
 tmp = r12vrr_stack + 9025;
 target_ptr = Libr12->rvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+5267, r12vrr_stack+9025, r12vrr_stack+1203, r12vrr_stack+2667, r12vrr_stack+2173, r12vrr_stack+2089, r12vrr_stack+1350);
 tmp = r12vrr_stack + 5267;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_d0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+264, r12vrr_stack+460, r12vrr_stack+755, r12vrr_stack+520, r12vrr_stack+204, r12vrr_stack+75);
 tmp = r12vrr_stack + 264;
 target_ptr = Libr12->t2vrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_d0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1921, r12vrr_stack+755, r12vrr_stack+1350, r12vrr_stack+1011, r12vrr_stack+520, r12vrr_stack+460);
 tmp = r12vrr_stack + 1921;
 target_ptr = Libr12->t2vrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1161, r12vrr_stack+1350, r12vrr_stack+2173, r12vrr_stack+1711, r12vrr_stack+1011, r12vrr_stack+755);
 tmp = r12vrr_stack + 1161;
 target_ptr = Libr12->t2vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9193, r12vrr_stack+2173, r12vrr_stack+3271, r12vrr_stack+2667, r12vrr_stack+1711, r12vrr_stack+1350);
 tmp = r12vrr_stack + 9193;
 target_ptr = Libr12->t2vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_f0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5547, r12vrr_stack+520, r12vrr_stack+1011, r12vrr_stack+3893, r12vrr_stack+3613, r12vrr_stack+204);
 tmp = r12vrr_stack + 5547;
 target_ptr = Libr12->t2vrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5647, r12vrr_stack+1011, r12vrr_stack+1711, r12vrr_stack+4328, r12vrr_stack+3893, r12vrr_stack+520);
 tmp = r12vrr_stack + 5647;
 target_ptr = Libr12->t2vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8269, r12vrr_stack+1711, r12vrr_stack+2667, r12vrr_stack+4952, r12vrr_stack+4328, r12vrr_stack+1011);
 tmp = r12vrr_stack + 8269;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7579, r12vrr_stack+2667, r12vrr_stack+6543, r12vrr_stack+5799, r12vrr_stack+4952, r12vrr_stack+1711);
 tmp = r12vrr_stack + 7579;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_g0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7119, r12vrr_stack+3893, r12vrr_stack+4328, r12vrr_stack+7369, r12vrr_stack+6993, r12vrr_stack+3613);
 tmp = r12vrr_stack + 7119;
 target_ptr = Libr12->t2vrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3613, r12vrr_stack+4328, r12vrr_stack+4952, r12vrr_stack+7954, r12vrr_stack+7369, r12vrr_stack+3893);
 tmp = r12vrr_stack + 3613;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2341, r12vrr_stack+4952, r12vrr_stack+5799, r12vrr_stack+8584, r12vrr_stack+7954, r12vrr_stack+4328);
 tmp = r12vrr_stack + 2341;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10573, r12vrr_stack+5799, r12vrr_stack+10033, r12vrr_stack+9445, r12vrr_stack+8584, r12vrr_stack+4952);
 tmp = r12vrr_stack + 10573;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_d0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6993, r12vrr_stack+460, r12vrr_stack+520, r12vrr_stack+755, r12vrr_stack+710, r12vrr_stack+324);
 tmp = r12vrr_stack + 6993;
 target_ptr = Libr12->t1vrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_d0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+324, r12vrr_stack+755, r12vrr_stack+1011, r12vrr_stack+1350, r12vrr_stack+1287, r12vrr_stack+710);
 tmp = r12vrr_stack + 324;
 target_ptr = Libr12->t1vrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+1350, r12vrr_stack+1711, r12vrr_stack+2173, r12vrr_stack+2089, r12vrr_stack+1287);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t1vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4043, r12vrr_stack+2173, r12vrr_stack+2667, r12vrr_stack+3271, r12vrr_stack+3163, r12vrr_stack+2089);
 tmp = r12vrr_stack + 4043;
 target_ptr = Libr12->t1vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_f0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7269, r12vrr_stack+520, r12vrr_stack+3893, r12vrr_stack+1011, r12vrr_stack+755, r12vrr_stack+460);
 tmp = r12vrr_stack + 7269;
 target_ptr = Libr12->t1vrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2011, r12vrr_stack+1011, r12vrr_stack+4328, r12vrr_stack+1711, r12vrr_stack+1350, r12vrr_stack+755);
 tmp = r12vrr_stack + 2011;
 target_ptr = Libr12->t1vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1476, r12vrr_stack+1711, r12vrr_stack+4952, r12vrr_stack+2667, r12vrr_stack+2173, r12vrr_stack+1350);
 tmp = r12vrr_stack + 1476;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2947, r12vrr_stack+2667, r12vrr_stack+5799, r12vrr_stack+6543, r12vrr_stack+3271, r12vrr_stack+2173);
 tmp = r12vrr_stack + 2947;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_g0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+845, r12vrr_stack+3893, r12vrr_stack+7369, r12vrr_stack+4328, r12vrr_stack+1011, r12vrr_stack+520);
 tmp = r12vrr_stack + 845;
 target_ptr = Libr12->t1vrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3227, r12vrr_stack+4328, r12vrr_stack+7954, r12vrr_stack+4952, r12vrr_stack+1711, r12vrr_stack+1011);
 tmp = r12vrr_stack + 3227;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7859, r12vrr_stack+4952, r12vrr_stack+8584, r12vrr_stack+5799, r12vrr_stack+2667, r12vrr_stack+1711);
 tmp = r12vrr_stack + 7859;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8479, r12vrr_stack+5799, r12vrr_stack+9445, r12vrr_stack+10033, r12vrr_stack+6543, r12vrr_stack+2667);
 tmp = r12vrr_stack + 8479;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||f0)^0 ---*/
 _R_BUILD_g0f0(Data,r12vrr_stack+7369, r12vrr_stack+4602, r12vrr_stack+650, r12vrr_stack+3893, r12vrr_stack+520, r12vrr_stack+460, r12vrr_stack+204);
 tmp = r12vrr_stack + 7369;
 target_ptr = Libr12->rvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+6492, r12vrr_stack+4747, r12vrr_stack+6903, r12vrr_stack+4328, r12vrr_stack+1011, r12vrr_stack+755, r12vrr_stack+520);
 tmp = r12vrr_stack + 6492;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+414, r12vrr_stack+6282, r12vrr_stack+3487, r12vrr_stack+4952, r12vrr_stack+1711, r12vrr_stack+1350, r12vrr_stack+1011);
 tmp = r12vrr_stack + 414;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+9361, r12vrr_stack+5267, r12vrr_stack+9025, r12vrr_stack+5799, r12vrr_stack+2667, r12vrr_stack+2173, r12vrr_stack+1711);
 tmp = r12vrr_stack + 9361;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];


}

