/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_f0hf(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+49, r12vrr_stack+12, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+12, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+68, r12vrr_stack+3, r12vrr_stack+12, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+84, r12vrr_stack+39, r12vrr_stack+74, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+58, r12vrr_stack+39, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+21);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+204, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+219, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+234, r12vrr_stack+219, r12vrr_stack+204, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+279, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+282, r12vrr_stack+279, r12vrr_stack+49, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+52, r12vrr_stack+279, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+58, r12vrr_stack+282, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+313, r12vrr_stack+298, r12vrr_stack+219, NULL, NULL, r12vrr_stack+58);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+12, r12vrr_stack+49, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+358, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+3, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+368, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+6, r12vrr_stack+68, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+383, r12vrr_stack+204, r12vrr_stack+368, NULL, NULL, r12vrr_stack+74);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+428, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+84);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+518, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+114);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+608, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+144);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+758, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+767, r12vrr_stack+6, r12vrr_stack+68, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+785, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+758);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+821, r12vrr_stack+74, r12vrr_stack+358, NULL, NULL, r12vrr_stack+68);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+851, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+767);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+911, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+785);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+84, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+49, r12vrr_stack+84, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+52, r12vrr_stack+87, r12vrr_stack+12, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+103, r12vrr_stack+358, r12vrr_stack+93, r12vrr_stack+68, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+118, r12vrr_stack+368, r12vrr_stack+103, NULL, NULL, r12vrr_stack+358);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1011, r12vrr_stack+383, r12vrr_stack+118, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+821);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1101, r12vrr_stack+428, r12vrr_stack+1011, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+851);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1251, r12vrr_stack+608, r12vrr_stack+1101, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+911);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+163, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+39, r12vrr_stack+74, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+758, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+779, r12vrr_stack+368, r12vrr_stack+103, r12vrr_stack+74, r12vrr_stack+358, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+800, r12vrr_stack+163, r12vrr_stack+779, NULL, NULL, r12vrr_stack+368);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+863, r12vrr_stack+758, r12vrr_stack+163, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1476, r12vrr_stack+863, r12vrr_stack+800, r12vrr_stack+758, r12vrr_stack+163, r12vrr_stack+383);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+383, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+288, r12vrr_stack+58, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+926, r12vrr_stack+383, r12vrr_stack+758, NULL, NULL, r12vrr_stack+219);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1602, r12vrr_stack+926, r12vrr_stack+863, r12vrr_stack+383, r12vrr_stack+758, r12vrr_stack+234);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+234, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+237, r12vrr_stack+84, r12vrr_stack+234, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+243, r12vrr_stack+87, r12vrr_stack+237, r12vrr_stack+49, r12vrr_stack+84, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+253, r12vrr_stack+93, r12vrr_stack+243, r12vrr_stack+52, r12vrr_stack+87, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+404, r12vrr_stack+103, r12vrr_stack+253, r12vrr_stack+358, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+0, r12vrr_stack+779, r12vrr_stack+404, NULL, NULL, r12vrr_stack+103);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1728, r12vrr_stack+800, r12vrr_stack+0, r12vrr_stack+163, r12vrr_stack+779, r12vrr_stack+118);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1854, r12vrr_stack+1476, r12vrr_stack+1728, r12vrr_stack+863, r12vrr_stack+800, r12vrr_stack+1011);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2064, r12vrr_stack+1602, r12vrr_stack+1476, r12vrr_stack+926, r12vrr_stack+863, r12vrr_stack+428);
 tmp = r12vrr_stack + 2064;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2274, r12vrr_stack+2064, r12vrr_stack+1854, r12vrr_stack+1602, r12vrr_stack+1476, r12vrr_stack+1101);
 tmp = r12vrr_stack + 2274;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+118, r12vrr_stack+163, r12vrr_stack+779, r12vrr_stack+204, r12vrr_stack+368, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+425, r12vrr_stack+758, r12vrr_stack+163, r12vrr_stack+219, r12vrr_stack+204, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+989, r12vrr_stack+425, r12vrr_stack+118, NULL, NULL, r12vrr_stack+163);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+453, r12vrr_stack+383, r12vrr_stack+758, r12vrr_stack+298, r12vrr_stack+219, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1073, r12vrr_stack+453, r12vrr_stack+425, NULL, NULL, r12vrr_stack+758);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+481, r12vrr_stack+779, r12vrr_stack+404, r12vrr_stack+368, r12vrr_stack+103, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1157, r12vrr_stack+118, r12vrr_stack+481, NULL, NULL, r12vrr_stack+779);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2589, r12vrr_stack+989, r12vrr_stack+1157, r12vrr_stack+425, r12vrr_stack+118, r12vrr_stack+800);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2757, r12vrr_stack+1073, r12vrr_stack+989, r12vrr_stack+453, r12vrr_stack+425, r12vrr_stack+863);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2925, r12vrr_stack+2757, r12vrr_stack+2589, r12vrr_stack+1073, r12vrr_stack+989, r12vrr_stack+1476);
 tmp = r12vrr_stack + 2925;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1476, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1479, r12vrr_stack+234, r12vrr_stack+1476, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1241, r12vrr_stack+237, r12vrr_stack+1479, r12vrr_stack+84, r12vrr_stack+234, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1485, r12vrr_stack+243, r12vrr_stack+1241, r12vrr_stack+87, r12vrr_stack+237, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1500, r12vrr_stack+253, r12vrr_stack+1485, r12vrr_stack+93, r12vrr_stack+243, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1521, r12vrr_stack+404, r12vrr_stack+1500, r12vrr_stack+103, r12vrr_stack+253, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+800, r12vrr_stack+481, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+404);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3205, r12vrr_stack+1157, r12vrr_stack+800, r12vrr_stack+118, r12vrr_stack+481, r12vrr_stack+0);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3373, r12vrr_stack+2589, r12vrr_stack+3205, r12vrr_stack+989, r12vrr_stack+1157, r12vrr_stack+1728);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+3653, r12vrr_stack+2925, r12vrr_stack+3373, r12vrr_stack+2757, r12vrr_stack+2589, r12vrr_stack+1854);
 tmp = r12vrr_stack + 3653;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1728, r12vrr_stack+118, r12vrr_stack+481, r12vrr_stack+163, r12vrr_stack+779, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1764, r12vrr_stack+425, r12vrr_stack+118, r12vrr_stack+758, r12vrr_stack+163, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1800, r12vrr_stack+1764, r12vrr_stack+1728, NULL, NULL, r12vrr_stack+118);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1908, r12vrr_stack+453, r12vrr_stack+425, r12vrr_stack+383, r12vrr_stack+758, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1944, r12vrr_stack+1908, r12vrr_stack+1764, NULL, NULL, r12vrr_stack+425);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+481, r12vrr_stack+1521, r12vrr_stack+779, r12vrr_stack+404, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4073, r12vrr_stack+1728, r12vrr_stack+0, NULL, NULL, r12vrr_stack+481);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4181, r12vrr_stack+1800, r12vrr_stack+4073, r12vrr_stack+1764, r12vrr_stack+1728, r12vrr_stack+1157);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4397, r12vrr_stack+1944, r12vrr_stack+1800, r12vrr_stack+1908, r12vrr_stack+1764, r12vrr_stack+989);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4613, r12vrr_stack+4397, r12vrr_stack+4181, r12vrr_stack+1944, r12vrr_stack+1800, r12vrr_stack+2589);
 tmp = r12vrr_stack + 4613;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+2589, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2592, r12vrr_stack+1476, r12vrr_stack+2589, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2598, r12vrr_stack+1479, r12vrr_stack+2592, r12vrr_stack+234, r12vrr_stack+1476, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2608, r12vrr_stack+1241, r12vrr_stack+2598, r12vrr_stack+237, r12vrr_stack+1479, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2623, r12vrr_stack+1485, r12vrr_stack+2608, r12vrr_stack+243, r12vrr_stack+1241, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4973, r12vrr_stack+1500, r12vrr_stack+2623, r12vrr_stack+253, r12vrr_stack+1485, NULL);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2644, r12vrr_stack+1521, r12vrr_stack+4973, r12vrr_stack+404, r12vrr_stack+1500, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+146, r12vrr_stack+0, r12vrr_stack+2644, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5001, r12vrr_stack+4073, r12vrr_stack+146, r12vrr_stack+1728, r12vrr_stack+0, r12vrr_stack+800);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5217, r12vrr_stack+4181, r12vrr_stack+5001, r12vrr_stack+1800, r12vrr_stack+4073, r12vrr_stack+3205);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5577, r12vrr_stack+4613, r12vrr_stack+5217, r12vrr_stack+4397, r12vrr_stack+4181, r12vrr_stack+3373);
 tmp = r12vrr_stack + 5577;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3205, r12vrr_stack+1728, r12vrr_stack+0, r12vrr_stack+118, r12vrr_stack+481, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3250, r12vrr_stack+1764, r12vrr_stack+1728, r12vrr_stack+425, r12vrr_stack+118, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3295, r12vrr_stack+3250, r12vrr_stack+3205, NULL, NULL, r12vrr_stack+1728);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3430, r12vrr_stack+1908, r12vrr_stack+1764, r12vrr_stack+453, r12vrr_stack+425, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3475, r12vrr_stack+3430, r12vrr_stack+3250, NULL, NULL, r12vrr_stack+1764);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+404, r12vrr_stack+0, r12vrr_stack+2644, r12vrr_stack+481, r12vrr_stack+1521, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+758, r12vrr_stack+3205, r12vrr_stack+404, NULL, NULL, r12vrr_stack+0);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6117, r12vrr_stack+3295, r12vrr_stack+758, r12vrr_stack+3250, r12vrr_stack+3205, r12vrr_stack+4073);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6387, r12vrr_stack+3475, r12vrr_stack+3295, r12vrr_stack+3430, r12vrr_stack+3250, r12vrr_stack+1800);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6657, r12vrr_stack+6387, r12vrr_stack+6117, r12vrr_stack+3475, r12vrr_stack+3295, r12vrr_stack+4181);
 tmp = r12vrr_stack + 6657;
 target_ptr = Libr12->gvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1800, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1803, r12vrr_stack+2589, r12vrr_stack+1800, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1809, r12vrr_stack+2592, r12vrr_stack+1803, r12vrr_stack+1476, r12vrr_stack+2589, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1819, r12vrr_stack+2598, r12vrr_stack+1809, r12vrr_stack+1479, r12vrr_stack+2592, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1834, r12vrr_stack+2608, r12vrr_stack+1819, r12vrr_stack+1241, r12vrr_stack+2598, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1800, r12vrr_stack+2623, r12vrr_stack+1834, r12vrr_stack+1485, r12vrr_stack+2608, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1828, r12vrr_stack+4973, r12vrr_stack+1800, r12vrr_stack+1500, r12vrr_stack+2623, NULL);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1476, r12vrr_stack+2644, r12vrr_stack+1828, r12vrr_stack+1521, r12vrr_stack+4973, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+4073, r12vrr_stack+404, r12vrr_stack+1476, NULL, NULL, r12vrr_stack+2644);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7107, r12vrr_stack+758, r12vrr_stack+4073, r12vrr_stack+3205, r12vrr_stack+404, r12vrr_stack+146);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7377, r12vrr_stack+6117, r12vrr_stack+7107, r12vrr_stack+3295, r12vrr_stack+758, r12vrr_stack+5001);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7827, r12vrr_stack+6657, r12vrr_stack+7377, r12vrr_stack+6387, r12vrr_stack+6117, r12vrr_stack+5217);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2589, r12vrr_stack+3205, r12vrr_stack+404, r12vrr_stack+1728, r12vrr_stack+0, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7107, r12vrr_stack+3250, r12vrr_stack+3205, r12vrr_stack+1764, r12vrr_stack+1728, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7162, r12vrr_stack+7107, r12vrr_stack+2589, NULL, NULL, r12vrr_stack+3205);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7327, r12vrr_stack+3430, r12vrr_stack+3250, r12vrr_stack+1908, r12vrr_stack+1764, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+1728, r12vrr_stack+7327, r12vrr_stack+7107, NULL, NULL, r12vrr_stack+3250);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+3205, r12vrr_stack+404, r12vrr_stack+1476, r12vrr_stack+0, r12vrr_stack+2644, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+2589, r12vrr_stack+3205, NULL, NULL, r12vrr_stack+404);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7382, r12vrr_stack+7162, r12vrr_stack+0, r12vrr_stack+7107, r12vrr_stack+2589, r12vrr_stack+758);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4973, r12vrr_stack+1728, r12vrr_stack+7162, r12vrr_stack+7327, r12vrr_stack+7107, r12vrr_stack+3295);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+8502, r12vrr_stack+4973, r12vrr_stack+7382, r12vrr_stack+1728, r12vrr_stack+7162, r12vrr_stack+6117);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+6117, &(Data->ss_r12_ss), NULL, r12vrr_stack+279, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+6120, r12vrr_stack+6117, &(Data->ss_r12_ss), r12vrr_stack+282, r12vrr_stack+279, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+6126, r12vrr_stack+6120, r12vrr_stack+6117, r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+279, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+6136, r12vrr_stack+6126, r12vrr_stack+6120, r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+282, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+6151, r12vrr_stack+6136, r12vrr_stack+6126, r12vrr_stack+383, r12vrr_stack+298, r12vrr_stack+288, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+6172, r12vrr_stack+6151, NULL, r12vrr_stack+926, r12vrr_stack+383, NULL, r12vrr_stack+298);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+1476, r12vrr_stack+6172, r12vrr_stack+6151, r12vrr_stack+1602, r12vrr_stack+926, r12vrr_stack+383, r12vrr_stack+313);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+313, r12vrr_stack+6151, r12vrr_stack+6136, r12vrr_stack+453, r12vrr_stack+383, r12vrr_stack+298, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+989, r12vrr_stack+313, NULL, r12vrr_stack+1073, r12vrr_stack+453, NULL, r12vrr_stack+383);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+758, r12vrr_stack+989, r12vrr_stack+313, r12vrr_stack+2757, r12vrr_stack+1073, r12vrr_stack+453, r12vrr_stack+926);

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+341, r12vrr_stack+313, r12vrr_stack+6151, r12vrr_stack+1908, r12vrr_stack+453, r12vrr_stack+383, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+6235, r12vrr_stack+341, NULL, r12vrr_stack+1944, r12vrr_stack+1908, NULL, r12vrr_stack+453);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+7107, r12vrr_stack+6235, r12vrr_stack+341, r12vrr_stack+4397, r12vrr_stack+1944, r12vrr_stack+1908, r12vrr_stack+1073);

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+377, r12vrr_stack+341, r12vrr_stack+313, r12vrr_stack+3430, r12vrr_stack+1908, r12vrr_stack+453, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+1728, r12vrr_stack+377, NULL, r12vrr_stack+3475, r12vrr_stack+3430, NULL, r12vrr_stack+1908);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+7323, r12vrr_stack+1728, r12vrr_stack+377, r12vrr_stack+6387, r12vrr_stack+3475, r12vrr_stack+3430, r12vrr_stack+1944);

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7593, r12vrr_stack+2064, r12vrr_stack+2925, r12vrr_stack+2274, r12vrr_stack+1251, r12vrr_stack+608);
 tmp = r12vrr_stack + 7593;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+2925, r12vrr_stack+4613, r12vrr_stack+3653, r12vrr_stack+2274, r12vrr_stack+2064);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_f0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9052, r12vrr_stack+4613, r12vrr_stack+6657, r12vrr_stack+5577, r12vrr_stack+3653, r12vrr_stack+2925);
 tmp = r12vrr_stack + 9052;
 target_ptr = Libr12->t2vrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_f0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9412, r12vrr_stack+6657, r12vrr_stack+8502, r12vrr_stack+7827, r12vrr_stack+5577, r12vrr_stack+4613);
 tmp = r12vrr_stack + 9412;
 target_ptr = Libr12->t2vrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+280, r12vrr_stack+2064, r12vrr_stack+2274, r12vrr_stack+2925, r12vrr_stack+2757, r12vrr_stack+1602);
 tmp = r12vrr_stack + 280;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2274, r12vrr_stack+2925, r12vrr_stack+3653, r12vrr_stack+4613, r12vrr_stack+4397, r12vrr_stack+2757);
 tmp = r12vrr_stack + 2274;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_f0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3610, r12vrr_stack+4613, r12vrr_stack+5577, r12vrr_stack+6657, r12vrr_stack+6387, r12vrr_stack+4397);
 tmp = r12vrr_stack + 3610;
 target_ptr = Libr12->t1vrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_f0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5303, r12vrr_stack+6657, r12vrr_stack+7827, r12vrr_stack+8502, r12vrr_stack+4973, r12vrr_stack+6387);
 tmp = r12vrr_stack + 5303;
 target_ptr = Libr12->t1vrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+4973, r12vrr_stack+1476, r12vrr_stack+6172, r12vrr_stack+2064, r12vrr_stack+1602, r12vrr_stack+926, r12vrr_stack+518);
 tmp = r12vrr_stack + 4973;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+7803, r12vrr_stack+758, r12vrr_stack+989, r12vrr_stack+2925, r12vrr_stack+2757, r12vrr_stack+1073, r12vrr_stack+1602);
 tmp = r12vrr_stack + 7803;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+2925, r12vrr_stack+7107, r12vrr_stack+6235, r12vrr_stack+4613, r12vrr_stack+4397, r12vrr_stack+1944, r12vrr_stack+2757);
 tmp = r12vrr_stack + 2925;
 target_ptr = Libr12->rvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+8083, r12vrr_stack+7323, r12vrr_stack+1728, r12vrr_stack+6657, r12vrr_stack+6387, r12vrr_stack+3475, r12vrr_stack+4397);
 tmp = r12vrr_stack + 8083;
 target_ptr = Libr12->rvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];


}

