/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_p0dd(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (p0|p0)^0 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+1);

 /*--- compute (p0|00)^1 ---*/
 _BUILD_p000(Data,r12vrr_stack+15, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+18, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+0, r12vrr_stack+18, NULL, NULL, Data->F+2);

 /*--- compute (d0|p0)^0 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+15);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+0, r12vrr_stack+18, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+3, r12vrr_stack+0, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+60, r12vrr_stack+18, r12vrr_stack+15, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+66, r12vrr_stack+48, r12vrr_stack+60, NULL, NULL, r12vrr_stack+18);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+84, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+0);
 tmp = r12vrr_stack + 84;
 target_ptr = Libr12->gvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+102, r12vrr_stack+84, r12vrr_stack+66, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+21);
 tmp = r12vrr_stack + 102;
 target_ptr = Libr12->gvrr_classes[2][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+138, r12vrr_stack+48, r12vrr_stack+60, r12vrr_stack+0, r12vrr_stack+18, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+148, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+158, r12vrr_stack+148, r12vrr_stack+138, NULL, NULL, r12vrr_stack+48);
 tmp = r12vrr_stack + 158;
 target_ptr = Libr12->gvrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+188, r12vrr_stack+60, r12vrr_stack+21, r12vrr_stack+18, r12vrr_stack+15, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+198, r12vrr_stack+138, r12vrr_stack+188, NULL, NULL, r12vrr_stack+60);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+228, r12vrr_stack+158, r12vrr_stack+198, r12vrr_stack+148, r12vrr_stack+138, r12vrr_stack+66);
 tmp = r12vrr_stack + 228;
 target_ptr = Libr12->gvrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+66, r12vrr_stack+138, r12vrr_stack+188, r12vrr_stack+48, r12vrr_stack+60, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+288, r12vrr_stack+148, r12vrr_stack+138, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+303, r12vrr_stack+288, r12vrr_stack+66, NULL, NULL, r12vrr_stack+138);
 tmp = r12vrr_stack + 303;
 target_ptr = Libr12->gvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+81, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+0, r12vrr_stack+81, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+348, r12vrr_stack+21, r12vrr_stack+48, r12vrr_stack+15, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+358, r12vrr_stack+188, r12vrr_stack+348, r12vrr_stack+60, r12vrr_stack+21, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+373, r12vrr_stack+66, r12vrr_stack+358, NULL, NULL, r12vrr_stack+188);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+418, r12vrr_stack+303, r12vrr_stack+373, r12vrr_stack+288, r12vrr_stack+66, r12vrr_stack+198);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+198, r12vrr_stack+66, r12vrr_stack+358, r12vrr_stack+138, r12vrr_stack+188, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+348, r12vrr_stack+288, r12vrr_stack+66, r12vrr_stack+148, r12vrr_stack+138, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+508, r12vrr_stack+348, r12vrr_stack+198, NULL, NULL, r12vrr_stack+66);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+0, &(Data->ss_r12_ss), NULL, r12vrr_stack+3, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+0, &(Data->ss_r12_ss), r12vrr_stack+54, r12vrr_stack+3, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+138, r12vrr_stack+48, r12vrr_stack+0, r12vrr_stack+148, r12vrr_stack+54, r12vrr_stack+3, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+15, r12vrr_stack+138, r12vrr_stack+48, r12vrr_stack+288, r12vrr_stack+148, r12vrr_stack+54, NULL);

 /*--- compute (p0|[r12,T2]|d0)^0 ---*/
 _T2_BUILD_p0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+188, r12vrr_stack+84, r12vrr_stack+158, r12vrr_stack+102, r12vrr_stack+30, r12vrr_stack+6);
 tmp = r12vrr_stack + 188;
 target_ptr = Libr12->t2vrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_p0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+369, r12vrr_stack+158, r12vrr_stack+303, r12vrr_stack+228, r12vrr_stack+102, r12vrr_stack+84);
 tmp = r12vrr_stack + 369;
 target_ptr = Libr12->t2vrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_p0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+571, r12vrr_stack+303, r12vrr_stack+508, r12vrr_stack+418, r12vrr_stack+228, r12vrr_stack+158);
 tmp = r12vrr_stack + 571;
 target_ptr = Libr12->t2vrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|d0)^0 ---*/
 _T1_BUILD_p0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+30, r12vrr_stack+84, r12vrr_stack+102, r12vrr_stack+158, r12vrr_stack+148, r12vrr_stack+54);
 tmp = r12vrr_stack + 30;
 target_ptr = Libr12->t1vrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_p0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+102, r12vrr_stack+158, r12vrr_stack+228, r12vrr_stack+303, r12vrr_stack+288, r12vrr_stack+148);
 tmp = r12vrr_stack + 102;
 target_ptr = Libr12->t1vrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_p0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+206, r12vrr_stack+303, r12vrr_stack+418, r12vrr_stack+508, r12vrr_stack+348, r12vrr_stack+288);
 tmp = r12vrr_stack + 206;
 target_ptr = Libr12->t1vrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||d0)^0 ---*/
 _R_BUILD_p0d0(Data,r12vrr_stack+348, r12vrr_stack+48, NULL, r12vrr_stack+84, r12vrr_stack+54, NULL, r12vrr_stack+3);
 tmp = r12vrr_stack + 348;
 target_ptr = Libr12->rvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+251, r12vrr_stack+138, NULL, r12vrr_stack+158, r12vrr_stack+148, NULL, r12vrr_stack+54);
 tmp = r12vrr_stack + 251;
 target_ptr = Libr12->rvrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+48, r12vrr_stack+15, NULL, r12vrr_stack+303, r12vrr_stack+288, NULL, r12vrr_stack+148);
 tmp = r12vrr_stack + 48;
 target_ptr = Libr12->rvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];


}

