/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_ffgd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ff|gd) integrals */

void d12hrr_order_ffgd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][6][10] = int_stack + 784;
 Libderiv->deriv_classes[6][6][9] = int_stack + 1568;
 Libderiv->deriv_classes[6][6][8] = int_stack + 2352;
 Libderiv->deriv_classes[6][6][7] = int_stack + 3136;
 Libderiv->dvrr_classes[6][5] = int_stack + 3920;
 Libderiv->deriv_classes[6][6][6] = int_stack + 4508;
 Libderiv->deriv_classes[6][6][2] = int_stack + 5292;
 Libderiv->deriv_classes[6][6][1] = int_stack + 6076;
 Libderiv->dvrr_classes[5][6] = int_stack + 6860;
 Libderiv->deriv_classes[6][6][0] = int_stack + 7448;
 Libderiv->deriv2_classes[3][4][143] = int_stack + 8232;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 8382;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 8592;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 8872;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 9097;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 9412;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 9832;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 10147;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 10588;
 Libderiv->deriv2_classes[6][4][143] = int_stack + 11176;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 11596;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 12184;
 Libderiv->deriv2_classes[3][4][131] = int_stack + 12968;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 13118;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 13328;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 13608;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 13833;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 14148;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 14568;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 14883;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 15324;
 Libderiv->deriv2_classes[6][4][131] = int_stack + 15912;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 16332;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 16920;
 Libderiv->deriv2_classes[3][4][130] = int_stack + 17704;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 17854;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 18064;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 18344;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 18569;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 18884;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 19304;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 19619;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 20060;
 Libderiv->deriv2_classes[6][4][130] = int_stack + 20648;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 21068;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 21656;
 Libderiv->deriv2_classes[3][4][119] = int_stack + 22440;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 22590;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 22800;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 23080;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 23305;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 23620;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 24040;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 24355;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 24796;
 Libderiv->deriv2_classes[6][4][119] = int_stack + 25384;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 25804;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 26392;
 Libderiv->deriv2_classes[3][4][118] = int_stack + 27176;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 27326;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 27536;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 27816;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 28041;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 28356;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 28776;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 29091;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 29532;
 Libderiv->deriv2_classes[6][4][118] = int_stack + 30120;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 30540;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 31128;
 Libderiv->deriv2_classes[3][4][117] = int_stack + 31912;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 32062;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 32272;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 32552;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 32777;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 33092;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 33512;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 33827;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 34268;
 Libderiv->deriv2_classes[6][4][117] = int_stack + 34856;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 35276;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 35864;
 Libderiv->deriv2_classes[3][4][107] = int_stack + 36648;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 36798;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 37008;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 37288;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 37513;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 37828;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 38248;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 38563;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 39004;
 Libderiv->deriv2_classes[6][4][107] = int_stack + 39592;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 40012;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 40600;
 Libderiv->deriv2_classes[3][4][106] = int_stack + 41384;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 41534;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 41744;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 42024;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 42249;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 42564;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 42984;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 43299;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 43740;
 Libderiv->deriv2_classes[6][4][106] = int_stack + 44328;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 44748;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 45336;
 Libderiv->deriv2_classes[3][4][105] = int_stack + 46120;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 46270;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 46480;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 46760;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 46985;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 47300;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 47720;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 48035;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 48476;
 Libderiv->deriv2_classes[6][4][105] = int_stack + 49064;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 49484;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 50072;
 Libderiv->deriv2_classes[3][4][104] = int_stack + 50856;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 51006;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 51216;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 51496;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 51721;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 52036;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 52456;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 52771;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 53212;
 Libderiv->deriv2_classes[6][4][104] = int_stack + 53800;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 54220;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 54808;
 Libderiv->deriv2_classes[3][4][95] = int_stack + 55592;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 55742;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 55952;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 56232;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 56457;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 56772;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 57192;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 57507;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 57948;
 Libderiv->deriv2_classes[6][4][95] = int_stack + 58536;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 58956;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 59544;
 Libderiv->deriv2_classes[3][4][94] = int_stack + 60328;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 60478;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 60688;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 60968;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 61193;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 61508;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 61928;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 62243;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 62684;
 Libderiv->deriv2_classes[6][4][94] = int_stack + 63272;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 63692;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 64280;
 Libderiv->deriv2_classes[3][4][93] = int_stack + 65064;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 65214;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 65424;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 65704;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 65929;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 66244;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 66664;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 66979;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 67420;
 Libderiv->deriv2_classes[6][4][93] = int_stack + 68008;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 68428;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 69016;
 Libderiv->deriv2_classes[3][4][92] = int_stack + 69800;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 69950;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 70160;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 70440;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 70665;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 70980;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 71400;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 71715;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 72156;
 Libderiv->deriv2_classes[6][4][92] = int_stack + 72744;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 73164;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 73752;
 Libderiv->deriv2_classes[3][4][91] = int_stack + 74536;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 74686;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 74896;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 75176;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 75401;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 75716;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 76136;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 76451;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 76892;
 Libderiv->deriv2_classes[6][4][91] = int_stack + 77480;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 77900;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 78488;
 Libderiv->deriv2_classes[3][4][83] = int_stack + 79272;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 79422;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 79632;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 79912;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 80137;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 80452;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 80872;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 81187;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 81628;
 Libderiv->deriv_classes[6][4][11] = int_stack + 82216;
 Libderiv->deriv2_classes[6][4][83] = int_stack + 82636;
 Libderiv->deriv_classes[6][5][11] = int_stack + 83056;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 83644;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 84232;
 Libderiv->deriv2_classes[3][4][82] = int_stack + 85016;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 85166;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 85376;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 85656;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 85881;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 86196;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 86616;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 86931;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 87372;
 Libderiv->deriv_classes[6][4][10] = int_stack + 87960;
 Libderiv->deriv2_classes[6][4][82] = int_stack + 88380;
 Libderiv->deriv_classes[6][5][10] = int_stack + 88800;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 89388;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 89976;
 Libderiv->deriv2_classes[3][4][81] = int_stack + 90760;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 90910;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 91120;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 91400;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 91625;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 91940;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 92360;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 92675;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 93116;
 Libderiv->deriv_classes[6][4][9] = int_stack + 93704;
 Libderiv->deriv2_classes[6][4][81] = int_stack + 94124;
 Libderiv->deriv_classes[6][5][9] = int_stack + 94544;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 95132;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 95720;
 Libderiv->deriv2_classes[3][4][80] = int_stack + 96504;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 96654;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 96864;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 97144;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 97369;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 97684;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 98104;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 98419;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 98860;
 Libderiv->deriv_classes[6][4][8] = int_stack + 99448;
 Libderiv->deriv2_classes[6][4][80] = int_stack + 99868;
 Libderiv->deriv_classes[6][5][8] = int_stack + 100288;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 100876;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 101464;
 Libderiv->deriv2_classes[3][4][79] = int_stack + 102248;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 102398;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 102608;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 102888;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 103113;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 103428;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 103848;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 104163;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 104604;
 Libderiv->deriv_classes[6][4][7] = int_stack + 105192;
 Libderiv->deriv2_classes[6][4][79] = int_stack + 105612;
 Libderiv->deriv_classes[6][5][7] = int_stack + 106032;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 106620;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 107208;
 Libderiv->deriv2_classes[3][4][78] = int_stack + 107992;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 108142;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 108352;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 108632;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 108857;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 109172;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 109592;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 109907;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 110348;
 Libderiv->dvrr_classes[6][4] = int_stack + 110936;
 Libderiv->deriv_classes[6][4][6] = int_stack + 111356;
 Libderiv->deriv2_classes[6][4][78] = int_stack + 111776;
 Libderiv->deriv_classes[6][5][6] = int_stack + 112196;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 112784;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 113372;
 Libderiv->deriv2_classes[3][4][35] = int_stack + 114156;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 114306;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 114516;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 114796;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 115021;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 115336;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 115756;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 116071;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 116512;
 Libderiv->deriv2_classes[6][4][35] = int_stack + 117100;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 117520;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 118108;
 Libderiv->deriv2_classes[3][4][34] = int_stack + 118892;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 119042;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 119252;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 119532;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 119757;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 120072;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 120492;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 120807;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 121248;
 Libderiv->deriv2_classes[6][4][34] = int_stack + 121836;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 122256;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 122844;
 Libderiv->deriv2_classes[3][4][33] = int_stack + 123628;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 123778;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 123988;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 124268;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 124493;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 124808;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 125228;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 125543;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 125984;
 Libderiv->deriv2_classes[6][4][33] = int_stack + 126572;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 126992;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 127580;
 Libderiv->deriv2_classes[3][4][32] = int_stack + 128364;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 128514;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 128724;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 129004;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 129229;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 129544;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 129964;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 130279;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 130720;
 Libderiv->deriv2_classes[6][4][32] = int_stack + 131308;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 131728;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 132316;
 Libderiv->deriv2_classes[3][4][31] = int_stack + 133100;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 133250;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 133460;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 133740;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 133965;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 134280;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 134700;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 135015;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 135456;
 Libderiv->deriv2_classes[6][4][31] = int_stack + 136044;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 136464;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 137052;
 Libderiv->deriv2_classes[3][4][30] = int_stack + 137836;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 137986;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 138196;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 138476;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 138701;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 139016;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 139436;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 139751;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 140192;
 Libderiv->deriv_classes[6][4][2] = int_stack + 140780;
 Libderiv->deriv2_classes[6][4][30] = int_stack + 141200;
 Libderiv->deriv_classes[6][5][2] = int_stack + 141620;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 142208;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 142796;
 Libderiv->deriv2_classes[3][4][26] = int_stack + 143580;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 143730;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 143940;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 144220;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 144445;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 144760;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 145180;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 145495;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 145936;
 Libderiv->deriv2_classes[6][4][26] = int_stack + 146524;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 146944;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 147532;
 Libderiv->deriv2_classes[3][4][23] = int_stack + 148316;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 148466;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 148676;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 148956;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 149181;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 149496;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 149916;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 150231;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 150672;
 Libderiv->deriv2_classes[6][4][23] = int_stack + 151260;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 151680;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 152268;
 Libderiv->deriv2_classes[3][4][22] = int_stack + 153052;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 153202;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 153412;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 153692;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 153917;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 154232;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 154652;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 154967;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 155408;
 Libderiv->deriv2_classes[6][4][22] = int_stack + 155996;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 156416;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 157004;
 Libderiv->deriv2_classes[3][4][21] = int_stack + 157788;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 157938;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 158148;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 158428;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 158653;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 158968;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 159388;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 159703;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 160144;
 Libderiv->deriv2_classes[6][4][21] = int_stack + 160732;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 161152;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 161740;
 Libderiv->deriv2_classes[3][4][20] = int_stack + 162524;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 162674;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 162884;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 163164;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 163389;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 163704;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 164124;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 164439;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 164880;
 Libderiv->deriv2_classes[6][4][20] = int_stack + 165468;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 165888;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 166476;
 Libderiv->deriv2_classes[3][4][19] = int_stack + 167260;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 167410;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 167620;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 167900;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 168125;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 168440;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 168860;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 169175;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 169616;
 Libderiv->deriv2_classes[6][4][19] = int_stack + 170204;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 170624;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 171212;
 Libderiv->deriv2_classes[3][4][18] = int_stack + 171996;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 172146;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 172356;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 172636;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 172861;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 173176;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 173596;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 173911;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 174352;
 Libderiv->deriv_classes[6][4][1] = int_stack + 174940;
 Libderiv->deriv2_classes[6][4][18] = int_stack + 175360;
 Libderiv->deriv_classes[6][5][1] = int_stack + 175780;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 176368;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 176956;
 Libderiv->deriv2_classes[3][4][14] = int_stack + 177740;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 177890;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 178100;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 178380;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 178605;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 178920;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 179340;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 179655;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 180096;
 Libderiv->deriv2_classes[6][4][14] = int_stack + 180684;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 181104;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 181692;
 Libderiv->deriv2_classes[3][4][13] = int_stack + 182476;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 182626;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 182836;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 183116;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 183341;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 183656;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 184076;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 184391;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 184832;
 Libderiv->deriv2_classes[6][4][13] = int_stack + 185420;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 185840;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 186428;
 Libderiv->deriv_classes[3][4][11] = int_stack + 187212;
 Libderiv->deriv_classes[3][5][11] = int_stack + 187362;
 Libderiv->deriv_classes[3][6][11] = int_stack + 187572;
 Libderiv->deriv2_classes[3][4][11] = int_stack + 187852;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 188002;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 188212;
 Libderiv->deriv_classes[4][4][11] = int_stack + 188492;
 Libderiv->deriv_classes[4][5][11] = int_stack + 188717;
 Libderiv->deriv_classes[4][6][11] = int_stack + 189032;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 189452;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 189677;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 189992;
 Libderiv->deriv_classes[5][4][11] = int_stack + 190412;
 Libderiv->deriv_classes[5][5][11] = int_stack + 190727;
 Libderiv->deriv_classes[5][6][11] = int_stack + 191168;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 191756;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 192071;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 192512;
 Libderiv->deriv2_classes[6][4][11] = int_stack + 193100;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 193520;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 194108;
 Libderiv->deriv_classes[3][4][10] = int_stack + 194892;
 Libderiv->deriv_classes[3][5][10] = int_stack + 195042;
 Libderiv->deriv_classes[3][6][10] = int_stack + 195252;
 Libderiv->deriv2_classes[3][4][10] = int_stack + 195532;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 195682;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 195892;
 Libderiv->deriv_classes[4][4][10] = int_stack + 196172;
 Libderiv->deriv_classes[4][5][10] = int_stack + 196397;
 Libderiv->deriv_classes[4][6][10] = int_stack + 196712;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 197132;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 197357;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 197672;
 Libderiv->deriv_classes[5][4][10] = int_stack + 198092;
 Libderiv->deriv_classes[5][5][10] = int_stack + 198407;
 Libderiv->deriv_classes[5][6][10] = int_stack + 198848;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 199436;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 199751;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 200192;
 Libderiv->deriv2_classes[6][4][10] = int_stack + 200780;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 201200;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 201788;
 Libderiv->deriv_classes[3][4][9] = int_stack + 202572;
 Libderiv->deriv_classes[3][5][9] = int_stack + 202722;
 Libderiv->deriv_classes[3][6][9] = int_stack + 202932;
 Libderiv->deriv2_classes[3][4][9] = int_stack + 203212;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 203362;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 203572;
 Libderiv->deriv_classes[4][4][9] = int_stack + 203852;
 Libderiv->deriv_classes[4][5][9] = int_stack + 204077;
 Libderiv->deriv_classes[4][6][9] = int_stack + 204392;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 204812;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 205037;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 205352;
 Libderiv->deriv_classes[5][4][9] = int_stack + 205772;
 Libderiv->deriv_classes[5][5][9] = int_stack + 206087;
 Libderiv->deriv_classes[5][6][9] = int_stack + 206528;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 207116;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 207431;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 207872;
 Libderiv->deriv2_classes[6][4][9] = int_stack + 208460;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 208880;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 209468;
 Libderiv->deriv_classes[3][4][8] = int_stack + 210252;
 Libderiv->deriv_classes[3][5][8] = int_stack + 210402;
 Libderiv->deriv_classes[3][6][8] = int_stack + 210612;
 Libderiv->deriv2_classes[3][4][8] = int_stack + 210892;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 211042;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 211252;
 Libderiv->deriv_classes[4][4][8] = int_stack + 211532;
 Libderiv->deriv_classes[4][5][8] = int_stack + 211757;
 Libderiv->deriv_classes[4][6][8] = int_stack + 212072;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 212492;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 212717;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 213032;
 Libderiv->deriv_classes[5][4][8] = int_stack + 213452;
 Libderiv->deriv_classes[5][5][8] = int_stack + 213767;
 Libderiv->deriv_classes[5][6][8] = int_stack + 214208;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 214796;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 215111;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 215552;
 Libderiv->deriv2_classes[6][4][8] = int_stack + 216140;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 216560;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 217148;
 Libderiv->deriv_classes[3][4][7] = int_stack + 217932;
 Libderiv->deriv_classes[3][5][7] = int_stack + 218082;
 Libderiv->deriv_classes[3][6][7] = int_stack + 218292;
 Libderiv->deriv2_classes[3][4][7] = int_stack + 218572;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 218722;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 218932;
 Libderiv->deriv_classes[4][4][7] = int_stack + 219212;
 Libderiv->deriv_classes[4][5][7] = int_stack + 219437;
 Libderiv->deriv_classes[4][6][7] = int_stack + 219752;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 220172;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 220397;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 220712;
 Libderiv->deriv_classes[5][4][7] = int_stack + 221132;
 Libderiv->deriv_classes[5][5][7] = int_stack + 221447;
 Libderiv->deriv_classes[5][6][7] = int_stack + 221888;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 222476;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 222791;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 223232;
 Libderiv->deriv2_classes[6][4][7] = int_stack + 223820;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 224240;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 224828;
 Libderiv->deriv_classes[3][4][6] = int_stack + 225612;
 Libderiv->deriv_classes[3][5][6] = int_stack + 225762;
 Libderiv->deriv_classes[3][6][6] = int_stack + 225972;
 Libderiv->deriv2_classes[3][4][6] = int_stack + 226252;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 226402;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 226612;
 Libderiv->deriv_classes[4][4][6] = int_stack + 226892;
 Libderiv->deriv_classes[4][5][6] = int_stack + 227117;
 Libderiv->deriv_classes[4][6][6] = int_stack + 227432;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 227852;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 228077;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 228392;
 Libderiv->dvrr_classes[5][4] = int_stack + 228812;
 Libderiv->deriv_classes[5][4][6] = int_stack + 229127;
 Libderiv->dvrr_classes[5][5] = int_stack + 229442;
 Libderiv->deriv_classes[5][5][6] = int_stack + 229883;
 Libderiv->deriv_classes[5][6][6] = int_stack + 230324;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 230912;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 231227;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 231668;
 Libderiv->deriv_classes[6][4][0] = int_stack + 232256;
 Libderiv->deriv2_classes[6][4][6] = int_stack + 232676;
 Libderiv->deriv_classes[6][5][0] = int_stack + 233096;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 233684;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 234272;
 Libderiv->deriv_classes[3][4][2] = int_stack + 235056;
 Libderiv->deriv_classes[3][5][2] = int_stack + 235206;
 Libderiv->deriv_classes[3][6][2] = int_stack + 235416;
 Libderiv->deriv2_classes[3][4][2] = int_stack + 235696;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 235846;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 236056;
 Libderiv->deriv_classes[4][4][2] = int_stack + 236336;
 Libderiv->deriv_classes[4][5][2] = int_stack + 236561;
 Libderiv->deriv_classes[4][6][2] = int_stack + 236876;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 237296;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 237521;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 237836;
 Libderiv->deriv_classes[5][4][2] = int_stack + 238256;
 Libderiv->deriv_classes[5][5][2] = int_stack + 238571;
 Libderiv->deriv_classes[5][6][2] = int_stack + 239012;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 239600;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 239915;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 240356;
 Libderiv->deriv2_classes[6][4][2] = int_stack + 240944;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 241364;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 241952;
 Libderiv->deriv_classes[3][4][1] = int_stack + 242736;
 Libderiv->deriv_classes[3][5][1] = int_stack + 242886;
 Libderiv->deriv_classes[3][6][1] = int_stack + 243096;
 Libderiv->deriv2_classes[3][4][1] = int_stack + 243376;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 243526;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 243736;
 Libderiv->deriv_classes[4][4][1] = int_stack + 244016;
 Libderiv->deriv_classes[4][5][1] = int_stack + 244241;
 Libderiv->deriv_classes[4][6][1] = int_stack + 244556;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 244976;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 245201;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 245516;
 Libderiv->deriv_classes[5][4][1] = int_stack + 245936;
 Libderiv->deriv_classes[5][5][1] = int_stack + 246251;
 Libderiv->deriv_classes[5][6][1] = int_stack + 246692;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 247280;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 247595;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 248036;
 Libderiv->deriv2_classes[6][4][1] = int_stack + 248624;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 249044;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 249632;
 Libderiv->dvrr_classes[3][4] = int_stack + 250416;
 Libderiv->dvrr_classes[3][5] = int_stack + 250566;
 Libderiv->dvrr_classes[3][6] = int_stack + 250776;
 Libderiv->deriv_classes[3][4][0] = int_stack + 251056;
 Libderiv->deriv_classes[3][5][0] = int_stack + 251206;
 Libderiv->deriv_classes[3][6][0] = int_stack + 251416;
 Libderiv->deriv2_classes[3][4][0] = int_stack + 251696;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 251846;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 252056;
 Libderiv->dvrr_classes[4][4] = int_stack + 252336;
 Libderiv->dvrr_classes[4][5] = int_stack + 252561;
 Libderiv->dvrr_classes[4][6] = int_stack + 252876;
 Libderiv->deriv_classes[4][4][0] = int_stack + 253296;
 Libderiv->deriv_classes[4][5][0] = int_stack + 253521;
 Libderiv->deriv_classes[4][6][0] = int_stack + 253836;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 254256;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 254481;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 254796;
 Libderiv->deriv_classes[5][4][0] = int_stack + 255216;
 Libderiv->deriv_classes[5][5][0] = int_stack + 255531;
 Libderiv->deriv_classes[5][6][0] = int_stack + 255972;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 256560;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 256875;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 257316;
 Libderiv->deriv2_classes[6][4][0] = int_stack + 257904;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 258324;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 258912;
 memset(int_stack,0,2077568);

 Libderiv->dvrr_stack = int_stack + 857881;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_ffgd(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+259696,int_stack+250566,int_stack+250416,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+260146,int_stack+187362,int_stack+187212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250416,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+187572,int_stack+187362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250566,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+261226,int_stack+260596,int_stack+260146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+262126,int_stack+252561,int_stack+252336,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+188717,int_stack+188492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252336,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+263476,int_stack+189032,int_stack+188717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252561,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+264421,int_stack+263476,int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+265771,int_stack+264421,int_stack+261226,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+263476,int_stack+229442,int_stack+228812,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+268471,int_stack+190727,int_stack+190412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228812,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+191168,int_stack+190727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229442,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+270739,int_stack+269416,int_stack+268471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263476,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+272629,int_stack+270739,int_stack+264421,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+276679,int_stack+272629,int_stack+265771,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+269416,int_stack+3920,int_stack+110936,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+282079,int_stack+83056,int_stack+82216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110936,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+283339,int_stack+0,int_stack+83056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+285103,int_stack+283339,int_stack+282079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269416,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+287623,int_stack+285103,int_stack+270739,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+293293,int_stack+287623,int_stack+272629,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+283339,int_stack+195042,int_stack+194892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250416, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+195252,int_stack+195042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250566, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+283789,int_stack+260596,int_stack+283339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284689,int_stack+196397,int_stack+196172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252336, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+285364,int_stack+196712,int_stack+196397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252561, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+286309,int_stack+285364,int_stack+284689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+287659,int_stack+286309,int_stack+283789,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+285364,int_stack+198407,int_stack+198092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228812, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290359,int_stack+198848,int_stack+198407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229442, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+301393,int_stack+290359,int_stack+285364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263476, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+303283,int_stack+301393,int_stack+286309,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+307333,int_stack+303283,int_stack+287659,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+290359,int_stack+88800,int_stack+87960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110936, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+312733,int_stack+784,int_stack+88800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+314497,int_stack+312733,int_stack+290359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269416, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+317017,int_stack+314497,int_stack+301393,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+322687,int_stack+317017,int_stack+303283,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+312733,int_stack+202722,int_stack+202572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250416, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+202932,int_stack+202722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250566, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+313183,int_stack+260596,int_stack+312733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+314083,int_stack+204077,int_stack+203852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252336, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+314758,int_stack+204392,int_stack+204077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252561, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315703,int_stack+314758,int_stack+314083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+317053,int_stack+315703,int_stack+313183,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+314758,int_stack+206087,int_stack+205772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228812, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+319753,int_stack+206528,int_stack+206087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229442, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+330787,int_stack+319753,int_stack+314758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263476, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+332677,int_stack+330787,int_stack+315703,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+336727,int_stack+332677,int_stack+317053,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+319753,int_stack+94544,int_stack+93704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110936, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342127,int_stack+1568,int_stack+94544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+343891,int_stack+342127,int_stack+319753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+346411,int_stack+343891,int_stack+330787,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+352081,int_stack+346411,int_stack+332677,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+342127,int_stack+210402,int_stack+210252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+210612,int_stack+210402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+342577,int_stack+260596,int_stack+342127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+343477,int_stack+211757,int_stack+211532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+344152,int_stack+212072,int_stack+211757, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+345097,int_stack+344152,int_stack+343477, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+346447,int_stack+345097,int_stack+342577,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+344152,int_stack+213767,int_stack+213452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+349147,int_stack+214208,int_stack+213767, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+349147,int_stack+344152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+360181,int_stack+0,int_stack+345097,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+364231,int_stack+360181,int_stack+346447,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+349147,int_stack+100288,int_stack+99448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+369631,int_stack+2352,int_stack+100288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+371395,int_stack+369631,int_stack+349147, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+373915,int_stack+371395,int_stack+0,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+379585,int_stack+373915,int_stack+360181,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+369631,int_stack+218082,int_stack+217932, 0.0, zero_stack, 1.0, int_stack+250416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+218292,int_stack+218082, 0.0, zero_stack, 1.0, int_stack+250566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+370081,int_stack+260596,int_stack+369631, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+370981,int_stack+219437,int_stack+219212, 0.0, zero_stack, 1.0, int_stack+252336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+371656,int_stack+219752,int_stack+219437, 0.0, zero_stack, 1.0, int_stack+252561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+372601,int_stack+371656,int_stack+370981, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+373951,int_stack+372601,int_stack+370081,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+371656,int_stack+221447,int_stack+221132, 0.0, zero_stack, 1.0, int_stack+228812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+376651,int_stack+221888,int_stack+221447, 0.0, zero_stack, 1.0, int_stack+229442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+387685,int_stack+376651,int_stack+371656, 0.0, zero_stack, 1.0, int_stack+263476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+389575,int_stack+387685,int_stack+372601,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+393625,int_stack+389575,int_stack+373951,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+376651,int_stack+106032,int_stack+105192, 0.0, zero_stack, 1.0, int_stack+110936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+399025,int_stack+3136,int_stack+106032, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+400789,int_stack+399025,int_stack+376651, 0.0, zero_stack, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+403309,int_stack+400789,int_stack+387685,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+408979,int_stack+403309,int_stack+389575,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+225762,int_stack+225612, 1.0, int_stack+250416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+225972,int_stack+225762, 1.0, int_stack+250566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+399475,int_stack+260596,int_stack+399025, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+400375,int_stack+227117,int_stack+226892, 1.0, int_stack+252336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+401050,int_stack+227432,int_stack+227117, 1.0, int_stack+252561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+401995,int_stack+401050,int_stack+400375, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+403345,int_stack+401995,int_stack+399475,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+401050,int_stack+229883,int_stack+229127, 1.0, int_stack+228812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+406045,int_stack+230324,int_stack+229883, 1.0, int_stack+229442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1890,int_stack+406045,int_stack+401050, 1.0, int_stack+263476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+417079,int_stack+1890,int_stack+401995,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+421129,int_stack+417079,int_stack+403345,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+406045,int_stack+112196,int_stack+111356, 1.0, int_stack+110936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+4508,int_stack+112196, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+428293,int_stack+426529,int_stack+406045, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+430813,int_stack+428293,int_stack+1890,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+436483,int_stack+430813,int_stack+417079,90);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+250776,int_stack+250566,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+269416,int_stack+260596,int_stack+259696,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+252876,int_stack+252561,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+427474,int_stack+426529,int_stack+262126,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+428824,int_stack+427474,int_stack+269416,90);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+431524,int_stack+6860,int_stack+229442,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+432847,int_stack+431524,int_stack+263476,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+432847,int_stack+427474,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+448633,int_stack+444583,int_stack+428824,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+259696,int_stack+235206,int_stack+235056,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+235416,int_stack+235206,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+263476,int_stack+260596,int_stack+259696,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+262126,int_stack+236561,int_stack+236336,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+236876,int_stack+236561,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+434737,int_stack+426529,int_stack+262126,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+454033,int_stack+434737,int_stack+263476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+238571,int_stack+238256,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+431524,int_stack+239012,int_stack+238571,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+456733,int_stack+431524,int_stack+426529,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+458623,int_stack+456733,int_stack+434737, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+462673,int_stack+458623,int_stack+454033, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+431524,int_stack+141620,int_stack+140780,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+468073,int_stack+5292,int_stack+141620,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+469837,int_stack+468073,int_stack+431524,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+472357,int_stack+469837,int_stack+456733, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+478027,int_stack+472357,int_stack+458623, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+242886,int_stack+242736,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+243096,int_stack+242886,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+468523,int_stack+260596,int_stack+468073,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+469423,int_stack+244241,int_stack+244016,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+470098,int_stack+244556,int_stack+244241,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+471043,int_stack+470098,int_stack+469423,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+472393,int_stack+471043,int_stack+468523, 0.0, zero_stack, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+470098,int_stack+246251,int_stack+245936,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+475093,int_stack+246692,int_stack+246251,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+3780,int_stack+475093,int_stack+470098,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+486127,int_stack+3780,int_stack+471043, 0.0, zero_stack, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+490177,int_stack+486127,int_stack+472393, 0.0, zero_stack, 1.0, int_stack+428824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+475093,int_stack+175780,int_stack+174940,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+495577,int_stack+6076,int_stack+175780,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+497341,int_stack+495577,int_stack+475093,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+499861,int_stack+497341,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+432847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+505531,int_stack+499861,int_stack+486127, 0.0, zero_stack, 1.0, int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+495577,int_stack+251206,int_stack+251056,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+251416,int_stack+251206,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+496027,int_stack+260596,int_stack+495577,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+496927,int_stack+253521,int_stack+253296,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+497602,int_stack+253836,int_stack+253521,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+498547,int_stack+497602,int_stack+496927,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+499897,int_stack+498547,int_stack+496027, 1.0, int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+497602,int_stack+255531,int_stack+255216,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+255972,int_stack+255531,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+502597,int_stack+269416,int_stack+497602,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+513631,int_stack+502597,int_stack+498547, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+517681,int_stack+513631,int_stack+499897, 1.0, int_stack+428824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+427474,int_stack+233096,int_stack+232256,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+428734,int_stack+7448,int_stack+233096,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+5670,int_stack+428734,int_stack+427474,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+523081,int_stack+5670,int_stack+502597, 1.0, int_stack+432847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+528751,int_stack+523081,int_stack+513631, 1.0, int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+8382,int_stack+8232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+187212,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+8592,int_stack+8382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+187362,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+260146,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+9097,int_stack+8872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+188492,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+9412,int_stack+9097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+188717,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+446608,int_stack+445933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+262801,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+523081,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+10147,int_stack+9832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+190412,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+10588,int_stack+10147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+190727,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+524431,int_stack+269416,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+268471,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+5670,int_stack+524431,int_stack+523081,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+536851,int_stack+5670,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+523081,int_stack+11596,int_stack+11176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+82216,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+12184,int_stack+11596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+83056,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+9720,int_stack+444583,int_stack+523081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+282079,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+542251,int_stack+9720,int_stack+524431,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+547921,int_stack+542251,int_stack+5670,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+5670,int_stack+13118,int_stack+12968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187212, 1.0, int_stack+194892,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+13328,int_stack+13118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187362, 1.0, int_stack+195042,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+6120,int_stack+260596,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260146, 1.0, int_stack+283339,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+7020,int_stack+13833,int_stack+13608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188492, 1.0, int_stack+196172,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7695,int_stack+14148,int_stack+13833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188717, 1.0, int_stack+196397,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+8640,int_stack+7695,int_stack+7020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262801, 1.0, int_stack+284689,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+9990,int_stack+8640,int_stack+6120,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+5670,int_stack+14883,int_stack+14568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190412, 1.0, int_stack+198092,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+15324,int_stack+14883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190727, 1.0, int_stack+198407,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+6615,int_stack+269416,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268471, 1.0, int_stack+285364,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+6615,int_stack+8640,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+542251,int_stack+444583,int_stack+9990,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+269416,int_stack+16332,int_stack+15912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82216, 1.0, int_stack+87960,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8505,int_stack+16920,int_stack+16332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83056, 1.0, int_stack+88800,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282079, 1.0, int_stack+290359,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+523081,int_stack+10269,int_stack+6615,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+5670,int_stack+523081,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+17854,int_stack+17704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+194892, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+18064,int_stack+17854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+195042, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+283339, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+18569,int_stack+18344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+196172, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+18884,int_stack+18569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+196397, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+446608,int_stack+445933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+284689, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+523081,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+19619,int_stack+19304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+198092, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+20060,int_stack+19619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+198407, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+524431,int_stack+269416,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+285364, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+13770,int_stack+524431,int_stack+523081,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+556021,int_stack+13770,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+523081,int_stack+21068,int_stack+20648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+87960, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+21656,int_stack+21068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88800, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17820,int_stack+444583,int_stack+523081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+290359, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+561421,int_stack+17820,int_stack+524431,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+567091,int_stack+561421,int_stack+13770,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+13770,int_stack+22590,int_stack+22440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187212, 0.0, zero_stack, 1.0, int_stack+202572,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+22800,int_stack+22590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187362, 0.0, zero_stack, 1.0, int_stack+202722,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14220,int_stack+260596,int_stack+13770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260146, 0.0, zero_stack, 1.0, int_stack+312733,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+15120,int_stack+23305,int_stack+23080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188492, 0.0, zero_stack, 1.0, int_stack+203852,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15795,int_stack+23620,int_stack+23305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188717, 0.0, zero_stack, 1.0, int_stack+204077,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16740,int_stack+15795,int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262801, 0.0, zero_stack, 1.0, int_stack+314083,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+18090,int_stack+16740,int_stack+14220,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+13770,int_stack+24355,int_stack+24040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190412, 0.0, zero_stack, 1.0, int_stack+205772,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+24796,int_stack+24355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190727, 0.0, zero_stack, 1.0, int_stack+206087,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14715,int_stack+269416,int_stack+13770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268471, 0.0, zero_stack, 1.0, int_stack+314758,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+14715,int_stack+16740,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+561421,int_stack+444583,int_stack+18090,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+269416,int_stack+25804,int_stack+25384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82216, 0.0, zero_stack, 1.0, int_stack+93704,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16605,int_stack+26392,int_stack+25804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83056, 0.0, zero_stack, 1.0, int_stack+94544,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+18369,int_stack+16605,int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282079, 0.0, zero_stack, 1.0, int_stack+319753,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+523081,int_stack+18369,int_stack+14715,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+13770,int_stack+523081,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+27326,int_stack+27176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+194892, 1.0, int_stack+202572, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+27536,int_stack+27326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195042, 1.0, int_stack+202722, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283339, 1.0, int_stack+312733, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+28041,int_stack+27816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196172, 1.0, int_stack+203852, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+28356,int_stack+28041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196397, 1.0, int_stack+204077, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+446608,int_stack+445933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284689, 1.0, int_stack+314083, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+523081,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+29091,int_stack+28776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198092, 1.0, int_stack+205772, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+29532,int_stack+29091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198407, 1.0, int_stack+206087, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+524431,int_stack+269416,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285364, 1.0, int_stack+314758, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+21870,int_stack+524431,int_stack+523081,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+575191,int_stack+21870,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+523081,int_stack+30540,int_stack+30120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87960, 1.0, int_stack+93704, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+31128,int_stack+30540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88800, 1.0, int_stack+94544, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+25920,int_stack+444583,int_stack+523081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290359, 1.0, int_stack+319753, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+580591,int_stack+25920,int_stack+524431,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+586261,int_stack+580591,int_stack+21870,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+21870,int_stack+32062,int_stack+31912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+202572, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+32272,int_stack+32062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+202722, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22320,int_stack+260596,int_stack+21870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+312733, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23220,int_stack+32777,int_stack+32552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+203852, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23895,int_stack+33092,int_stack+32777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+204077, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+24840,int_stack+23895,int_stack+23220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+314083, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+26190,int_stack+24840,int_stack+22320,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+21870,int_stack+33827,int_stack+33512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+205772, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+34268,int_stack+33827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+206087, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22815,int_stack+269416,int_stack+21870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+314758, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+22815,int_stack+24840,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+28890,int_stack+444583,int_stack+26190,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+269416,int_stack+35276,int_stack+34856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+93704, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24705,int_stack+35864,int_stack+35276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+94544, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+580591,int_stack+24705,int_stack+269416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+319753, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+523081,int_stack+580591,int_stack+22815,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+594361,int_stack+523081,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+36798,int_stack+36648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210252,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+37008,int_stack+36798, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187362, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210402,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260146, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342127,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+37513,int_stack+37288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211532,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+37828,int_stack+37513, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188717, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211757,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+446608,int_stack+445933, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343477,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+523081,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+38563,int_stack+38248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213452,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+39004,int_stack+38563, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213767,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+524431,int_stack+269416,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344152,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+580591,int_stack+524431,int_stack+523081,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+21870,int_stack+580591,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+523081,int_stack+40012,int_stack+39592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99448,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+40600,int_stack+40012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100288,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+34290,int_stack+444583,int_stack+523081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282079, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349147,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+602461,int_stack+34290,int_stack+524431,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+608131,int_stack+602461,int_stack+580591,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+580591,int_stack+41534,int_stack+41384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+194892, 0.0, zero_stack, 1.0, int_stack+210252, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+41744,int_stack+41534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195042, 0.0, zero_stack, 1.0, int_stack+210402, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+581041,int_stack+260596,int_stack+580591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283339, 0.0, zero_stack, 1.0, int_stack+342127, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+581941,int_stack+42249,int_stack+42024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196172, 0.0, zero_stack, 1.0, int_stack+211532, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+582616,int_stack+42564,int_stack+42249, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196397, 0.0, zero_stack, 1.0, int_stack+211757, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+583561,int_stack+582616,int_stack+581941, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284689, 0.0, zero_stack, 1.0, int_stack+343477, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+602461,int_stack+583561,int_stack+581041,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+580591,int_stack+43299,int_stack+42984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198092, 0.0, zero_stack, 1.0, int_stack+213452, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+43740,int_stack+43299, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198407, 0.0, zero_stack, 1.0, int_stack+213767, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+581536,int_stack+269416,int_stack+580591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285364, 0.0, zero_stack, 1.0, int_stack+344152, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+581536,int_stack+583561,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+34290,int_stack+444583,int_stack+602461,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+602461,int_stack+44748,int_stack+44328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87960, 0.0, zero_stack, 1.0, int_stack+99448, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+603721,int_stack+45336,int_stack+44748, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88800, 0.0, zero_stack, 1.0, int_stack+100288, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+605485,int_stack+603721,int_stack+602461, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290359, 0.0, zero_stack, 1.0, int_stack+349147, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+523081,int_stack+605485,int_stack+581536,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+616231,int_stack+523081,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+46270,int_stack+46120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202572, 1.0, int_stack+210252, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+46480,int_stack+46270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202722, 1.0, int_stack+210402, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+312733, 1.0, int_stack+342127, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+46985,int_stack+46760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203852, 1.0, int_stack+211532, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+47300,int_stack+46985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204077, 1.0, int_stack+211757, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+446608,int_stack+445933, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314083, 1.0, int_stack+343477, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+523081,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+48035,int_stack+47720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205772, 1.0, int_stack+213452, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+48476,int_stack+48035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206087, 1.0, int_stack+213767, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+524431,int_stack+269416,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314758, 1.0, int_stack+344152, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+602461,int_stack+524431,int_stack+523081,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+580591,int_stack+602461,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+523081,int_stack+49484,int_stack+49064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93704, 1.0, int_stack+99448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+50072,int_stack+49484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94544, 1.0, int_stack+100288, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39690,int_stack+444583,int_stack+523081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319753, 1.0, int_stack+349147, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+42210,int_stack+39690,int_stack+524431,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+624331,int_stack+42210,int_stack+602461,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+602461,int_stack+51006,int_stack+50856, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+210252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+51216,int_stack+51006, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+210402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+602911,int_stack+260596,int_stack+602461, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+342127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+603811,int_stack+51721,int_stack+51496, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+211532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+604486,int_stack+52036,int_stack+51721, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+211757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+605431,int_stack+604486,int_stack+603811, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+343477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+605431,int_stack+602911,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+602461,int_stack+52771,int_stack+52456, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+213452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+53212,int_stack+52771, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+213767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+603406,int_stack+269416,int_stack+602461, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+344152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+603406,int_stack+605431,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+42390,int_stack+444583,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+54220,int_stack+53800, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+99448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+605296,int_stack+54808,int_stack+54220, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+100288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+47790,int_stack+605296,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+349147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+523081,int_stack+47790,int_stack+603406,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+632431,int_stack+523081,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+55742,int_stack+55592, 0.0, zero_stack, 1.0, int_stack+187212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217932,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+55952,int_stack+55742, 0.0, zero_stack, 1.0, int_stack+187362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218082,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 1.0, int_stack+260146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369631,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+56457,int_stack+56232, 0.0, zero_stack, 1.0, int_stack+188492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+219212,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+56772,int_stack+56457, 0.0, zero_stack, 1.0, int_stack+188717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+219437,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+446608,int_stack+445933, 0.0, zero_stack, 1.0, int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370981,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+523081,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+57507,int_stack+57192, 0.0, zero_stack, 1.0, int_stack+190412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221132,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+57948,int_stack+57507, 0.0, zero_stack, 1.0, int_stack+190727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221447,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+524431,int_stack+269416,int_stack+444583, 0.0, zero_stack, 1.0, int_stack+268471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371656,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+524431,int_stack+523081,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+51840,int_stack+47790,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+523081,int_stack+58956,int_stack+58536, 0.0, zero_stack, 1.0, int_stack+82216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105192,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+59544,int_stack+58956, 0.0, zero_stack, 1.0, int_stack+83056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106032,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+57240,int_stack+444583,int_stack+523081, 0.0, zero_stack, 1.0, int_stack+282079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376651,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+602461,int_stack+57240,int_stack+524431,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+640531,int_stack+602461,int_stack+47790,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+60478,int_stack+60328, 0.0, zero_stack, 1.0, int_stack+194892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217932, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+60688,int_stack+60478, 0.0, zero_stack, 1.0, int_stack+195042, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218082, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48240,int_stack+260596,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+283339, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369631, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49140,int_stack+61193,int_stack+60968, 0.0, zero_stack, 1.0, int_stack+196172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+219212, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49815,int_stack+61508,int_stack+61193, 0.0, zero_stack, 1.0, int_stack+196397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+219437, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+602461,int_stack+49815,int_stack+49140, 0.0, zero_stack, 1.0, int_stack+284689, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370981, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+49140,int_stack+602461,int_stack+48240,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+62243,int_stack+61928, 0.0, zero_stack, 1.0, int_stack+198092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221132, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+62684,int_stack+62243, 0.0, zero_stack, 1.0, int_stack+198407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221447, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+603811,int_stack+269416,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+285364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371656, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+603811,int_stack+602461,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+57240,int_stack+444583,int_stack+49140,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+602461,int_stack+63692,int_stack+63272, 0.0, zero_stack, 1.0, int_stack+87960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105192, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+64280,int_stack+63692, 0.0, zero_stack, 1.0, int_stack+88800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106032, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+523081,int_stack+47790,int_stack+602461, 0.0, zero_stack, 1.0, int_stack+290359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376651, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+648631,int_stack+523081,int_stack+603811,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+654301,int_stack+648631,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+65214,int_stack+65064, 0.0, zero_stack, 1.0, int_stack+202572, 0.0, zero_stack, 1.0, int_stack+217932, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+65424,int_stack+65214, 0.0, zero_stack, 1.0, int_stack+202722, 0.0, zero_stack, 1.0, int_stack+218082, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 1.0, int_stack+312733, 0.0, zero_stack, 1.0, int_stack+369631, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+65929,int_stack+65704, 0.0, zero_stack, 1.0, int_stack+203852, 0.0, zero_stack, 1.0, int_stack+219212, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+66244,int_stack+65929, 0.0, zero_stack, 1.0, int_stack+204077, 0.0, zero_stack, 1.0, int_stack+219437, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+648631,int_stack+446608,int_stack+445933, 0.0, zero_stack, 1.0, int_stack+314083, 0.0, zero_stack, 1.0, int_stack+370981, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+648631,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+66979,int_stack+66664, 0.0, zero_stack, 1.0, int_stack+205772, 0.0, zero_stack, 1.0, int_stack+221132, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+67420,int_stack+66979, 0.0, zero_stack, 1.0, int_stack+206087, 0.0, zero_stack, 1.0, int_stack+221447, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+649981,int_stack+269416,int_stack+444583, 0.0, zero_stack, 1.0, int_stack+314758, 0.0, zero_stack, 1.0, int_stack+371656, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+649981,int_stack+648631,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+523081,int_stack+47790,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+648631,int_stack+68428,int_stack+68008, 0.0, zero_stack, 1.0, int_stack+93704, 0.0, zero_stack, 1.0, int_stack+105192, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+69016,int_stack+68428, 0.0, zero_stack, 1.0, int_stack+94544, 0.0, zero_stack, 1.0, int_stack+106032, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+602461,int_stack+444583,int_stack+648631, 0.0, zero_stack, 1.0, int_stack+319753, 0.0, zero_stack, 1.0, int_stack+376651, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+62640,int_stack+602461,int_stack+649981,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+662401,int_stack+62640,int_stack+47790,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+69950,int_stack+69800, 0.0, zero_stack, 1.0, int_stack+210252, 1.0, int_stack+217932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+70160,int_stack+69950, 0.0, zero_stack, 1.0, int_stack+210402, 1.0, int_stack+218082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48240,int_stack+260596,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+342127, 1.0, int_stack+369631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49140,int_stack+70665,int_stack+70440, 0.0, zero_stack, 1.0, int_stack+211532, 1.0, int_stack+219212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49815,int_stack+70980,int_stack+70665, 0.0, zero_stack, 1.0, int_stack+211757, 1.0, int_stack+219437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+62640,int_stack+49815,int_stack+49140, 0.0, zero_stack, 1.0, int_stack+343477, 1.0, int_stack+370981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+49140,int_stack+62640,int_stack+48240,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+71715,int_stack+71400, 0.0, zero_stack, 1.0, int_stack+213452, 1.0, int_stack+221132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+72156,int_stack+71715, 0.0, zero_stack, 1.0, int_stack+213767, 1.0, int_stack+221447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+63990,int_stack+269416,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+344152, 1.0, int_stack+371656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+63990,int_stack+62640,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+65880,int_stack+444583,int_stack+49140,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+62640,int_stack+73164,int_stack+72744, 0.0, zero_stack, 1.0, int_stack+99448, 1.0, int_stack+105192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+73752,int_stack+73164, 0.0, zero_stack, 1.0, int_stack+100288, 1.0, int_stack+106032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+71280,int_stack+47790,int_stack+62640, 0.0, zero_stack, 1.0, int_stack+349147, 1.0, int_stack+376651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+602461,int_stack+71280,int_stack+63990,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+670501,int_stack+602461,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+74686,int_stack+74536, 0.0, zero_stack, 2.0, int_stack+217932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+74896,int_stack+74686, 0.0, zero_stack, 2.0, int_stack+218082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445033,int_stack+260596,int_stack+444583, 0.0, zero_stack, 2.0, int_stack+369631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+445933,int_stack+75401,int_stack+75176, 0.0, zero_stack, 2.0, int_stack+219212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446608,int_stack+75716,int_stack+75401, 0.0, zero_stack, 2.0, int_stack+219437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+602461,int_stack+446608,int_stack+445933, 0.0, zero_stack, 2.0, int_stack+370981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+445933,int_stack+602461,int_stack+445033,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+76451,int_stack+76136, 0.0, zero_stack, 2.0, int_stack+221132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+76892,int_stack+76451, 0.0, zero_stack, 2.0, int_stack+221447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+603811,int_stack+269416,int_stack+444583, 0.0, zero_stack, 2.0, int_stack+371656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+603811,int_stack+602461,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+71280,int_stack+47790,int_stack+445933,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+602461,int_stack+77900,int_stack+77480, 0.0, zero_stack, 2.0, int_stack+105192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+78488,int_stack+77900, 0.0, zero_stack, 2.0, int_stack+106032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+76680,int_stack+444583,int_stack+602461, 0.0, zero_stack, 2.0, int_stack+376651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+648631,int_stack+76680,int_stack+603811,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+678601,int_stack+648631,int_stack+47790,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+79422,int_stack+79272, 1.0, int_stack+187212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225612,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+260596,int_stack+79632,int_stack+79422, 1.0, int_stack+187362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225762,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48240,int_stack+260596,int_stack+47790, 1.0, int_stack+260146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399025,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+260146,int_stack+80137,int_stack+79912, 1.0, int_stack+188492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226892,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49140,int_stack+80452,int_stack+80137, 1.0, int_stack+188717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227117,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50085,int_stack+49140,int_stack+260146, 1.0, int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400375,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+50085,int_stack+48240,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+260146,int_stack+81187,int_stack+80872, 1.0, int_stack+190412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229127,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+269416,int_stack+81628,int_stack+81187, 1.0, int_stack+190727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229883,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+47790,int_stack+269416,int_stack+260146, 1.0, int_stack+268471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401050,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+47790,int_stack+50085,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+648631,int_stack+444583,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+83644,int_stack+82636, 1.0, int_stack+82216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111356,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+268471,int_stack+84232,int_stack+83644, 1.0, int_stack+83056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112196,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+76680,int_stack+268471,int_stack+39690, 1.0, int_stack+282079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406045,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+602461,int_stack+76680,int_stack+47790,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+76680,int_stack+602461,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+85166,int_stack+85016, 1.0, int_stack+194892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225612, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+445033,int_stack+85376,int_stack+85166, 1.0, int_stack+195042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225762, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445663,int_stack+445033,int_stack+444583, 1.0, int_stack+283339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399025, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+85881,int_stack+85656, 1.0, int_stack+196172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226892, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+86196,int_stack+85881, 1.0, int_stack+196397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227117, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+446563,int_stack+444583,int_stack+262801, 1.0, int_stack+284689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400375, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+446563,int_stack+445663,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+86931,int_stack+86616, 1.0, int_stack+198092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229127, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+602461,int_stack+87372,int_stack+86931, 1.0, int_stack+198407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229883, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+603784,int_stack+602461,int_stack+444583, 1.0, int_stack+285364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401050, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+603784,int_stack+446563,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+686701,int_stack+47790,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+89388,int_stack+88380, 1.0, int_stack+87960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111356, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+89976,int_stack+89388, 1.0, int_stack+88800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112196, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+84780,int_stack+444583,int_stack+39690, 1.0, int_stack+290359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406045, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+692101,int_stack+84780,int_stack+603784,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+697771,int_stack+692101,int_stack+47790,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+90910,int_stack+90760, 1.0, int_stack+202572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225612, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48240,int_stack+91120,int_stack+90910, 1.0, int_stack+202722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225762, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48870,int_stack+48240,int_stack+47790, 1.0, int_stack+312733, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399025, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+91625,int_stack+91400, 1.0, int_stack+203852, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226892, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+91940,int_stack+91625, 1.0, int_stack+204077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227117, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49770,int_stack+47790,int_stack+262801, 1.0, int_stack+314083, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+49770,int_stack+48870,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+92675,int_stack+92360, 1.0, int_stack+205772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229127, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692101,int_stack+93116,int_stack+92675, 1.0, int_stack+206087, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229883, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+693424,int_stack+692101,int_stack+47790, 1.0, int_stack+314758, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401050, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+693424,int_stack+49770,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+84780,int_stack+444583,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+95132,int_stack+94124, 1.0, int_stack+93704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111356, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+95720,int_stack+95132, 1.0, int_stack+94544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112196, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+90180,int_stack+47790,int_stack+39690, 1.0, int_stack+319753, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406045, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+602461,int_stack+90180,int_stack+693424,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+705871,int_stack+602461,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+312733,int_stack+96654,int_stack+96504, 1.0, int_stack+210252, 0.0, zero_stack, 1.0, int_stack+225612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+96864,int_stack+96654, 1.0, int_stack+210402, 0.0, zero_stack, 1.0, int_stack+225762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+312733, 1.0, int_stack+342127, 0.0, zero_stack, 1.0, int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+97369,int_stack+97144, 1.0, int_stack+211532, 0.0, zero_stack, 1.0, int_stack+226892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446113,int_stack+97684,int_stack+97369, 1.0, int_stack+211757, 0.0, zero_stack, 1.0, int_stack+227117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+447058,int_stack+446113,int_stack+262801, 1.0, int_stack+343477, 0.0, zero_stack, 1.0, int_stack+400375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+447058,int_stack+445213,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+211532,int_stack+98419,int_stack+98104, 1.0, int_stack+213452, 0.0, zero_stack, 1.0, int_stack+229127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+98860,int_stack+98419, 1.0, int_stack+213767, 0.0, zero_stack, 1.0, int_stack+229883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+602461,int_stack+444583,int_stack+211532, 1.0, int_stack+344152, 0.0, zero_stack, 1.0, int_stack+401050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+602461,int_stack+447058,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+90180,int_stack+47790,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+100876,int_stack+99868, 1.0, int_stack+99448, 0.0, zero_stack, 1.0, int_stack+111356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+101464,int_stack+100876, 1.0, int_stack+100288, 0.0, zero_stack, 1.0, int_stack+112196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+604351,int_stack+444583,int_stack+39690, 1.0, int_stack+349147, 0.0, zero_stack, 1.0, int_stack+406045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+692101,int_stack+604351,int_stack+602461,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+713971,int_stack+692101,int_stack+47790,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+342127,int_stack+102398,int_stack+102248, 1.0, int_stack+217932, 1.0, int_stack+225612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+102608,int_stack+102398, 1.0, int_stack+218082, 1.0, int_stack+225762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+342127, 1.0, int_stack+369631, 1.0, int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+103113,int_stack+102888, 1.0, int_stack+219212, 1.0, int_stack+226892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49320,int_stack+103428,int_stack+103113, 1.0, int_stack+219437, 1.0, int_stack+227117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50265,int_stack+49320,int_stack+262801, 1.0, int_stack+370981, 1.0, int_stack+400375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+50265,int_stack+48420,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+219212,int_stack+104163,int_stack+103848, 1.0, int_stack+221132, 1.0, int_stack+229127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+104604,int_stack+104163, 1.0, int_stack+221447, 1.0, int_stack+229883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+692101,int_stack+47790,int_stack+219212, 1.0, int_stack+371656, 1.0, int_stack+401050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+692101,int_stack+50265,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+602461,int_stack+444583,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+106620,int_stack+105612, 1.0, int_stack+105192, 1.0, int_stack+111356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+107208,int_stack+106620, 1.0, int_stack+106032, 1.0, int_stack+112196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+693991,int_stack+47790,int_stack+39690, 1.0, int_stack+376651, 1.0, int_stack+406045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+95580,int_stack+693991,int_stack+692101,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+722071,int_stack+95580,int_stack+444583,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+369631,int_stack+108142,int_stack+107992, 2.0, int_stack+225612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+108352,int_stack+108142, 2.0, int_stack+225762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+369631, 2.0, int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+108857,int_stack+108632, 2.0, int_stack+226892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446113,int_stack+109172,int_stack+108857, 2.0, int_stack+227117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+447058,int_stack+446113,int_stack+262801, 2.0, int_stack+400375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+447058,int_stack+445213,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+226892,int_stack+109907,int_stack+109592, 2.0, int_stack+229127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+110348,int_stack+109907, 2.0, int_stack+229883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+444583,int_stack+226892, 2.0, int_stack+401050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+447058,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+97470,int_stack+47790,int_stack+39690,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+112784,int_stack+111776, 2.0, int_stack+111356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+113372,int_stack+112784, 2.0, int_stack+112196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+102870,int_stack+444583,int_stack+39690, 2.0, int_stack+406045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+692101,int_stack+102870,int_stack+95580,90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+102870,int_stack+692101,int_stack+47790,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+114306,int_stack+114156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235056,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+114516,int_stack+114306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235206,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+115021,int_stack+114796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236336,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49320,int_stack+115336,int_stack+115021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236561,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50265,int_stack+49320,int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+50265,int_stack+48420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+116071,int_stack+115756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238256,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48735,int_stack+116512,int_stack+116071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238571,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+48735,int_stack+47790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426529,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+95580,int_stack+50265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+692101,int_stack+444583,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+117520,int_stack+117100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140780,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+118108,int_stack+117520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+110970,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431524,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+730171,int_stack+110970,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+735841,int_stack+730171,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+119042,int_stack+118892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235056, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+119252,int_stack+119042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235206, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+119757,int_stack+119532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236336, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446113,int_stack+120072,int_stack+119757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236561, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+447058,int_stack+446113,int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+447058,int_stack+445213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+120807,int_stack+120492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238256, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+445528,int_stack+121248,int_stack+120807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238571, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+445528,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426529, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+447058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+730171,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+122256,int_stack+121836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140780, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+122844,int_stack+122256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+110970,int_stack+444583,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431524, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+113490,int_stack+110970,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+743941,int_stack+113490,int_stack+47790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+123778,int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235056, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+123988,int_stack+123778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235206, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+124493,int_stack+124268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236336, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49320,int_stack+124808,int_stack+124493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236561, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50265,int_stack+49320,int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+50265,int_stack+48420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+125543,int_stack+125228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238256, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48735,int_stack+125984,int_stack+125543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238571, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+48735,int_stack+47790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426529, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+95580,int_stack+50265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+110970,int_stack+444583,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+126992,int_stack+126572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+127580,int_stack+126992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+116370,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431524, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+118890,int_stack+116370,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+752041,int_stack+118890,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+128514,int_stack+128364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+128724,int_stack+128514, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+129229,int_stack+129004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+446113,int_stack+129544,int_stack+129229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+447058,int_stack+446113,int_stack+262801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+447058,int_stack+445213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+444583,int_stack+130279,int_stack+129964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+445528,int_stack+130720,int_stack+130279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+445528,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+447058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+116370,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+131728,int_stack+131308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+132316,int_stack+131728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+121770,int_stack+444583,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+124290,int_stack+121770,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+760141,int_stack+124290,int_stack+47790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+133250,int_stack+133100, 0.0, zero_stack, 1.0, int_stack+235056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+133460,int_stack+133250, 0.0, zero_stack, 1.0, int_stack+235206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+133965,int_stack+133740, 0.0, zero_stack, 1.0, int_stack+236336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49320,int_stack+134280,int_stack+133965, 0.0, zero_stack, 1.0, int_stack+236561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50265,int_stack+49320,int_stack+262801, 0.0, zero_stack, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+50265,int_stack+48420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47790,int_stack+135015,int_stack+134700, 0.0, zero_stack, 1.0, int_stack+238256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48735,int_stack+135456,int_stack+135015, 0.0, zero_stack, 1.0, int_stack+238571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+48735,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+95580,int_stack+50265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+372601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+121770,int_stack+444583,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+136464,int_stack+136044, 0.0, zero_stack, 1.0, int_stack+140780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+137052,int_stack+136464, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+127170,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+431524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+129690,int_stack+127170,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+768241,int_stack+129690,int_stack+444583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+137986,int_stack+137836, 1.0, int_stack+235056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+138196,int_stack+137986, 1.0, int_stack+235206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+399025, 1.0, int_stack+259696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262801,int_stack+138701,int_stack+138476, 1.0, int_stack+236336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259696,int_stack+139016,int_stack+138701, 1.0, int_stack+236561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+446113,int_stack+259696,int_stack+262801, 1.0, int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+446113,int_stack+445213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262126,int_stack+139751,int_stack+139436, 1.0, int_stack+238256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259696,int_stack+140192,int_stack+139751, 1.0, int_stack+238571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+259696,int_stack+262126, 1.0, int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+446113, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+127170,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+142208,int_stack+141200, 1.0, int_stack+140780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+142796,int_stack+142208, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+132570,int_stack+444583,int_stack+39690, 1.0, int_stack+431524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+135090,int_stack+132570,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+776341,int_stack+135090,int_stack+47790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+143730,int_stack+143580,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+143940,int_stack+143730,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+144445,int_stack+144220,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+144760,int_stack+144445,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+263476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+145495,int_stack+145180,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+145936,int_stack+145495,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+434737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+132570,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+454033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+146944,int_stack+146524,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+137970,int_stack+147532,int_stack+146944,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+139734,int_stack+137970,int_stack+39690,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+142254,int_stack+139734,int_stack+95580, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+456733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+784441,int_stack+142254,int_stack+47790, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+458623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+148466,int_stack+148316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242736,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+148676,int_stack+148466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242886,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468073,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+149181,int_stack+148956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244016,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+149496,int_stack+149181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244241,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469423,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+261226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+150231,int_stack+149916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245936,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+150672,int_stack+150231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246251,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470098,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+264421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+137970,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+265771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+151680,int_stack+151260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174940,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+143370,int_stack+152268,int_stack+151680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175780,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+145134,int_stack+143370,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475093,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+428734,int_stack+145134,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+270739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+143370,int_stack+428734,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+272629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+153202,int_stack+153052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242736, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+153412,int_stack+153202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242886, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468073, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+153917,int_stack+153692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244016, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+154232,int_stack+153917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244241, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469423, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+283789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+154967,int_stack+154652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245936, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+155408,int_stack+154967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246251, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470098, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+286309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+428734,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+287659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+156416,int_stack+155996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174940, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+151470,int_stack+157004,int_stack+156416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175780, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+153234,int_stack+151470,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475093, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+792541,int_stack+153234,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+301393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+798211,int_stack+792541,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+303283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+157938,int_stack+157788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242736, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+158148,int_stack+157938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242886, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468073, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+158653,int_stack+158428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244016, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+158968,int_stack+158653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244241, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469423, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+313183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+159703,int_stack+159388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245936, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+160144,int_stack+159703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246251, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470098, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+315703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+792541,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+317053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+161152,int_stack+160732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174940, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+151470,int_stack+161740,int_stack+161152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+153234,int_stack+151470,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475093, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+155754,int_stack+153234,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+330787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+806311,int_stack+155754,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+332677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+162674,int_stack+162524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+162884,int_stack+162674, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+163389,int_stack+163164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+163704,int_stack+163389, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+342577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+164439,int_stack+164124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+164880,int_stack+164439, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+345097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+151470,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+346447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+165888,int_stack+165468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+156870,int_stack+166476,int_stack+165888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+158634,int_stack+156870,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+161154,int_stack+158634,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+814411,int_stack+161154,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+360181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+167410,int_stack+167260, 0.0, zero_stack, 1.0, int_stack+242736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+167620,int_stack+167410, 0.0, zero_stack, 1.0, int_stack+242886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 0.0, zero_stack, 1.0, int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+168125,int_stack+167900, 0.0, zero_stack, 1.0, int_stack+244016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+168440,int_stack+168125, 0.0, zero_stack, 1.0, int_stack+244241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 0.0, zero_stack, 1.0, int_stack+469423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+370081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+169175,int_stack+168860, 0.0, zero_stack, 1.0, int_stack+245936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+169616,int_stack+169175, 0.0, zero_stack, 1.0, int_stack+246251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 1.0, int_stack+470098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+372601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+156870,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+373951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+170624,int_stack+170204, 0.0, zero_stack, 1.0, int_stack+174940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162270,int_stack+171212,int_stack+170624, 0.0, zero_stack, 1.0, int_stack+175780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+164034,int_stack+162270,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+475093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+822511,int_stack+164034,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+387685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+162270,int_stack+822511,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+389575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+399025,int_stack+172146,int_stack+171996, 1.0, int_stack+242736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+172356,int_stack+172146, 1.0, int_stack+242886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+399025, 1.0, int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+172861,int_stack+172636, 1.0, int_stack+244016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+173176,int_stack+172861, 1.0, int_stack+244241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 1.0, int_stack+469423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+399475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+173911,int_stack+173596, 1.0, int_stack+245936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+174352,int_stack+173911, 1.0, int_stack+246251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 1.0, int_stack+470098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+401995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+822511,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+403345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+176368,int_stack+175360, 1.0, int_stack+174940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+170370,int_stack+176956,int_stack+176368, 1.0, int_stack+175780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+172134,int_stack+170370,int_stack+39690, 1.0, int_stack+475093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+827911,int_stack+172134,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+833581,int_stack+827911,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+417079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+177890,int_stack+177740,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+178100,int_stack+177890,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+468073,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+178605,int_stack+178380,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+178920,int_stack+178605,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 1.0, int_stack+263476, 1.0, int_stack+468523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+179655,int_stack+179340,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+180096,int_stack+179655,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 1.0, int_stack+434737, 1.0, int_stack+471043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+827911,int_stack+47790,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+454033, 1.0, int_stack+472393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+181104,int_stack+180684,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+475093,int_stack+181692,int_stack+181104,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+170370,int_stack+475093,int_stack+39690,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+172890,int_stack+170370,int_stack+95580, 0.0, zero_stack, 1.0, int_stack+456733, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+841681,int_stack+172890,int_stack+47790, 0.0, zero_stack, 1.0, int_stack+458623, 1.0, int_stack+486127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+182626,int_stack+182476,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+182836,int_stack+182626,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+468073,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+183341,int_stack+183116,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+183656,int_stack+183341,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 0.0, zero_stack, 2.0, int_stack+468523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+184391,int_stack+184076,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+184832,int_stack+184391,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 0.0, zero_stack, 2.0, int_stack+471043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+170370,int_stack+47790,int_stack+39690, 0.0, zero_stack, 2.0, int_stack+472393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+185840,int_stack+185420,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+175770,int_stack+186428,int_stack+185840,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+177534,int_stack+175770,int_stack+39690,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+180054,int_stack+177534,int_stack+95580, 0.0, zero_stack, 2.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+849781,int_stack+180054,int_stack+47790, 0.0, zero_stack, 2.0, int_stack+486127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+188002,int_stack+187852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251056,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+188212,int_stack+188002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251206,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495577,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+189677,int_stack+189452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253296,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+189992,int_stack+189677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253521,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262126,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496927,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+262126,int_stack+48420, 1.0, int_stack+261226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+192071,int_stack+191756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255216,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+192512,int_stack+192071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255531,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497602,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+262126, 1.0, int_stack+264421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+175770,int_stack+47790,int_stack+39690, 1.0, int_stack+265771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+193520,int_stack+193100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232256,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+181170,int_stack+194108,int_stack+193520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233096,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+182934,int_stack+181170,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427474,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+185454,int_stack+182934,int_stack+95580, 1.0, int_stack+270739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+264376,int_stack+185454,int_stack+47790, 1.0, int_stack+272629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+195682,int_stack+195532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251056, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+195892,int_stack+195682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251206, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495577, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+197357,int_stack+197132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253296, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+197672,int_stack+197357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253521, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49995,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496927, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+49995,int_stack+48420, 1.0, int_stack+283789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+199751,int_stack+199436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255216, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+200192,int_stack+199751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255531, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497602, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+95580,int_stack+49995, 1.0, int_stack+286309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+181170,int_stack+444583,int_stack+39690, 1.0, int_stack+287659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+201200,int_stack+200780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232256, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+201788,int_stack+201200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233096, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+186570,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427474, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+189090,int_stack+186570,int_stack+95580, 1.0, int_stack+301393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+194760,int_stack+189090,int_stack+444583, 1.0, int_stack+303283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+203362,int_stack+203212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251056, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+203572,int_stack+203362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251206, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495577, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+446113,int_stack+205037,int_stack+204812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253296, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+205352,int_stack+205037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253521, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+446788,int_stack+426529,int_stack+446113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496927, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+446788,int_stack+445213, 1.0, int_stack+313183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+207431,int_stack+207116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255216, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+207872,int_stack+207431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255531, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+444583,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497602, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+47790,int_stack+95580,int_stack+446788, 1.0, int_stack+315703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+301393,int_stack+47790,int_stack+39690, 1.0, int_stack+317053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+208880,int_stack+208460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232256, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+209468,int_stack+208880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233096, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+186570,int_stack+444583,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+189090,int_stack+186570,int_stack+95580, 1.0, int_stack+330787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+312733,int_stack+189090,int_stack+47790, 1.0, int_stack+332677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+211042,int_stack+210892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+211252,int_stack+211042, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47790,int_stack+468073, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49320,int_stack+212717,int_stack+212492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+213032,int_stack+212717, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49995,int_stack+426529,int_stack+49320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+49995,int_stack+48420, 1.0, int_stack+342577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+215111,int_stack+214796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+215552,int_stack+215111, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+47790,int_stack+426529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+95580,int_stack+49995, 1.0, int_stack+345097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+330787,int_stack+444583,int_stack+39690, 1.0, int_stack+346447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+216560,int_stack+216140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47790,int_stack+217148,int_stack+216560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+186570,int_stack+47790,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+189090,int_stack+186570,int_stack+95580, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+202860,int_stack+189090,int_stack+444583, 1.0, int_stack+360181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+218722,int_stack+218572, 0.0, zero_stack, 1.0, int_stack+251056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+360181,int_stack+218932,int_stack+218722, 0.0, zero_stack, 1.0, int_stack+251206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+360811,int_stack+360181,int_stack+468073, 0.0, zero_stack, 1.0, int_stack+495577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+361711,int_stack+220397,int_stack+220172, 0.0, zero_stack, 1.0, int_stack+253296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+220712,int_stack+220397, 0.0, zero_stack, 1.0, int_stack+253521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+362386,int_stack+426529,int_stack+361711, 0.0, zero_stack, 1.0, int_stack+496927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+362386,int_stack+360811, 1.0, int_stack+370081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+222791,int_stack+222476, 0.0, zero_stack, 1.0, int_stack+255216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+360181,int_stack+223232,int_stack+222791, 0.0, zero_stack, 1.0, int_stack+255531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+360181,int_stack+426529, 0.0, zero_stack, 1.0, int_stack+497602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+444583,int_stack+0,int_stack+362386, 1.0, int_stack+372601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+186570,int_stack+444583,int_stack+39690, 1.0, int_stack+373951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+224240,int_stack+223820, 0.0, zero_stack, 1.0, int_stack+232256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+360181,int_stack+224828,int_stack+224240, 0.0, zero_stack, 1.0, int_stack+233096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+191970,int_stack+360181,int_stack+39690, 0.0, zero_stack, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+210960,int_stack+191970,int_stack+0, 1.0, int_stack+387685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+216630,int_stack+210960,int_stack+444583, 1.0, int_stack+389575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+468073,int_stack+226402,int_stack+226252, 1.0, int_stack+251056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+226612,int_stack+226402, 1.0, int_stack+251206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+445213,int_stack+444583,int_stack+468073, 1.0, int_stack+495577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+446113,int_stack+228077,int_stack+227852, 1.0, int_stack+253296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+426529,int_stack+228392,int_stack+228077, 1.0, int_stack+253521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+446788,int_stack+426529,int_stack+446113, 1.0, int_stack+496927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+446788,int_stack+445213, 1.0, int_stack+399475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+426529,int_stack+231227,int_stack+230912, 1.0, int_stack+255216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+231668,int_stack+231227, 1.0, int_stack+255531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+444583,int_stack+426529, 1.0, int_stack+497602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+360181,int_stack+0,int_stack+446788, 1.0, int_stack+401995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+210960,int_stack+360181,int_stack+39690, 1.0, int_stack+403345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+233684,int_stack+232676, 1.0, int_stack+232256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444583,int_stack+234272,int_stack+233684, 1.0, int_stack+233096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+387685,int_stack+444583,int_stack+39690, 1.0, int_stack+427474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+224730,int_stack+387685,int_stack+0, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+399025,int_stack+224730,int_stack+360181, 1.0, int_stack+417079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+495577,int_stack+235846,int_stack+235696,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+417079,int_stack+236056,int_stack+235846,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+417709,int_stack+417079,int_stack+495577,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+418609,int_stack+237521,int_stack+237296,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+419284,int_stack+237836,int_stack+237521,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+360181,int_stack+419284,int_stack+418609,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+361531,int_stack+360181,int_stack+417709, 1.0, int_stack+263476, 0.0, zero_stack, 1.0, int_stack+496027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+417079,int_stack+239915,int_stack+239600,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+418024,int_stack+240356,int_stack+239915,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+418024,int_stack+417079,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+417079,int_stack+95580,int_stack+360181, 1.0, int_stack+434737, 0.0, zero_stack, 1.0, int_stack+498547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+224730,int_stack+417079,int_stack+361531, 1.0, int_stack+454033, 0.0, zero_stack, 1.0, int_stack+499897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+454033,int_stack+241364,int_stack+240944,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+360181,int_stack+241952,int_stack+241364,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+230130,int_stack+360181,int_stack+454033,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+232650,int_stack+230130,int_stack+95580, 1.0, int_stack+456733, 0.0, zero_stack, 1.0, int_stack+502597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+369631,int_stack+232650,int_stack+417079, 1.0, int_stack+458623, 0.0, zero_stack, 1.0, int_stack+513631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+495577,int_stack+243526,int_stack+243376,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+417079,int_stack+243736,int_stack+243526,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+417709,int_stack+417079,int_stack+495577,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+418609,int_stack+245201,int_stack+244976,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+419284,int_stack+245516,int_stack+245201,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+95580,int_stack+419284,int_stack+418609,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+95580,int_stack+417709, 1.0, int_stack+468523, 1.0, int_stack+496027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+417079,int_stack+247595,int_stack+247280,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+418024,int_stack+248036,int_stack+247595,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+230130,int_stack+418024,int_stack+417079,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+417079,int_stack+230130,int_stack+95580, 1.0, int_stack+471043, 1.0, int_stack+498547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+232020,int_stack+417079,int_stack+39690, 1.0, int_stack+472393, 1.0, int_stack+499897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+39690,int_stack+249044,int_stack+248624,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+95580,int_stack+249632,int_stack+249044,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+237420,int_stack+95580,int_stack+39690,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+239940,int_stack+237420,int_stack+230130, 1.0, int_stack+3780, 1.0, int_stack+502597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+454033,int_stack+239940,int_stack+417079, 1.0, int_stack+486127, 1.0, int_stack+513631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+495577,int_stack+251846,int_stack+251696,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+486127,int_stack+252056,int_stack+251846,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+486757,int_stack+486127,int_stack+495577,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+487657,int_stack+254481,int_stack+254256,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+488332,int_stack+254796,int_stack+254481,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+417079,int_stack+488332,int_stack+487657,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+418429,int_stack+417079,int_stack+486757, 2.0, int_stack+496027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+495577,int_stack+256875,int_stack+256560,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+496522,int_stack+257316,int_stack+256875,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+230130,int_stack+496522,int_stack+495577,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+486127,int_stack+230130,int_stack+417079, 2.0, int_stack+498547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+237420,int_stack+486127,int_stack+418429, 2.0, int_stack+499897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+417079,int_stack+258324,int_stack+257904,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+418339,int_stack+258912,int_stack+258324,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+495577,int_stack+418339,int_stack+417079,28);
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+495577,int_stack+230130, 2.0, int_stack+502597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (gd|gd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+495577,int_stack+0,int_stack+486127, 2.0, int_stack+513631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+242820,int_stack+293293,int_stack+276679,90);
     Libderiv->ABCD[11] = int_stack + 242820;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+251820,int_stack+322687,int_stack+307333,90);
     Libderiv->ABCD[10] = int_stack + 251820;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+468073,int_stack+352081,int_stack+336727,90);
     Libderiv->ABCD[9] = int_stack + 468073;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+342127,int_stack+379585,int_stack+364231,90);
     Libderiv->ABCD[8] = int_stack + 342127;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+377731,int_stack+408979,int_stack+393625,90);
     Libderiv->ABCD[7] = int_stack + 377731;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+407125,int_stack+436483,int_stack+421129,90);
     Libderiv->ABCD[6] = int_stack + 407125;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+434134,int_stack+478027,int_stack+462673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[2] = int_stack + 434134;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+477073,int_stack+505531,int_stack+490177, 0.0, zero_stack, 1.0, int_stack+448633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[1] = int_stack + 477073;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+503677,int_stack+528751,int_stack+517681, 1.0, int_stack+448633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[0] = int_stack + 503677;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+443134,int_stack+547921,int_stack+536851,90);
     Libderiv->ABCD[155] = int_stack + 443134;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+351127,int_stack+5670,int_stack+542251,90);
     Libderiv->ABCD[143] = int_stack + 351127;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+0,int_stack+567091,int_stack+556021,90);
     Libderiv->ABCD[142] = int_stack + 0;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+320833,int_stack+13770,int_stack+561421,90);
     Libderiv->ABCD[131] = int_stack + 320833;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+9000,int_stack+586261,int_stack+575191,90);
     Libderiv->ABCD[130] = int_stack + 9000;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+282079,int_stack+594361,int_stack+28890,90);
     Libderiv->ABCD[129] = int_stack + 282079;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+291079,int_stack+608131,int_stack+21870,90);
     Libderiv->ABCD[119] = int_stack + 291079;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+18000,int_stack+616231,int_stack+34290,90);
     Libderiv->ABCD[118] = int_stack + 18000;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+27000,int_stack+624331,int_stack+580591,90);
     Libderiv->ABCD[117] = int_stack + 27000;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+607861,int_stack+632431,int_stack+42390,90);
     Libderiv->ABCD[116] = int_stack + 607861;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+36000,int_stack+640531,int_stack+51840,90);
     Libderiv->ABCD[107] = int_stack + 36000;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+45000,int_stack+654301,int_stack+57240,90);
     Libderiv->ABCD[106] = int_stack + 45000;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+54000,int_stack+662401,int_stack+523081,90);
     Libderiv->ABCD[105] = int_stack + 54000;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+523081,int_stack+670501,int_stack+65880,90);
     Libderiv->ABCD[104] = int_stack + 523081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+532081,int_stack+678601,int_stack+71280,90);
     Libderiv->ABCD[103] = int_stack + 532081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+541081,int_stack+76680,int_stack+648631,90);
     Libderiv->ABCD[95] = int_stack + 541081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+550081,int_stack+697771,int_stack+686701,90);
     Libderiv->ABCD[94] = int_stack + 550081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+559081,int_stack+705871,int_stack+84780,90);
     Libderiv->ABCD[93] = int_stack + 559081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+568081,int_stack+713971,int_stack+90180,90);
     Libderiv->ABCD[92] = int_stack + 568081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+577081,int_stack+722071,int_stack+602461,90);
     Libderiv->ABCD[91] = int_stack + 577081;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+586081,int_stack+102870,int_stack+97470,90);
     Libderiv->ABCD[90] = int_stack + 586081;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+595081,int_stack+735841,int_stack+692101, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[47] = int_stack + 595081;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+63000,int_stack+743941,int_stack+730171, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[46] = int_stack + 63000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+72000,int_stack+752041,int_stack+110970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[45] = int_stack + 72000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+81000,int_stack+760141,int_stack+116370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[44] = int_stack + 81000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+90000,int_stack+768241,int_stack+121770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[43] = int_stack + 90000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+99000,int_stack+776341,int_stack+127170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[42] = int_stack + 99000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+108000,int_stack+784441,int_stack+132570, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+462673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[38] = int_stack + 108000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+117000,int_stack+143370,int_stack+137970, 0.0, zero_stack, 1.0, int_stack+276679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[35] = int_stack + 117000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+126000,int_stack+798211,int_stack+428734, 0.0, zero_stack, 1.0, int_stack+307333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[34] = int_stack + 126000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+135000,int_stack+806311,int_stack+792541, 0.0, zero_stack, 1.0, int_stack+336727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[33] = int_stack + 135000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+616861,int_stack+814411,int_stack+151470, 0.0, zero_stack, 1.0, int_stack+364231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[32] = int_stack + 616861;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+144000,int_stack+162270,int_stack+156870, 0.0, zero_stack, 1.0, int_stack+393625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[31] = int_stack + 144000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+153000,int_stack+833581,int_stack+822511, 0.0, zero_stack, 1.0, int_stack+421129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[30] = int_stack + 153000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+625861,int_stack+841681,int_stack+827911, 0.0, zero_stack, 1.0, int_stack+462673, 1.0, int_stack+490177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[26] = int_stack + 625861;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+634861,int_stack+849781,int_stack+170370, 0.0, zero_stack, 2.0, int_stack+490177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[25] = int_stack + 634861;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+162000,int_stack+264376,int_stack+175770, 1.0, int_stack+276679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[23] = int_stack + 162000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+171000,int_stack+194760,int_stack+181170, 1.0, int_stack+307333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[22] = int_stack + 171000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+260820,int_stack+312733,int_stack+301393, 1.0, int_stack+336727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[21] = int_stack + 260820;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+269820,int_stack+202860,int_stack+330787, 1.0, int_stack+364231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[20] = int_stack + 269820;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+191970,int_stack+216630,int_stack+186570, 1.0, int_stack+393625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[19] = int_stack + 191970;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+180000,int_stack+399025,int_stack+210960, 1.0, int_stack+421129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[18] = int_stack + 180000;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+200970,int_stack+369631,int_stack+224730, 1.0, int_stack+462673, 0.0, zero_stack, 1.0, int_stack+517681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[14] = int_stack + 200970;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+209970,int_stack+454033,int_stack+232020, 1.0, int_stack+490177, 1.0, int_stack+517681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[13] = int_stack + 209970;
 /*--- compute (ff|gd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+486073,int_stack+495577,int_stack+237420, 2.0, int_stack+517681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[12] = int_stack + 486073;

}
