/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (dd|hg) integrals */

void d12vrr_order_ddhg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+9, dvrr_stack+34, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+21, dvrr_stack+40, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+65, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+74, dvrr_stack+68, dvrr_stack+15, dvrr_stack+65, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+74, dvrr_stack+21, dvrr_stack+68, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+99, dvrr_stack+84, dvrr_stack+50, NULL, NULL, dvrr_stack+21);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+144, dvrr_stack+84, dvrr_stack+50, dvrr_stack+74, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+165, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+168, dvrr_stack+165, dvrr_stack+65, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+174, dvrr_stack+168, dvrr_stack+68, dvrr_stack+165, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+184, dvrr_stack+174, dvrr_stack+74, dvrr_stack+168, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+199, dvrr_stack+184, dvrr_stack+84, dvrr_stack+174, dvrr_stack+74, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+165, dvrr_stack+31, dvrr_stack+65, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+220, dvrr_stack+34, dvrr_stack+165, dvrr_stack+6, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+230, dvrr_stack+40, dvrr_stack+220, dvrr_stack+9, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+245, dvrr_stack+50, dvrr_stack+230, dvrr_stack+21, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+266, dvrr_stack+144, dvrr_stack+245, NULL, NULL, dvrr_stack+50);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+329, dvrr_stack+199, dvrr_stack+144, NULL, NULL, dvrr_stack+84);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+392, dvrr_stack+329, dvrr_stack+266, dvrr_stack+199, dvrr_stack+144, dvrr_stack+99);
 tmp = dvrr_stack + 392;
 target_ptr = Libderiv->dvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+518, dvrr_stack+144, dvrr_stack+245, dvrr_stack+84, dvrr_stack+50, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+546, dvrr_stack+199, dvrr_stack+144, dvrr_stack+184, dvrr_stack+84, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+171, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+574, dvrr_stack+65, dvrr_stack+171, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+580, dvrr_stack+165, dvrr_stack+574, dvrr_stack+31, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+590, dvrr_stack+220, dvrr_stack+580, dvrr_stack+34, dvrr_stack+165, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+605, dvrr_stack+230, dvrr_stack+590, dvrr_stack+40, dvrr_stack+220, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+626, dvrr_stack+245, dvrr_stack+605, dvrr_stack+50, dvrr_stack+230, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+654, dvrr_stack+518, dvrr_stack+626, NULL, NULL, dvrr_stack+245);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+738, dvrr_stack+546, dvrr_stack+518, NULL, NULL, dvrr_stack+144);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+822, dvrr_stack+738, dvrr_stack+654, dvrr_stack+546, dvrr_stack+518, dvrr_stack+266);
 tmp = dvrr_stack + 822;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+990,dvrr_stack+822,dvrr_stack+392,6);


 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1368, dvrr_stack+518, dvrr_stack+626, dvrr_stack+144, dvrr_stack+245, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1404, dvrr_stack+546, dvrr_stack+518, dvrr_stack+199, dvrr_stack+144, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1440, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1443, dvrr_stack+171, dvrr_stack+1440, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1449, dvrr_stack+574, dvrr_stack+1443, dvrr_stack+65, dvrr_stack+171, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1459, dvrr_stack+580, dvrr_stack+1449, dvrr_stack+165, dvrr_stack+574, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1474, dvrr_stack+590, dvrr_stack+1459, dvrr_stack+220, dvrr_stack+580, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1495, dvrr_stack+605, dvrr_stack+1474, dvrr_stack+230, dvrr_stack+590, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1523, dvrr_stack+626, dvrr_stack+1495, dvrr_stack+245, dvrr_stack+605, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1559, dvrr_stack+1368, dvrr_stack+1523, NULL, NULL, dvrr_stack+626);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1667, dvrr_stack+1404, dvrr_stack+1368, NULL, NULL, dvrr_stack+518);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1775, dvrr_stack+1667, dvrr_stack+1559, dvrr_stack+1404, dvrr_stack+1368, dvrr_stack+654);
 tmp = dvrr_stack + 1775;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+1991,dvrr_stack+1775,dvrr_stack+822,6);


 /* compute (2 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+2495,dvrr_stack+1991,dvrr_stack+990,6);


 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,126,dvrr_stack+3251, dvrr_stack+2495, dvrr_stack+392);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3629, dvrr_stack+1368, dvrr_stack+1523, dvrr_stack+518, dvrr_stack+626, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3674, dvrr_stack+1404, dvrr_stack+1368, dvrr_stack+546, dvrr_stack+518, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3719, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3722, dvrr_stack+1440, dvrr_stack+3719, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3728, dvrr_stack+1443, dvrr_stack+3722, dvrr_stack+171, dvrr_stack+1440, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3738, dvrr_stack+1449, dvrr_stack+3728, dvrr_stack+574, dvrr_stack+1443, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3753, dvrr_stack+1459, dvrr_stack+3738, dvrr_stack+580, dvrr_stack+1449, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3774, dvrr_stack+1474, dvrr_stack+3753, dvrr_stack+590, dvrr_stack+1459, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3802, dvrr_stack+1495, dvrr_stack+3774, dvrr_stack+605, dvrr_stack+1474, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3838, dvrr_stack+1523, dvrr_stack+3802, dvrr_stack+626, dvrr_stack+1495, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3883, dvrr_stack+3629, dvrr_stack+3838, NULL, NULL, dvrr_stack+1523);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4018, dvrr_stack+3674, dvrr_stack+3629, NULL, NULL, dvrr_stack+1368);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4153, dvrr_stack+4018, dvrr_stack+3883, dvrr_stack+3674, dvrr_stack+3629, dvrr_stack+1559);
 tmp = dvrr_stack + 4153;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+4423,dvrr_stack+4153,dvrr_stack+1775,6);


 /* compute (2 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+5071,dvrr_stack+4423,dvrr_stack+1991,6);


 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,168,dvrr_stack+6079, dvrr_stack+5071, dvrr_stack+822);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6583, dvrr_stack+3629, dvrr_stack+3838, dvrr_stack+1368, dvrr_stack+1523, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6638, dvrr_stack+3674, dvrr_stack+3629, dvrr_stack+1404, dvrr_stack+1368, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+171, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6693, dvrr_stack+3719, dvrr_stack+171, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6699, dvrr_stack+3722, dvrr_stack+6693, dvrr_stack+1440, dvrr_stack+3719, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6709, dvrr_stack+3728, dvrr_stack+6699, dvrr_stack+1443, dvrr_stack+3722, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6724, dvrr_stack+3738, dvrr_stack+6709, dvrr_stack+1449, dvrr_stack+3728, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6745, dvrr_stack+3753, dvrr_stack+6724, dvrr_stack+1459, dvrr_stack+3738, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6773, dvrr_stack+3774, dvrr_stack+6745, dvrr_stack+1474, dvrr_stack+3753, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6809, dvrr_stack+3802, dvrr_stack+6773, dvrr_stack+1495, dvrr_stack+3774, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6854, dvrr_stack+3838, dvrr_stack+6809, dvrr_stack+1523, dvrr_stack+3802, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6909, dvrr_stack+6583, dvrr_stack+6854, NULL, NULL, dvrr_stack+3838);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7074, dvrr_stack+6638, dvrr_stack+6583, NULL, NULL, dvrr_stack+3629);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7239, dvrr_stack+7074, dvrr_stack+6909, dvrr_stack+6638, dvrr_stack+6583, dvrr_stack+3883);
 tmp = dvrr_stack + 7239;
 target_ptr = Libderiv->dvrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+7569,dvrr_stack+7239,dvrr_stack+4153,6);


 /* compute (2 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+8379,dvrr_stack+7569,dvrr_stack+4423,6);


 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,216,dvrr_stack+9675, dvrr_stack+8379, dvrr_stack+1775);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10323, dvrr_stack+6583, dvrr_stack+6854, dvrr_stack+3629, dvrr_stack+3838, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10389, dvrr_stack+6638, dvrr_stack+6583, dvrr_stack+3674, dvrr_stack+3629, NULL);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1440, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1443, dvrr_stack+171, dvrr_stack+1440, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10455, dvrr_stack+6693, dvrr_stack+1443, dvrr_stack+3719, dvrr_stack+171, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10465, dvrr_stack+6699, dvrr_stack+10455, dvrr_stack+3722, dvrr_stack+6693, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10480, dvrr_stack+6709, dvrr_stack+10465, dvrr_stack+3728, dvrr_stack+6699, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10501, dvrr_stack+6724, dvrr_stack+10480, dvrr_stack+3738, dvrr_stack+6709, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10529, dvrr_stack+6745, dvrr_stack+10501, dvrr_stack+3753, dvrr_stack+6724, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10565, dvrr_stack+6773, dvrr_stack+10529, dvrr_stack+3774, dvrr_stack+6745, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10610, dvrr_stack+6809, dvrr_stack+10565, dvrr_stack+3802, dvrr_stack+6773, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10665, dvrr_stack+6854, dvrr_stack+10610, dvrr_stack+3838, dvrr_stack+6809, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10731, dvrr_stack+10323, dvrr_stack+10665, NULL, NULL, dvrr_stack+6854);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10929, dvrr_stack+10389, dvrr_stack+10323, NULL, NULL, dvrr_stack+6583);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11127, dvrr_stack+10929, dvrr_stack+10731, dvrr_stack+10389, dvrr_stack+10323, dvrr_stack+6909);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+11523,dvrr_stack+11127,dvrr_stack+7239,6);


 /* compute (2 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+12513,dvrr_stack+11523,dvrr_stack+7569,6);


 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,270,dvrr_stack+14133, dvrr_stack+12513, dvrr_stack+4153);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14943, dvrr_stack+10323, dvrr_stack+10665, dvrr_stack+6583, dvrr_stack+6854, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15021, dvrr_stack+10389, dvrr_stack+10323, dvrr_stack+6638, dvrr_stack+6583, NULL);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+10389, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+10392, dvrr_stack+1440, dvrr_stack+10389, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10398, dvrr_stack+1443, dvrr_stack+10392, dvrr_stack+171, dvrr_stack+1440, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10408, dvrr_stack+10455, dvrr_stack+10398, dvrr_stack+6693, dvrr_stack+1443, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10423, dvrr_stack+10465, dvrr_stack+10408, dvrr_stack+6699, dvrr_stack+10455, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+15099, dvrr_stack+10480, dvrr_stack+10423, dvrr_stack+6709, dvrr_stack+10465, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+15127, dvrr_stack+10501, dvrr_stack+15099, dvrr_stack+6724, dvrr_stack+10480, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15163, dvrr_stack+10529, dvrr_stack+15127, dvrr_stack+6745, dvrr_stack+10501, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15208, dvrr_stack+10565, dvrr_stack+15163, dvrr_stack+6773, dvrr_stack+10529, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+15263, dvrr_stack+10610, dvrr_stack+15208, dvrr_stack+6809, dvrr_stack+10565, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15329, dvrr_stack+10665, dvrr_stack+15263, dvrr_stack+6854, dvrr_stack+10610, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15407, dvrr_stack+14943, dvrr_stack+15329, NULL, NULL, dvrr_stack+10665);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15641, dvrr_stack+15021, dvrr_stack+14943, NULL, NULL, dvrr_stack+10323);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15875, dvrr_stack+15641, dvrr_stack+15407, dvrr_stack+15021, dvrr_stack+14943, dvrr_stack+10731);

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+16343,dvrr_stack+15875,dvrr_stack+11127,6);


 /* compute (2 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+17531,dvrr_stack+16343,dvrr_stack+11523,6);


 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,330,dvrr_stack+19511, dvrr_stack+17531, dvrr_stack+7239);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+15021, dvrr_stack+21, dvrr_stack+40, NULL, NULL, dvrr_stack+9);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+15051, dvrr_stack+50, dvrr_stack+230, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+20501, dvrr_stack+99, dvrr_stack+15051, dvrr_stack+84, dvrr_stack+50, dvrr_stack+15021);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+20591, dvrr_stack+245, dvrr_stack+605, NULL, NULL, dvrr_stack+230);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+20654, dvrr_stack+266, dvrr_stack+20591, dvrr_stack+144, dvrr_stack+245, dvrr_stack+15051);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+20780, dvrr_stack+392, dvrr_stack+20654, dvrr_stack+329, dvrr_stack+266, dvrr_stack+20501);
 tmp = dvrr_stack + 20780;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+20990, dvrr_stack+626, dvrr_stack+1495, NULL, NULL, dvrr_stack+605);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+21074, dvrr_stack+654, dvrr_stack+20990, dvrr_stack+518, dvrr_stack+626, dvrr_stack+20591);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+21242, dvrr_stack+822, dvrr_stack+21074, dvrr_stack+738, dvrr_stack+654, dvrr_stack+20654);
 tmp = dvrr_stack + 21242;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+21522,dvrr_stack+21242,dvrr_stack+20780,10);


 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22152, dvrr_stack+1523, dvrr_stack+3802, NULL, NULL, dvrr_stack+1495);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22260, dvrr_stack+1559, dvrr_stack+22152, dvrr_stack+1368, dvrr_stack+1523, dvrr_stack+20990);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22476, dvrr_stack+1775, dvrr_stack+22260, dvrr_stack+1667, dvrr_stack+1559, dvrr_stack+21074);
 tmp = dvrr_stack + 22476;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+22836,dvrr_stack+22476,dvrr_stack+21242,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+23676,dvrr_stack+22836,dvrr_stack+21522,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+24936, dvrr_stack+23676, dvrr_stack+20780);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+25566, dvrr_stack+3838, dvrr_stack+6809, NULL, NULL, dvrr_stack+3802);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+25701, dvrr_stack+3883, dvrr_stack+25566, dvrr_stack+3629, dvrr_stack+3838, dvrr_stack+22152);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+25971, dvrr_stack+4153, dvrr_stack+25701, dvrr_stack+4018, dvrr_stack+3883, dvrr_stack+22260);
 tmp = dvrr_stack + 25971;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+26421,dvrr_stack+25971,dvrr_stack+22476,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+27501,dvrr_stack+26421,dvrr_stack+22836,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+29181, dvrr_stack+27501, dvrr_stack+21242);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30021, dvrr_stack+6854, dvrr_stack+10610, NULL, NULL, dvrr_stack+6809);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30186, dvrr_stack+6909, dvrr_stack+30021, dvrr_stack+6583, dvrr_stack+6854, dvrr_stack+25566);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30516, dvrr_stack+7239, dvrr_stack+30186, dvrr_stack+7074, dvrr_stack+6909, dvrr_stack+25701);
 tmp = dvrr_stack + 30516;
 target_ptr = Libderiv->dvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+31066,dvrr_stack+30516,dvrr_stack+25971,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+32416,dvrr_stack+31066,dvrr_stack+26421,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+34576, dvrr_stack+32416, dvrr_stack+22476);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35656, dvrr_stack+10665, dvrr_stack+15263, NULL, NULL, dvrr_stack+10610);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35854, dvrr_stack+10731, dvrr_stack+35656, dvrr_stack+10323, dvrr_stack+10665, dvrr_stack+30021);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+36250, dvrr_stack+11127, dvrr_stack+35854, dvrr_stack+10929, dvrr_stack+10731, dvrr_stack+30186);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+36910,dvrr_stack+36250,dvrr_stack+30516,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+38560,dvrr_stack+36910,dvrr_stack+31066,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+41260, dvrr_stack+38560, dvrr_stack+25971);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+15096, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+10323, dvrr_stack+10389, dvrr_stack+15096, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10329, dvrr_stack+10392, dvrr_stack+10323, dvrr_stack+1440, dvrr_stack+10389, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10339, dvrr_stack+10398, dvrr_stack+10329, dvrr_stack+1443, dvrr_stack+10392, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+144, dvrr_stack+10408, dvrr_stack+10339, dvrr_stack+10455, dvrr_stack+10398, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+518, dvrr_stack+10423, dvrr_stack+144, dvrr_stack+10465, dvrr_stack+10408, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1368, dvrr_stack+15099, dvrr_stack+518, dvrr_stack+10480, dvrr_stack+10423, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3629, dvrr_stack+15127, dvrr_stack+1368, dvrr_stack+10501, dvrr_stack+15099, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6583, dvrr_stack+15163, dvrr_stack+3629, dvrr_stack+10529, dvrr_stack+15127, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42610, dvrr_stack+15208, dvrr_stack+6583, dvrr_stack+10565, dvrr_stack+15163, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42676, dvrr_stack+15263, dvrr_stack+42610, dvrr_stack+10610, dvrr_stack+15208, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42754, dvrr_stack+15329, dvrr_stack+42676, NULL, NULL, dvrr_stack+15263);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42988, dvrr_stack+15407, dvrr_stack+42754, dvrr_stack+14943, dvrr_stack+15329, dvrr_stack+35656);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43456, dvrr_stack+15875, dvrr_stack+42988, dvrr_stack+15641, dvrr_stack+15407, dvrr_stack+35854);

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+44236,dvrr_stack+43456,dvrr_stack+36250,10);


 /* compute (3 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+46216,dvrr_stack+44236,dvrr_stack+36910,10);


 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,550,dvrr_stack+49516, dvrr_stack+46216, dvrr_stack+30516);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+15641, dvrr_stack+9, dvrr_stack+34, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+15659, dvrr_stack+40, dvrr_stack+220, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+15689, dvrr_stack+15021, dvrr_stack+15659, dvrr_stack+21, dvrr_stack+40, dvrr_stack+15641);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+15749, dvrr_stack+230, dvrr_stack+590, NULL, NULL, dvrr_stack+220);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+51166, dvrr_stack+15051, dvrr_stack+15749, dvrr_stack+50, dvrr_stack+230, dvrr_stack+15659);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+51256, dvrr_stack+20501, dvrr_stack+51166, dvrr_stack+99, dvrr_stack+15051, dvrr_stack+15689);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+15794, dvrr_stack+605, dvrr_stack+1474, NULL, NULL, dvrr_stack+590);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+51406, dvrr_stack+20591, dvrr_stack+15794, dvrr_stack+245, dvrr_stack+605, dvrr_stack+15749);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+51532, dvrr_stack+20654, dvrr_stack+51406, dvrr_stack+266, dvrr_stack+20591, dvrr_stack+51166);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+51742, dvrr_stack+20780, dvrr_stack+51532, dvrr_stack+392, dvrr_stack+20654, dvrr_stack+51256);
 tmp = dvrr_stack + 51742;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+245, dvrr_stack+1495, dvrr_stack+3774, NULL, NULL, dvrr_stack+1474);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+52057, dvrr_stack+20990, dvrr_stack+245, dvrr_stack+626, dvrr_stack+1495, dvrr_stack+15794);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+52225, dvrr_stack+21074, dvrr_stack+52057, dvrr_stack+654, dvrr_stack+20990, dvrr_stack+51406);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+52505, dvrr_stack+21242, dvrr_stack+52225, dvrr_stack+822, dvrr_stack+21074, dvrr_stack+51532);
 tmp = dvrr_stack + 52505;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+52925,dvrr_stack+52505,dvrr_stack+51742,15);


 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+626, dvrr_stack+3802, dvrr_stack+6773, NULL, NULL, dvrr_stack+3774);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53870, dvrr_stack+22152, dvrr_stack+626, dvrr_stack+1523, dvrr_stack+3802, dvrr_stack+245);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+54086, dvrr_stack+22260, dvrr_stack+53870, dvrr_stack+1559, dvrr_stack+22152, dvrr_stack+52057);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+54446, dvrr_stack+22476, dvrr_stack+54086, dvrr_stack+1775, dvrr_stack+22260, dvrr_stack+52225);
 tmp = dvrr_stack + 54446;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+54986,dvrr_stack+54446,dvrr_stack+52505,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+56246,dvrr_stack+54986,dvrr_stack+52925,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+58136, dvrr_stack+56246, dvrr_stack+51742);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1523, dvrr_stack+6809, dvrr_stack+10565, NULL, NULL, dvrr_stack+6773);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+59081, dvrr_stack+25566, dvrr_stack+1523, dvrr_stack+3838, dvrr_stack+6809, dvrr_stack+626);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+59351, dvrr_stack+25701, dvrr_stack+59081, dvrr_stack+3883, dvrr_stack+25566, dvrr_stack+53870);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+59801, dvrr_stack+25971, dvrr_stack+59351, dvrr_stack+4153, dvrr_stack+25701, dvrr_stack+54086);
 tmp = dvrr_stack + 59801;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+60476,dvrr_stack+59801,dvrr_stack+54446,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+62096,dvrr_stack+60476,dvrr_stack+54986,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+64616, dvrr_stack+62096, dvrr_stack+52505);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3838, dvrr_stack+10610, dvrr_stack+15208, NULL, NULL, dvrr_stack+10565);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+65876, dvrr_stack+30021, dvrr_stack+3838, dvrr_stack+6854, dvrr_stack+10610, dvrr_stack+1523);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66206, dvrr_stack+30186, dvrr_stack+65876, dvrr_stack+6909, dvrr_stack+30021, dvrr_stack+59081);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66756, dvrr_stack+30516, dvrr_stack+66206, dvrr_stack+7239, dvrr_stack+30186, dvrr_stack+59351);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+67581,dvrr_stack+66756,dvrr_stack+59801,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+69606,dvrr_stack+67581,dvrr_stack+60476,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+72846, dvrr_stack+69606, dvrr_stack+54446);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6854, dvrr_stack+15263, dvrr_stack+42610, NULL, NULL, dvrr_stack+15208);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+74466, dvrr_stack+35656, dvrr_stack+6854, dvrr_stack+10665, dvrr_stack+15263, dvrr_stack+3838);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+74862, dvrr_stack+35854, dvrr_stack+74466, dvrr_stack+10731, dvrr_stack+35656, dvrr_stack+65876);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+75522, dvrr_stack+36250, dvrr_stack+74862, dvrr_stack+11127, dvrr_stack+35854, dvrr_stack+66206);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+76512,dvrr_stack+75522,dvrr_stack+66756,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+78987,dvrr_stack+76512,dvrr_stack+67581,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+83037, dvrr_stack+78987, dvrr_stack+59801);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+171, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+10665, dvrr_stack+15096, dvrr_stack+171, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10671, dvrr_stack+10323, dvrr_stack+10665, dvrr_stack+10389, dvrr_stack+15096, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4003, dvrr_stack+10329, dvrr_stack+10671, dvrr_stack+10392, dvrr_stack+10323, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10665, dvrr_stack+10339, dvrr_stack+4003, dvrr_stack+10398, dvrr_stack+10329, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10686, dvrr_stack+144, dvrr_stack+10665, dvrr_stack+10408, dvrr_stack+10339, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10323, dvrr_stack+518, dvrr_stack+10686, dvrr_stack+10423, dvrr_stack+144, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10665, dvrr_stack+1368, dvrr_stack+10323, dvrr_stack+15099, dvrr_stack+518, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10323, dvrr_stack+3629, dvrr_stack+10665, dvrr_stack+15127, dvrr_stack+1368, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10665, dvrr_stack+6583, dvrr_stack+10323, dvrr_stack+15163, dvrr_stack+3629, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14943, dvrr_stack+42610, dvrr_stack+10665, dvrr_stack+15208, dvrr_stack+6583, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+85062, dvrr_stack+42676, dvrr_stack+14943, NULL, NULL, dvrr_stack+42610);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+85296, dvrr_stack+42754, dvrr_stack+85062, dvrr_stack+15329, dvrr_stack+42676, dvrr_stack+6854);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+85764, dvrr_stack+42988, dvrr_stack+85296, dvrr_stack+15407, dvrr_stack+42754, dvrr_stack+74466);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+86544, dvrr_stack+43456, dvrr_stack+85764, dvrr_stack+15875, dvrr_stack+42988, dvrr_stack+74862);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+87714,dvrr_stack+86544,dvrr_stack+75522,15);


 /* compute (4 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+90684,dvrr_stack+87714,dvrr_stack+76512,15);


 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,825,dvrr_stack+95634, dvrr_stack+90684, dvrr_stack+66756);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,126,dvrr_stack+42676, dvrr_stack+2495, dvrr_stack+392);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,168,dvrr_stack+85062, dvrr_stack+5071, dvrr_stack+822);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,216,dvrr_stack+85566, dvrr_stack+8379, dvrr_stack+1775);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,270,dvrr_stack+98109, dvrr_stack+12513, dvrr_stack+4153);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,330,dvrr_stack+98919, dvrr_stack+17531, dvrr_stack+7239);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+99909, dvrr_stack+23676, dvrr_stack+20780);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+100539, dvrr_stack+27501, dvrr_stack+21242);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+101379, dvrr_stack+32416, dvrr_stack+22476);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+102459, dvrr_stack+38560, dvrr_stack+25971);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,550,dvrr_stack+103809, dvrr_stack+46216, dvrr_stack+30516);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+105459, dvrr_stack+56246, dvrr_stack+51742);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+106404, dvrr_stack+62096, dvrr_stack+52505);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+107664, dvrr_stack+69606, dvrr_stack+54446);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+109284, dvrr_stack+78987, dvrr_stack+59801);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,825,dvrr_stack+111309, dvrr_stack+90684, dvrr_stack+66756);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,126,dvrr_stack+43054, dvrr_stack+2495, dvrr_stack+392);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,168,dvrr_stack+2495, dvrr_stack+5071, dvrr_stack+822);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,216,dvrr_stack+5071, dvrr_stack+8379, dvrr_stack+1775);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,270,dvrr_stack+8379, dvrr_stack+12513, dvrr_stack+4153);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,330,dvrr_stack+12513, dvrr_stack+17531, dvrr_stack+7239);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+13503, dvrr_stack+23676, dvrr_stack+20780);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+23676, dvrr_stack+27501, dvrr_stack+21242);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+27501, dvrr_stack+32416, dvrr_stack+22476);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+32416, dvrr_stack+38560, dvrr_stack+25971);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,550,dvrr_stack+38560, dvrr_stack+46216, dvrr_stack+30516);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+46216, dvrr_stack+56246, dvrr_stack+51742);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+56246, dvrr_stack+62096, dvrr_stack+52505);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+62096, dvrr_stack+69606, dvrr_stack+54446);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+69606, dvrr_stack+78987, dvrr_stack+59801);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,825,dvrr_stack+78987, dvrr_stack+90684, dvrr_stack+66756);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+90684, dvrr_stack+74, dvrr_stack+21, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+90714, dvrr_stack+184, dvrr_stack+84, NULL, NULL, dvrr_stack+74);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+90759, dvrr_stack+90714, dvrr_stack+99, dvrr_stack+184, dvrr_stack+84, dvrr_stack+90684);

 /* compute (2 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+90849,dvrr_stack+392,dvrr_stack+90759,6);


 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,90,dvrr_stack+91119, dvrr_stack+90849, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+91209, dvrr_stack+1991, NULL);
 tmp = dvrr_stack + 91209;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+91377, dvrr_stack+990, NULL);
 tmp = dvrr_stack + 91377;
 target_ptr = Libderiv->deriv_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+91503, dvrr_stack+4423, NULL);
 tmp = dvrr_stack + 91503;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+91719, dvrr_stack+7569, NULL);
 tmp = dvrr_stack + 91719;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+86214, dvrr_stack+11523, NULL);
 tmp = dvrr_stack + 86214;
 target_ptr = Libderiv->deriv_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+91989, dvrr_stack+16343, NULL);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+15857, dvrr_stack+15, dvrr_stack+9, NULL, NULL, dvrr_stack+0);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+92385, dvrr_stack+90684, dvrr_stack+15021, dvrr_stack+74, dvrr_stack+21, dvrr_stack+15857);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+92445, dvrr_stack+90759, dvrr_stack+20501, dvrr_stack+90714, dvrr_stack+99, dvrr_stack+92385);

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+92595,dvrr_stack+20780,dvrr_stack+92445,10);


 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+93045, dvrr_stack+92595, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+93195, dvrr_stack+22836, NULL);
 tmp = dvrr_stack + 93195;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+93475, dvrr_stack+21522, NULL);
 tmp = dvrr_stack + 93475;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+5719, dvrr_stack+26421, NULL);
 tmp = dvrr_stack + 5719;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+93685, dvrr_stack+31066, NULL);
 tmp = dvrr_stack + 93685;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+94135, dvrr_stack+36910, NULL);
 tmp = dvrr_stack + 94135;
 target_ptr = Libderiv->deriv_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+94685, dvrr_stack+44236, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1658, dvrr_stack+0, dvrr_stack+6, NULL, NULL, Data->F+4);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+1368, dvrr_stack+15857, dvrr_stack+15641, dvrr_stack+15, dvrr_stack+9, dvrr_stack+1658);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+95345, dvrr_stack+92385, dvrr_stack+15689, dvrr_stack+90684, dvrr_stack+15021, dvrr_stack+1368);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+81462, dvrr_stack+92445, dvrr_stack+51256, dvrr_stack+90759, dvrr_stack+20501, dvrr_stack+95345);

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+81687,dvrr_stack+51742,dvrr_stack+81462,15);


 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+82362, dvrr_stack+81687, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+24516, dvrr_stack+54986, NULL);
 tmp = dvrr_stack + 24516;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+82587, dvrr_stack+52925, NULL);
 tmp = dvrr_stack + 82587;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+71631, dvrr_stack+60476, NULL);
 tmp = dvrr_stack + 71631;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+72171, dvrr_stack+67581, NULL);
 tmp = dvrr_stack + 72171;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+63716, dvrr_stack+76512, NULL);
 tmp = dvrr_stack + 63716;
 target_ptr = Libderiv->deriv_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+47161, dvrr_stack+87714, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+95445, dvrr_stack+90849, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+57506, dvrr_stack+1991, NULL);
 tmp = dvrr_stack + 57506;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+82902, dvrr_stack+990, NULL);
 tmp = dvrr_stack + 82902;
 target_ptr = Libderiv->deriv_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+57674, dvrr_stack+4423, NULL);
 tmp = dvrr_stack + 57674;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+48151, dvrr_stack+7569, NULL);
 tmp = dvrr_stack + 48151;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+48421, dvrr_stack+11523, NULL);
 tmp = dvrr_stack + 48421;
 target_ptr = Libderiv->deriv_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+48751, dvrr_stack+16343, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+57890, dvrr_stack+92595, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+49147, dvrr_stack+22836, NULL);
 tmp = dvrr_stack + 49147;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+40210, dvrr_stack+21522, NULL);
 tmp = dvrr_stack + 40210;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+40420, dvrr_stack+26421, NULL);
 tmp = dvrr_stack + 40420;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+40780, dvrr_stack+31066, NULL);
 tmp = dvrr_stack + 40780;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+33766, dvrr_stack+36910, NULL);
 tmp = dvrr_stack + 33766;
 target_ptr = Libderiv->deriv_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+17531, dvrr_stack+44236, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+34316, dvrr_stack+81687, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+28581, dvrr_stack+54986, NULL);
 tmp = dvrr_stack + 28581;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+18191, dvrr_stack+52925, NULL);
 tmp = dvrr_stack + 18191;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+18506, dvrr_stack+60476, NULL);
 tmp = dvrr_stack + 18506;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+113784, dvrr_stack+67581, NULL);
 tmp = dvrr_stack + 113784;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+114459, dvrr_stack+76512, NULL);
 tmp = dvrr_stack + 114459;
 target_ptr = Libderiv->deriv_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+115284, dvrr_stack+87714, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+95535, dvrr_stack+90849, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+90849, dvrr_stack+1991, NULL);
 tmp = dvrr_stack + 90849;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+1991, dvrr_stack+990, NULL);
 tmp = dvrr_stack + 1991;
 target_ptr = Libderiv->deriv_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+990, dvrr_stack+4423, NULL);
 tmp = dvrr_stack + 990;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+4423, dvrr_stack+7569, NULL);
 tmp = dvrr_stack + 4423;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+7569, dvrr_stack+11523, NULL);
 tmp = dvrr_stack + 7569;
 target_ptr = Libderiv->deriv_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+11523, dvrr_stack+16343, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+16343, dvrr_stack+92595, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+92595, dvrr_stack+22836, NULL);
 tmp = dvrr_stack + 92595;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+22836, dvrr_stack+21522, NULL);
 tmp = dvrr_stack + 22836;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+21522, dvrr_stack+26421, NULL);
 tmp = dvrr_stack + 21522;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+26421, dvrr_stack+31066, NULL);
 tmp = dvrr_stack + 26421;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+31066, dvrr_stack+36910, NULL);
 tmp = dvrr_stack + 31066;
 target_ptr = Libderiv->deriv_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+36910, dvrr_stack+44236, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+44236, dvrr_stack+81687, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+81687, dvrr_stack+54986, NULL);
 tmp = dvrr_stack + 81687;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+54986, dvrr_stack+52925, NULL);
 tmp = dvrr_stack + 54986;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+52925, dvrr_stack+60476, NULL);
 tmp = dvrr_stack + 52925;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+60476, dvrr_stack+67581, NULL);
 tmp = dvrr_stack + 60476;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+67581, dvrr_stack+76512, NULL);
 tmp = dvrr_stack + 67581;
 target_ptr = Libderiv->deriv_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+37570, dvrr_stack+87714, NULL);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+87714, dvrr_stack+68, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+41230, dvrr_stack+174, dvrr_stack+74, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+87732, dvrr_stack+41230, dvrr_stack+90684, dvrr_stack+174, dvrr_stack+74, dvrr_stack+87714);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+74, dvrr_stack+392, dvrr_stack+87732);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+87792, dvrr_stack+1775, dvrr_stack+392);
 tmp = dvrr_stack + 87792;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+87960, dvrr_stack+822, dvrr_stack+90759);
 tmp = dvrr_stack + 87960;
 target_ptr = Libderiv->deriv_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+88086, dvrr_stack+4153, dvrr_stack+822);
 tmp = dvrr_stack + 88086;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+21882, dvrr_stack+7239, dvrr_stack+1775);
 tmp = dvrr_stack + 21882;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+88302, dvrr_stack+11127, dvrr_stack+4153);
 tmp = dvrr_stack + 88302;
 target_ptr = Libderiv->deriv_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+88632, dvrr_stack+15875, dvrr_stack+7239);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+95625, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+3);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+89028, dvrr_stack+87714, dvrr_stack+15857, dvrr_stack+68, dvrr_stack+15, dvrr_stack+95625);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+89064, dvrr_stack+87732, dvrr_stack+92385, dvrr_stack+41230, dvrr_stack+90684, dvrr_stack+89028);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+89164, dvrr_stack+20780, dvrr_stack+89064);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+89314, dvrr_stack+22476, dvrr_stack+20780);
 tmp = dvrr_stack + 89314;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+89594, dvrr_stack+21242, dvrr_stack+92445);
 tmp = dvrr_stack + 89594;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+89804, dvrr_stack+25971, dvrr_stack+21242);
 tmp = dvrr_stack + 89804;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+90164, dvrr_stack+30516, dvrr_stack+22476);
 tmp = dvrr_stack + 90164;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+76512, dvrr_stack+36250, dvrr_stack+25971);
 tmp = dvrr_stack + 76512;
 target_ptr = Libderiv->deriv_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+77062, dvrr_stack+43456, dvrr_stack+30516);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+41230, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+41233, dvrr_stack+95625, dvrr_stack+1658, dvrr_stack+3, dvrr_stack+0, dvrr_stack+41230);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+90614, dvrr_stack+89028, dvrr_stack+1368, dvrr_stack+87714, dvrr_stack+15857, dvrr_stack+41233);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+77722, dvrr_stack+89064, dvrr_stack+95345, dvrr_stack+87732, dvrr_stack+92385, dvrr_stack+90614);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+77872, dvrr_stack+51742, dvrr_stack+77722);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+78097, dvrr_stack+54446, dvrr_stack+51742);
 tmp = dvrr_stack + 78097;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+78517, dvrr_stack+52505, dvrr_stack+81462);
 tmp = dvrr_stack + 78517;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+68406, dvrr_stack+59801, dvrr_stack+52505);
 tmp = dvrr_stack + 68406;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+61151, dvrr_stack+66756, dvrr_stack+54446);
 tmp = dvrr_stack + 61151;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+55301, dvrr_stack+75522, dvrr_stack+59801);
 tmp = dvrr_stack + 55301;
 target_ptr = Libderiv->deriv_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+44461, dvrr_stack+86544, dvrr_stack+66756);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+90614, dvrr_stack+392, dvrr_stack+87732);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+68946, dvrr_stack+1775, dvrr_stack+392);
 tmp = dvrr_stack + 68946;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+78832, dvrr_stack+822, dvrr_stack+90759);
 tmp = dvrr_stack + 78832;
 target_ptr = Libderiv->deriv_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+69114, dvrr_stack+4153, dvrr_stack+822);
 tmp = dvrr_stack + 69114;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+61826, dvrr_stack+7239, dvrr_stack+1775);
 tmp = dvrr_stack + 61826;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+53465, dvrr_stack+11127, dvrr_stack+4153);
 tmp = dvrr_stack + 53465;
 target_ptr = Libderiv->deriv_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+45451, dvrr_stack+15875, dvrr_stack+7239);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+69330, dvrr_stack+20780, dvrr_stack+89064);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+45847, dvrr_stack+22476, dvrr_stack+20780);
 tmp = dvrr_stack + 45847;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+82107, dvrr_stack+21242, dvrr_stack+92445);
 tmp = dvrr_stack + 82107;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+31616, dvrr_stack+25971, dvrr_stack+21242);
 tmp = dvrr_stack + 31616;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+26871, dvrr_stack+30516, dvrr_stack+22476);
 tmp = dvrr_stack + 26871;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+23046, dvrr_stack+36250, dvrr_stack+25971);
 tmp = dvrr_stack + 23046;
 target_ptr = Libderiv->deriv_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+16493, dvrr_stack+43456, dvrr_stack+30516);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+31976, dvrr_stack+51742, dvrr_stack+77722);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+11919, dvrr_stack+54446, dvrr_stack+51742);
 tmp = dvrr_stack + 11919;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+17153, dvrr_stack+52505, dvrr_stack+81462);
 tmp = dvrr_stack + 17153;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+116274, dvrr_stack+59801, dvrr_stack+52505);
 tmp = dvrr_stack + 116274;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+116814, dvrr_stack+66756, dvrr_stack+54446);
 tmp = dvrr_stack + 116814;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+117489, dvrr_stack+75522, dvrr_stack+59801);
 tmp = dvrr_stack + 117489;
 target_ptr = Libderiv->deriv_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+118314, dvrr_stack+86544, dvrr_stack+66756);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+69480, dvrr_stack+392, dvrr_stack+87732);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+32201, dvrr_stack+1775, dvrr_stack+392);
 tmp = dvrr_stack + 32201;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+27321, dvrr_stack+822, dvrr_stack+90759);
 tmp = dvrr_stack + 27321;
 target_ptr = Libderiv->deriv_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+7899, dvrr_stack+4153, dvrr_stack+822);
 tmp = dvrr_stack + 7899;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+4693, dvrr_stack+7239, dvrr_stack+1775);
 tmp = dvrr_stack + 4693;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+2117, dvrr_stack+11127, dvrr_stack+4153);
 tmp = dvrr_stack + 2117;
 target_ptr = Libderiv->deriv_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+11127, dvrr_stack+15875, dvrr_stack+7239);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+15875, dvrr_stack+20780, dvrr_stack+89064);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+16025, dvrr_stack+22476, dvrr_stack+20780);
 tmp = dvrr_stack + 16025;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+8115, dvrr_stack+21242, dvrr_stack+92445);
 tmp = dvrr_stack + 8115;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+19046, dvrr_stack+25971, dvrr_stack+21242);
 tmp = dvrr_stack + 19046;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+9189, dvrr_stack+30516, dvrr_stack+22476);
 tmp = dvrr_stack + 9189;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+119304, dvrr_stack+36250, dvrr_stack+25971);
 tmp = dvrr_stack + 119304;
 target_ptr = Libderiv->deriv_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+119854, dvrr_stack+43456, dvrr_stack+30516);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+2999, dvrr_stack+51742, dvrr_stack+77722);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+43432, dvrr_stack+54446, dvrr_stack+51742);
 tmp = dvrr_stack + 43432;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+43852, dvrr_stack+52505, dvrr_stack+81462);
 tmp = dvrr_stack + 43852;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+120514, dvrr_stack+59801, dvrr_stack+52505);
 tmp = dvrr_stack + 120514;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+121054, dvrr_stack+66756, dvrr_stack+54446);
 tmp = dvrr_stack + 121054;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+121729, dvrr_stack+75522, dvrr_stack+59801);
 tmp = dvrr_stack + 121729;
 target_ptr = Libderiv->deriv_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+122554, dvrr_stack+86544, dvrr_stack+66756);

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+86544,dvrr_stack+738,dvrr_stack+329,3);


 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+17468, dvrr_stack+86544, NULL);

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+86733,dvrr_stack+1667,dvrr_stack+738,3);


 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+86985, dvrr_stack+86733, NULL);

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+87069,dvrr_stack+4018,dvrr_stack+1667,3);


 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+4963, dvrr_stack+87069, NULL);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+123544,dvrr_stack+7074,dvrr_stack+4018,3);


 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+87393, dvrr_stack+123544, NULL);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+123949,dvrr_stack+10929,dvrr_stack+7074,3);


 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+87528, dvrr_stack+123949, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+95625, dvrr_stack+6, dvrr_stack+31, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+87693, dvrr_stack+34, dvrr_stack+165, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+69570, dvrr_stack+15641, dvrr_stack+87693, dvrr_stack+9, dvrr_stack+34, dvrr_stack+95625);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+41230, dvrr_stack+220, dvrr_stack+580, NULL, NULL, dvrr_stack+165);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+87711, dvrr_stack+15659, dvrr_stack+41230, dvrr_stack+40, dvrr_stack+220, dvrr_stack+87693);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+77722, dvrr_stack+15689, dvrr_stack+87711, dvrr_stack+15021, dvrr_stack+15659, dvrr_stack+69570);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+82317, dvrr_stack+590, dvrr_stack+1459, NULL, NULL, dvrr_stack+580);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+90759, dvrr_stack+15749, dvrr_stack+82317, dvrr_stack+230, dvrr_stack+590, dvrr_stack+41230);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+92875, dvrr_stack+51166, dvrr_stack+90759, dvrr_stack+15051, dvrr_stack+15749, dvrr_stack+87711);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+15329, dvrr_stack+51256, dvrr_stack+92875, dvrr_stack+20501, dvrr_stack+51166, dvrr_stack+77722);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+20501, dvrr_stack+1474, dvrr_stack+3753, NULL, NULL, dvrr_stack+1459);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+89028, dvrr_stack+15794, dvrr_stack+20501, dvrr_stack+605, dvrr_stack+1474, dvrr_stack+82317);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+124444, dvrr_stack+51406, dvrr_stack+89028, dvrr_stack+20591, dvrr_stack+15794, dvrr_stack+90759);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+124654, dvrr_stack+51532, dvrr_stack+124444, dvrr_stack+20654, dvrr_stack+51406, dvrr_stack+92875);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+124969, dvrr_stack+51742, dvrr_stack+124654, dvrr_stack+20780, dvrr_stack+51532, dvrr_stack+15329);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+20564, dvrr_stack+3774, dvrr_stack+6745, NULL, NULL, dvrr_stack+3753);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+12339, dvrr_stack+245, dvrr_stack+20564, dvrr_stack+1495, dvrr_stack+3774, dvrr_stack+20501);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+125410, dvrr_stack+52057, dvrr_stack+12339, dvrr_stack+20990, dvrr_stack+245, dvrr_stack+89028);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+125690, dvrr_stack+52225, dvrr_stack+125410, dvrr_stack+21074, dvrr_stack+52057, dvrr_stack+124444);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+126110, dvrr_stack+52505, dvrr_stack+125690, dvrr_stack+21242, dvrr_stack+52225, dvrr_stack+124654);

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+126698,dvrr_stack+126110,dvrr_stack+124969,21);


 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+128021, dvrr_stack+126698, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+20990, dvrr_stack+6773, dvrr_stack+10529, NULL, NULL, dvrr_stack+6745);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+128462, dvrr_stack+626, dvrr_stack+20990, dvrr_stack+3802, dvrr_stack+6773, dvrr_stack+20564);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+128678, dvrr_stack+53870, dvrr_stack+128462, dvrr_stack+22152, dvrr_stack+626, dvrr_stack+12339);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+129038, dvrr_stack+54086, dvrr_stack+128678, dvrr_stack+22260, dvrr_stack+53870, dvrr_stack+125410);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+129578, dvrr_stack+54446, dvrr_stack+129038, dvrr_stack+22476, dvrr_stack+54086, dvrr_stack+125690);

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+130334,dvrr_stack+129578,dvrr_stack+126110,21);


 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+132098, dvrr_stack+130334, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22152, dvrr_stack+10565, dvrr_stack+15163, NULL, NULL, dvrr_stack+10529);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+132686, dvrr_stack+1523, dvrr_stack+22152, dvrr_stack+6809, dvrr_stack+10565, dvrr_stack+20990);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+132956, dvrr_stack+59081, dvrr_stack+132686, dvrr_stack+25566, dvrr_stack+1523, dvrr_stack+128462);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+133406, dvrr_stack+59351, dvrr_stack+132956, dvrr_stack+25701, dvrr_stack+59081, dvrr_stack+128678);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+134081, dvrr_stack+59801, dvrr_stack+133406, dvrr_stack+25971, dvrr_stack+59351, dvrr_stack+129038);

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+135026,dvrr_stack+134081,dvrr_stack+129578,21);


 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+137294, dvrr_stack+135026, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+25566, dvrr_stack+15208, dvrr_stack+6583, NULL, NULL, dvrr_stack+15163);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+138050, dvrr_stack+3838, dvrr_stack+25566, dvrr_stack+10610, dvrr_stack+15208, dvrr_stack+22152);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+138380, dvrr_stack+65876, dvrr_stack+138050, dvrr_stack+30021, dvrr_stack+3838, dvrr_stack+132686);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+138930, dvrr_stack+66206, dvrr_stack+138380, dvrr_stack+30186, dvrr_stack+65876, dvrr_stack+132956);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+139755, dvrr_stack+66756, dvrr_stack+138930, dvrr_stack+30516, dvrr_stack+66206, dvrr_stack+133406);

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+140910,dvrr_stack+139755,dvrr_stack+134081,21);


 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+143745, dvrr_stack+140910, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10731, dvrr_stack+42610, dvrr_stack+10665, NULL, NULL, dvrr_stack+6583);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30021, dvrr_stack+6854, dvrr_stack+10731, dvrr_stack+15263, dvrr_stack+42610, dvrr_stack+25566);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+144690, dvrr_stack+74466, dvrr_stack+30021, dvrr_stack+35656, dvrr_stack+6854, dvrr_stack+138050);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+145350, dvrr_stack+74862, dvrr_stack+144690, dvrr_stack+35854, dvrr_stack+74466, dvrr_stack+138380);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+146340, dvrr_stack+75522, dvrr_stack+145350, dvrr_stack+36250, dvrr_stack+74862, dvrr_stack+138930);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+147726,dvrr_stack+146340,dvrr_stack+139755,21);


 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+74466, dvrr_stack+147726, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+75621, dvrr_stack+86544, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+75684, dvrr_stack+86733, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+75768, dvrr_stack+87069, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+75876, dvrr_stack+123544, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+76011, dvrr_stack+123949, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+144690, dvrr_stack+126698, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+145131, dvrr_stack+130334, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+35656, dvrr_stack+135026, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+151191, dvrr_stack+140910, NULL);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+152136, dvrr_stack+147726, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+76176, dvrr_stack+86544, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+86544, dvrr_stack+86733, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+86628, dvrr_stack+87069, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+87069, dvrr_stack+123544, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+123544, dvrr_stack+123949, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+123709, dvrr_stack+126698, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+126698, dvrr_stack+130334, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+130334, dvrr_stack+135026, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+135026, dvrr_stack+140910, NULL);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+140910, dvrr_stack+147726, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+147726, dvrr_stack+738, dvrr_stack+90714);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+147789, dvrr_stack+1667, dvrr_stack+329);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+147873, dvrr_stack+4018, dvrr_stack+738);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+147981, dvrr_stack+7074, dvrr_stack+1667);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+148116, dvrr_stack+10929, dvrr_stack+4018);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+148281, dvrr_stack+1658, dvrr_stack+95625, dvrr_stack+0, dvrr_stack+6, dvrr_stack+3);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+148299, dvrr_stack+1368, dvrr_stack+69570, dvrr_stack+15857, dvrr_stack+15641, dvrr_stack+148281);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+148359, dvrr_stack+95345, dvrr_stack+77722, dvrr_stack+92385, dvrr_stack+15689, dvrr_stack+148299);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+148509, dvrr_stack+81462, dvrr_stack+15329, dvrr_stack+92445, dvrr_stack+51256, dvrr_stack+148359);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+148824, dvrr_stack+126110, dvrr_stack+148509);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+149265, dvrr_stack+129578, dvrr_stack+124969);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+149853, dvrr_stack+134081, dvrr_stack+126110);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+142065, dvrr_stack+139755, dvrr_stack+129578);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+135971, dvrr_stack+146340, dvrr_stack+134081);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+81462, dvrr_stack+738, dvrr_stack+90714);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+81525, dvrr_stack+1667, dvrr_stack+329);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+92385, dvrr_stack+4018, dvrr_stack+738);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+148281, dvrr_stack+7074, dvrr_stack+1667);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+150609, dvrr_stack+10929, dvrr_stack+4018);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+143010, dvrr_stack+126110, dvrr_stack+148509);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+131090, dvrr_stack+129578, dvrr_stack+124969);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+153291, dvrr_stack+134081, dvrr_stack+126110);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+154047, dvrr_stack+139755, dvrr_stack+129578);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+154992, dvrr_stack+146340, dvrr_stack+134081);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+81609, dvrr_stack+738, dvrr_stack+90714);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+92493, dvrr_stack+1667, dvrr_stack+329);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+150774, dvrr_stack+4018, dvrr_stack+738);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+150882, dvrr_stack+7074, dvrr_stack+1667);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+151017, dvrr_stack+10929, dvrr_stack+4018);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+127286, dvrr_stack+126110, dvrr_stack+148509);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+145719, dvrr_stack+129578, dvrr_stack+124969);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+156147, dvrr_stack+134081, dvrr_stack+126110);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+156903, dvrr_stack+139755, dvrr_stack+129578);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+157848, dvrr_stack+146340, dvrr_stack+134081);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+95345, dvrr_stack+392, dvrr_stack+199);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+148416, dvrr_stack+51742, dvrr_stack+392);
 tmp = dvrr_stack + 148416;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+148626, dvrr_stack+822, dvrr_stack+546);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+143451, dvrr_stack+52505, dvrr_stack+822);
 tmp = dvrr_stack + 143451;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+148710, dvrr_stack+1775, dvrr_stack+1404);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+131678, dvrr_stack+54446, dvrr_stack+1775);
 tmp = dvrr_stack + 131678;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+137126, dvrr_stack+4153, dvrr_stack+3674);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+146307, dvrr_stack+59801, dvrr_stack+4153);
 tmp = dvrr_stack + 146307;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+127727, dvrr_stack+7239, dvrr_stack+6638);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+146757, dvrr_stack+66756, dvrr_stack+7239);
 tmp = dvrr_stack + 146757;
 target_ptr = Libderiv->deriv_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+127892, dvrr_stack+20780, dvrr_stack+329);
 tmp = dvrr_stack + 127892;
 target_ptr = Libderiv->deriv_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+147307, dvrr_stack+124969, dvrr_stack+20780);
 tmp = dvrr_stack + 147307;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+124150, dvrr_stack+21242, dvrr_stack+738);
 tmp = dvrr_stack + 124150;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+36412, dvrr_stack+126110, dvrr_stack+21242);
 tmp = dvrr_stack + 36412;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+86736, dvrr_stack+22476, dvrr_stack+1667);
 tmp = dvrr_stack + 86736;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+159003, dvrr_stack+129578, dvrr_stack+22476);
 tmp = dvrr_stack + 159003;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+76239, dvrr_stack+25971, dvrr_stack+4018);
 tmp = dvrr_stack + 76239;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+159543, dvrr_stack+134081, dvrr_stack+25971);
 tmp = dvrr_stack + 159543;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+30021, dvrr_stack+30516, dvrr_stack+7074);
 tmp = dvrr_stack + 30021;
 target_ptr = Libderiv->deriv_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+160218, dvrr_stack+139755, dvrr_stack+30516);
 tmp = dvrr_stack + 160218;
 target_ptr = Libderiv->deriv_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+128018, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1658, dvrr_stack+31, dvrr_stack+65, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+92577, dvrr_stack+95625, dvrr_stack+1658, dvrr_stack+6, dvrr_stack+31, dvrr_stack+128018);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+15857, dvrr_stack+165, dvrr_stack+574, NULL, NULL, dvrr_stack+65);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+3802, dvrr_stack+87693, dvrr_stack+15857, dvrr_stack+34, dvrr_stack+165, dvrr_stack+1658);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+132038, dvrr_stack+69570, dvrr_stack+3802, dvrr_stack+15641, dvrr_stack+87693, dvrr_stack+92577);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+69570, dvrr_stack+580, dvrr_stack+1449, NULL, NULL, dvrr_stack+574);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+0, dvrr_stack+41230, dvrr_stack+69570, dvrr_stack+220, dvrr_stack+580, dvrr_stack+15857);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+124318, dvrr_stack+87711, dvrr_stack+0, dvrr_stack+15659, dvrr_stack+41230, dvrr_stack+3802);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+87204, dvrr_stack+77722, dvrr_stack+124318, dvrr_stack+15689, dvrr_stack+87711, dvrr_stack+132038);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+132038, dvrr_stack+1459, dvrr_stack+3738, NULL, NULL, dvrr_stack+1449);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+77722, dvrr_stack+82317, dvrr_stack+132038, dvrr_stack+590, dvrr_stack+1459, dvrr_stack+69570);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+30351, dvrr_stack+90759, dvrr_stack+77722, dvrr_stack+15749, dvrr_stack+82317, dvrr_stack+0);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+10610, dvrr_stack+92875, dvrr_stack+30351, dvrr_stack+51166, dvrr_stack+90759, dvrr_stack+124318);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+161043, dvrr_stack+15329, dvrr_stack+10610, dvrr_stack+51256, dvrr_stack+92875, dvrr_stack+87204);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+87204, dvrr_stack+3753, dvrr_stack+6724, NULL, NULL, dvrr_stack+3738);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+87267, dvrr_stack+20501, dvrr_stack+87204, dvrr_stack+1474, dvrr_stack+3753, dvrr_stack+132038);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+51166, dvrr_stack+89028, dvrr_stack+87267, dvrr_stack+15794, dvrr_stack+20501, dvrr_stack+77722);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+15263, dvrr_stack+124444, dvrr_stack+51166, dvrr_stack+51406, dvrr_stack+89028, dvrr_stack+30351);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+161358, dvrr_stack+124654, dvrr_stack+15263, dvrr_stack+51532, dvrr_stack+124444, dvrr_stack+10610);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+161799, dvrr_stack+124969, dvrr_stack+161358, dvrr_stack+51742, dvrr_stack+124654, dvrr_stack+161043);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+10610, dvrr_stack+161799, dvrr_stack+51742);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+161043, dvrr_stack+6745, dvrr_stack+10501, NULL, NULL, dvrr_stack+6724);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+161127, dvrr_stack+20564, dvrr_stack+161043, dvrr_stack+3774, dvrr_stack+6745, dvrr_stack+87204);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+124318, dvrr_stack+12339, dvrr_stack+161127, dvrr_stack+245, dvrr_stack+20564, dvrr_stack+87267);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+162387, dvrr_stack+125410, dvrr_stack+124318, dvrr_stack+52057, dvrr_stack+12339, dvrr_stack+51166);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+162807, dvrr_stack+125690, dvrr_stack+162387, dvrr_stack+52225, dvrr_stack+125410, dvrr_stack+15263);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+163395, dvrr_stack+126110, dvrr_stack+162807, dvrr_stack+52505, dvrr_stack+125690, dvrr_stack+161358);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+15263, dvrr_stack+163395, dvrr_stack+52505);

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+125410, dvrr_stack+10529, dvrr_stack+15127, NULL, NULL, dvrr_stack+10501);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+125518, dvrr_stack+20990, dvrr_stack+125410, dvrr_stack+6773, dvrr_stack+10529, dvrr_stack+161043);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+125734, dvrr_stack+128462, dvrr_stack+125518, dvrr_stack+626, dvrr_stack+20990, dvrr_stack+161127);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+161043, dvrr_stack+128678, dvrr_stack+125734, dvrr_stack+53870, dvrr_stack+128462, dvrr_stack+124318);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+164179, dvrr_stack+129038, dvrr_stack+161043, dvrr_stack+54086, dvrr_stack+128678, dvrr_stack+162387);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+164935, dvrr_stack+129578, dvrr_stack+164179, dvrr_stack+54446, dvrr_stack+129038, dvrr_stack+162807);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+162387, dvrr_stack+164935, dvrr_stack+54446);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+163143, dvrr_stack+15163, dvrr_stack+3629, NULL, NULL, dvrr_stack+15127);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+124318, dvrr_stack+22152, dvrr_stack+163143, dvrr_stack+10565, dvrr_stack+15163, dvrr_stack+125410);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+128462, dvrr_stack+132686, dvrr_stack+124318, dvrr_stack+1523, dvrr_stack+22152, dvrr_stack+125518);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+165943, dvrr_stack+132956, dvrr_stack+128462, dvrr_stack+59081, dvrr_stack+132686, dvrr_stack+125734);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+166618, dvrr_stack+133406, dvrr_stack+165943, dvrr_stack+59351, dvrr_stack+132956, dvrr_stack+161043);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+167563, dvrr_stack+134081, dvrr_stack+166618, dvrr_stack+59801, dvrr_stack+133406, dvrr_stack+164179);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+132686, dvrr_stack+167563, dvrr_stack+59801);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30351, dvrr_stack+6583, dvrr_stack+10323, NULL, NULL, dvrr_stack+3629);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+164179, dvrr_stack+25566, dvrr_stack+30351, dvrr_stack+15208, dvrr_stack+6583, dvrr_stack+163143);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+161043, dvrr_stack+138050, dvrr_stack+164179, dvrr_stack+3838, dvrr_stack+25566, dvrr_stack+124318);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+168823, dvrr_stack+138380, dvrr_stack+161043, dvrr_stack+65876, dvrr_stack+138050, dvrr_stack+128462);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+169648, dvrr_stack+138930, dvrr_stack+168823, dvrr_stack+66206, dvrr_stack+138380, dvrr_stack+165943);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+170803, dvrr_stack+139755, dvrr_stack+169648, dvrr_stack+66756, dvrr_stack+138930, dvrr_stack+166618);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+165943, dvrr_stack+170803, dvrr_stack+66756);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+167098, dvrr_stack+392, dvrr_stack+199);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+167161, dvrr_stack+51742, dvrr_stack+392);
 tmp = dvrr_stack + 167161;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+167371, dvrr_stack+822, dvrr_stack+546);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+168823, dvrr_stack+52505, dvrr_stack+822);
 tmp = dvrr_stack + 168823;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+167455, dvrr_stack+1775, dvrr_stack+1404);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+169103, dvrr_stack+54446, dvrr_stack+1775);
 tmp = dvrr_stack + 169103;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+169463, dvrr_stack+4153, dvrr_stack+3674);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+133631, dvrr_stack+59801, dvrr_stack+4153);
 tmp = dvrr_stack + 133631;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+30351, dvrr_stack+7239, dvrr_stack+6638);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+169598, dvrr_stack+66756, dvrr_stack+7239);
 tmp = dvrr_stack + 169598;
 target_ptr = Libderiv->deriv_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+170148, dvrr_stack+20780, dvrr_stack+329);
 tmp = dvrr_stack + 170148;
 target_ptr = Libderiv->deriv_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+170274, dvrr_stack+124969, dvrr_stack+20780);
 tmp = dvrr_stack + 170274;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+170589, dvrr_stack+21242, dvrr_stack+738);
 tmp = dvrr_stack + 170589;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+128462, dvrr_stack+126110, dvrr_stack+21242);
 tmp = dvrr_stack + 128462;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+128882, dvrr_stack+22476, dvrr_stack+1667);
 tmp = dvrr_stack + 128882;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+138050, dvrr_stack+129578, dvrr_stack+22476);
 tmp = dvrr_stack + 138050;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+129098, dvrr_stack+25971, dvrr_stack+4018);
 tmp = dvrr_stack + 129098;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+138590, dvrr_stack+134081, dvrr_stack+25971);
 tmp = dvrr_stack + 138590;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+139265, dvrr_stack+30516, dvrr_stack+7074);
 tmp = dvrr_stack + 139265;
 target_ptr = Libderiv->deriv_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+65876, dvrr_stack+139755, dvrr_stack+30516);
 tmp = dvrr_stack + 65876;
 target_ptr = Libderiv->deriv_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+161043, dvrr_stack+161799, dvrr_stack+51742);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+124318, dvrr_stack+163395, dvrr_stack+52505);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+164179, dvrr_stack+164935, dvrr_stack+54446);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+172343, dvrr_stack+167563, dvrr_stack+59801);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+173288, dvrr_stack+170803, dvrr_stack+66756);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+124906, dvrr_stack+392, dvrr_stack+199);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+129368, dvrr_stack+51742, dvrr_stack+392);
 tmp = dvrr_stack + 129368;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+392, dvrr_stack+822, dvrr_stack+546);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+161484, dvrr_stack+52505, dvrr_stack+822);
 tmp = dvrr_stack + 161484;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+822, dvrr_stack+1775, dvrr_stack+1404);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+25566, dvrr_stack+54446, dvrr_stack+1775);
 tmp = dvrr_stack + 25566;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+1775, dvrr_stack+4153, dvrr_stack+3674);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+59081, dvrr_stack+59801, dvrr_stack+4153);
 tmp = dvrr_stack + 59081;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+164, dvrr_stack+7239, dvrr_stack+6638);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+125410, dvrr_stack+66756, dvrr_stack+7239);
 tmp = dvrr_stack + 125410;
 target_ptr = Libderiv->deriv_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+7239, dvrr_stack+20780, dvrr_stack+329);
 tmp = dvrr_stack + 7239;
 target_ptr = Libderiv->deriv_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+6583, dvrr_stack+124969, dvrr_stack+20780);
 tmp = dvrr_stack + 6583;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+124969, dvrr_stack+21242, dvrr_stack+738);
 tmp = dvrr_stack + 124969;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+51166, dvrr_stack+126110, dvrr_stack+21242);
 tmp = dvrr_stack + 51166;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+125137, dvrr_stack+22476, dvrr_stack+1667);
 tmp = dvrr_stack + 125137;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+125960, dvrr_stack+129578, dvrr_stack+22476);
 tmp = dvrr_stack + 125960;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+4153, dvrr_stack+25971, dvrr_stack+4018);
 tmp = dvrr_stack + 4153;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+129578, dvrr_stack+134081, dvrr_stack+25971);
 tmp = dvrr_stack + 129578;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+134081, dvrr_stack+30516, dvrr_stack+7074);
 tmp = dvrr_stack + 134081;
 target_ptr = Libderiv->deriv_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+20501, dvrr_stack+139755, dvrr_stack+30516);
 tmp = dvrr_stack + 20501;
 target_ptr = Libderiv->deriv_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+30516, dvrr_stack+161799, dvrr_stack+51742);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+134411, dvrr_stack+163395, dvrr_stack+52505);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+139595, dvrr_stack+164935, dvrr_stack+54446);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+164935, dvrr_stack+167563, dvrr_stack+59801);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+167563, dvrr_stack+170803, dvrr_stack+66756);

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,126,dvrr_stack+7365, dvrr_stack+3251, NULL);
 tmp = dvrr_stack + 7365;
 target_ptr = Libderiv->deriv2_classes[2][5][143];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,168,dvrr_stack+476, dvrr_stack+6079, NULL);
 tmp = dvrr_stack + 476;
 target_ptr = Libderiv->deriv2_classes[2][6][143];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,216,dvrr_stack+170757, dvrr_stack+9675, NULL);
 tmp = dvrr_stack + 170757;
 target_ptr = Libderiv->deriv2_classes[2][7][143];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,270,dvrr_stack+170973, dvrr_stack+14133, NULL);
 tmp = dvrr_stack + 170973;
 target_ptr = Libderiv->deriv2_classes[2][8][143];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,330,dvrr_stack+171243, dvrr_stack+19511, NULL);
 tmp = dvrr_stack + 171243;
 target_ptr = Libderiv->deriv2_classes[2][9][143];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+171573, dvrr_stack+24936, NULL);
 tmp = dvrr_stack + 171573;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+171783, dvrr_stack+29181, NULL);
 tmp = dvrr_stack + 171783;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+140351, dvrr_stack+34576, NULL);
 tmp = dvrr_stack + 140351;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+66701, dvrr_stack+41260, NULL);
 tmp = dvrr_stack + 66701;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,550,dvrr_stack+161764, dvrr_stack+49516, NULL);
 tmp = dvrr_stack + 161764;
 target_ptr = Libderiv->deriv2_classes[3][9][143];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+67151, dvrr_stack+58136, NULL);
 tmp = dvrr_stack + 67151;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+25926, dvrr_stack+64616, NULL);
 tmp = dvrr_stack + 25926;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+163143, dvrr_stack+72846, NULL);
 tmp = dvrr_stack + 163143;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+59531, dvrr_stack+83037, NULL);
 tmp = dvrr_stack + 59531;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,825,dvrr_stack+51586, dvrr_stack+95634, NULL);
 tmp = dvrr_stack + 51586;
 target_ptr = Libderiv->deriv2_classes[4][9][143];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,126,dvrr_stack+644, dvrr_stack+3251, NULL);
 tmp = dvrr_stack + 644;
 target_ptr = Libderiv->deriv2_classes[2][5][131];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,168,dvrr_stack+172063, dvrr_stack+6079, NULL);
 tmp = dvrr_stack + 172063;
 target_ptr = Libderiv->deriv2_classes[2][6][131];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,216,dvrr_stack+163683, dvrr_stack+9675, NULL);
 tmp = dvrr_stack + 163683;
 target_ptr = Libderiv->deriv2_classes[2][7][131];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,270,dvrr_stack+60206, dvrr_stack+14133, NULL);
 tmp = dvrr_stack + 60206;
 target_ptr = Libderiv->deriv2_classes[2][8][131];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,330,dvrr_stack+6898, dvrr_stack+19511, NULL);
 tmp = dvrr_stack + 6898;
 target_ptr = Libderiv->deriv2_classes[2][9][131];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+163899, dvrr_stack+24936, NULL);
 tmp = dvrr_stack + 163899;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+3629, dvrr_stack+29181, NULL);
 tmp = dvrr_stack + 3629;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+22152, dvrr_stack+34576, NULL);
 tmp = dvrr_stack + 22152;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+52411, dvrr_stack+41260, NULL);
 tmp = dvrr_stack + 52411;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,550,dvrr_stack+53795, dvrr_stack+49516, NULL);
 tmp = dvrr_stack + 53795;
 target_ptr = Libderiv->deriv2_classes[3][9][131];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+22512, dvrr_stack+58136, NULL);
 tmp = dvrr_stack + 22512;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+54345, dvrr_stack+64616, NULL);
 tmp = dvrr_stack + 54345;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+1206, dvrr_stack+72846, NULL);
 tmp = dvrr_stack + 1206;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+174443, dvrr_stack+83037, NULL);
 tmp = dvrr_stack + 174443;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,825,dvrr_stack+175118, dvrr_stack+95634, NULL);
 tmp = dvrr_stack + 175118;
 target_ptr = Libderiv->deriv2_classes[4][9][131];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+140711, dvrr_stack+42676, NULL);
 tmp = dvrr_stack + 140711;
 target_ptr = Libderiv->deriv2_classes[2][5][130];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+3909, dvrr_stack+85062, NULL);
 tmp = dvrr_stack + 3909;
 target_ptr = Libderiv->deriv2_classes[2][6][130];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+10323, dvrr_stack+85566, NULL);
 tmp = dvrr_stack + 10323;
 target_ptr = Libderiv->deriv2_classes[2][7][130];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+14943, dvrr_stack+98109, NULL);
 tmp = dvrr_stack + 14943;
 target_ptr = Libderiv->deriv2_classes[2][8][130];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+175943, dvrr_stack+98919, NULL);
 tmp = dvrr_stack + 175943;
 target_ptr = Libderiv->deriv2_classes[2][9][130];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+54765, dvrr_stack+99909, NULL);
 tmp = dvrr_stack + 54765;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+176273, dvrr_stack+100539, NULL);
 tmp = dvrr_stack + 176273;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+176553, dvrr_stack+101379, NULL);
 tmp = dvrr_stack + 176553;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+176913, dvrr_stack+102459, NULL);
 tmp = dvrr_stack + 176913;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+177363, dvrr_stack+103809, NULL);
 tmp = dvrr_stack + 177363;
 target_ptr = Libderiv->deriv2_classes[3][9][130];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+177913, dvrr_stack+105459, NULL);
 tmp = dvrr_stack + 177913;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+178228, dvrr_stack+106404, NULL);
 tmp = dvrr_stack + 178228;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+178648, dvrr_stack+107664, NULL);
 tmp = dvrr_stack + 178648;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+179188, dvrr_stack+109284, NULL);
 tmp = dvrr_stack + 179188;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+179863, dvrr_stack+111309, NULL);
 tmp = dvrr_stack + 179863;
 target_ptr = Libderiv->deriv2_classes[4][9][130];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,126,dvrr_stack+126500, dvrr_stack+3251, NULL);
 tmp = dvrr_stack + 126500;
 target_ptr = Libderiv->deriv2_classes[2][5][119];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,168,dvrr_stack+12339, dvrr_stack+6079, NULL);
 tmp = dvrr_stack + 12339;
 target_ptr = Libderiv->deriv2_classes[2][6][119];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,216,dvrr_stack+6079, dvrr_stack+9675, NULL);
 tmp = dvrr_stack + 6079;
 target_ptr = Libderiv->deriv2_classes[2][7][119];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,270,dvrr_stack+6295, dvrr_stack+14133, NULL);
 tmp = dvrr_stack + 6295;
 target_ptr = Libderiv->deriv2_classes[2][8][119];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,330,dvrr_stack+14133, dvrr_stack+19511, NULL);
 tmp = dvrr_stack + 14133;
 target_ptr = Libderiv->deriv2_classes[2][9][119];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+14463, dvrr_stack+24936, NULL);
 tmp = dvrr_stack + 14463;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+24936, dvrr_stack+29181, NULL);
 tmp = dvrr_stack + 24936;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+29001, dvrr_stack+34576, NULL);
 tmp = dvrr_stack + 29001;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+34541, dvrr_stack+41260, NULL);
 tmp = dvrr_stack + 34541;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,550,dvrr_stack+41230, dvrr_stack+49516, NULL);
 tmp = dvrr_stack + 41230;
 target_ptr = Libderiv->deriv2_classes[3][9][119];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+25216, dvrr_stack+58136, NULL);
 tmp = dvrr_stack + 25216;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+41780, dvrr_stack+64616, NULL);
 tmp = dvrr_stack + 41780;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+64541, dvrr_stack+72846, NULL);
 tmp = dvrr_stack + 64541;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+72846, dvrr_stack+83037, NULL);
 tmp = dvrr_stack + 72846;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,825,dvrr_stack+73521, dvrr_stack+95634, NULL);
 tmp = dvrr_stack + 73521;
 target_ptr = Libderiv->deriv2_classes[4][9][119];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+14673, dvrr_stack+42676, NULL);
 tmp = dvrr_stack + 14673;
 target_ptr = Libderiv->deriv2_classes[2][5][118];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+87204, dvrr_stack+85062, NULL);
 tmp = dvrr_stack + 87204;
 target_ptr = Libderiv->deriv2_classes[2][6][118];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+42200, dvrr_stack+85566, NULL);
 tmp = dvrr_stack + 42200;
 target_ptr = Libderiv->deriv2_classes[2][7][118];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+42416, dvrr_stack+98109, NULL);
 tmp = dvrr_stack + 42416;
 target_ptr = Libderiv->deriv2_classes[2][8][118];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+42686, dvrr_stack+98919, NULL);
 tmp = dvrr_stack + 42686;
 target_ptr = Libderiv->deriv2_classes[2][9][118];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+95625, dvrr_stack+99909, NULL);
 tmp = dvrr_stack + 95625;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+95835, dvrr_stack+100539, NULL);
 tmp = dvrr_stack + 95835;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+96115, dvrr_stack+101379, NULL);
 tmp = dvrr_stack + 96115;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+96475, dvrr_stack+102459, NULL);
 tmp = dvrr_stack + 96475;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+96925, dvrr_stack+103809, NULL);
 tmp = dvrr_stack + 96925;
 target_ptr = Libderiv->deriv2_classes[3][9][118];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+97475, dvrr_stack+105459, NULL);
 tmp = dvrr_stack + 97475;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+97790, dvrr_stack+106404, NULL);
 tmp = dvrr_stack + 97790;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+98210, dvrr_stack+107664, NULL);
 tmp = dvrr_stack + 98210;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+98750, dvrr_stack+109284, NULL);
 tmp = dvrr_stack + 98750;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+99425, dvrr_stack+111309, NULL);
 tmp = dvrr_stack + 99425;
 target_ptr = Libderiv->deriv2_classes[4][9][118];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+14799, dvrr_stack+43054, NULL);
 tmp = dvrr_stack + 14799;
 target_ptr = Libderiv->deriv2_classes[2][5][117];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+21326, dvrr_stack+2495, NULL);
 tmp = dvrr_stack + 21326;
 target_ptr = Libderiv->deriv2_classes[2][6][117];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+43016, dvrr_stack+5071, NULL);
 tmp = dvrr_stack + 43016;
 target_ptr = Libderiv->deriv2_classes[2][7][117];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+5071, dvrr_stack+8379, NULL);
 tmp = dvrr_stack + 5071;
 target_ptr = Libderiv->deriv2_classes[2][8][117];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+5341, dvrr_stack+12513, NULL);
 tmp = dvrr_stack + 5341;
 target_ptr = Libderiv->deriv2_classes[2][9][117];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+12507, dvrr_stack+13503, NULL);
 tmp = dvrr_stack + 12507;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+12717, dvrr_stack+23676, NULL);
 tmp = dvrr_stack + 12717;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+12997, dvrr_stack+27501, NULL);
 tmp = dvrr_stack + 12997;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+13357, dvrr_stack+32416, NULL);
 tmp = dvrr_stack + 13357;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+100250, dvrr_stack+38560, NULL);
 tmp = dvrr_stack + 100250;
 target_ptr = Libderiv->deriv2_classes[3][9][117];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+38560, dvrr_stack+46216, NULL);
 tmp = dvrr_stack + 38560;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+38875, dvrr_stack+56246, NULL);
 tmp = dvrr_stack + 38875;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+39295, dvrr_stack+62096, NULL);
 tmp = dvrr_stack + 39295;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+62096, dvrr_stack+69606, NULL);
 tmp = dvrr_stack + 62096;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+62771, dvrr_stack+78987, NULL);
 tmp = dvrr_stack + 62771;
 target_ptr = Libderiv->deriv2_classes[4][9][117];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+39835, dvrr_stack+91209, dvrr_stack+91119);
 tmp = dvrr_stack + 39835;
 target_ptr = Libderiv->deriv2_classes[2][5][107];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+39961, dvrr_stack+91503, dvrr_stack+91377);
 tmp = dvrr_stack + 39961;
 target_ptr = Libderiv->deriv2_classes[2][6][107];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+13807, dvrr_stack+91719, dvrr_stack+91209);
 tmp = dvrr_stack + 13807;
 target_ptr = Libderiv->deriv2_classes[2][7][107];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+69570, dvrr_stack+86214, dvrr_stack+91503);
 tmp = dvrr_stack + 69570;
 target_ptr = Libderiv->deriv2_classes[2][8][107];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+69840, dvrr_stack+91989, dvrr_stack+91719);
 tmp = dvrr_stack + 69840;
 target_ptr = Libderiv->deriv2_classes[2][9][107];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+70170, dvrr_stack+93195, dvrr_stack+93045);
 tmp = dvrr_stack + 70170;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+70380, dvrr_stack+5719, dvrr_stack+93475);
 tmp = dvrr_stack + 70380;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+70660, dvrr_stack+93685, dvrr_stack+93195);
 tmp = dvrr_stack + 70660;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+71020, dvrr_stack+94135, dvrr_stack+5719);
 tmp = dvrr_stack + 71020;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+100800, dvrr_stack+94685, dvrr_stack+93685);
 tmp = dvrr_stack + 100800;
 target_ptr = Libderiv->deriv2_classes[3][9][107];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+101350, dvrr_stack+24516, dvrr_stack+82362);
 tmp = dvrr_stack + 101350;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+101665, dvrr_stack+71631, dvrr_stack+82587);
 tmp = dvrr_stack + 101665;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+102085, dvrr_stack+72171, dvrr_stack+24516);
 tmp = dvrr_stack + 102085;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+102625, dvrr_stack+63716, dvrr_stack+71631);
 tmp = dvrr_stack + 102625;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+103300, dvrr_stack+47161, dvrr_stack+72171);
 tmp = dvrr_stack + 103300;
 target_ptr = Libderiv->deriv2_classes[4][9][107];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+89028, dvrr_stack+57506, dvrr_stack+95445);
 tmp = dvrr_stack + 89028;
 target_ptr = Libderiv->deriv2_classes[2][5][106];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+92875, dvrr_stack+57674, dvrr_stack+82902);
 tmp = dvrr_stack + 92875;
 target_ptr = Libderiv->deriv2_classes[2][6][106];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+104125, dvrr_stack+48151, dvrr_stack+57506);
 tmp = dvrr_stack + 104125;
 target_ptr = Libderiv->deriv2_classes[2][7][106];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+104341, dvrr_stack+48421, dvrr_stack+57674);
 tmp = dvrr_stack + 104341;
 target_ptr = Libderiv->deriv2_classes[2][8][106];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+104611, dvrr_stack+48751, dvrr_stack+48151);
 tmp = dvrr_stack + 104611;
 target_ptr = Libderiv->deriv2_classes[2][9][106];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+104941, dvrr_stack+49147, dvrr_stack+57890);
 tmp = dvrr_stack + 104941;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+105151, dvrr_stack+40420, dvrr_stack+40210);
 tmp = dvrr_stack + 105151;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+105431, dvrr_stack+40780, dvrr_stack+49147);
 tmp = dvrr_stack + 105431;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+105791, dvrr_stack+33766, dvrr_stack+40420);
 tmp = dvrr_stack + 105791;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+106241, dvrr_stack+17531, dvrr_stack+40780);
 tmp = dvrr_stack + 106241;
 target_ptr = Libderiv->deriv2_classes[3][9][106];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+106791, dvrr_stack+28581, dvrr_stack+34316);
 tmp = dvrr_stack + 106791;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+107106, dvrr_stack+18506, dvrr_stack+18191);
 tmp = dvrr_stack + 107106;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+107526, dvrr_stack+113784, dvrr_stack+28581);
 tmp = dvrr_stack + 107526;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+108066, dvrr_stack+114459, dvrr_stack+18506);
 tmp = dvrr_stack + 108066;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+108741, dvrr_stack+115284, dvrr_stack+113784);
 tmp = dvrr_stack + 108741;
 target_ptr = Libderiv->deriv2_classes[4][9][106];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+77722, dvrr_stack+90849, dvrr_stack+95535);
 tmp = dvrr_stack + 77722;
 target_ptr = Libderiv->deriv2_classes[2][5][105];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+43232, dvrr_stack+990, dvrr_stack+1991);
 tmp = dvrr_stack + 43232;
 target_ptr = Libderiv->deriv2_classes[2][6][105];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+109566, dvrr_stack+4423, dvrr_stack+90849);
 tmp = dvrr_stack + 109566;
 target_ptr = Libderiv->deriv2_classes[2][7][105];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+109782, dvrr_stack+7569, dvrr_stack+990);
 tmp = dvrr_stack + 109782;
 target_ptr = Libderiv->deriv2_classes[2][8][105];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+110052, dvrr_stack+11523, dvrr_stack+4423);
 tmp = dvrr_stack + 110052;
 target_ptr = Libderiv->deriv2_classes[2][9][105];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+110382, dvrr_stack+92595, dvrr_stack+16343);
 tmp = dvrr_stack + 110382;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+110592, dvrr_stack+21522, dvrr_stack+22836);
 tmp = dvrr_stack + 110592;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+110872, dvrr_stack+26421, dvrr_stack+92595);
 tmp = dvrr_stack + 110872;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+111232, dvrr_stack+31066, dvrr_stack+21522);
 tmp = dvrr_stack + 111232;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+111682, dvrr_stack+36910, dvrr_stack+26421);
 tmp = dvrr_stack + 111682;
 target_ptr = Libderiv->deriv2_classes[3][9][105];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+112232, dvrr_stack+81687, dvrr_stack+44236);
 tmp = dvrr_stack + 112232;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+112547, dvrr_stack+52925, dvrr_stack+54986);
 tmp = dvrr_stack + 112547;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+112967, dvrr_stack+60476, dvrr_stack+81687);
 tmp = dvrr_stack + 112967;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+78958, dvrr_stack+67581, dvrr_stack+52925);
 tmp = dvrr_stack + 78958;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+79633, dvrr_stack+37570, dvrr_stack+60476);
 tmp = dvrr_stack + 79633;
 target_ptr = Libderiv->deriv2_classes[4][9][105];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+71470, dvrr_stack+87792, dvrr_stack+74);
 tmp = dvrr_stack + 71470;
 target_ptr = Libderiv->deriv2_classes[2][5][104];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+113507, dvrr_stack+88086, dvrr_stack+87960);
 tmp = dvrr_stack + 113507;
 target_ptr = Libderiv->deriv2_classes[2][6][104];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+80458, dvrr_stack+21882, dvrr_stack+87792);
 tmp = dvrr_stack + 80458;
 target_ptr = Libderiv->deriv2_classes[2][7][104];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+80674, dvrr_stack+88302, dvrr_stack+88086);
 tmp = dvrr_stack + 80674;
 target_ptr = Libderiv->deriv2_classes[2][8][104];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+80944, dvrr_stack+88632, dvrr_stack+21882);
 tmp = dvrr_stack + 80944;
 target_ptr = Libderiv->deriv2_classes[2][9][104];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+56126, dvrr_stack+89314, dvrr_stack+89164);
 tmp = dvrr_stack + 56126;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+56336, dvrr_stack+89804, dvrr_stack+89594);
 tmp = dvrr_stack + 56336;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+56616, dvrr_stack+90164, dvrr_stack+89314);
 tmp = dvrr_stack + 56616;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+56976, dvrr_stack+76512, dvrr_stack+89804);
 tmp = dvrr_stack + 56976;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+46127, dvrr_stack+77062, dvrr_stack+90164);
 tmp = dvrr_stack + 46127;
 target_ptr = Libderiv->deriv2_classes[3][9][104];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+46677, dvrr_stack+78097, dvrr_stack+77872);
 tmp = dvrr_stack + 46677;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+32369, dvrr_stack+68406, dvrr_stack+78517);
 tmp = dvrr_stack + 32369;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+32789, dvrr_stack+61151, dvrr_stack+78097);
 tmp = dvrr_stack + 32789;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+27447, dvrr_stack+55301, dvrr_stack+68406);
 tmp = dvrr_stack + 27447;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+23596, dvrr_stack+44461, dvrr_stack+61151);
 tmp = dvrr_stack + 23596;
 target_ptr = Libderiv->deriv2_classes[4][9][104];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+90704, dvrr_stack+91209, dvrr_stack+91119);
 tmp = dvrr_stack + 90704;
 target_ptr = Libderiv->deriv2_classes[2][5][95];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+81274, dvrr_stack+91503, dvrr_stack+91377);
 tmp = dvrr_stack + 81274;
 target_ptr = Libderiv->deriv2_classes[2][6][95];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+33329, dvrr_stack+91719, dvrr_stack+91209);
 tmp = dvrr_stack + 33329;
 target_ptr = Libderiv->deriv2_classes[2][7][95];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+28122, dvrr_stack+86214, dvrr_stack+91503);
 tmp = dvrr_stack + 28122;
 target_ptr = Libderiv->deriv2_classes[2][8][95];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+8325, dvrr_stack+91989, dvrr_stack+91719);
 tmp = dvrr_stack + 8325;
 target_ptr = Libderiv->deriv2_classes[2][9][95];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+33545, dvrr_stack+93195, dvrr_stack+93045);
 tmp = dvrr_stack + 33545;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+8655, dvrr_stack+5719, dvrr_stack+93475);
 tmp = dvrr_stack + 8655;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+2447, dvrr_stack+93685, dvrr_stack+93195);
 tmp = dvrr_stack + 2447;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+83028, dvrr_stack+94135, dvrr_stack+5719);
 tmp = dvrr_stack + 83028;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+83478, dvrr_stack+94685, dvrr_stack+93685);
 tmp = dvrr_stack + 83478;
 target_ptr = Libderiv->deriv2_classes[3][9][95];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+84028, dvrr_stack+24516, dvrr_stack+82362);
 tmp = dvrr_stack + 84028;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+84343, dvrr_stack+71631, dvrr_stack+82587);
 tmp = dvrr_stack + 84343;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+84763, dvrr_stack+72171, dvrr_stack+24516);
 tmp = dvrr_stack + 84763;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+85303, dvrr_stack+63716, dvrr_stack+71631);
 tmp = dvrr_stack + 85303;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+58040, dvrr_stack+47161, dvrr_stack+72171);
 tmp = dvrr_stack + 58040;
 target_ptr = Libderiv->deriv2_classes[4][9][95];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+46992, dvrr_stack+57506, dvrr_stack+95445);
 tmp = dvrr_stack + 46992;
 target_ptr = Libderiv->deriv2_classes[2][5][94];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+28392, dvrr_stack+57674, dvrr_stack+82902);
 tmp = dvrr_stack + 28392;
 target_ptr = Libderiv->deriv2_classes[2][6][94];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+58865, dvrr_stack+48151, dvrr_stack+57506);
 tmp = dvrr_stack + 58865;
 target_ptr = Libderiv->deriv2_classes[2][7][94];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+65081, dvrr_stack+48421, dvrr_stack+57674);
 tmp = dvrr_stack + 65081;
 target_ptr = Libderiv->deriv2_classes[2][8][94];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+65351, dvrr_stack+48751, dvrr_stack+48151);
 tmp = dvrr_stack + 65351;
 target_ptr = Libderiv->deriv2_classes[2][9][94];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+8935, dvrr_stack+49147, dvrr_stack+57890);
 tmp = dvrr_stack + 8935;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+49427, dvrr_stack+40420, dvrr_stack+40210);
 tmp = dvrr_stack + 49427;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+49707, dvrr_stack+40780, dvrr_stack+49147);
 tmp = dvrr_stack + 49707;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+50067, dvrr_stack+33766, dvrr_stack+40420);
 tmp = dvrr_stack + 50067;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+50517, dvrr_stack+17531, dvrr_stack+40780);
 tmp = dvrr_stack + 50517;
 target_ptr = Libderiv->deriv2_classes[3][9][94];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+34991, dvrr_stack+28581, dvrr_stack+34316);
 tmp = dvrr_stack + 34991;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+29361, dvrr_stack+18506, dvrr_stack+18191);
 tmp = dvrr_stack + 29361;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+19406, dvrr_stack+113784, dvrr_stack+28581);
 tmp = dvrr_stack + 19406;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+9639, dvrr_stack+114459, dvrr_stack+18506);
 tmp = dvrr_stack + 9639;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+180688, dvrr_stack+115284, dvrr_stack+113784);
 tmp = dvrr_stack + 180688;
 target_ptr = Libderiv->deriv2_classes[4][9][94];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+2807, dvrr_stack+90849, dvrr_stack+95535);
 tmp = dvrr_stack + 2807;
 target_ptr = Libderiv->deriv2_classes[2][5][93];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+85978, dvrr_stack+990, dvrr_stack+1991);
 tmp = dvrr_stack + 85978;
 target_ptr = Libderiv->deriv2_classes[2][6][93];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+35306, dvrr_stack+4423, dvrr_stack+90849);
 tmp = dvrr_stack + 35306;
 target_ptr = Libderiv->deriv2_classes[2][7][93];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+19946, dvrr_stack+7569, dvrr_stack+990);
 tmp = dvrr_stack + 19946;
 target_ptr = Libderiv->deriv2_classes[2][8][93];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+3224, dvrr_stack+11523, dvrr_stack+4423);
 tmp = dvrr_stack + 3224;
 target_ptr = Libderiv->deriv2_classes[2][9][93];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+29781, dvrr_stack+92595, dvrr_stack+16343);
 tmp = dvrr_stack + 29781;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+20216, dvrr_stack+21522, dvrr_stack+22836);
 tmp = dvrr_stack + 20216;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+181513, dvrr_stack+26421, dvrr_stack+92595);
 tmp = dvrr_stack + 181513;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+181873, dvrr_stack+31066, dvrr_stack+21522);
 tmp = dvrr_stack + 181873;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+182323, dvrr_stack+36910, dvrr_stack+26421);
 tmp = dvrr_stack + 182323;
 target_ptr = Libderiv->deriv2_classes[3][9][93];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+182873, dvrr_stack+81687, dvrr_stack+44236);
 tmp = dvrr_stack + 182873;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+183188, dvrr_stack+52925, dvrr_stack+54986);
 tmp = dvrr_stack + 183188;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+183608, dvrr_stack+60476, dvrr_stack+81687);
 tmp = dvrr_stack + 183608;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+184148, dvrr_stack+67581, dvrr_stack+52925);
 tmp = dvrr_stack + 184148;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+184823, dvrr_stack+37570, dvrr_stack+60476);
 tmp = dvrr_stack + 184823;
 target_ptr = Libderiv->deriv2_classes[4][9][93];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+65681, dvrr_stack+87792, dvrr_stack+74);
 tmp = dvrr_stack + 65681;
 target_ptr = Libderiv->deriv2_classes[2][5][92];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+185648, dvrr_stack+88086, dvrr_stack+87960);
 tmp = dvrr_stack + 185648;
 target_ptr = Libderiv->deriv2_classes[2][6][92];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+185816, dvrr_stack+21882, dvrr_stack+87792);
 tmp = dvrr_stack + 185816;
 target_ptr = Libderiv->deriv2_classes[2][7][92];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+186032, dvrr_stack+88302, dvrr_stack+88086);
 tmp = dvrr_stack + 186032;
 target_ptr = Libderiv->deriv2_classes[2][8][92];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+186302, dvrr_stack+88632, dvrr_stack+21882);
 tmp = dvrr_stack + 186302;
 target_ptr = Libderiv->deriv2_classes[2][9][92];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+186632, dvrr_stack+89314, dvrr_stack+89164);
 tmp = dvrr_stack + 186632;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+186842, dvrr_stack+89804, dvrr_stack+89594);
 tmp = dvrr_stack + 186842;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+187122, dvrr_stack+90164, dvrr_stack+89314);
 tmp = dvrr_stack + 187122;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+187482, dvrr_stack+76512, dvrr_stack+89804);
 tmp = dvrr_stack + 187482;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+187932, dvrr_stack+77062, dvrr_stack+90164);
 tmp = dvrr_stack + 187932;
 target_ptr = Libderiv->deriv2_classes[3][9][92];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+188482, dvrr_stack+78097, dvrr_stack+77872);
 tmp = dvrr_stack + 188482;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+188797, dvrr_stack+68406, dvrr_stack+78517);
 tmp = dvrr_stack + 188797;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+189217, dvrr_stack+61151, dvrr_stack+78097);
 tmp = dvrr_stack + 189217;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+189757, dvrr_stack+55301, dvrr_stack+68406);
 tmp = dvrr_stack + 189757;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+190432, dvrr_stack+44461, dvrr_stack+61151);
 tmp = dvrr_stack + 190432;
 target_ptr = Libderiv->deriv2_classes[4][9][92];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+35522, dvrr_stack+68946, dvrr_stack+90614);
 tmp = dvrr_stack + 35522;
 target_ptr = Libderiv->deriv2_classes[2][5][91];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+191257, dvrr_stack+69114, dvrr_stack+78832);
 tmp = dvrr_stack + 191257;
 target_ptr = Libderiv->deriv2_classes[2][6][91];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+191425, dvrr_stack+61826, dvrr_stack+68946);
 tmp = dvrr_stack + 191425;
 target_ptr = Libderiv->deriv2_classes[2][7][91];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+191641, dvrr_stack+53465, dvrr_stack+69114);
 tmp = dvrr_stack + 191641;
 target_ptr = Libderiv->deriv2_classes[2][8][91];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+191911, dvrr_stack+45451, dvrr_stack+61826);
 tmp = dvrr_stack + 191911;
 target_ptr = Libderiv->deriv2_classes[2][9][91];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+192241, dvrr_stack+45847, dvrr_stack+69330);
 tmp = dvrr_stack + 192241;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+192451, dvrr_stack+31616, dvrr_stack+82107);
 tmp = dvrr_stack + 192451;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+192731, dvrr_stack+26871, dvrr_stack+45847);
 tmp = dvrr_stack + 192731;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+193091, dvrr_stack+23046, dvrr_stack+31616);
 tmp = dvrr_stack + 193091;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+193541, dvrr_stack+16493, dvrr_stack+26871);
 tmp = dvrr_stack + 193541;
 target_ptr = Libderiv->deriv2_classes[3][9][91];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+194091, dvrr_stack+11919, dvrr_stack+31976);
 tmp = dvrr_stack + 194091;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+194406, dvrr_stack+116274, dvrr_stack+17153);
 tmp = dvrr_stack + 194406;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+194826, dvrr_stack+116814, dvrr_stack+11919);
 tmp = dvrr_stack + 194826;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+195366, dvrr_stack+117489, dvrr_stack+116274);
 tmp = dvrr_stack + 195366;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+196041, dvrr_stack+118314, dvrr_stack+116814);
 tmp = dvrr_stack + 196041;
 target_ptr = Libderiv->deriv2_classes[4][9][91];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+196866, dvrr_stack+91209, dvrr_stack+91119);
 tmp = dvrr_stack + 196866;
 target_ptr = Libderiv->deriv2_classes[2][5][83];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+91017, dvrr_stack+91503, dvrr_stack+91377);
 tmp = dvrr_stack + 91017;
 target_ptr = Libderiv->deriv2_classes[2][6][83];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+196992, dvrr_stack+91719, dvrr_stack+91209);
 tmp = dvrr_stack + 196992;
 target_ptr = Libderiv->deriv2_classes[2][7][83];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+197208, dvrr_stack+86214, dvrr_stack+91503);
 tmp = dvrr_stack + 197208;
 target_ptr = Libderiv->deriv2_classes[2][8][83];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+197478, dvrr_stack+91989, dvrr_stack+91719);
 tmp = dvrr_stack + 197478;
 target_ptr = Libderiv->deriv2_classes[2][9][83];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+91989, dvrr_stack+93195, dvrr_stack+93045);
 tmp = dvrr_stack + 91989;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+197808, dvrr_stack+5719, dvrr_stack+93475);
 tmp = dvrr_stack + 197808;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+198088, dvrr_stack+93685, dvrr_stack+93195);
 tmp = dvrr_stack + 198088;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+198448, dvrr_stack+94135, dvrr_stack+5719);
 tmp = dvrr_stack + 198448;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+198898, dvrr_stack+94685, dvrr_stack+93685);
 tmp = dvrr_stack + 198898;
 target_ptr = Libderiv->deriv2_classes[3][9][83];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+94685, dvrr_stack+24516, dvrr_stack+82362);
 tmp = dvrr_stack + 94685;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+199448, dvrr_stack+71631, dvrr_stack+82587);
 tmp = dvrr_stack + 199448;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+199868, dvrr_stack+72171, dvrr_stack+24516);
 tmp = dvrr_stack + 199868;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+200408, dvrr_stack+63716, dvrr_stack+71631);
 tmp = dvrr_stack + 200408;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+201083, dvrr_stack+47161, dvrr_stack+72171);
 tmp = dvrr_stack + 201083;
 target_ptr = Libderiv->deriv2_classes[4][9][83];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+95000, dvrr_stack+57506, dvrr_stack+95445);
 tmp = dvrr_stack + 95000;
 target_ptr = Libderiv->deriv2_classes[2][5][82];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+95126, dvrr_stack+57674, dvrr_stack+82902);
 tmp = dvrr_stack + 95126;
 target_ptr = Libderiv->deriv2_classes[2][6][82];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+82317, dvrr_stack+48151, dvrr_stack+57506);
 tmp = dvrr_stack + 82317;
 target_ptr = Libderiv->deriv2_classes[2][7][82];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+47118, dvrr_stack+48421, dvrr_stack+57674);
 tmp = dvrr_stack + 47118;
 target_ptr = Libderiv->deriv2_classes[2][8][82];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+47388, dvrr_stack+48751, dvrr_stack+48151);
 tmp = dvrr_stack + 47388;
 target_ptr = Libderiv->deriv2_classes[2][9][82];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+48751, dvrr_stack+49147, dvrr_stack+57890);
 tmp = dvrr_stack + 48751;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+47718, dvrr_stack+40420, dvrr_stack+40210);
 tmp = dvrr_stack + 47718;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+201908, dvrr_stack+40780, dvrr_stack+49147);
 tmp = dvrr_stack + 201908;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+202268, dvrr_stack+33766, dvrr_stack+40420);
 tmp = dvrr_stack + 202268;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+202718, dvrr_stack+17531, dvrr_stack+40780);
 tmp = dvrr_stack + 202718;
 target_ptr = Libderiv->deriv2_classes[3][9][82];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+17531, dvrr_stack+28581, dvrr_stack+34316);
 tmp = dvrr_stack + 17531;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+203268, dvrr_stack+18506, dvrr_stack+18191);
 tmp = dvrr_stack + 203268;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+203688, dvrr_stack+113784, dvrr_stack+28581);
 tmp = dvrr_stack + 203688;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+204228, dvrr_stack+114459, dvrr_stack+18506);
 tmp = dvrr_stack + 204228;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+204903, dvrr_stack+115284, dvrr_stack+113784);
 tmp = dvrr_stack + 204903;
 target_ptr = Libderiv->deriv2_classes[4][9][82];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+115284, dvrr_stack+90849, dvrr_stack+95535);
 tmp = dvrr_stack + 115284;
 target_ptr = Libderiv->deriv2_classes[2][5][81];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+115410, dvrr_stack+990, dvrr_stack+1991);
 tmp = dvrr_stack + 115410;
 target_ptr = Libderiv->deriv2_classes[2][6][81];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+115578, dvrr_stack+4423, dvrr_stack+90849);
 tmp = dvrr_stack + 115578;
 target_ptr = Libderiv->deriv2_classes[2][7][81];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+115794, dvrr_stack+7569, dvrr_stack+990);
 tmp = dvrr_stack + 115794;
 target_ptr = Libderiv->deriv2_classes[2][8][81];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+17846, dvrr_stack+11523, dvrr_stack+4423);
 tmp = dvrr_stack + 17846;
 target_ptr = Libderiv->deriv2_classes[2][9][81];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+116064, dvrr_stack+92595, dvrr_stack+16343);
 tmp = dvrr_stack + 116064;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+11523, dvrr_stack+21522, dvrr_stack+22836);
 tmp = dvrr_stack + 11523;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+205728, dvrr_stack+26421, dvrr_stack+92595);
 tmp = dvrr_stack + 205728;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+206088, dvrr_stack+31066, dvrr_stack+21522);
 tmp = dvrr_stack + 206088;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+206538, dvrr_stack+36910, dvrr_stack+26421);
 tmp = dvrr_stack + 206538;
 target_ptr = Libderiv->deriv2_classes[3][9][81];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+36832, dvrr_stack+81687, dvrr_stack+44236);
 tmp = dvrr_stack + 36832;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+37147, dvrr_stack+52925, dvrr_stack+54986);
 tmp = dvrr_stack + 37147;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+207088, dvrr_stack+60476, dvrr_stack+81687);
 tmp = dvrr_stack + 207088;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+207628, dvrr_stack+67581, dvrr_stack+52925);
 tmp = dvrr_stack + 207628;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+208303, dvrr_stack+37570, dvrr_stack+60476);
 tmp = dvrr_stack + 208303;
 target_ptr = Libderiv->deriv2_classes[4][9][81];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+34316, dvrr_stack+87792, dvrr_stack+74);
 tmp = dvrr_stack + 34316;
 target_ptr = Libderiv->deriv2_classes[2][5][80];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+48961, dvrr_stack+88086, dvrr_stack+87960);
 tmp = dvrr_stack + 48961;
 target_ptr = Libderiv->deriv2_classes[2][6][80];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+95408, dvrr_stack+21882, dvrr_stack+87792);
 tmp = dvrr_stack + 95408;
 target_ptr = Libderiv->deriv2_classes[2][7][80];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+37567, dvrr_stack+88302, dvrr_stack+88086);
 tmp = dvrr_stack + 37567;
 target_ptr = Libderiv->deriv2_classes[2][8][80];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+37837, dvrr_stack+88632, dvrr_stack+21882);
 tmp = dvrr_stack + 37837;
 target_ptr = Libderiv->deriv2_classes[2][9][80];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+88632, dvrr_stack+89314, dvrr_stack+89164);
 tmp = dvrr_stack + 88632;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+38167, dvrr_stack+89804, dvrr_stack+89594);
 tmp = dvrr_stack + 38167;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+209128, dvrr_stack+90164, dvrr_stack+89314);
 tmp = dvrr_stack + 209128;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+209488, dvrr_stack+76512, dvrr_stack+89804);
 tmp = dvrr_stack + 209488;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+209938, dvrr_stack+77062, dvrr_stack+90164);
 tmp = dvrr_stack + 209938;
 target_ptr = Libderiv->deriv2_classes[3][9][80];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+77062, dvrr_stack+78097, dvrr_stack+77872);
 tmp = dvrr_stack + 77062;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+210488, dvrr_stack+68406, dvrr_stack+78517);
 tmp = dvrr_stack + 210488;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+210908, dvrr_stack+61151, dvrr_stack+78097);
 tmp = dvrr_stack + 210908;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+211448, dvrr_stack+55301, dvrr_stack+68406);
 tmp = dvrr_stack + 211448;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+212123, dvrr_stack+44461, dvrr_stack+61151);
 tmp = dvrr_stack + 212123;
 target_ptr = Libderiv->deriv2_classes[4][9][80];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+77377, dvrr_stack+68946, dvrr_stack+90614);
 tmp = dvrr_stack + 77377;
 target_ptr = Libderiv->deriv2_classes[2][5][79];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+77503, dvrr_stack+69114, dvrr_stack+78832);
 tmp = dvrr_stack + 77503;
 target_ptr = Libderiv->deriv2_classes[2][6][79];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+77848, dvrr_stack+61826, dvrr_stack+68946);
 tmp = dvrr_stack + 77848;
 target_ptr = Libderiv->deriv2_classes[2][7][79];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+44167, dvrr_stack+53465, dvrr_stack+69114);
 tmp = dvrr_stack + 44167;
 target_ptr = Libderiv->deriv2_classes[2][8][79];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+44437, dvrr_stack+45451, dvrr_stack+61826);
 tmp = dvrr_stack + 44437;
 target_ptr = Libderiv->deriv2_classes[2][9][79];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+44767, dvrr_stack+45847, dvrr_stack+69330);
 tmp = dvrr_stack + 44767;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+44977, dvrr_stack+31616, dvrr_stack+82107);
 tmp = dvrr_stack + 44977;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+45257, dvrr_stack+26871, dvrr_stack+45847);
 tmp = dvrr_stack + 45257;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+212948, dvrr_stack+23046, dvrr_stack+31616);
 tmp = dvrr_stack + 212948;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+213398, dvrr_stack+16493, dvrr_stack+26871);
 tmp = dvrr_stack + 213398;
 target_ptr = Libderiv->deriv2_classes[3][9][79];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+16305, dvrr_stack+11919, dvrr_stack+31976);
 tmp = dvrr_stack + 16305;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+16620, dvrr_stack+116274, dvrr_stack+17153);
 tmp = dvrr_stack + 16620;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+213948, dvrr_stack+116814, dvrr_stack+11919);
 tmp = dvrr_stack + 213948;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+214488, dvrr_stack+117489, dvrr_stack+116274);
 tmp = dvrr_stack + 214488;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+215163, dvrr_stack+118314, dvrr_stack+116814);
 tmp = dvrr_stack + 215163;
 target_ptr = Libderiv->deriv2_classes[4][9][79];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+118314, dvrr_stack+32201, dvrr_stack+69480);
 tmp = dvrr_stack + 118314;
 target_ptr = Libderiv->deriv2_classes[2][5][78];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+118440, dvrr_stack+7899, dvrr_stack+27321);
 tmp = dvrr_stack + 118440;
 target_ptr = Libderiv->deriv2_classes[2][6][78];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+118608, dvrr_stack+4693, dvrr_stack+32201);
 tmp = dvrr_stack + 118608;
 target_ptr = Libderiv->deriv2_classes[2][7][78];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+118824, dvrr_stack+2117, dvrr_stack+7899);
 tmp = dvrr_stack + 118824;
 target_ptr = Libderiv->deriv2_classes[2][8][78];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+215988, dvrr_stack+11127, dvrr_stack+4693);
 tmp = dvrr_stack + 215988;
 target_ptr = Libderiv->deriv2_classes[2][9][78];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+119094, dvrr_stack+16025, dvrr_stack+15875);
 tmp = dvrr_stack + 119094;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+11051, dvrr_stack+19046, dvrr_stack+8115);
 tmp = dvrr_stack + 11051;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+216318, dvrr_stack+9189, dvrr_stack+16025);
 tmp = dvrr_stack + 216318;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+216678, dvrr_stack+119304, dvrr_stack+19046);
 tmp = dvrr_stack + 216678;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+217128, dvrr_stack+119854, dvrr_stack+9189);
 tmp = dvrr_stack + 217128;
 target_ptr = Libderiv->deriv2_classes[3][9][78];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+119854, dvrr_stack+43432, dvrr_stack+2999);
 tmp = dvrr_stack + 119854;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+217678, dvrr_stack+120514, dvrr_stack+43852);
 tmp = dvrr_stack + 217678;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+218098, dvrr_stack+121054, dvrr_stack+43432);
 tmp = dvrr_stack + 218098;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+218638, dvrr_stack+121729, dvrr_stack+120514);
 tmp = dvrr_stack + 218638;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+219313, dvrr_stack+122554, dvrr_stack+121054);
 tmp = dvrr_stack + 219313;
 target_ptr = Libderiv->deriv2_classes[4][9][78];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,21,dvrr_stack+122554, dvrr_stack+93475, dvrr_stack+17468);
 tmp = dvrr_stack + 122554;
 target_ptr = Libderiv->deriv2_classes[2][5][35];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,28,dvrr_stack+122680, dvrr_stack+93195, dvrr_stack+86985);
 tmp = dvrr_stack + 122680;
 target_ptr = Libderiv->deriv2_classes[2][6][35];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,36,dvrr_stack+122848, dvrr_stack+5719, dvrr_stack+4963);
 tmp = dvrr_stack + 122848;
 target_ptr = Libderiv->deriv2_classes[2][7][35];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,45,dvrr_stack+123064, dvrr_stack+93685, dvrr_stack+87393);
 tmp = dvrr_stack + 123064;
 target_ptr = Libderiv->deriv2_classes[2][8][35];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,55,dvrr_stack+120169, dvrr_stack+94135, dvrr_stack+87528);
 tmp = dvrr_stack + 120169;
 target_ptr = Libderiv->deriv2_classes[2][9][35];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+123334, dvrr_stack+82587, dvrr_stack+91377);
 tmp = dvrr_stack + 123334;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+2933, dvrr_stack+24516, dvrr_stack+91209);
 tmp = dvrr_stack + 2933;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+220138, dvrr_stack+71631, dvrr_stack+91503);
 tmp = dvrr_stack + 220138;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+220498, dvrr_stack+72171, dvrr_stack+91719);
 tmp = dvrr_stack + 220498;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,55,dvrr_stack+220948, dvrr_stack+63716, dvrr_stack+86214);
 tmp = dvrr_stack + 220948;
 target_ptr = Libderiv->deriv2_classes[3][9][35];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+221498, dvrr_stack+128021, dvrr_stack+93475);
 tmp = dvrr_stack + 221498;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+221813, dvrr_stack+132098, dvrr_stack+93195);
 tmp = dvrr_stack + 221813;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+222233, dvrr_stack+137294, dvrr_stack+5719);
 tmp = dvrr_stack + 222233;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+222773, dvrr_stack+143745, dvrr_stack+93685);
 tmp = dvrr_stack + 222773;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,55,dvrr_stack+223448, dvrr_stack+74466, dvrr_stack+94135);
 tmp = dvrr_stack + 223448;
 target_ptr = Libderiv->deriv2_classes[4][9][35];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+31976, dvrr_stack+40210, dvrr_stack+75621);
 tmp = dvrr_stack + 31976;
 target_ptr = Libderiv->deriv2_classes[2][5][34];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+69330, dvrr_stack+49147, dvrr_stack+75684);
 tmp = dvrr_stack + 69330;
 target_ptr = Libderiv->deriv2_classes[2][6][34];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+45617, dvrr_stack+40420, dvrr_stack+75768);
 tmp = dvrr_stack + 45617;
 target_ptr = Libderiv->deriv2_classes[2][7][34];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+224273, dvrr_stack+40780, dvrr_stack+75876);
 tmp = dvrr_stack + 224273;
 target_ptr = Libderiv->deriv2_classes[2][8][34];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+224543, dvrr_stack+33766, dvrr_stack+76011);
 tmp = dvrr_stack + 224543;
 target_ptr = Libderiv->deriv2_classes[2][9][34];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+224873, dvrr_stack+18191, dvrr_stack+82902);
 tmp = dvrr_stack + 224873;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+225083, dvrr_stack+28581, dvrr_stack+57506);
 tmp = dvrr_stack + 225083;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+225363, dvrr_stack+18506, dvrr_stack+57674);
 tmp = dvrr_stack + 225363;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+225723, dvrr_stack+113784, dvrr_stack+48151);
 tmp = dvrr_stack + 225723;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+226173, dvrr_stack+114459, dvrr_stack+48421);
 tmp = dvrr_stack + 226173;
 target_ptr = Libderiv->deriv2_classes[3][9][34];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+226723, dvrr_stack+144690, dvrr_stack+40210);
 tmp = dvrr_stack + 226723;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+227038, dvrr_stack+145131, dvrr_stack+49147);
 tmp = dvrr_stack + 227038;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+227458, dvrr_stack+35656, dvrr_stack+40420);
 tmp = dvrr_stack + 227458;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+227998, dvrr_stack+151191, dvrr_stack+40780);
 tmp = dvrr_stack + 227998;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+228673, dvrr_stack+152136, dvrr_stack+33766);
 tmp = dvrr_stack + 228673;
 target_ptr = Libderiv->deriv2_classes[4][9][34];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+88842, dvrr_stack+22836, dvrr_stack+76176);
 tmp = dvrr_stack + 88842;
 target_ptr = Libderiv->deriv2_classes[2][5][33];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+92199, dvrr_stack+92595, dvrr_stack+86544);
 tmp = dvrr_stack + 92199;
 target_ptr = Libderiv->deriv2_classes[2][6][33];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+229498, dvrr_stack+21522, dvrr_stack+86628);
 tmp = dvrr_stack + 229498;
 target_ptr = Libderiv->deriv2_classes[2][7][33];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+229714, dvrr_stack+26421, dvrr_stack+87069);
 tmp = dvrr_stack + 229714;
 target_ptr = Libderiv->deriv2_classes[2][8][33];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+229984, dvrr_stack+31066, dvrr_stack+123544);
 tmp = dvrr_stack + 229984;
 target_ptr = Libderiv->deriv2_classes[2][9][33];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+230314, dvrr_stack+54986, dvrr_stack+1991);
 tmp = dvrr_stack + 230314;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+230524, dvrr_stack+81687, dvrr_stack+90849);
 tmp = dvrr_stack + 230524;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+230804, dvrr_stack+52925, dvrr_stack+990);
 tmp = dvrr_stack + 230804;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+231164, dvrr_stack+60476, dvrr_stack+4423);
 tmp = dvrr_stack + 231164;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+231614, dvrr_stack+67581, dvrr_stack+7569);
 tmp = dvrr_stack + 231614;
 target_ptr = Libderiv->deriv2_classes[3][9][33];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+232164, dvrr_stack+123709, dvrr_stack+22836);
 tmp = dvrr_stack + 232164;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+232479, dvrr_stack+126698, dvrr_stack+92595);
 tmp = dvrr_stack + 232479;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+232899, dvrr_stack+130334, dvrr_stack+21522);
 tmp = dvrr_stack + 232899;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+233439, dvrr_stack+135026, dvrr_stack+26421);
 tmp = dvrr_stack + 233439;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+234114, dvrr_stack+140910, dvrr_stack+31066);
 tmp = dvrr_stack + 234114;
 target_ptr = Libderiv->deriv2_classes[4][9][33];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+57890, dvrr_stack+89594, dvrr_stack+147726);
 tmp = dvrr_stack + 57890;
 target_ptr = Libderiv->deriv2_classes[2][5][32];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+15851, dvrr_stack+89314, dvrr_stack+147789);
 tmp = dvrr_stack + 15851;
 target_ptr = Libderiv->deriv2_classes[2][6][32];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+234939, dvrr_stack+89804, dvrr_stack+147873);
 tmp = dvrr_stack + 234939;
 target_ptr = Libderiv->deriv2_classes[2][7][32];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+235155, dvrr_stack+90164, dvrr_stack+147981);
 tmp = dvrr_stack + 235155;
 target_ptr = Libderiv->deriv2_classes[2][8][32];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+235425, dvrr_stack+76512, dvrr_stack+148116);
 tmp = dvrr_stack + 235425;
 target_ptr = Libderiv->deriv2_classes[2][9][32];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+235755, dvrr_stack+78517, dvrr_stack+87960);
 tmp = dvrr_stack + 235755;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+235965, dvrr_stack+78097, dvrr_stack+87792);
 tmp = dvrr_stack + 235965;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+236245, dvrr_stack+68406, dvrr_stack+88086);
 tmp = dvrr_stack + 236245;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+236605, dvrr_stack+61151, dvrr_stack+21882);
 tmp = dvrr_stack + 236605;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+237055, dvrr_stack+55301, dvrr_stack+88302);
 tmp = dvrr_stack + 237055;
 target_ptr = Libderiv->deriv2_classes[3][9][32];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+237605, dvrr_stack+148824, dvrr_stack+89594);
 tmp = dvrr_stack + 237605;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+237920, dvrr_stack+149265, dvrr_stack+89314);
 tmp = dvrr_stack + 237920;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+238340, dvrr_stack+149853, dvrr_stack+89804);
 tmp = dvrr_stack + 238340;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+238880, dvrr_stack+142065, dvrr_stack+90164);
 tmp = dvrr_stack + 238880;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+239555, dvrr_stack+135971, dvrr_stack+76512);
 tmp = dvrr_stack + 239555;
 target_ptr = Libderiv->deriv2_classes[4][9][32];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+11331, dvrr_stack+82107, dvrr_stack+81462);
 tmp = dvrr_stack + 11331;
 target_ptr = Libderiv->deriv2_classes[2][5][31];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+240380, dvrr_stack+45847, dvrr_stack+81525);
 tmp = dvrr_stack + 240380;
 target_ptr = Libderiv->deriv2_classes[2][6][31];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+240548, dvrr_stack+31616, dvrr_stack+92385);
 tmp = dvrr_stack + 240548;
 target_ptr = Libderiv->deriv2_classes[2][7][31];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+240764, dvrr_stack+26871, dvrr_stack+148281);
 tmp = dvrr_stack + 240764;
 target_ptr = Libderiv->deriv2_classes[2][8][31];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+241034, dvrr_stack+23046, dvrr_stack+150609);
 tmp = dvrr_stack + 241034;
 target_ptr = Libderiv->deriv2_classes[2][9][31];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+241364, dvrr_stack+17153, dvrr_stack+78832);
 tmp = dvrr_stack + 241364;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+241574, dvrr_stack+11919, dvrr_stack+68946);
 tmp = dvrr_stack + 241574;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+241854, dvrr_stack+116274, dvrr_stack+69114);
 tmp = dvrr_stack + 241854;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+242214, dvrr_stack+116814, dvrr_stack+61826);
 tmp = dvrr_stack + 242214;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+242664, dvrr_stack+117489, dvrr_stack+53465);
 tmp = dvrr_stack + 242664;
 target_ptr = Libderiv->deriv2_classes[3][9][31];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+243214, dvrr_stack+143010, dvrr_stack+82107);
 tmp = dvrr_stack + 243214;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+243529, dvrr_stack+131090, dvrr_stack+45847);
 tmp = dvrr_stack + 243529;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+243949, dvrr_stack+153291, dvrr_stack+31616);
 tmp = dvrr_stack + 243949;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+244489, dvrr_stack+154047, dvrr_stack+26871);
 tmp = dvrr_stack + 244489;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+245164, dvrr_stack+154992, dvrr_stack+23046);
 tmp = dvrr_stack + 245164;
 target_ptr = Libderiv->deriv2_classes[4][9][31];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+89154, dvrr_stack+8115, dvrr_stack+81609);
 tmp = dvrr_stack + 89154;
 target_ptr = Libderiv->deriv2_classes[2][5][30];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+245989, dvrr_stack+16025, dvrr_stack+92493);
 tmp = dvrr_stack + 245989;
 target_ptr = Libderiv->deriv2_classes[2][6][30];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+246157, dvrr_stack+19046, dvrr_stack+150774);
 tmp = dvrr_stack + 246157;
 target_ptr = Libderiv->deriv2_classes[2][7][30];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+246373, dvrr_stack+9189, dvrr_stack+150882);
 tmp = dvrr_stack + 246373;
 target_ptr = Libderiv->deriv2_classes[2][8][30];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+246643, dvrr_stack+119304, dvrr_stack+151017);
 tmp = dvrr_stack + 246643;
 target_ptr = Libderiv->deriv2_classes[2][9][30];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+246973, dvrr_stack+43852, dvrr_stack+27321);
 tmp = dvrr_stack + 246973;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+247183, dvrr_stack+43432, dvrr_stack+32201);
 tmp = dvrr_stack + 247183;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+247463, dvrr_stack+120514, dvrr_stack+7899);
 tmp = dvrr_stack + 247463;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+247823, dvrr_stack+121054, dvrr_stack+4693);
 tmp = dvrr_stack + 247823;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+248273, dvrr_stack+121729, dvrr_stack+2117);
 tmp = dvrr_stack + 248273;
 target_ptr = Libderiv->deriv2_classes[3][9][30];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+248823, dvrr_stack+127286, dvrr_stack+8115);
 tmp = dvrr_stack + 248823;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+249138, dvrr_stack+145719, dvrr_stack+16025);
 tmp = dvrr_stack + 249138;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+249558, dvrr_stack+156147, dvrr_stack+19046);
 tmp = dvrr_stack + 249558;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+250098, dvrr_stack+156903, dvrr_stack+9189);
 tmp = dvrr_stack + 250098;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+250773, dvrr_stack+157848, dvrr_stack+119304);
 tmp = dvrr_stack + 250773;
 target_ptr = Libderiv->deriv2_classes[4][9][30];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+93043, dvrr_stack+148416, dvrr_stack+95345);
 tmp = dvrr_stack + 93043;
 target_ptr = Libderiv->deriv2_classes[2][5][26];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+251598, dvrr_stack+143451, dvrr_stack+148626);
 tmp = dvrr_stack + 251598;
 target_ptr = Libderiv->deriv2_classes[2][6][26];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+251766, dvrr_stack+131678, dvrr_stack+148710);
 tmp = dvrr_stack + 251766;
 target_ptr = Libderiv->deriv2_classes[2][7][26];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+251982, dvrr_stack+146307, dvrr_stack+137126);
 tmp = dvrr_stack + 251982;
 target_ptr = Libderiv->deriv2_classes[2][8][26];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+252252, dvrr_stack+146757, dvrr_stack+127727);
 tmp = dvrr_stack + 252252;
 target_ptr = Libderiv->deriv2_classes[2][9][26];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+252582, dvrr_stack+147307, dvrr_stack+127892);
 tmp = dvrr_stack + 252582;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+252792, dvrr_stack+36412, dvrr_stack+124150);
 tmp = dvrr_stack + 252792;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+253072, dvrr_stack+159003, dvrr_stack+86736);
 tmp = dvrr_stack + 253072;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+253432, dvrr_stack+159543, dvrr_stack+76239);
 tmp = dvrr_stack + 253432;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+253882, dvrr_stack+160218, dvrr_stack+30021);
 tmp = dvrr_stack + 253882;
 target_ptr = Libderiv->deriv2_classes[3][9][26];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+254432, dvrr_stack+10610, dvrr_stack+148416);
 tmp = dvrr_stack + 254432;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+254747, dvrr_stack+15263, dvrr_stack+143451);
 tmp = dvrr_stack + 254747;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+255167, dvrr_stack+162387, dvrr_stack+131678);
 tmp = dvrr_stack + 255167;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+255707, dvrr_stack+132686, dvrr_stack+146307);
 tmp = dvrr_stack + 255707;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+256382, dvrr_stack+165943, dvrr_stack+146757);
 tmp = dvrr_stack + 256382;
 target_ptr = Libderiv->deriv2_classes[4][9][26];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,21,dvrr_stack+0, dvrr_stack+93475, dvrr_stack+17468);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[2][5][23];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,28,dvrr_stack+257207, dvrr_stack+93195, dvrr_stack+86985);
 tmp = dvrr_stack + 257207;
 target_ptr = Libderiv->deriv2_classes[2][6][23];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,36,dvrr_stack+257375, dvrr_stack+5719, dvrr_stack+4963);
 tmp = dvrr_stack + 257375;
 target_ptr = Libderiv->deriv2_classes[2][7][23];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,45,dvrr_stack+257591, dvrr_stack+93685, dvrr_stack+87393);
 tmp = dvrr_stack + 257591;
 target_ptr = Libderiv->deriv2_classes[2][8][23];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,55,dvrr_stack+257861, dvrr_stack+94135, dvrr_stack+87528);
 tmp = dvrr_stack + 257861;
 target_ptr = Libderiv->deriv2_classes[2][9][23];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+258191, dvrr_stack+82587, dvrr_stack+91377);
 tmp = dvrr_stack + 258191;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+258401, dvrr_stack+24516, dvrr_stack+91209);
 tmp = dvrr_stack + 258401;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+258681, dvrr_stack+71631, dvrr_stack+91503);
 tmp = dvrr_stack + 258681;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+259041, dvrr_stack+72171, dvrr_stack+91719);
 tmp = dvrr_stack + 259041;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,55,dvrr_stack+259491, dvrr_stack+63716, dvrr_stack+86214);
 tmp = dvrr_stack + 259491;
 target_ptr = Libderiv->deriv2_classes[3][9][23];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+260041, dvrr_stack+128021, dvrr_stack+93475);
 tmp = dvrr_stack + 260041;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+260356, dvrr_stack+132098, dvrr_stack+93195);
 tmp = dvrr_stack + 260356;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+260776, dvrr_stack+137294, dvrr_stack+5719);
 tmp = dvrr_stack + 260776;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+261316, dvrr_stack+143745, dvrr_stack+93685);
 tmp = dvrr_stack + 261316;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,55,dvrr_stack+261991, dvrr_stack+74466, dvrr_stack+94135);
 tmp = dvrr_stack + 261991;
 target_ptr = Libderiv->deriv2_classes[4][9][23];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+47998, dvrr_stack+40210, dvrr_stack+75621);
 tmp = dvrr_stack + 47998;
 target_ptr = Libderiv->deriv2_classes[2][5][22];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+262816, dvrr_stack+49147, dvrr_stack+75684);
 tmp = dvrr_stack + 262816;
 target_ptr = Libderiv->deriv2_classes[2][6][22];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+262984, dvrr_stack+40420, dvrr_stack+75768);
 tmp = dvrr_stack + 262984;
 target_ptr = Libderiv->deriv2_classes[2][7][22];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+263200, dvrr_stack+40780, dvrr_stack+75876);
 tmp = dvrr_stack + 263200;
 target_ptr = Libderiv->deriv2_classes[2][8][22];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+263470, dvrr_stack+33766, dvrr_stack+76011);
 tmp = dvrr_stack + 263470;
 target_ptr = Libderiv->deriv2_classes[2][9][22];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+263800, dvrr_stack+18191, dvrr_stack+82902);
 tmp = dvrr_stack + 263800;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+264010, dvrr_stack+28581, dvrr_stack+57506);
 tmp = dvrr_stack + 264010;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+264290, dvrr_stack+18506, dvrr_stack+57674);
 tmp = dvrr_stack + 264290;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+264650, dvrr_stack+113784, dvrr_stack+48151);
 tmp = dvrr_stack + 264650;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+265100, dvrr_stack+114459, dvrr_stack+48421);
 tmp = dvrr_stack + 265100;
 target_ptr = Libderiv->deriv2_classes[3][9][22];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+265650, dvrr_stack+144690, dvrr_stack+40210);
 tmp = dvrr_stack + 265650;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+265965, dvrr_stack+145131, dvrr_stack+49147);
 tmp = dvrr_stack + 265965;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+266385, dvrr_stack+35656, dvrr_stack+40420);
 tmp = dvrr_stack + 266385;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+266925, dvrr_stack+151191, dvrr_stack+40780);
 tmp = dvrr_stack + 266925;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+267600, dvrr_stack+152136, dvrr_stack+33766);
 tmp = dvrr_stack + 267600;
 target_ptr = Libderiv->deriv2_classes[4][9][22];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+268425, dvrr_stack+22836, dvrr_stack+76176);
 tmp = dvrr_stack + 268425;
 target_ptr = Libderiv->deriv2_classes[2][5][21];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+268551, dvrr_stack+92595, dvrr_stack+86544);
 tmp = dvrr_stack + 268551;
 target_ptr = Libderiv->deriv2_classes[2][6][21];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+268719, dvrr_stack+21522, dvrr_stack+86628);
 tmp = dvrr_stack + 268719;
 target_ptr = Libderiv->deriv2_classes[2][7][21];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+268935, dvrr_stack+26421, dvrr_stack+87069);
 tmp = dvrr_stack + 268935;
 target_ptr = Libderiv->deriv2_classes[2][8][21];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+269205, dvrr_stack+31066, dvrr_stack+123544);
 tmp = dvrr_stack + 269205;
 target_ptr = Libderiv->deriv2_classes[2][9][21];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+269535, dvrr_stack+54986, dvrr_stack+1991);
 tmp = dvrr_stack + 269535;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+269745, dvrr_stack+81687, dvrr_stack+90849);
 tmp = dvrr_stack + 269745;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+270025, dvrr_stack+52925, dvrr_stack+990);
 tmp = dvrr_stack + 270025;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+270385, dvrr_stack+60476, dvrr_stack+4423);
 tmp = dvrr_stack + 270385;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+270835, dvrr_stack+67581, dvrr_stack+7569);
 tmp = dvrr_stack + 270835;
 target_ptr = Libderiv->deriv2_classes[3][9][21];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+271385, dvrr_stack+123709, dvrr_stack+22836);
 tmp = dvrr_stack + 271385;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+271700, dvrr_stack+126698, dvrr_stack+92595);
 tmp = dvrr_stack + 271700;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+272120, dvrr_stack+130334, dvrr_stack+21522);
 tmp = dvrr_stack + 272120;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+272660, dvrr_stack+135026, dvrr_stack+26421);
 tmp = dvrr_stack + 272660;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+273335, dvrr_stack+140910, dvrr_stack+31066);
 tmp = dvrr_stack + 273335;
 target_ptr = Libderiv->deriv2_classes[4][9][21];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+274160, dvrr_stack+89594, dvrr_stack+147726);
 tmp = dvrr_stack + 274160;
 target_ptr = Libderiv->deriv2_classes[2][5][20];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+274286, dvrr_stack+89314, dvrr_stack+147789);
 tmp = dvrr_stack + 274286;
 target_ptr = Libderiv->deriv2_classes[2][6][20];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+274454, dvrr_stack+89804, dvrr_stack+147873);
 tmp = dvrr_stack + 274454;
 target_ptr = Libderiv->deriv2_classes[2][7][20];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+274670, dvrr_stack+90164, dvrr_stack+147981);
 tmp = dvrr_stack + 274670;
 target_ptr = Libderiv->deriv2_classes[2][8][20];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+274940, dvrr_stack+76512, dvrr_stack+148116);
 tmp = dvrr_stack + 274940;
 target_ptr = Libderiv->deriv2_classes[2][9][20];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+275270, dvrr_stack+78517, dvrr_stack+87960);
 tmp = dvrr_stack + 275270;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+275480, dvrr_stack+78097, dvrr_stack+87792);
 tmp = dvrr_stack + 275480;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+275760, dvrr_stack+68406, dvrr_stack+88086);
 tmp = dvrr_stack + 275760;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+276120, dvrr_stack+61151, dvrr_stack+21882);
 tmp = dvrr_stack + 276120;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+276570, dvrr_stack+55301, dvrr_stack+88302);
 tmp = dvrr_stack + 276570;
 target_ptr = Libderiv->deriv2_classes[3][9][20];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+277120, dvrr_stack+148824, dvrr_stack+89594);
 tmp = dvrr_stack + 277120;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+277435, dvrr_stack+149265, dvrr_stack+89314);
 tmp = dvrr_stack + 277435;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+277855, dvrr_stack+149853, dvrr_stack+89804);
 tmp = dvrr_stack + 277855;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+278395, dvrr_stack+142065, dvrr_stack+90164);
 tmp = dvrr_stack + 278395;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+279070, dvrr_stack+135971, dvrr_stack+76512);
 tmp = dvrr_stack + 279070;
 target_ptr = Libderiv->deriv2_classes[4][9][20];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+279895, dvrr_stack+82107, dvrr_stack+81462);
 tmp = dvrr_stack + 279895;
 target_ptr = Libderiv->deriv2_classes[2][5][19];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+280021, dvrr_stack+45847, dvrr_stack+81525);
 tmp = dvrr_stack + 280021;
 target_ptr = Libderiv->deriv2_classes[2][6][19];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+280189, dvrr_stack+31616, dvrr_stack+92385);
 tmp = dvrr_stack + 280189;
 target_ptr = Libderiv->deriv2_classes[2][7][19];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+280405, dvrr_stack+26871, dvrr_stack+148281);
 tmp = dvrr_stack + 280405;
 target_ptr = Libderiv->deriv2_classes[2][8][19];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+280675, dvrr_stack+23046, dvrr_stack+150609);
 tmp = dvrr_stack + 280675;
 target_ptr = Libderiv->deriv2_classes[2][9][19];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+281005, dvrr_stack+17153, dvrr_stack+78832);
 tmp = dvrr_stack + 281005;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+281215, dvrr_stack+11919, dvrr_stack+68946);
 tmp = dvrr_stack + 281215;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+281495, dvrr_stack+116274, dvrr_stack+69114);
 tmp = dvrr_stack + 281495;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+281855, dvrr_stack+116814, dvrr_stack+61826);
 tmp = dvrr_stack + 281855;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+282305, dvrr_stack+117489, dvrr_stack+53465);
 tmp = dvrr_stack + 282305;
 target_ptr = Libderiv->deriv2_classes[3][9][19];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+282855, dvrr_stack+143010, dvrr_stack+82107);
 tmp = dvrr_stack + 282855;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+283170, dvrr_stack+131090, dvrr_stack+45847);
 tmp = dvrr_stack + 283170;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+283590, dvrr_stack+153291, dvrr_stack+31616);
 tmp = dvrr_stack + 283590;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+284130, dvrr_stack+154047, dvrr_stack+26871);
 tmp = dvrr_stack + 284130;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+284805, dvrr_stack+154992, dvrr_stack+23046);
 tmp = dvrr_stack + 284805;
 target_ptr = Libderiv->deriv2_classes[4][9][19];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+285630, dvrr_stack+8115, dvrr_stack+81609);
 tmp = dvrr_stack + 285630;
 target_ptr = Libderiv->deriv2_classes[2][5][18];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+285756, dvrr_stack+16025, dvrr_stack+92493);
 tmp = dvrr_stack + 285756;
 target_ptr = Libderiv->deriv2_classes[2][6][18];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+285924, dvrr_stack+19046, dvrr_stack+150774);
 tmp = dvrr_stack + 285924;
 target_ptr = Libderiv->deriv2_classes[2][7][18];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+286140, dvrr_stack+9189, dvrr_stack+150882);
 tmp = dvrr_stack + 286140;
 target_ptr = Libderiv->deriv2_classes[2][8][18];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+286410, dvrr_stack+119304, dvrr_stack+151017);
 tmp = dvrr_stack + 286410;
 target_ptr = Libderiv->deriv2_classes[2][9][18];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+286740, dvrr_stack+43852, dvrr_stack+27321);
 tmp = dvrr_stack + 286740;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+286950, dvrr_stack+43432, dvrr_stack+32201);
 tmp = dvrr_stack + 286950;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+287230, dvrr_stack+120514, dvrr_stack+7899);
 tmp = dvrr_stack + 287230;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+287590, dvrr_stack+121054, dvrr_stack+4693);
 tmp = dvrr_stack + 287590;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+288040, dvrr_stack+121729, dvrr_stack+2117);
 tmp = dvrr_stack + 288040;
 target_ptr = Libderiv->deriv2_classes[3][9][18];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+288590, dvrr_stack+127286, dvrr_stack+8115);
 tmp = dvrr_stack + 288590;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+288905, dvrr_stack+145719, dvrr_stack+16025);
 tmp = dvrr_stack + 288905;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+289325, dvrr_stack+156147, dvrr_stack+19046);
 tmp = dvrr_stack + 289325;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+289865, dvrr_stack+156903, dvrr_stack+9189);
 tmp = dvrr_stack + 289865;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+290540, dvrr_stack+157848, dvrr_stack+119304);
 tmp = dvrr_stack + 290540;
 target_ptr = Libderiv->deriv2_classes[4][9][18];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+291365, dvrr_stack+148416, dvrr_stack+95345);
 tmp = dvrr_stack + 291365;
 target_ptr = Libderiv->deriv2_classes[2][5][14];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+291491, dvrr_stack+143451, dvrr_stack+148626);
 tmp = dvrr_stack + 291491;
 target_ptr = Libderiv->deriv2_classes[2][6][14];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+291659, dvrr_stack+131678, dvrr_stack+148710);
 tmp = dvrr_stack + 291659;
 target_ptr = Libderiv->deriv2_classes[2][7][14];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+291875, dvrr_stack+146307, dvrr_stack+137126);
 tmp = dvrr_stack + 291875;
 target_ptr = Libderiv->deriv2_classes[2][8][14];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+292145, dvrr_stack+146757, dvrr_stack+127727);
 tmp = dvrr_stack + 292145;
 target_ptr = Libderiv->deriv2_classes[2][9][14];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+292475, dvrr_stack+147307, dvrr_stack+127892);
 tmp = dvrr_stack + 292475;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+292685, dvrr_stack+36412, dvrr_stack+124150);
 tmp = dvrr_stack + 292685;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+292965, dvrr_stack+159003, dvrr_stack+86736);
 tmp = dvrr_stack + 292965;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+293325, dvrr_stack+159543, dvrr_stack+76239);
 tmp = dvrr_stack + 293325;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+293775, dvrr_stack+160218, dvrr_stack+30021);
 tmp = dvrr_stack + 293775;
 target_ptr = Libderiv->deriv2_classes[3][9][14];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+294325, dvrr_stack+10610, dvrr_stack+148416);
 tmp = dvrr_stack + 294325;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+294640, dvrr_stack+15263, dvrr_stack+143451);
 tmp = dvrr_stack + 294640;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+295060, dvrr_stack+162387, dvrr_stack+131678);
 tmp = dvrr_stack + 295060;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+295600, dvrr_stack+132686, dvrr_stack+146307);
 tmp = dvrr_stack + 295600;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+296275, dvrr_stack+165943, dvrr_stack+146757);
 tmp = dvrr_stack + 296275;
 target_ptr = Libderiv->deriv2_classes[4][9][14];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+297100, dvrr_stack+167161, dvrr_stack+167098);
 tmp = dvrr_stack + 297100;
 target_ptr = Libderiv->deriv2_classes[2][5][13];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+297226, dvrr_stack+168823, dvrr_stack+167371);
 tmp = dvrr_stack + 297226;
 target_ptr = Libderiv->deriv2_classes[2][6][13];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+297394, dvrr_stack+169103, dvrr_stack+167455);
 tmp = dvrr_stack + 297394;
 target_ptr = Libderiv->deriv2_classes[2][7][13];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+297610, dvrr_stack+133631, dvrr_stack+169463);
 tmp = dvrr_stack + 297610;
 target_ptr = Libderiv->deriv2_classes[2][8][13];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+297880, dvrr_stack+169598, dvrr_stack+30351);
 tmp = dvrr_stack + 297880;
 target_ptr = Libderiv->deriv2_classes[2][9][13];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+298210, dvrr_stack+170274, dvrr_stack+170148);
 tmp = dvrr_stack + 298210;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+298420, dvrr_stack+128462, dvrr_stack+170589);
 tmp = dvrr_stack + 298420;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+298700, dvrr_stack+138050, dvrr_stack+128882);
 tmp = dvrr_stack + 298700;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+299060, dvrr_stack+138590, dvrr_stack+129098);
 tmp = dvrr_stack + 299060;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+299510, dvrr_stack+65876, dvrr_stack+139265);
 tmp = dvrr_stack + 299510;
 target_ptr = Libderiv->deriv2_classes[3][9][13];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+300060, dvrr_stack+161043, dvrr_stack+167161);
 tmp = dvrr_stack + 300060;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+300375, dvrr_stack+124318, dvrr_stack+168823);
 tmp = dvrr_stack + 300375;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+300795, dvrr_stack+164179, dvrr_stack+169103);
 tmp = dvrr_stack + 300795;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+301335, dvrr_stack+172343, dvrr_stack+133631);
 tmp = dvrr_stack + 301335;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+302010, dvrr_stack+173288, dvrr_stack+169598);
 tmp = dvrr_stack + 302010;
 target_ptr = Libderiv->deriv2_classes[4][9][13];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,21,dvrr_stack+302835, dvrr_stack+93475, dvrr_stack+17468);
 tmp = dvrr_stack + 302835;
 target_ptr = Libderiv->deriv2_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,28,dvrr_stack+302961, dvrr_stack+93195, dvrr_stack+86985);
 tmp = dvrr_stack + 302961;
 target_ptr = Libderiv->deriv2_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,36,dvrr_stack+303129, dvrr_stack+5719, dvrr_stack+4963);
 tmp = dvrr_stack + 303129;
 target_ptr = Libderiv->deriv2_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,45,dvrr_stack+303345, dvrr_stack+93685, dvrr_stack+87393);
 tmp = dvrr_stack + 303345;
 target_ptr = Libderiv->deriv2_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,55,dvrr_stack+303615, dvrr_stack+94135, dvrr_stack+87528);
 tmp = dvrr_stack + 303615;
 target_ptr = Libderiv->deriv2_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+87372, dvrr_stack+82587, dvrr_stack+91377);
 tmp = dvrr_stack + 87372;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+82533, dvrr_stack+24516, dvrr_stack+91209);
 tmp = dvrr_stack + 82533;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+24421, dvrr_stack+71631, dvrr_stack+91503);
 tmp = dvrr_stack + 24421;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+71596, dvrr_stack+72171, dvrr_stack+91719);
 tmp = dvrr_stack + 71596;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,55,dvrr_stack+72046, dvrr_stack+63716, dvrr_stack+86214);
 tmp = dvrr_stack + 72046;
 target_ptr = Libderiv->deriv2_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+63596, dvrr_stack+128021, dvrr_stack+93475);
 tmp = dvrr_stack + 63596;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+63911, dvrr_stack+132098, dvrr_stack+93195);
 tmp = dvrr_stack + 63911;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+132038, dvrr_stack+137294, dvrr_stack+5719);
 tmp = dvrr_stack + 132038;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+137261, dvrr_stack+143745, dvrr_stack+93685);
 tmp = dvrr_stack + 137261;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,55,dvrr_stack+93169, dvrr_stack+74466, dvrr_stack+94135);
 tmp = dvrr_stack + 93169;
 target_ptr = Libderiv->deriv2_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+64331, dvrr_stack+40210, dvrr_stack+75621);
 tmp = dvrr_stack + 64331;
 target_ptr = Libderiv->deriv2_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+5671, dvrr_stack+49147, dvrr_stack+75684);
 tmp = dvrr_stack + 5671;
 target_ptr = Libderiv->deriv2_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+5839, dvrr_stack+40420, dvrr_stack+75768);
 tmp = dvrr_stack + 5839;
 target_ptr = Libderiv->deriv2_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+74346, dvrr_stack+40780, dvrr_stack+75876);
 tmp = dvrr_stack + 74346;
 target_ptr = Libderiv->deriv2_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+74616, dvrr_stack+33766, dvrr_stack+76011);
 tmp = dvrr_stack + 74616;
 target_ptr = Libderiv->deriv2_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+87582, dvrr_stack+18191, dvrr_stack+82902);
 tmp = dvrr_stack + 87582;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+18176, dvrr_stack+28581, dvrr_stack+57506);
 tmp = dvrr_stack + 18176;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+74946, dvrr_stack+18506, dvrr_stack+57674);
 tmp = dvrr_stack + 74946;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+18456, dvrr_stack+113784, dvrr_stack+48151);
 tmp = dvrr_stack + 18456;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+75306, dvrr_stack+114459, dvrr_stack+48421);
 tmp = dvrr_stack + 75306;
 target_ptr = Libderiv->deriv2_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+75856, dvrr_stack+144690, dvrr_stack+40210);
 tmp = dvrr_stack + 75856;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+93994, dvrr_stack+145131, dvrr_stack+49147);
 tmp = dvrr_stack + 93994;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+113675, dvrr_stack+35656, dvrr_stack+40420);
 tmp = dvrr_stack + 113675;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+114215, dvrr_stack+151191, dvrr_stack+40780);
 tmp = dvrr_stack + 114215;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+40129, dvrr_stack+152136, dvrr_stack+33766);
 tmp = dvrr_stack + 40129;
 target_ptr = Libderiv->deriv2_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+18906, dvrr_stack+22836, dvrr_stack+76176);
 tmp = dvrr_stack + 18906;
 target_ptr = Libderiv->deriv2_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+49129, dvrr_stack+92595, dvrr_stack+86544);
 tmp = dvrr_stack + 49129;
 target_ptr = Libderiv->deriv2_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+40954, dvrr_stack+21522, dvrr_stack+86628);
 tmp = dvrr_stack + 40954;
 target_ptr = Libderiv->deriv2_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+94414, dvrr_stack+26421, dvrr_stack+87069);
 tmp = dvrr_stack + 94414;
 target_ptr = Libderiv->deriv2_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+128018, dvrr_stack+31066, dvrr_stack+123544);
 tmp = dvrr_stack + 128018;
 target_ptr = Libderiv->deriv2_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+82813, dvrr_stack+54986, dvrr_stack+1991);
 tmp = dvrr_stack + 82813;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+114890, dvrr_stack+81687, dvrr_stack+90849);
 tmp = dvrr_stack + 114890;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+81672, dvrr_stack+52925, dvrr_stack+990);
 tmp = dvrr_stack + 81672;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+52861, dvrr_stack+60476, dvrr_stack+4423);
 tmp = dvrr_stack + 52861;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+60476, dvrr_stack+67581, dvrr_stack+7569);
 tmp = dvrr_stack + 60476;
 target_ptr = Libderiv->deriv2_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+7491, dvrr_stack+123709, dvrr_stack+22836);
 tmp = dvrr_stack + 7491;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+123544, dvrr_stack+126698, dvrr_stack+92595);
 tmp = dvrr_stack + 123544;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+67466, dvrr_stack+130334, dvrr_stack+21522);
 tmp = dvrr_stack + 67466;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+130253, dvrr_stack+135026, dvrr_stack+26421);
 tmp = dvrr_stack + 130253;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+134999, dvrr_stack+140910, dvrr_stack+31066);
 tmp = dvrr_stack + 134999;
 target_ptr = Libderiv->deriv2_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+4423, dvrr_stack+89594, dvrr_stack+147726);
 tmp = dvrr_stack + 4423;
 target_ptr = Libderiv->deriv2_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+123964, dvrr_stack+89314, dvrr_stack+147789);
 tmp = dvrr_stack + 123964;
 target_ptr = Libderiv->deriv2_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+30957, dvrr_stack+89804, dvrr_stack+147873);
 tmp = dvrr_stack + 30957;
 target_ptr = Libderiv->deriv2_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+31173, dvrr_stack+90164, dvrr_stack+147981);
 tmp = dvrr_stack + 31173;
 target_ptr = Libderiv->deriv2_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+140837, dvrr_stack+76512, dvrr_stack+148116);
 tmp = dvrr_stack + 140837;
 target_ptr = Libderiv->deriv2_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+930, dvrr_stack+78517, dvrr_stack+87960);
 tmp = dvrr_stack + 930;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+78517, dvrr_stack+78097, dvrr_stack+87792);
 tmp = dvrr_stack + 78517;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+141167, dvrr_stack+68406, dvrr_stack+88086);
 tmp = dvrr_stack + 141167;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+87792, dvrr_stack+61151, dvrr_stack+21882);
 tmp = dvrr_stack + 87792;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+61026, dvrr_stack+55301, dvrr_stack+88302);
 tmp = dvrr_stack + 61026;
 target_ptr = Libderiv->deriv2_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+88242, dvrr_stack+148824, dvrr_stack+89594);
 tmp = dvrr_stack + 88242;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+141527, dvrr_stack+149265, dvrr_stack+89314);
 tmp = dvrr_stack + 141527;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+68006, dvrr_stack+149853, dvrr_stack+89804);
 tmp = dvrr_stack + 68006;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+89280, dvrr_stack+142065, dvrr_stack+90164);
 tmp = dvrr_stack + 89280;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+141947, dvrr_stack+135971, dvrr_stack+76512);
 tmp = dvrr_stack + 141947;
 target_ptr = Libderiv->deriv2_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+4549, dvrr_stack+82107, dvrr_stack+81462);
 tmp = dvrr_stack + 4549;
 target_ptr = Libderiv->deriv2_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+61576, dvrr_stack+45847, dvrr_stack+81525);
 tmp = dvrr_stack + 61576;
 target_ptr = Libderiv->deriv2_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+135824, dvrr_stack+31616, dvrr_stack+92385);
 tmp = dvrr_stack + 135824;
 target_ptr = Libderiv->deriv2_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+136040, dvrr_stack+26871, dvrr_stack+148281);
 tmp = dvrr_stack + 136040;
 target_ptr = Libderiv->deriv2_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+136310, dvrr_stack+23046, dvrr_stack+150609);
 tmp = dvrr_stack + 136310;
 target_ptr = Libderiv->deriv2_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+136640, dvrr_stack+17153, dvrr_stack+78832);
 tmp = dvrr_stack + 136640;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+68546, dvrr_stack+11919, dvrr_stack+68946);
 tmp = dvrr_stack + 68546;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+11803, dvrr_stack+116274, dvrr_stack+69114);
 tmp = dvrr_stack + 11803;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+116274, dvrr_stack+116814, dvrr_stack+61826);
 tmp = dvrr_stack + 116274;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+116724, dvrr_stack+117489, dvrr_stack+53465);
 tmp = dvrr_stack + 116724;
 target_ptr = Libderiv->deriv2_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+117274, dvrr_stack+143010, dvrr_stack+82107);
 tmp = dvrr_stack + 117274;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+117589, dvrr_stack+131090, dvrr_stack+45847);
 tmp = dvrr_stack + 117589;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+130928, dvrr_stack+153291, dvrr_stack+31616);
 tmp = dvrr_stack + 130928;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+142772, dvrr_stack+154047, dvrr_stack+26871);
 tmp = dvrr_stack + 142772;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+26346, dvrr_stack+154992, dvrr_stack+23046);
 tmp = dvrr_stack + 26346;
 target_ptr = Libderiv->deriv2_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+92367, dvrr_stack+8115, dvrr_stack+81609);
 tmp = dvrr_stack + 92367;
 target_ptr = Libderiv->deriv2_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+118009, dvrr_stack+16025, dvrr_stack+92493);
 tmp = dvrr_stack + 118009;
 target_ptr = Libderiv->deriv2_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+92493, dvrr_stack+19046, dvrr_stack+150774);
 tmp = dvrr_stack + 92493;
 target_ptr = Libderiv->deriv2_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+61744, dvrr_stack+9189, dvrr_stack+150882);
 tmp = dvrr_stack + 61744;
 target_ptr = Libderiv->deriv2_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+31443, dvrr_stack+119304, dvrr_stack+151017);
 tmp = dvrr_stack + 31443;
 target_ptr = Libderiv->deriv2_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+131468, dvrr_stack+43852, dvrr_stack+27321);
 tmp = dvrr_stack + 131468;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+43852, dvrr_stack+43432, dvrr_stack+32201);
 tmp = dvrr_stack + 43852;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+68826, dvrr_stack+120514, dvrr_stack+7899);
 tmp = dvrr_stack + 68826;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+120499, dvrr_stack+121054, dvrr_stack+4693);
 tmp = dvrr_stack + 120499;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+120949, dvrr_stack+121729, dvrr_stack+2117);
 tmp = dvrr_stack + 120949;
 target_ptr = Libderiv->deriv2_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+4675, dvrr_stack+127286, dvrr_stack+8115);
 tmp = dvrr_stack + 4675;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+121499, dvrr_stack+145719, dvrr_stack+16025);
 tmp = dvrr_stack + 121499;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+121919, dvrr_stack+156147, dvrr_stack+19046);
 tmp = dvrr_stack + 121919;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+22827, dvrr_stack+156903, dvrr_stack+9189);
 tmp = dvrr_stack + 22827;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+126626, dvrr_stack+157848, dvrr_stack+119304);
 tmp = dvrr_stack + 126626;
 target_ptr = Libderiv->deriv2_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+119304, dvrr_stack+148416, dvrr_stack+95345);
 tmp = dvrr_stack + 119304;
 target_ptr = Libderiv->deriv2_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+119430, dvrr_stack+143451, dvrr_stack+148626);
 tmp = dvrr_stack + 119430;
 target_ptr = Libderiv->deriv2_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+119598, dvrr_stack+131678, dvrr_stack+148710);
 tmp = dvrr_stack + 119598;
 target_ptr = Libderiv->deriv2_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+148626, dvrr_stack+146307, dvrr_stack+137126);
 tmp = dvrr_stack + 148626;
 target_ptr = Libderiv->deriv2_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+148896, dvrr_stack+146757, dvrr_stack+127727);
 tmp = dvrr_stack + 148896;
 target_ptr = Libderiv->deriv2_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+149226, dvrr_stack+147307, dvrr_stack+127892);
 tmp = dvrr_stack + 149226;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+147307, dvrr_stack+36412, dvrr_stack+124150);
 tmp = dvrr_stack + 147307;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+147587, dvrr_stack+159003, dvrr_stack+86736);
 tmp = dvrr_stack + 147587;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+147947, dvrr_stack+159543, dvrr_stack+76239);
 tmp = dvrr_stack + 147947;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+149436, dvrr_stack+160218, dvrr_stack+30021);
 tmp = dvrr_stack + 149436;
 target_ptr = Libderiv->deriv2_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+149986, dvrr_stack+10610, dvrr_stack+148416);
 tmp = dvrr_stack + 149986;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+150301, dvrr_stack+15263, dvrr_stack+143451);
 tmp = dvrr_stack + 150301;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+150721, dvrr_stack+162387, dvrr_stack+131678);
 tmp = dvrr_stack + 150721;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+151261, dvrr_stack+132686, dvrr_stack+146307);
 tmp = dvrr_stack + 151261;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+151936, dvrr_stack+165943, dvrr_stack+146757);
 tmp = dvrr_stack + 151936;
 target_ptr = Libderiv->deriv2_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+131678, dvrr_stack+167161, dvrr_stack+167098);
 tmp = dvrr_stack + 131678;
 target_ptr = Libderiv->deriv2_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+131804, dvrr_stack+168823, dvrr_stack+167371);
 tmp = dvrr_stack + 131804;
 target_ptr = Libderiv->deriv2_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+148397, dvrr_stack+169103, dvrr_stack+167455);
 tmp = dvrr_stack + 148397;
 target_ptr = Libderiv->deriv2_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+152761, dvrr_stack+133631, dvrr_stack+169463);
 tmp = dvrr_stack + 152761;
 target_ptr = Libderiv->deriv2_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+153031, dvrr_stack+169598, dvrr_stack+30351);
 tmp = dvrr_stack + 153031;
 target_ptr = Libderiv->deriv2_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+153361, dvrr_stack+170274, dvrr_stack+170148);
 tmp = dvrr_stack + 153361;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+170148, dvrr_stack+128462, dvrr_stack+170589);
 tmp = dvrr_stack + 170148;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+153571, dvrr_stack+138050, dvrr_stack+128882);
 tmp = dvrr_stack + 153571;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+153931, dvrr_stack+138590, dvrr_stack+129098);
 tmp = dvrr_stack + 153931;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+154381, dvrr_stack+65876, dvrr_stack+139265);
 tmp = dvrr_stack + 154381;
 target_ptr = Libderiv->deriv2_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+170428, dvrr_stack+161043, dvrr_stack+167161);
 tmp = dvrr_stack + 170428;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+154931, dvrr_stack+124318, dvrr_stack+168823);
 tmp = dvrr_stack + 154931;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+155351, dvrr_stack+164179, dvrr_stack+169103);
 tmp = dvrr_stack + 155351;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+155891, dvrr_stack+172343, dvrr_stack+133631);
 tmp = dvrr_stack + 155891;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+156566, dvrr_stack+173288, dvrr_stack+169598);
 tmp = dvrr_stack + 156566;
 target_ptr = Libderiv->deriv2_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+157391, dvrr_stack+129368, dvrr_stack+124906);
 tmp = dvrr_stack + 157391;
 target_ptr = Libderiv->deriv2_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+157517, dvrr_stack+161484, dvrr_stack+392);
 tmp = dvrr_stack + 157517;
 target_ptr = Libderiv->deriv2_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+157685, dvrr_stack+25566, dvrr_stack+822);
 tmp = dvrr_stack + 157685;
 target_ptr = Libderiv->deriv2_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+157901, dvrr_stack+59081, dvrr_stack+1775);
 tmp = dvrr_stack + 157901;
 target_ptr = Libderiv->deriv2_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+158171, dvrr_stack+125410, dvrr_stack+164);
 tmp = dvrr_stack + 158171;
 target_ptr = Libderiv->deriv2_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+158501, dvrr_stack+6583, dvrr_stack+7239);
 tmp = dvrr_stack + 158501;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+158711, dvrr_stack+51166, dvrr_stack+124969);
 tmp = dvrr_stack + 158711;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+158991, dvrr_stack+125960, dvrr_stack+125137);
 tmp = dvrr_stack + 158991;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+125960, dvrr_stack+129578, dvrr_stack+4153);
 tmp = dvrr_stack + 125960;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+129578, dvrr_stack+20501, dvrr_stack+134081);
 tmp = dvrr_stack + 129578;
 target_ptr = Libderiv->deriv2_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+159351, dvrr_stack+30516, dvrr_stack+129368);
 tmp = dvrr_stack + 159351;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+159666, dvrr_stack+134411, dvrr_stack+161484);
 tmp = dvrr_stack + 159666;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+160086, dvrr_stack+139595, dvrr_stack+25566);
 tmp = dvrr_stack + 160086;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+160626, dvrr_stack+164935, dvrr_stack+59081);
 tmp = dvrr_stack + 160626;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+124132, dvrr_stack+167563, dvrr_stack+125410);
 tmp = dvrr_stack + 124132;
 target_ptr = Libderiv->deriv2_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];


}

