/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (f0|hg) integrals */

void d12vrr_order_f0hg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+15, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+50, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+53, dvrr_stack+6, dvrr_stack+50, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+59, dvrr_stack+9, dvrr_stack+53, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+69, dvrr_stack+21, dvrr_stack+59, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+99, dvrr_stack+84, dvrr_stack+69, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+120, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+123, dvrr_stack+120, dvrr_stack+31, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+129, dvrr_stack+123, dvrr_stack+34, dvrr_stack+120, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+139, dvrr_stack+129, dvrr_stack+40, dvrr_stack+123, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+154, dvrr_stack+139, dvrr_stack+84, dvrr_stack+129, dvrr_stack+40, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+175, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+178, dvrr_stack+50, dvrr_stack+175, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+184, dvrr_stack+53, dvrr_stack+178, dvrr_stack+6, dvrr_stack+50, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+194, dvrr_stack+59, dvrr_stack+184, dvrr_stack+9, dvrr_stack+53, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+209, dvrr_stack+69, dvrr_stack+194, dvrr_stack+21, dvrr_stack+59, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+230, dvrr_stack+99, dvrr_stack+209, dvrr_stack+84, dvrr_stack+69, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+258, dvrr_stack+154, dvrr_stack+99, dvrr_stack+139, dvrr_stack+84, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+286, dvrr_stack+258, dvrr_stack+230, dvrr_stack+154, dvrr_stack+99, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+322, dvrr_stack+175, dvrr_stack+6, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+328, dvrr_stack+178, dvrr_stack+322, dvrr_stack+50, dvrr_stack+175, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+338, dvrr_stack+184, dvrr_stack+328, dvrr_stack+53, dvrr_stack+178, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+353, dvrr_stack+194, dvrr_stack+338, dvrr_stack+59, dvrr_stack+184, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+374, dvrr_stack+209, dvrr_stack+353, dvrr_stack+69, dvrr_stack+194, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+402, dvrr_stack+230, dvrr_stack+374, dvrr_stack+99, dvrr_stack+209, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+438, dvrr_stack+286, dvrr_stack+402, dvrr_stack+258, dvrr_stack+230, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+50, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+53, dvrr_stack+50, dvrr_stack+120, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+483, dvrr_stack+53, dvrr_stack+123, dvrr_stack+50, dvrr_stack+120, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+493, dvrr_stack+483, dvrr_stack+129, dvrr_stack+53, dvrr_stack+123, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+508, dvrr_stack+493, dvrr_stack+139, dvrr_stack+483, dvrr_stack+129, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+529, dvrr_stack+508, dvrr_stack+154, dvrr_stack+493, dvrr_stack+139, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+557, dvrr_stack+529, dvrr_stack+258, dvrr_stack+508, dvrr_stack+154, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+593, dvrr_stack+557, dvrr_stack+286, dvrr_stack+529, dvrr_stack+258, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+638, dvrr_stack+593, dvrr_stack+438, NULL, NULL, dvrr_stack+286);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+773, dvrr_stack+593, dvrr_stack+438, dvrr_stack+557, dvrr_stack+286, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+828, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+831, dvrr_stack+828, dvrr_stack+50, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+837, dvrr_stack+831, dvrr_stack+53, dvrr_stack+828, dvrr_stack+50, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+847, dvrr_stack+837, dvrr_stack+483, dvrr_stack+831, dvrr_stack+53, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+862, dvrr_stack+847, dvrr_stack+493, dvrr_stack+837, dvrr_stack+483, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+883, dvrr_stack+862, dvrr_stack+508, dvrr_stack+847, dvrr_stack+493, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+911, dvrr_stack+883, dvrr_stack+529, dvrr_stack+862, dvrr_stack+508, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+947, dvrr_stack+911, dvrr_stack+557, dvrr_stack+883, dvrr_stack+529, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+992, dvrr_stack+947, dvrr_stack+593, dvrr_stack+911, dvrr_stack+557, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+50, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+828, dvrr_stack+6, dvrr_stack+50, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1047, dvrr_stack+322, dvrr_stack+828, dvrr_stack+175, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1057, dvrr_stack+328, dvrr_stack+1047, dvrr_stack+178, dvrr_stack+322, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1072, dvrr_stack+338, dvrr_stack+1057, dvrr_stack+184, dvrr_stack+328, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1093, dvrr_stack+353, dvrr_stack+1072, dvrr_stack+194, dvrr_stack+338, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1121, dvrr_stack+374, dvrr_stack+1093, dvrr_stack+209, dvrr_stack+353, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1157, dvrr_stack+402, dvrr_stack+1121, dvrr_stack+230, dvrr_stack+374, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1202, dvrr_stack+438, dvrr_stack+1157, dvrr_stack+286, dvrr_stack+402, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1257, dvrr_stack+773, dvrr_stack+1202, NULL, NULL, dvrr_stack+438);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1422, dvrr_stack+992, dvrr_stack+773, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1587, dvrr_stack+1422, dvrr_stack+1257, dvrr_stack+992, dvrr_stack+773, dvrr_stack+638);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1917, dvrr_stack+230, dvrr_stack+374, NULL, NULL, dvrr_stack+209);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2001, dvrr_stack+402, dvrr_stack+1121, NULL, NULL, dvrr_stack+374);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2109, dvrr_stack+286, dvrr_stack+402, NULL, NULL, dvrr_stack+230);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2217, dvrr_stack+2109, dvrr_stack+2001, dvrr_stack+286, dvrr_stack+402, dvrr_stack+1917);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2433, dvrr_stack+438, dvrr_stack+1157, NULL, NULL, dvrr_stack+402);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+834, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+175, dvrr_stack+50, dvrr_stack+834, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+181, dvrr_stack+828, dvrr_stack+175, dvrr_stack+6, dvrr_stack+50, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2568, dvrr_stack+1047, dvrr_stack+181, dvrr_stack+322, dvrr_stack+828, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2583, dvrr_stack+1057, dvrr_stack+2568, dvrr_stack+328, dvrr_stack+1047, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2604, dvrr_stack+1072, dvrr_stack+2583, dvrr_stack+338, dvrr_stack+1057, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2632, dvrr_stack+1093, dvrr_stack+2604, dvrr_stack+353, dvrr_stack+1072, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2668, dvrr_stack+1121, dvrr_stack+2632, dvrr_stack+374, dvrr_stack+1093, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2713, dvrr_stack+1157, dvrr_stack+2668, NULL, NULL, dvrr_stack+1121);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2848, dvrr_stack+2433, dvrr_stack+2713, dvrr_stack+438, dvrr_stack+1157, dvrr_stack+2001);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3118, dvrr_stack+638, dvrr_stack+2433, dvrr_stack+593, dvrr_stack+438, dvrr_stack+2109);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3388, dvrr_stack+3118, dvrr_stack+2848, dvrr_stack+638, dvrr_stack+2433, dvrr_stack+2217);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3838, dvrr_stack+1157, dvrr_stack+2668, dvrr_stack+402, dvrr_stack+1121, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3893, dvrr_stack+1202, dvrr_stack+3838, NULL, NULL, dvrr_stack+1157);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4058, dvrr_stack+1257, dvrr_stack+3893, dvrr_stack+773, dvrr_stack+1202, dvrr_stack+2433);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+322, dvrr_stack+834, dvrr_stack+6, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+328, dvrr_stack+175, dvrr_stack+322, dvrr_stack+50, dvrr_stack+834, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+338, dvrr_stack+181, dvrr_stack+328, dvrr_stack+828, dvrr_stack+175, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+4388, dvrr_stack+2568, dvrr_stack+338, dvrr_stack+1047, dvrr_stack+181, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4409, dvrr_stack+2583, dvrr_stack+4388, dvrr_stack+1057, dvrr_stack+2568, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4437, dvrr_stack+2604, dvrr_stack+4409, dvrr_stack+1072, dvrr_stack+2583, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1047, dvrr_stack+2632, dvrr_stack+4437, dvrr_stack+1093, dvrr_stack+2604, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4473, dvrr_stack+2668, dvrr_stack+1047, dvrr_stack+1121, dvrr_stack+2632, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4528, dvrr_stack+3838, dvrr_stack+4473, NULL, NULL, dvrr_stack+2668);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4693, dvrr_stack+3893, dvrr_stack+4528, dvrr_stack+1202, dvrr_stack+3838, dvrr_stack+2713);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5023, dvrr_stack+4058, dvrr_stack+4693, dvrr_stack+1257, dvrr_stack+3893, dvrr_stack+2848);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5573, dvrr_stack+1587, dvrr_stack+4058, dvrr_stack+1422, dvrr_stack+1257, dvrr_stack+3118);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6123, dvrr_stack+5573, dvrr_stack+5023, dvrr_stack+1587, dvrr_stack+4058, dvrr_stack+3388);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+6948, dvrr_stack+129, dvrr_stack+40, NULL, NULL, dvrr_stack+34);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+6978, dvrr_stack+139, dvrr_stack+84, NULL, NULL, dvrr_stack+40);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+7023, dvrr_stack+493, dvrr_stack+139, NULL, NULL, dvrr_stack+129);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+7068, dvrr_stack+7023, dvrr_stack+6978, dvrr_stack+493, dvrr_stack+139, dvrr_stack+6948);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+7158, dvrr_stack+508, dvrr_stack+154, NULL, NULL, dvrr_stack+139);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+7221, dvrr_stack+862, dvrr_stack+508, NULL, NULL, dvrr_stack+493);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+7284, dvrr_stack+154, dvrr_stack+99, NULL, NULL, dvrr_stack+84);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+7347, dvrr_stack+7158, dvrr_stack+7284, dvrr_stack+508, dvrr_stack+154, dvrr_stack+6978);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+7473, dvrr_stack+7221, dvrr_stack+7158, dvrr_stack+862, dvrr_stack+508, dvrr_stack+7023);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+7599, dvrr_stack+7473, dvrr_stack+7347, dvrr_stack+7221, dvrr_stack+7158, dvrr_stack+7068);
 tmp = dvrr_stack + 7599;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+7809, dvrr_stack+529, dvrr_stack+258, NULL, NULL, dvrr_stack+154);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+7893, dvrr_stack+883, dvrr_stack+529, NULL, NULL, dvrr_stack+508);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+7977, dvrr_stack+258, dvrr_stack+230, NULL, NULL, dvrr_stack+99);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+8061, dvrr_stack+7809, dvrr_stack+7977, dvrr_stack+529, dvrr_stack+258, dvrr_stack+7284);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+8229, dvrr_stack+7893, dvrr_stack+7809, dvrr_stack+883, dvrr_stack+529, dvrr_stack+7158);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+8397, dvrr_stack+8229, dvrr_stack+8061, dvrr_stack+7893, dvrr_stack+7809, dvrr_stack+7347);
 tmp = dvrr_stack + 8397;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+8677,dvrr_stack+8397,dvrr_stack+7599,10);


 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9307, dvrr_stack+557, dvrr_stack+286, NULL, NULL, dvrr_stack+258);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9415, dvrr_stack+911, dvrr_stack+557, NULL, NULL, dvrr_stack+529);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9523, dvrr_stack+9307, dvrr_stack+2109, dvrr_stack+557, dvrr_stack+286, dvrr_stack+7977);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9739, dvrr_stack+9415, dvrr_stack+9307, dvrr_stack+911, dvrr_stack+557, dvrr_stack+7809);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9955, dvrr_stack+9739, dvrr_stack+9523, dvrr_stack+9415, dvrr_stack+9307, dvrr_stack+8061);
 tmp = dvrr_stack + 9955;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+10315,dvrr_stack+9955,dvrr_stack+8397,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+11155,dvrr_stack+10315,dvrr_stack+8677,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+12415, dvrr_stack+11155, dvrr_stack+7599);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13045, dvrr_stack+947, dvrr_stack+593, NULL, NULL, dvrr_stack+557);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13180, dvrr_stack+13045, dvrr_stack+638, dvrr_stack+947, dvrr_stack+593, dvrr_stack+9307);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13450, dvrr_stack+13180, dvrr_stack+3118, dvrr_stack+13045, dvrr_stack+638, dvrr_stack+9523);
 tmp = dvrr_stack + 13450;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+13900,dvrr_stack+13450,dvrr_stack+9955,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+14980,dvrr_stack+13900,dvrr_stack+10315,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+16660, dvrr_stack+14980, dvrr_stack+8397);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+17500,dvrr_stack+5573,dvrr_stack+13450,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+18850,dvrr_stack+17500,dvrr_stack+13900,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+21010, dvrr_stack+18850, dvrr_stack+9955);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+638, dvrr_stack+1202, dvrr_stack+3838, dvrr_stack+438, dvrr_stack+1157, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+704, dvrr_stack+773, dvrr_stack+1202, dvrr_stack+593, dvrr_stack+438, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22090, dvrr_stack+704, dvrr_stack+638, NULL, NULL, dvrr_stack+1202);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+508, dvrr_stack+992, dvrr_stack+773, dvrr_stack+947, dvrr_stack+593, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22288, dvrr_stack+508, dvrr_stack+704, NULL, NULL, dvrr_stack+773);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+862, dvrr_stack+3838, dvrr_stack+4473, dvrr_stack+1157, dvrr_stack+2668, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22486, dvrr_stack+638, dvrr_stack+862, NULL, NULL, dvrr_stack+3838);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22684, dvrr_stack+22090, dvrr_stack+22486, dvrr_stack+704, dvrr_stack+638, dvrr_stack+3893);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+23080, dvrr_stack+22288, dvrr_stack+22090, dvrr_stack+508, dvrr_stack+704, dvrr_stack+1257);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+23476, dvrr_stack+23080, dvrr_stack+22684, dvrr_stack+22288, dvrr_stack+22090, dvrr_stack+4058);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+24136,dvrr_stack+23476,dvrr_stack+5573,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+25786,dvrr_stack+24136,dvrr_stack+17500,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+28486, dvrr_stack+25786, dvrr_stack+13450);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22288, dvrr_stack+638, dvrr_stack+862, dvrr_stack+1202, dvrr_stack+3838, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22366, dvrr_stack+704, dvrr_stack+638, dvrr_stack+773, dvrr_stack+1202, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29836, dvrr_stack+22366, dvrr_stack+22288, NULL, NULL, dvrr_stack+638);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1202, dvrr_stack+508, dvrr_stack+704, dvrr_stack+992, dvrr_stack+773, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30070, dvrr_stack+1202, dvrr_stack+22366, NULL, NULL, dvrr_stack+704);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+50, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+704, dvrr_stack+6, dvrr_stack+50, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+710, dvrr_stack+322, dvrr_stack+704, dvrr_stack+834, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+720, dvrr_stack+328, dvrr_stack+710, dvrr_stack+175, dvrr_stack+322, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+735, dvrr_stack+338, dvrr_stack+720, dvrr_stack+181, dvrr_stack+328, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+704, dvrr_stack+4388, dvrr_stack+735, dvrr_stack+2568, dvrr_stack+338, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+732, dvrr_stack+4409, dvrr_stack+704, dvrr_stack+2583, dvrr_stack+4388, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+438, dvrr_stack+4437, dvrr_stack+732, dvrr_stack+2604, dvrr_stack+4409, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+704, dvrr_stack+1047, dvrr_stack+438, dvrr_stack+2632, dvrr_stack+4437, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+4388, dvrr_stack+4473, dvrr_stack+704, dvrr_stack+2668, dvrr_stack+1047, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+759, dvrr_stack+862, dvrr_stack+4388, dvrr_stack+3838, dvrr_stack+4473, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30304, dvrr_stack+22288, dvrr_stack+759, NULL, NULL, dvrr_stack+862);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30538, dvrr_stack+29836, dvrr_stack+30304, dvrr_stack+22366, dvrr_stack+22288, dvrr_stack+22486);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31006, dvrr_stack+30070, dvrr_stack+29836, dvrr_stack+1202, dvrr_stack+22366, dvrr_stack+22090);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31474, dvrr_stack+31006, dvrr_stack+30538, dvrr_stack+30070, dvrr_stack+29836, dvrr_stack+22684);

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+32254,dvrr_stack+31474,dvrr_stack+23476,10);


 /* compute (3 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+34234,dvrr_stack+32254,dvrr_stack+24136,10);


 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,550,dvrr_stack+37534, dvrr_stack+34234, dvrr_stack+5573);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+29836, dvrr_stack+11155, dvrr_stack+7599);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+30466, dvrr_stack+14980, dvrr_stack+8397);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+39184, dvrr_stack+18850, dvrr_stack+9955);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+40264, dvrr_stack+25786, dvrr_stack+13450);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,550,dvrr_stack+41614, dvrr_stack+34234, dvrr_stack+5573);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+43264, dvrr_stack+11155, dvrr_stack+7599);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+11155, dvrr_stack+14980, dvrr_stack+8397);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+14980, dvrr_stack+18850, dvrr_stack+9955);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+18850, dvrr_stack+25786, dvrr_stack+13450);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,550,dvrr_stack+25786, dvrr_stack+34234, dvrr_stack+5573);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+34234, dvrr_stack+123, dvrr_stack+34, NULL, NULL, dvrr_stack+31);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+34252, dvrr_stack+483, dvrr_stack+129, NULL, NULL, dvrr_stack+123);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+34282, dvrr_stack+34252, dvrr_stack+6948, dvrr_stack+483, dvrr_stack+129, dvrr_stack+34234);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+438, dvrr_stack+847, dvrr_stack+493, NULL, NULL, dvrr_stack+483);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+34342, dvrr_stack+438, dvrr_stack+7023, dvrr_stack+847, dvrr_stack+493, dvrr_stack+34252);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+34432, dvrr_stack+34342, dvrr_stack+7068, dvrr_stack+438, dvrr_stack+7023, dvrr_stack+34282);

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+34582,dvrr_stack+7599,dvrr_stack+34432,10);


 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+35032, dvrr_stack+34582, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+35182, dvrr_stack+10315, NULL);
 tmp = dvrr_stack + 35182;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+35462, dvrr_stack+8677, NULL);
 tmp = dvrr_stack + 35462;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+35672, dvrr_stack+13900, NULL);
 tmp = dvrr_stack + 35672;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+36032, dvrr_stack+17500, NULL);
 tmp = dvrr_stack + 36032;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+36482, dvrr_stack+24136, NULL);
 tmp = dvrr_stack + 36482;
 target_ptr = Libderiv->deriv_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+27436, dvrr_stack+32254, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+37032, dvrr_stack+34582, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+37182, dvrr_stack+10315, NULL);
 tmp = dvrr_stack + 37182;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+28096, dvrr_stack+8677, NULL);
 tmp = dvrr_stack + 28096;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+20200, dvrr_stack+13900, NULL);
 tmp = dvrr_stack + 20200;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+20560, dvrr_stack+17500, NULL);
 tmp = dvrr_stack + 20560;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+16060, dvrr_stack+24136, NULL);
 tmp = dvrr_stack + 16060;
 target_ptr = Libderiv->deriv_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+43894, dvrr_stack+32254, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+28306, dvrr_stack+34582, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+34582, dvrr_stack+10315, NULL);
 tmp = dvrr_stack + 34582;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+10315, dvrr_stack+8677, NULL);
 tmp = dvrr_stack + 10315;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+8677, dvrr_stack+13900, NULL);
 tmp = dvrr_stack + 8677;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+13900, dvrr_stack+17500, NULL);
 tmp = dvrr_stack + 13900;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+17500, dvrr_stack+24136, NULL);
 tmp = dvrr_stack + 17500;
 target_ptr = Libderiv->deriv_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+24136, dvrr_stack+32254, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+32254, dvrr_stack+120, dvrr_stack+31, NULL, NULL, Data->F+3);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+32263, dvrr_stack+53, dvrr_stack+123, NULL, NULL, dvrr_stack+120);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+32281, dvrr_stack+32263, dvrr_stack+34234, dvrr_stack+53, dvrr_stack+123, dvrr_stack+32254);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+28456, dvrr_stack+837, dvrr_stack+483, NULL, NULL, dvrr_stack+53);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+32317, dvrr_stack+28456, dvrr_stack+34252, dvrr_stack+837, dvrr_stack+483, dvrr_stack+32263);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+32377, dvrr_stack+32317, dvrr_stack+34282, dvrr_stack+28456, dvrr_stack+34252, dvrr_stack+32281);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+32477, dvrr_stack+7599, dvrr_stack+32377);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+32627, dvrr_stack+9955, dvrr_stack+7599);
 tmp = dvrr_stack + 32627;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+32907, dvrr_stack+8397, dvrr_stack+34432);
 tmp = dvrr_stack + 32907;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+33117, dvrr_stack+13450, dvrr_stack+8397);
 tmp = dvrr_stack + 33117;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+33477, dvrr_stack+5573, dvrr_stack+9955);
 tmp = dvrr_stack + 33477;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+24796, dvrr_stack+23476, dvrr_stack+13450);
 tmp = dvrr_stack + 24796;
 target_ptr = Libderiv->deriv_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+18050, dvrr_stack+31474, dvrr_stack+5573);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+33927, dvrr_stack+7599, dvrr_stack+32377);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+25346, dvrr_stack+9955, dvrr_stack+7599);
 tmp = dvrr_stack + 25346;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+14350, dvrr_stack+8397, dvrr_stack+34432);
 tmp = dvrr_stack + 14350;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+14560, dvrr_stack+13450, dvrr_stack+8397);
 tmp = dvrr_stack + 14560;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+10525, dvrr_stack+5573, dvrr_stack+9955);
 tmp = dvrr_stack + 10525;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+44554, dvrr_stack+23476, dvrr_stack+13450);
 tmp = dvrr_stack + 44554;
 target_ptr = Libderiv->deriv_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+45104, dvrr_stack+31474, dvrr_stack+5573);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+34077, dvrr_stack+7599, dvrr_stack+32377);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+11995, dvrr_stack+9955, dvrr_stack+7599);
 tmp = dvrr_stack + 11995;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+32254, dvrr_stack+8397, dvrr_stack+34432);
 tmp = dvrr_stack + 32254;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+45764, dvrr_stack+13450, dvrr_stack+8397);
 tmp = dvrr_stack + 45764;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+46124, dvrr_stack+5573, dvrr_stack+9955);
 tmp = dvrr_stack + 46124;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+46574, dvrr_stack+23476, dvrr_stack+13450);
 tmp = dvrr_stack + 46574;
 target_ptr = Libderiv->deriv_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+47124, dvrr_stack+31474, dvrr_stack+5573);

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+31306,dvrr_stack+8229,dvrr_stack+7473,6);


 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+25626, dvrr_stack+31306, NULL);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+28456, dvrr_stack+34, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+25752, dvrr_stack+40, dvrr_stack+21, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+14920, dvrr_stack+6948, dvrr_stack+25752, dvrr_stack+129, dvrr_stack+40, dvrr_stack+28456);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+18710, dvrr_stack+84, dvrr_stack+69, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+18755, dvrr_stack+6978, dvrr_stack+18710, dvrr_stack+139, dvrr_stack+84, dvrr_stack+25752);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+9037, dvrr_stack+7068, dvrr_stack+18755, dvrr_stack+7023, dvrr_stack+6978, dvrr_stack+14920);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+9187, dvrr_stack+99, dvrr_stack+209, NULL, NULL, dvrr_stack+69);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+10975, dvrr_stack+7284, dvrr_stack+9187, dvrr_stack+154, dvrr_stack+99, dvrr_stack+18710);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+31684, dvrr_stack+7347, dvrr_stack+10975, dvrr_stack+7158, dvrr_stack+7284, dvrr_stack+18755);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+31894, dvrr_stack+7599, dvrr_stack+31684, dvrr_stack+7473, dvrr_stack+7347, dvrr_stack+9037);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+34862, dvrr_stack+7977, dvrr_stack+1917, dvrr_stack+258, dvrr_stack+230, dvrr_stack+9187);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+47784, dvrr_stack+8061, dvrr_stack+34862, dvrr_stack+7809, dvrr_stack+7977, dvrr_stack+10975);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+48064, dvrr_stack+8397, dvrr_stack+47784, dvrr_stack+8229, dvrr_stack+8061, dvrr_stack+31684);

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+48484,dvrr_stack+48064,dvrr_stack+31894,15);


 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+49429, dvrr_stack+48484, NULL);

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+49744,dvrr_stack+9739,dvrr_stack+8229,6);


 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+438, dvrr_stack+49744, NULL);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+50248, dvrr_stack+9523, dvrr_stack+2217, dvrr_stack+9307, dvrr_stack+2109, dvrr_stack+34862);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+50608, dvrr_stack+9955, dvrr_stack+50248, dvrr_stack+9739, dvrr_stack+9523, dvrr_stack+47784);

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+51148,dvrr_stack+50608,dvrr_stack+48064,15);


 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+52408, dvrr_stack+51148, NULL);

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+52828,dvrr_stack+13180,dvrr_stack+9739,6);


 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+1202, dvrr_stack+52828, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+53476, dvrr_stack+13450, dvrr_stack+3388, dvrr_stack+13180, dvrr_stack+3118, dvrr_stack+50248);

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+54151,dvrr_stack+53476,dvrr_stack+50608,15);


 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+55771, dvrr_stack+54151, NULL);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+56311,dvrr_stack+1587,dvrr_stack+13180,6);


 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+57121, dvrr_stack+56311, NULL);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+57391,dvrr_stack+6123,dvrr_stack+53476,15);


 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+59416, dvrr_stack+57391, NULL);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+60091,dvrr_stack+23080,dvrr_stack+1587,6);


 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+61081, dvrr_stack+60091, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22288, dvrr_stack+862, dvrr_stack+4388, NULL, NULL, dvrr_stack+4473);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+61411, dvrr_stack+22486, dvrr_stack+22288, dvrr_stack+638, dvrr_stack+862, dvrr_stack+4528);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+61807, dvrr_stack+22684, dvrr_stack+61411, dvrr_stack+22090, dvrr_stack+22486, dvrr_stack+4693);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+62467, dvrr_stack+23476, dvrr_stack+61807, dvrr_stack+23080, dvrr_stack+22684, dvrr_stack+5023);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+63457,dvrr_stack+62467,dvrr_stack+6123,15);


 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+22090, dvrr_stack+63457, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+23476, dvrr_stack+31306, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+23602, dvrr_stack+48484, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+23917, dvrr_stack+49744, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+61411, dvrr_stack+51148, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+61831, dvrr_stack+52828, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+65932, dvrr_stack+54151, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+62047, dvrr_stack+56311, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+66472, dvrr_stack+57391, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+67147, dvrr_stack+60091, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+67477, dvrr_stack+63457, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+22915, dvrr_stack+31306, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+31306, dvrr_stack+48484, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+48484, dvrr_stack+49744, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+49744, dvrr_stack+51148, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+51148, dvrr_stack+52828, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+52828, dvrr_stack+54151, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+54151, dvrr_stack+56311, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+56311, dvrr_stack+57391, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+57391, dvrr_stack+60091, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+60091, dvrr_stack+63457, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+63457, dvrr_stack+8229, dvrr_stack+34342);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+50, dvrr_stack+31, dvrr_stack+3, NULL, NULL, Data->F+4);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+63583, dvrr_stack+34234, dvrr_stack+28456, dvrr_stack+123, dvrr_stack+34, dvrr_stack+50);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+63619, dvrr_stack+34282, dvrr_stack+14920, dvrr_stack+34252, dvrr_stack+6948, dvrr_stack+63583);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+63719, dvrr_stack+34432, dvrr_stack+9037, dvrr_stack+34342, dvrr_stack+7068, dvrr_stack+63619);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+63944, dvrr_stack+48064, dvrr_stack+63719);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+64259, dvrr_stack+9739, dvrr_stack+7473);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+64427, dvrr_stack+50608, dvrr_stack+31894);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+64847, dvrr_stack+13180, dvrr_stack+8229);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+65063, dvrr_stack+53476, dvrr_stack+48064);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+65603, dvrr_stack+1587, dvrr_stack+9739);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+57721, dvrr_stack+6123, dvrr_stack+50608);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+58396, dvrr_stack+23080, dvrr_stack+13180);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+54421, dvrr_stack+62467, dvrr_stack+53476);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+34432, dvrr_stack+8229, dvrr_stack+34342);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+58726, dvrr_stack+48064, dvrr_stack+63719);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+59041, dvrr_stack+9739, dvrr_stack+7473);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+55246, dvrr_stack+50608, dvrr_stack+31894);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+51364, dvrr_stack+13180, dvrr_stack+8229);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+51580, dvrr_stack+53476, dvrr_stack+48064);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+52120, dvrr_stack+1587, dvrr_stack+9739);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+48652, dvrr_stack+6123, dvrr_stack+50608);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+68302, dvrr_stack+23080, dvrr_stack+13180);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+68632, dvrr_stack+62467, dvrr_stack+53476);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+63583, dvrr_stack+8229, dvrr_stack+34342);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+69457, dvrr_stack+48064, dvrr_stack+63719);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+63709, dvrr_stack+9739, dvrr_stack+7473);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+69772, dvrr_stack+50608, dvrr_stack+31894);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+759, dvrr_stack+13180, dvrr_stack+8229);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+70192, dvrr_stack+53476, dvrr_stack+48064);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+70732, dvrr_stack+1587, dvrr_stack+9739);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+71002, dvrr_stack+6123, dvrr_stack+50608);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+71677, dvrr_stack+23080, dvrr_stack+13180);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+72007, dvrr_stack+62467, dvrr_stack+53476);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+60916, dvrr_stack+7599, dvrr_stack+7221);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+50, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+52390, dvrr_stack+15, dvrr_stack+9, NULL, NULL, dvrr_stack+0);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+63877, dvrr_stack+28456, dvrr_stack+52390, dvrr_stack+34, dvrr_stack+15, dvrr_stack+50);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+28456, dvrr_stack+21, dvrr_stack+59, NULL, NULL, dvrr_stack+9);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+59209, dvrr_stack+25752, dvrr_stack+28456, dvrr_stack+40, dvrr_stack+21, dvrr_stack+52390);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+59269, dvrr_stack+14920, dvrr_stack+59209, dvrr_stack+6948, dvrr_stack+25752, dvrr_stack+63877);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+7023, dvrr_stack+69, dvrr_stack+194, NULL, NULL, dvrr_stack+59);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+56986, dvrr_stack+18710, dvrr_stack+7023, dvrr_stack+84, dvrr_stack+69, dvrr_stack+28456);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+23041, dvrr_stack+18755, dvrr_stack+56986, dvrr_stack+6978, dvrr_stack+18710, dvrr_stack+59209);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+23191, dvrr_stack+9037, dvrr_stack+23041, dvrr_stack+7068, dvrr_stack+18755, dvrr_stack+59269);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+31621, dvrr_stack+209, dvrr_stack+353, NULL, NULL, dvrr_stack+194);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+7068, dvrr_stack+9187, dvrr_stack+31621, dvrr_stack+99, dvrr_stack+209, dvrr_stack+7023);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+0, dvrr_stack+10975, dvrr_stack+7068, dvrr_stack+7284, dvrr_stack+9187, dvrr_stack+56986);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+9037, dvrr_stack+31684, dvrr_stack+0, dvrr_stack+7347, dvrr_stack+10975, dvrr_stack+23041);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+62317, dvrr_stack+31894, dvrr_stack+9037, dvrr_stack+7599, dvrr_stack+31684, dvrr_stack+23191);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+23041, dvrr_stack+62317, dvrr_stack+7599);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+31684, dvrr_stack+8397, dvrr_stack+7893);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+50164, dvrr_stack+374, dvrr_stack+1093, NULL, NULL, dvrr_stack+353);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+10975, dvrr_stack+1917, dvrr_stack+50164, dvrr_stack+230, dvrr_stack+374, dvrr_stack+31621);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+62758, dvrr_stack+34862, dvrr_stack+10975, dvrr_stack+7977, dvrr_stack+1917, dvrr_stack+7068);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+72832, dvrr_stack+47784, dvrr_stack+62758, dvrr_stack+8061, dvrr_stack+34862, dvrr_stack+0);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+73252, dvrr_stack+48064, dvrr_stack+72832, dvrr_stack+8397, dvrr_stack+47784, dvrr_stack+9037);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+73840, dvrr_stack+73252, dvrr_stack+8397);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+9037, dvrr_stack+9955, dvrr_stack+9415);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53368, dvrr_stack+1121, dvrr_stack+2632, NULL, NULL, dvrr_stack+1093);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+47784, dvrr_stack+2001, dvrr_stack+53368, dvrr_stack+402, dvrr_stack+1121, dvrr_stack+50164);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+2217, dvrr_stack+47784, dvrr_stack+2109, dvrr_stack+2001, dvrr_stack+10975);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+74260, dvrr_stack+50248, dvrr_stack+0, dvrr_stack+9523, dvrr_stack+2217, dvrr_stack+62758);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+74800, dvrr_stack+50608, dvrr_stack+74260, dvrr_stack+9955, dvrr_stack+50248, dvrr_stack+72832);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+62758, dvrr_stack+74800, dvrr_stack+9955);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+72832, dvrr_stack+13450, dvrr_stack+13045);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+56986, dvrr_stack+2668, dvrr_stack+1047, NULL, NULL, dvrr_stack+2632);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+50164, dvrr_stack+2713, dvrr_stack+56986, dvrr_stack+1157, dvrr_stack+2668, dvrr_stack+53368);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1917, dvrr_stack+2848, dvrr_stack+50164, dvrr_stack+2433, dvrr_stack+2713, dvrr_stack+47784);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+75556, dvrr_stack+3388, dvrr_stack+1917, dvrr_stack+3118, dvrr_stack+2848, dvrr_stack+0);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2367, dvrr_stack+53476, dvrr_stack+75556, dvrr_stack+13450, dvrr_stack+3388, dvrr_stack+74260);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+76231, dvrr_stack+2367, dvrr_stack+13450);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+74260, dvrr_stack+5573, dvrr_stack+1422);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+74590, dvrr_stack+4473, dvrr_stack+704, NULL, NULL, dvrr_stack+1047);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+4528, dvrr_stack+74590, dvrr_stack+3838, dvrr_stack+4473, dvrr_stack+56986);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3312, dvrr_stack+4693, dvrr_stack+0, dvrr_stack+3893, dvrr_stack+4528, dvrr_stack+50164);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+76906, dvrr_stack+5023, dvrr_stack+3312, dvrr_stack+4058, dvrr_stack+4693, dvrr_stack+1917);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3312, dvrr_stack+6123, dvrr_stack+76906, dvrr_stack+5573, dvrr_stack+5023, dvrr_stack+75556);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+76906, dvrr_stack+3312, dvrr_stack+5573);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+75556, dvrr_stack+7599, dvrr_stack+7221);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+75682, dvrr_stack+62317, dvrr_stack+7599);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+75997, dvrr_stack+8397, dvrr_stack+7893);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+77731, dvrr_stack+73252, dvrr_stack+8397);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+9523, dvrr_stack+9955, dvrr_stack+9415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+4467, dvrr_stack+74800, dvrr_stack+9955);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+78151, dvrr_stack+13450, dvrr_stack+13045);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+78421, dvrr_stack+2367, dvrr_stack+13450);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+79096, dvrr_stack+5573, dvrr_stack+1422);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+79426, dvrr_stack+3312, dvrr_stack+5573);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+80251, dvrr_stack+7599, dvrr_stack+7221);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+1917, dvrr_stack+62317, dvrr_stack+7599);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+7599, dvrr_stack+8397, dvrr_stack+7893);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+7767, dvrr_stack+73252, dvrr_stack+8397);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+8397, dvrr_stack+9955, dvrr_stack+9415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+5007, dvrr_stack+74800, dvrr_stack+9955);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+9253, dvrr_stack+13450, dvrr_stack+13045);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+74590, dvrr_stack+2367, dvrr_stack+13450);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+13450, dvrr_stack+5573, dvrr_stack+1422);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+2232, dvrr_stack+3312, dvrr_stack+5573);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+3057, dvrr_stack+6123, dvrr_stack+1587);
 tmp = dvrr_stack + 3057;
 target_ptr = Libderiv->deriv_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+3607, dvrr_stack+6123, dvrr_stack+1587);
 tmp = dvrr_stack + 3607;
 target_ptr = Libderiv->deriv_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+5547, dvrr_stack+6123, dvrr_stack+1587);
 tmp = dvrr_stack + 5547;
 target_ptr = Libderiv->deriv_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+9955, dvrr_stack+12415, NULL);
 tmp = dvrr_stack + 9955;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+47784, dvrr_stack+16660, NULL);
 tmp = dvrr_stack + 47784;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+62317, dvrr_stack+21010, NULL);
 tmp = dvrr_stack + 62317;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+6097, dvrr_stack+28486, NULL);
 tmp = dvrr_stack + 6097;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,550,dvrr_stack+6547, dvrr_stack+37534, NULL);
 tmp = dvrr_stack + 6547;
 target_ptr = Libderiv->deriv2_classes[3][9][143];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+4157, dvrr_stack+12415, NULL);
 tmp = dvrr_stack + 4157;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+7097, dvrr_stack+16660, NULL);
 tmp = dvrr_stack + 7097;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+50164, dvrr_stack+21010, NULL);
 tmp = dvrr_stack + 50164;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+73102, dvrr_stack+28486, NULL);
 tmp = dvrr_stack + 73102;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,550,dvrr_stack+80377, dvrr_stack+37534, NULL);
 tmp = dvrr_stack + 80377;
 target_ptr = Libderiv->deriv2_classes[3][9][131];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+80927, dvrr_stack+29836, NULL);
 tmp = dvrr_stack + 80927;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+81137, dvrr_stack+30466, NULL);
 tmp = dvrr_stack + 81137;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+0, dvrr_stack+39184, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+1418, dvrr_stack+40264, NULL);
 tmp = dvrr_stack + 1418;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+81417, dvrr_stack+41614, NULL);
 tmp = dvrr_stack + 81417;
 target_ptr = Libderiv->deriv2_classes[3][9][130];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+81967, dvrr_stack+12415, NULL);
 tmp = dvrr_stack + 81967;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+82177, dvrr_stack+16660, NULL);
 tmp = dvrr_stack + 82177;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+16610, dvrr_stack+21010, NULL);
 tmp = dvrr_stack + 16610;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+21010, dvrr_stack+28486, NULL);
 tmp = dvrr_stack + 21010;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,550,dvrr_stack+21460, dvrr_stack+37534, NULL);
 tmp = dvrr_stack + 21460;
 target_ptr = Libderiv->deriv2_classes[3][9][119];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+75265, dvrr_stack+29836, NULL);
 tmp = dvrr_stack + 75265;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+73552, dvrr_stack+30466, NULL);
 tmp = dvrr_stack + 73552;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+28456, dvrr_stack+39184, NULL);
 tmp = dvrr_stack + 28456;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+28816, dvrr_stack+40264, NULL);
 tmp = dvrr_stack + 28816;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+29266, dvrr_stack+41614, NULL);
 tmp = dvrr_stack + 29266;
 target_ptr = Libderiv->deriv2_classes[3][9][118];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+29816, dvrr_stack+43264, NULL);
 tmp = dvrr_stack + 29816;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+30026, dvrr_stack+11155, NULL);
 tmp = dvrr_stack + 30026;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+10975, dvrr_stack+14980, NULL);
 tmp = dvrr_stack + 10975;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+11335, dvrr_stack+18850, NULL);
 tmp = dvrr_stack + 11335;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+18710, dvrr_stack+25786, NULL);
 tmp = dvrr_stack + 18710;
 target_ptr = Libderiv->deriv2_classes[3][9][117];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+11785, dvrr_stack+35182, dvrr_stack+35032);
 tmp = dvrr_stack + 11785;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+19260, dvrr_stack+35672, dvrr_stack+35462);
 tmp = dvrr_stack + 19260;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+19540, dvrr_stack+36032, dvrr_stack+35182);
 tmp = dvrr_stack + 19540;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+30306, dvrr_stack+36482, dvrr_stack+35672);
 tmp = dvrr_stack + 30306;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+30756, dvrr_stack+27436, dvrr_stack+36032);
 tmp = dvrr_stack + 30756;
 target_ptr = Libderiv->deriv2_classes[3][9][107];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+19900, dvrr_stack+37182, dvrr_stack+37032);
 tmp = dvrr_stack + 19900;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+25752, dvrr_stack+20200, dvrr_stack+28096);
 tmp = dvrr_stack + 25752;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+26032, dvrr_stack+20560, dvrr_stack+37182);
 tmp = dvrr_stack + 26032;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+26392, dvrr_stack+16060, dvrr_stack+20200);
 tmp = dvrr_stack + 26392;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+26842, dvrr_stack+43894, dvrr_stack+20560);
 tmp = dvrr_stack + 26842;
 target_ptr = Libderiv->deriv2_classes[3][9][106];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+14920, dvrr_stack+34582, dvrr_stack+28306);
 tmp = dvrr_stack + 14920;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+15130, dvrr_stack+8677, dvrr_stack+10315);
 tmp = dvrr_stack + 15130;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+15410, dvrr_stack+13900, dvrr_stack+34582);
 tmp = dvrr_stack + 15410;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+37462, dvrr_stack+17500, dvrr_stack+8677);
 tmp = dvrr_stack + 37462;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+37912, dvrr_stack+24136, dvrr_stack+13900);
 tmp = dvrr_stack + 37912;
 target_ptr = Libderiv->deriv2_classes[3][9][105];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+15770, dvrr_stack+32627, dvrr_stack+32477);
 tmp = dvrr_stack + 15770;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+38462, dvrr_stack+33117, dvrr_stack+32907);
 tmp = dvrr_stack + 38462;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+38742, dvrr_stack+33477, dvrr_stack+32627);
 tmp = dvrr_stack + 38742;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+39102, dvrr_stack+24796, dvrr_stack+33117);
 tmp = dvrr_stack + 39102;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+39552, dvrr_stack+18050, dvrr_stack+33477);
 tmp = dvrr_stack + 39552;
 target_ptr = Libderiv->deriv2_classes[3][9][104];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+40102, dvrr_stack+35182, dvrr_stack+35032);
 tmp = dvrr_stack + 40102;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+40312, dvrr_stack+35672, dvrr_stack+35462);
 tmp = dvrr_stack + 40312;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+40592, dvrr_stack+36032, dvrr_stack+35182);
 tmp = dvrr_stack + 40592;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+40952, dvrr_stack+36482, dvrr_stack+35672);
 tmp = dvrr_stack + 40952;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+41402, dvrr_stack+27436, dvrr_stack+36032);
 tmp = dvrr_stack + 41402;
 target_ptr = Libderiv->deriv2_classes[3][9][95];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+41952, dvrr_stack+37182, dvrr_stack+37032);
 tmp = dvrr_stack + 41952;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+42162, dvrr_stack+20200, dvrr_stack+28096);
 tmp = dvrr_stack + 42162;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+42442, dvrr_stack+20560, dvrr_stack+37182);
 tmp = dvrr_stack + 42442;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+42802, dvrr_stack+16060, dvrr_stack+20200);
 tmp = dvrr_stack + 42802;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+43252, dvrr_stack+43894, dvrr_stack+20560);
 tmp = dvrr_stack + 43252;
 target_ptr = Libderiv->deriv2_classes[3][9][94];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+16970, dvrr_stack+34582, dvrr_stack+28306);
 tmp = dvrr_stack + 16970;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+17180, dvrr_stack+8677, dvrr_stack+10315);
 tmp = dvrr_stack + 17180;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+12275, dvrr_stack+13900, dvrr_stack+34582);
 tmp = dvrr_stack + 12275;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+12635, dvrr_stack+17500, dvrr_stack+8677);
 tmp = dvrr_stack + 12635;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+82457, dvrr_stack+24136, dvrr_stack+13900);
 tmp = dvrr_stack + 82457;
 target_ptr = Libderiv->deriv2_classes[3][9][93];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+83007, dvrr_stack+32627, dvrr_stack+32477);
 tmp = dvrr_stack + 83007;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+83217, dvrr_stack+33117, dvrr_stack+32907);
 tmp = dvrr_stack + 83217;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+83497, dvrr_stack+33477, dvrr_stack+32627);
 tmp = dvrr_stack + 83497;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+83857, dvrr_stack+24796, dvrr_stack+33117);
 tmp = dvrr_stack + 83857;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+84307, dvrr_stack+18050, dvrr_stack+33477);
 tmp = dvrr_stack + 84307;
 target_ptr = Libderiv->deriv2_classes[3][9][92];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+84857, dvrr_stack+25346, dvrr_stack+33927);
 tmp = dvrr_stack + 84857;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+85067, dvrr_stack+14560, dvrr_stack+14350);
 tmp = dvrr_stack + 85067;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+85347, dvrr_stack+10525, dvrr_stack+25346);
 tmp = dvrr_stack + 85347;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+85707, dvrr_stack+44554, dvrr_stack+14560);
 tmp = dvrr_stack + 85707;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+86157, dvrr_stack+45104, dvrr_stack+10525);
 tmp = dvrr_stack + 86157;
 target_ptr = Libderiv->deriv2_classes[3][9][91];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+86707, dvrr_stack+35182, dvrr_stack+35032);
 tmp = dvrr_stack + 86707;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+86917, dvrr_stack+35672, dvrr_stack+35462);
 tmp = dvrr_stack + 86917;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+87197, dvrr_stack+36032, dvrr_stack+35182);
 tmp = dvrr_stack + 87197;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+87557, dvrr_stack+36482, dvrr_stack+35672);
 tmp = dvrr_stack + 87557;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+36482, dvrr_stack+27436, dvrr_stack+36032);
 tmp = dvrr_stack + 36482;
 target_ptr = Libderiv->deriv2_classes[3][9][83];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+88007, dvrr_stack+37182, dvrr_stack+37032);
 tmp = dvrr_stack + 88007;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+88217, dvrr_stack+20200, dvrr_stack+28096);
 tmp = dvrr_stack + 88217;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+34862, dvrr_stack+20560, dvrr_stack+37182);
 tmp = dvrr_stack + 34862;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+35222, dvrr_stack+16060, dvrr_stack+20200);
 tmp = dvrr_stack + 35222;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+35672, dvrr_stack+43894, dvrr_stack+20560);
 tmp = dvrr_stack + 35672;
 target_ptr = Libderiv->deriv2_classes[3][9][82];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+37032, dvrr_stack+34582, dvrr_stack+28306);
 tmp = dvrr_stack + 37032;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+20110, dvrr_stack+8677, dvrr_stack+10315);
 tmp = dvrr_stack + 20110;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+10165, dvrr_stack+13900, dvrr_stack+34582);
 tmp = dvrr_stack + 10165;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+20390, dvrr_stack+17500, dvrr_stack+8677);
 tmp = dvrr_stack + 20390;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+27392, dvrr_stack+24136, dvrr_stack+13900);
 tmp = dvrr_stack + 27392;
 target_ptr = Libderiv->deriv2_classes[3][9][81];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+37242, dvrr_stack+32627, dvrr_stack+32477);
 tmp = dvrr_stack + 37242;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+13780, dvrr_stack+33117, dvrr_stack+32907);
 tmp = dvrr_stack + 13780;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+8613, dvrr_stack+33477, dvrr_stack+32627);
 tmp = dvrr_stack + 8613;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+27942, dvrr_stack+24796, dvrr_stack+33117);
 tmp = dvrr_stack + 27942;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+15980, dvrr_stack+18050, dvrr_stack+33477);
 tmp = dvrr_stack + 15980;
 target_ptr = Libderiv->deriv2_classes[3][9][80];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+14060, dvrr_stack+25346, dvrr_stack+33927);
 tmp = dvrr_stack + 14060;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+34558, dvrr_stack+14560, dvrr_stack+14350);
 tmp = dvrr_stack + 34558;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+24085, dvrr_stack+10525, dvrr_stack+25346);
 tmp = dvrr_stack + 24085;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+24445, dvrr_stack+44554, dvrr_stack+14560);
 tmp = dvrr_stack + 24445;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+14270, dvrr_stack+45104, dvrr_stack+10525);
 tmp = dvrr_stack + 14270;
 target_ptr = Libderiv->deriv2_classes[3][9][79];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+10525, dvrr_stack+11995, dvrr_stack+34077);
 tmp = dvrr_stack + 10525;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+24895, dvrr_stack+45764, dvrr_stack+32254);
 tmp = dvrr_stack + 24895;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+25175, dvrr_stack+46124, dvrr_stack+11995);
 tmp = dvrr_stack + 25175;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+43802, dvrr_stack+46574, dvrr_stack+45764);
 tmp = dvrr_stack + 43802;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+46574, dvrr_stack+47124, dvrr_stack+46124);
 tmp = dvrr_stack + 46574;
 target_ptr = Libderiv->deriv2_classes[3][9][78];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+47124, dvrr_stack+49429, dvrr_stack+25626);
 tmp = dvrr_stack + 47124;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+11995, dvrr_stack+52408, dvrr_stack+438);
 tmp = dvrr_stack + 11995;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+47334, dvrr_stack+55771, dvrr_stack+1202);
 tmp = dvrr_stack + 47334;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+44252, dvrr_stack+59416, dvrr_stack+57121);
 tmp = dvrr_stack + 44252;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,55,dvrr_stack+44702, dvrr_stack+22090, dvrr_stack+61081);
 tmp = dvrr_stack + 44702;
 target_ptr = Libderiv->deriv2_classes[3][9][35];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+10735, dvrr_stack+23602, dvrr_stack+23476);
 tmp = dvrr_stack + 10735;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+45252, dvrr_stack+61411, dvrr_stack+23917);
 tmp = dvrr_stack + 45252;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+45532, dvrr_stack+65932, dvrr_stack+61831);
 tmp = dvrr_stack + 45532;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+45892, dvrr_stack+66472, dvrr_stack+62047);
 tmp = dvrr_stack + 45892;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+17460, dvrr_stack+67477, dvrr_stack+67147);
 tmp = dvrr_stack + 17460;
 target_ptr = Libderiv->deriv2_classes[3][9][34];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+36222, dvrr_stack+31306, dvrr_stack+22915);
 tmp = dvrr_stack + 36222;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+18010, dvrr_stack+49744, dvrr_stack+48484);
 tmp = dvrr_stack + 18010;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+18290, dvrr_stack+52828, dvrr_stack+51148);
 tmp = dvrr_stack + 18290;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+32209, dvrr_stack+56311, dvrr_stack+54151);
 tmp = dvrr_stack + 32209;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+32659, dvrr_stack+60091, dvrr_stack+57391);
 tmp = dvrr_stack + 32659;
 target_ptr = Libderiv->deriv2_classes[3][9][33];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+46342, dvrr_stack+63944, dvrr_stack+63457);
 tmp = dvrr_stack + 46342;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+33209, dvrr_stack+64427, dvrr_stack+64259);
 tmp = dvrr_stack + 33209;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+33489, dvrr_stack+65063, dvrr_stack+64847);
 tmp = dvrr_stack + 33489;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+33849, dvrr_stack+57721, dvrr_stack+65603);
 tmp = dvrr_stack + 33849;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+88497, dvrr_stack+54421, dvrr_stack+58396);
 tmp = dvrr_stack + 88497;
 target_ptr = Libderiv->deriv2_classes[3][9][32];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+89047, dvrr_stack+58726, dvrr_stack+34432);
 tmp = dvrr_stack + 89047;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+89257, dvrr_stack+55246, dvrr_stack+59041);
 tmp = dvrr_stack + 89257;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+89537, dvrr_stack+51580, dvrr_stack+51364);
 tmp = dvrr_stack + 89537;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+89897, dvrr_stack+48652, dvrr_stack+52120);
 tmp = dvrr_stack + 89897;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+90347, dvrr_stack+68632, dvrr_stack+68302);
 tmp = dvrr_stack + 90347;
 target_ptr = Libderiv->deriv2_classes[3][9][31];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+90897, dvrr_stack+31894, dvrr_stack+7473);
 tmp = dvrr_stack + 90897;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+91107, dvrr_stack+69457, dvrr_stack+63583);
 tmp = dvrr_stack + 91107;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+91317, dvrr_stack+48064, dvrr_stack+8229);
 tmp = dvrr_stack + 91317;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+91597, dvrr_stack+69772, dvrr_stack+63709);
 tmp = dvrr_stack + 91597;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+91877, dvrr_stack+50608, dvrr_stack+9739);
 tmp = dvrr_stack + 91877;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+92237, dvrr_stack+70192, dvrr_stack+759);
 tmp = dvrr_stack + 92237;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+92597, dvrr_stack+53476, dvrr_stack+13180);
 tmp = dvrr_stack + 92597;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+93047, dvrr_stack+71002, dvrr_stack+70732);
 tmp = dvrr_stack + 93047;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+93497, dvrr_stack+72007, dvrr_stack+71677);
 tmp = dvrr_stack + 93497;
 target_ptr = Libderiv->deriv2_classes[3][9][30];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+94047, dvrr_stack+23041, dvrr_stack+60916);
 tmp = dvrr_stack + 94047;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+94257, dvrr_stack+73840, dvrr_stack+31684);
 tmp = dvrr_stack + 94257;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+94537, dvrr_stack+62758, dvrr_stack+9037);
 tmp = dvrr_stack + 94537;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+94897, dvrr_stack+76231, dvrr_stack+72832);
 tmp = dvrr_stack + 94897;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+95347, dvrr_stack+76906, dvrr_stack+74260);
 tmp = dvrr_stack + 95347;
 target_ptr = Libderiv->deriv2_classes[3][9][26];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+95897, dvrr_stack+49429, dvrr_stack+25626);
 tmp = dvrr_stack + 95897;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+96107, dvrr_stack+52408, dvrr_stack+438);
 tmp = dvrr_stack + 96107;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+96387, dvrr_stack+55771, dvrr_stack+1202);
 tmp = dvrr_stack + 96387;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+96747, dvrr_stack+59416, dvrr_stack+57121);
 tmp = dvrr_stack + 96747;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,55,dvrr_stack+97197, dvrr_stack+22090, dvrr_stack+61081);
 tmp = dvrr_stack + 97197;
 target_ptr = Libderiv->deriv2_classes[3][9][23];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+97747, dvrr_stack+23602, dvrr_stack+23476);
 tmp = dvrr_stack + 97747;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+97957, dvrr_stack+61411, dvrr_stack+23917);
 tmp = dvrr_stack + 97957;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+98237, dvrr_stack+65932, dvrr_stack+61831);
 tmp = dvrr_stack + 98237;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+98597, dvrr_stack+66472, dvrr_stack+62047);
 tmp = dvrr_stack + 98597;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+99047, dvrr_stack+67477, dvrr_stack+67147);
 tmp = dvrr_stack + 99047;
 target_ptr = Libderiv->deriv2_classes[3][9][22];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+99597, dvrr_stack+31306, dvrr_stack+22915);
 tmp = dvrr_stack + 99597;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+99807, dvrr_stack+49744, dvrr_stack+48484);
 tmp = dvrr_stack + 99807;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+100087, dvrr_stack+52828, dvrr_stack+51148);
 tmp = dvrr_stack + 100087;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+100447, dvrr_stack+56311, dvrr_stack+54151);
 tmp = dvrr_stack + 100447;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+100897, dvrr_stack+60091, dvrr_stack+57391);
 tmp = dvrr_stack + 100897;
 target_ptr = Libderiv->deriv2_classes[3][9][21];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+975, dvrr_stack+63944, dvrr_stack+63457);
 tmp = dvrr_stack + 975;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+101447, dvrr_stack+64427, dvrr_stack+64259);
 tmp = dvrr_stack + 101447;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+101727, dvrr_stack+65063, dvrr_stack+64847);
 tmp = dvrr_stack + 101727;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+102087, dvrr_stack+57721, dvrr_stack+65603);
 tmp = dvrr_stack + 102087;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+102537, dvrr_stack+54421, dvrr_stack+58396);
 tmp = dvrr_stack + 102537;
 target_ptr = Libderiv->deriv2_classes[3][9][20];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+103087, dvrr_stack+58726, dvrr_stack+34432);
 tmp = dvrr_stack + 103087;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+103297, dvrr_stack+55246, dvrr_stack+59041);
 tmp = dvrr_stack + 103297;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+103577, dvrr_stack+51580, dvrr_stack+51364);
 tmp = dvrr_stack + 103577;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+103937, dvrr_stack+48652, dvrr_stack+52120);
 tmp = dvrr_stack + 103937;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+104387, dvrr_stack+68632, dvrr_stack+68302);
 tmp = dvrr_stack + 104387;
 target_ptr = Libderiv->deriv2_classes[3][9][19];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+104937, dvrr_stack+31894, dvrr_stack+7473);
 tmp = dvrr_stack + 104937;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+105147, dvrr_stack+69457, dvrr_stack+63583);
 tmp = dvrr_stack + 105147;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+105357, dvrr_stack+48064, dvrr_stack+8229);
 tmp = dvrr_stack + 105357;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+105637, dvrr_stack+69772, dvrr_stack+63709);
 tmp = dvrr_stack + 105637;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+105917, dvrr_stack+50608, dvrr_stack+9739);
 tmp = dvrr_stack + 105917;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+106277, dvrr_stack+70192, dvrr_stack+759);
 tmp = dvrr_stack + 106277;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+106637, dvrr_stack+53476, dvrr_stack+13180);
 tmp = dvrr_stack + 106637;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+107087, dvrr_stack+71002, dvrr_stack+70732);
 tmp = dvrr_stack + 107087;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+107537, dvrr_stack+72007, dvrr_stack+71677);
 tmp = dvrr_stack + 107537;
 target_ptr = Libderiv->deriv2_classes[3][9][18];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+108087, dvrr_stack+23041, dvrr_stack+60916);
 tmp = dvrr_stack + 108087;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+108297, dvrr_stack+73840, dvrr_stack+31684);
 tmp = dvrr_stack + 108297;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+108577, dvrr_stack+62758, dvrr_stack+9037);
 tmp = dvrr_stack + 108577;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+108937, dvrr_stack+76231, dvrr_stack+72832);
 tmp = dvrr_stack + 108937;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+109387, dvrr_stack+76906, dvrr_stack+74260);
 tmp = dvrr_stack + 109387;
 target_ptr = Libderiv->deriv2_classes[3][9][14];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+109937, dvrr_stack+75682, dvrr_stack+75556);
 tmp = dvrr_stack + 109937;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+110147, dvrr_stack+77731, dvrr_stack+75997);
 tmp = dvrr_stack + 110147;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+110427, dvrr_stack+4467, dvrr_stack+9523);
 tmp = dvrr_stack + 110427;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+110787, dvrr_stack+78421, dvrr_stack+78151);
 tmp = dvrr_stack + 110787;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+111237, dvrr_stack+79426, dvrr_stack+79096);
 tmp = dvrr_stack + 111237;
 target_ptr = Libderiv->deriv2_classes[3][9][13];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+111787, dvrr_stack+49429, dvrr_stack+25626);
 tmp = dvrr_stack + 111787;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+111997, dvrr_stack+52408, dvrr_stack+438);
 tmp = dvrr_stack + 111997;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+360, dvrr_stack+55771, dvrr_stack+1202);
 tmp = dvrr_stack + 360;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+55666, dvrr_stack+59416, dvrr_stack+57121);
 tmp = dvrr_stack + 55666;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,55,dvrr_stack+59209, dvrr_stack+22090, dvrr_stack+61081);
 tmp = dvrr_stack + 59209;
 target_ptr = Libderiv->deriv2_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+22010, dvrr_stack+23602, dvrr_stack+23476);
 tmp = dvrr_stack + 22010;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+22220, dvrr_stack+61411, dvrr_stack+23917);
 tmp = dvrr_stack + 22220;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+22500, dvrr_stack+65932, dvrr_stack+61831);
 tmp = dvrr_stack + 22500;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+23356, dvrr_stack+66472, dvrr_stack+62047);
 tmp = dvrr_stack + 23356;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+65873, dvrr_stack+67477, dvrr_stack+67147);
 tmp = dvrr_stack + 65873;
 target_ptr = Libderiv->deriv2_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+112277, dvrr_stack+31306, dvrr_stack+22915);
 tmp = dvrr_stack + 112277;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+31306, dvrr_stack+49744, dvrr_stack+48484);
 tmp = dvrr_stack + 31306;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+56986, dvrr_stack+52828, dvrr_stack+51148);
 tmp = dvrr_stack + 56986;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+52390, dvrr_stack+56311, dvrr_stack+54151);
 tmp = dvrr_stack + 52390;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+52840, dvrr_stack+60091, dvrr_stack+57391);
 tmp = dvrr_stack + 52840;
 target_ptr = Libderiv->deriv2_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+54151, dvrr_stack+63944, dvrr_stack+63457);
 tmp = dvrr_stack + 54151;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+57346, dvrr_stack+64427, dvrr_stack+64259);
 tmp = dvrr_stack + 57346;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+59759, dvrr_stack+65063, dvrr_stack+64847);
 tmp = dvrr_stack + 59759;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+60119, dvrr_stack+57721, dvrr_stack+65603);
 tmp = dvrr_stack + 60119;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+57626, dvrr_stack+54421, dvrr_stack+58396);
 tmp = dvrr_stack + 57626;
 target_ptr = Libderiv->deriv2_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+54361, dvrr_stack+58726, dvrr_stack+34432);
 tmp = dvrr_stack + 54361;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+54571, dvrr_stack+55246, dvrr_stack+59041);
 tmp = dvrr_stack + 54571;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+54851, dvrr_stack+51580, dvrr_stack+51364);
 tmp = dvrr_stack + 54851;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+55211, dvrr_stack+48652, dvrr_stack+52120);
 tmp = dvrr_stack + 55211;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+51148, dvrr_stack+68632, dvrr_stack+68302);
 tmp = dvrr_stack + 51148;
 target_ptr = Libderiv->deriv2_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+51698, dvrr_stack+31894, dvrr_stack+7473);
 tmp = dvrr_stack + 51698;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+51908, dvrr_stack+69457, dvrr_stack+63583);
 tmp = dvrr_stack + 51908;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+48484, dvrr_stack+48064, dvrr_stack+8229);
 tmp = dvrr_stack + 48484;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+48064, dvrr_stack+69772, dvrr_stack+63709);
 tmp = dvrr_stack + 48064;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+48764, dvrr_stack+50608, dvrr_stack+9739);
 tmp = dvrr_stack + 48764;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+49124, dvrr_stack+70192, dvrr_stack+759);
 tmp = dvrr_stack + 49124;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+49484, dvrr_stack+53476, dvrr_stack+13180);
 tmp = dvrr_stack + 49484;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+50524, dvrr_stack+71002, dvrr_stack+70732);
 tmp = dvrr_stack + 50524;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+58176, dvrr_stack+72007, dvrr_stack+71677);
 tmp = dvrr_stack + 58176;
 target_ptr = Libderiv->deriv2_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+8187, dvrr_stack+23041, dvrr_stack+60916);
 tmp = dvrr_stack + 8187;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+22860, dvrr_stack+73840, dvrr_stack+31684);
 tmp = dvrr_stack + 22860;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+31586, dvrr_stack+62758, dvrr_stack+9037);
 tmp = dvrr_stack + 31586;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+62677, dvrr_stack+76231, dvrr_stack+72832);
 tmp = dvrr_stack + 62677;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+63127, dvrr_stack+76906, dvrr_stack+74260);
 tmp = dvrr_stack + 63127;
 target_ptr = Libderiv->deriv2_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+9739, dvrr_stack+75682, dvrr_stack+75556);
 tmp = dvrr_stack + 9739;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+8973, dvrr_stack+77731, dvrr_stack+75997);
 tmp = dvrr_stack + 8973;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+63677, dvrr_stack+4467, dvrr_stack+9523);
 tmp = dvrr_stack + 63677;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+64037, dvrr_stack+78421, dvrr_stack+78151);
 tmp = dvrr_stack + 64037;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+64487, dvrr_stack+79426, dvrr_stack+79096);
 tmp = dvrr_stack + 64487;
 target_ptr = Libderiv->deriv2_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+9523, dvrr_stack+1917, dvrr_stack+80251);
 tmp = dvrr_stack + 9523;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+65037, dvrr_stack+7767, dvrr_stack+7599);
 tmp = dvrr_stack + 65037;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+65317, dvrr_stack+5007, dvrr_stack+8397);
 tmp = dvrr_stack + 65317;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+4367, dvrr_stack+74590, dvrr_stack+9253);
 tmp = dvrr_stack + 4367;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+4817, dvrr_stack+2232, dvrr_stack+13450);
 tmp = dvrr_stack + 4817;
 target_ptr = Libderiv->deriv2_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];


}

