/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (fp|hg) integrals */

void d12vrr_order_fphg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+0, dvrr_stack+12, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+6, dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+21, NULL, NULL, dvrr_stack+6);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+98, dvrr_stack+95, dvrr_stack+31, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+104, dvrr_stack+98, dvrr_stack+34, dvrr_stack+95, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+114, dvrr_stack+104, dvrr_stack+40, dvrr_stack+98, dvrr_stack+34, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+129, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+132, dvrr_stack+12, dvrr_stack+129, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+138, dvrr_stack+15, dvrr_stack+132, dvrr_stack+0, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+148, dvrr_stack+21, dvrr_stack+138, dvrr_stack+6, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+163, dvrr_stack+80, dvrr_stack+148, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+208, dvrr_stack+114, dvrr_stack+80, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+253, dvrr_stack+208, dvrr_stack+163, dvrr_stack+114, dvrr_stack+80, dvrr_stack+50);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+343, dvrr_stack+80, dvrr_stack+148, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+364, dvrr_stack+114, dvrr_stack+80, dvrr_stack+104, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+385, dvrr_stack+364, dvrr_stack+343, NULL, NULL, dvrr_stack+80);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+448, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+451, dvrr_stack+448, dvrr_stack+95, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+457, dvrr_stack+451, dvrr_stack+98, dvrr_stack+448, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+467, dvrr_stack+457, dvrr_stack+104, dvrr_stack+451, dvrr_stack+98, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+482, dvrr_stack+467, dvrr_stack+114, dvrr_stack+457, dvrr_stack+104, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+503, dvrr_stack+482, dvrr_stack+364, NULL, NULL, dvrr_stack+114);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+448, dvrr_stack+129, dvrr_stack+95, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+566, dvrr_stack+132, dvrr_stack+448, dvrr_stack+12, dvrr_stack+129, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+576, dvrr_stack+138, dvrr_stack+566, dvrr_stack+15, dvrr_stack+132, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+591, dvrr_stack+148, dvrr_stack+576, dvrr_stack+21, dvrr_stack+138, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+612, dvrr_stack+343, dvrr_stack+591, NULL, NULL, dvrr_stack+148);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+675, dvrr_stack+385, dvrr_stack+612, dvrr_stack+364, dvrr_stack+343, dvrr_stack+163);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+801, dvrr_stack+503, dvrr_stack+385, dvrr_stack+482, dvrr_stack+364, dvrr_stack+208);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+927, dvrr_stack+801, dvrr_stack+675, dvrr_stack+503, dvrr_stack+385, dvrr_stack+253);
 tmp = dvrr_stack + 927;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1137, dvrr_stack+343, dvrr_stack+591, dvrr_stack+80, dvrr_stack+148, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1165, dvrr_stack+364, dvrr_stack+343, dvrr_stack+114, dvrr_stack+80, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1193, dvrr_stack+1165, dvrr_stack+1137, NULL, NULL, dvrr_stack+343);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1277, dvrr_stack+482, dvrr_stack+364, dvrr_stack+467, dvrr_stack+114, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1305, dvrr_stack+1277, dvrr_stack+1165, NULL, NULL, dvrr_stack+364);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+454, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1389, dvrr_stack+95, dvrr_stack+454, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1395, dvrr_stack+448, dvrr_stack+1389, dvrr_stack+129, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1405, dvrr_stack+566, dvrr_stack+1395, dvrr_stack+132, dvrr_stack+448, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1420, dvrr_stack+576, dvrr_stack+1405, dvrr_stack+138, dvrr_stack+566, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1441, dvrr_stack+591, dvrr_stack+1420, dvrr_stack+148, dvrr_stack+576, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1469, dvrr_stack+1137, dvrr_stack+1441, NULL, NULL, dvrr_stack+591);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1553, dvrr_stack+1193, dvrr_stack+1469, dvrr_stack+1165, dvrr_stack+1137, dvrr_stack+612);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1721, dvrr_stack+1305, dvrr_stack+1193, dvrr_stack+1277, dvrr_stack+1165, dvrr_stack+385);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1889, dvrr_stack+1721, dvrr_stack+1553, dvrr_stack+1305, dvrr_stack+1193, dvrr_stack+675);
 tmp = dvrr_stack + 1889;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+2169,dvrr_stack+1889,dvrr_stack+927,10);


 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+1137, dvrr_stack+1441, dvrr_stack+343, dvrr_stack+591, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2835, dvrr_stack+1165, dvrr_stack+1137, dvrr_stack+364, dvrr_stack+343, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2871, dvrr_stack+2835, dvrr_stack+2799, NULL, NULL, dvrr_stack+1137);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2979, dvrr_stack+1277, dvrr_stack+1165, dvrr_stack+482, dvrr_stack+364, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3015, dvrr_stack+2979, dvrr_stack+2835, NULL, NULL, dvrr_stack+1165);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+364, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+367, dvrr_stack+454, dvrr_stack+364, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+373, dvrr_stack+1389, dvrr_stack+367, dvrr_stack+95, dvrr_stack+454, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+482, dvrr_stack+1395, dvrr_stack+373, dvrr_stack+448, dvrr_stack+1389, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3123, dvrr_stack+1405, dvrr_stack+482, dvrr_stack+566, dvrr_stack+1395, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3144, dvrr_stack+1420, dvrr_stack+3123, dvrr_stack+576, dvrr_stack+1405, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3172, dvrr_stack+1441, dvrr_stack+3144, dvrr_stack+591, dvrr_stack+1420, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3208, dvrr_stack+2799, dvrr_stack+3172, NULL, NULL, dvrr_stack+1441);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3316, dvrr_stack+2871, dvrr_stack+3208, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+1469);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3532, dvrr_stack+3015, dvrr_stack+2871, dvrr_stack+2979, dvrr_stack+2835, dvrr_stack+1193);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3748, dvrr_stack+3532, dvrr_stack+3316, dvrr_stack+3015, dvrr_stack+2871, dvrr_stack+1553);
 tmp = dvrr_stack + 3748;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+4108,dvrr_stack+3748,dvrr_stack+1889,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+4948,dvrr_stack+4108,dvrr_stack+2169,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+6208, dvrr_stack+4948, dvrr_stack+927);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6838, dvrr_stack+2799, dvrr_stack+3172, dvrr_stack+1137, dvrr_stack+1441, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6883, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+1165, dvrr_stack+1137, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6928, dvrr_stack+6883, dvrr_stack+6838, NULL, NULL, dvrr_stack+2799);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7063, dvrr_stack+2979, dvrr_stack+2835, dvrr_stack+1277, dvrr_stack+1165, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7108, dvrr_stack+7063, dvrr_stack+6883, NULL, NULL, dvrr_stack+2835);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+497, dvrr_stack+364, dvrr_stack+95, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1165, dvrr_stack+367, dvrr_stack+497, dvrr_stack+454, dvrr_stack+364, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1175, dvrr_stack+373, dvrr_stack+1165, dvrr_stack+1389, dvrr_stack+367, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1277, dvrr_stack+482, dvrr_stack+1175, dvrr_stack+1395, dvrr_stack+373, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7243, dvrr_stack+3123, dvrr_stack+1277, dvrr_stack+1405, dvrr_stack+482, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7271, dvrr_stack+3144, dvrr_stack+7243, dvrr_stack+1420, dvrr_stack+3123, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7307, dvrr_stack+3172, dvrr_stack+7271, dvrr_stack+1441, dvrr_stack+3144, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7352, dvrr_stack+6838, dvrr_stack+7307, NULL, NULL, dvrr_stack+3172);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7487, dvrr_stack+6928, dvrr_stack+7352, dvrr_stack+6883, dvrr_stack+6838, dvrr_stack+3208);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7757, dvrr_stack+7108, dvrr_stack+6928, dvrr_stack+7063, dvrr_stack+6883, dvrr_stack+2871);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8027, dvrr_stack+7757, dvrr_stack+7487, dvrr_stack+7108, dvrr_stack+6928, dvrr_stack+3316);
 tmp = dvrr_stack + 8027;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+8477,dvrr_stack+8027,dvrr_stack+3748,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+9557,dvrr_stack+8477,dvrr_stack+4108,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+11237, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+6838, dvrr_stack+7307, dvrr_stack+2799, dvrr_stack+3172, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12132, dvrr_stack+6883, dvrr_stack+6838, dvrr_stack+2835, dvrr_stack+2799, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12187, dvrr_stack+12132, dvrr_stack+12077, NULL, NULL, dvrr_stack+6838);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12352, dvrr_stack+7063, dvrr_stack+6883, dvrr_stack+2979, dvrr_stack+2835, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12407, dvrr_stack+12352, dvrr_stack+12132, NULL, NULL, dvrr_stack+6883);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+454, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1389, dvrr_stack+95, dvrr_stack+454, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2835, dvrr_stack+497, dvrr_stack+1389, dvrr_stack+364, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2845, dvrr_stack+1165, dvrr_stack+2835, dvrr_stack+367, dvrr_stack+497, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2979, dvrr_stack+1175, dvrr_stack+2845, dvrr_stack+373, dvrr_stack+1165, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12572, dvrr_stack+1277, dvrr_stack+2979, dvrr_stack+482, dvrr_stack+1175, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12600, dvrr_stack+7243, dvrr_stack+12572, dvrr_stack+3123, dvrr_stack+1277, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12636, dvrr_stack+7271, dvrr_stack+12600, dvrr_stack+3144, dvrr_stack+7243, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12681, dvrr_stack+7307, dvrr_stack+12636, dvrr_stack+3172, dvrr_stack+7271, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12736, dvrr_stack+12077, dvrr_stack+12681, NULL, NULL, dvrr_stack+7307);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12901, dvrr_stack+12187, dvrr_stack+12736, dvrr_stack+12132, dvrr_stack+12077, dvrr_stack+7352);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13231, dvrr_stack+12407, dvrr_stack+12187, dvrr_stack+12352, dvrr_stack+12132, dvrr_stack+6928);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13561, dvrr_stack+13231, dvrr_stack+12901, dvrr_stack+12407, dvrr_stack+12187, dvrr_stack+7487);
 tmp = dvrr_stack + 13561;
 target_ptr = Libderiv->dvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+14111,dvrr_stack+13561,dvrr_stack+8027,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+15461,dvrr_stack+14111,dvrr_stack+8477,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+17621, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18701, dvrr_stack+12077, dvrr_stack+12681, dvrr_stack+6838, dvrr_stack+7307, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18767, dvrr_stack+12132, dvrr_stack+12077, dvrr_stack+6883, dvrr_stack+6838, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18833, dvrr_stack+18767, dvrr_stack+18701, NULL, NULL, dvrr_stack+12077);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19031, dvrr_stack+12352, dvrr_stack+12132, dvrr_stack+7063, dvrr_stack+6883, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19097, dvrr_stack+19031, dvrr_stack+18767, NULL, NULL, dvrr_stack+12132);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1190, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6883, dvrr_stack+454, dvrr_stack+1190, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6889, dvrr_stack+1389, dvrr_stack+6883, dvrr_stack+95, dvrr_stack+454, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3000, dvrr_stack+2835, dvrr_stack+6889, dvrr_stack+497, dvrr_stack+1389, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+364, dvrr_stack+2845, dvrr_stack+3000, dvrr_stack+1165, dvrr_stack+2835, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6899, dvrr_stack+2979, dvrr_stack+364, dvrr_stack+1175, dvrr_stack+2845, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7063, dvrr_stack+12572, dvrr_stack+6899, dvrr_stack+1277, dvrr_stack+2979, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19295, dvrr_stack+12600, dvrr_stack+7063, dvrr_stack+7243, dvrr_stack+12572, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19340, dvrr_stack+12636, dvrr_stack+19295, dvrr_stack+7271, dvrr_stack+12600, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+12681, dvrr_stack+19340, dvrr_stack+7307, dvrr_stack+12636, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19461, dvrr_stack+18701, dvrr_stack+19395, NULL, NULL, dvrr_stack+12681);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19659, dvrr_stack+18833, dvrr_stack+19461, dvrr_stack+18767, dvrr_stack+18701, dvrr_stack+12736);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20055, dvrr_stack+19097, dvrr_stack+18833, dvrr_stack+19031, dvrr_stack+18767, dvrr_stack+12187);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20451, dvrr_stack+20055, dvrr_stack+19659, dvrr_stack+19097, dvrr_stack+18833, dvrr_stack+12901);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+21111,dvrr_stack+20451,dvrr_stack+13561,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+22761,dvrr_stack+21111,dvrr_stack+14111,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+25461, dvrr_stack+22761, dvrr_stack+8027);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19097, dvrr_stack+18701, dvrr_stack+19395, dvrr_stack+12077, dvrr_stack+12681, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19175, dvrr_stack+18767, dvrr_stack+18701, dvrr_stack+12132, dvrr_stack+12077, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+26811, dvrr_stack+19175, dvrr_stack+19097, NULL, NULL, dvrr_stack+18701);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27045, dvrr_stack+19031, dvrr_stack+18767, dvrr_stack+12352, dvrr_stack+12132, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27123, dvrr_stack+27045, dvrr_stack+19175, NULL, NULL, dvrr_stack+18767);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+497, dvrr_stack+1190, dvrr_stack+95, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18767, dvrr_stack+6883, dvrr_stack+497, dvrr_stack+454, dvrr_stack+1190, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18777, dvrr_stack+6889, dvrr_stack+18767, dvrr_stack+1389, dvrr_stack+6883, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18792, dvrr_stack+3000, dvrr_stack+18777, dvrr_stack+2835, dvrr_stack+6889, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12132, dvrr_stack+364, dvrr_stack+18792, dvrr_stack+2845, dvrr_stack+3000, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2835, dvrr_stack+6899, dvrr_stack+12132, dvrr_stack+2979, dvrr_stack+364, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12352, dvrr_stack+7063, dvrr_stack+2835, dvrr_stack+12572, dvrr_stack+6899, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19031, dvrr_stack+19295, dvrr_stack+12352, dvrr_stack+12600, dvrr_stack+7063, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27357, dvrr_stack+19340, dvrr_stack+19031, dvrr_stack+12636, dvrr_stack+19295, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27423, dvrr_stack+19395, dvrr_stack+27357, dvrr_stack+12681, dvrr_stack+19340, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27501, dvrr_stack+19097, dvrr_stack+27423, NULL, NULL, dvrr_stack+19395);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27735, dvrr_stack+26811, dvrr_stack+27501, dvrr_stack+19175, dvrr_stack+19097, dvrr_stack+19461);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28203, dvrr_stack+27123, dvrr_stack+26811, dvrr_stack+27045, dvrr_stack+19175, dvrr_stack+18833);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28671, dvrr_stack+28203, dvrr_stack+27735, dvrr_stack+27123, dvrr_stack+26811, dvrr_stack+19659);

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+29451,dvrr_stack+28671,dvrr_stack+20451,10);


 /* compute (3 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+31431,dvrr_stack+29451,dvrr_stack+21111,10);


 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,550,dvrr_stack+34731, dvrr_stack+31431, dvrr_stack+13561);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+19175, dvrr_stack+6, dvrr_stack+15, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+19193, dvrr_stack+21, dvrr_stack+138, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+19223, dvrr_stack+50, dvrr_stack+19193, dvrr_stack+40, dvrr_stack+21, dvrr_stack+19175);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+27045, dvrr_stack+148, dvrr_stack+576, NULL, NULL, dvrr_stack+138);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+27090, dvrr_stack+163, dvrr_stack+27045, dvrr_stack+80, dvrr_stack+148, dvrr_stack+19193);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+27180, dvrr_stack+253, dvrr_stack+27090, dvrr_stack+208, dvrr_stack+163, dvrr_stack+19223);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+36381, dvrr_stack+591, dvrr_stack+1420, NULL, NULL, dvrr_stack+576);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+36444, dvrr_stack+612, dvrr_stack+36381, dvrr_stack+343, dvrr_stack+591, dvrr_stack+27045);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+36570, dvrr_stack+675, dvrr_stack+36444, dvrr_stack+385, dvrr_stack+612, dvrr_stack+27090);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+36780, dvrr_stack+927, dvrr_stack+36570, dvrr_stack+801, dvrr_stack+675, dvrr_stack+27180);
 tmp = dvrr_stack + 36780;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+37095, dvrr_stack+1441, dvrr_stack+3144, NULL, NULL, dvrr_stack+1420);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+37179, dvrr_stack+1469, dvrr_stack+37095, dvrr_stack+1137, dvrr_stack+1441, dvrr_stack+36381);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+37347, dvrr_stack+1553, dvrr_stack+37179, dvrr_stack+1193, dvrr_stack+1469, dvrr_stack+36444);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+37627, dvrr_stack+1889, dvrr_stack+37347, dvrr_stack+1721, dvrr_stack+1553, dvrr_stack+36570);
 tmp = dvrr_stack + 37627;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+38047,dvrr_stack+37627,dvrr_stack+36780,15);


 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+38992, dvrr_stack+3172, dvrr_stack+7271, NULL, NULL, dvrr_stack+3144);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39100, dvrr_stack+3208, dvrr_stack+38992, dvrr_stack+2799, dvrr_stack+3172, dvrr_stack+37095);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39316, dvrr_stack+3316, dvrr_stack+39100, dvrr_stack+2871, dvrr_stack+3208, dvrr_stack+37179);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39676, dvrr_stack+3748, dvrr_stack+39316, dvrr_stack+3532, dvrr_stack+3316, dvrr_stack+37347);
 tmp = dvrr_stack + 39676;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+40216,dvrr_stack+39676,dvrr_stack+37627,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+41476,dvrr_stack+40216,dvrr_stack+38047,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+43366, dvrr_stack+41476, dvrr_stack+36780);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44311, dvrr_stack+7307, dvrr_stack+12636, NULL, NULL, dvrr_stack+7271);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44446, dvrr_stack+7352, dvrr_stack+44311, dvrr_stack+6838, dvrr_stack+7307, dvrr_stack+38992);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44716, dvrr_stack+7487, dvrr_stack+44446, dvrr_stack+6928, dvrr_stack+7352, dvrr_stack+39100);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+45166, dvrr_stack+8027, dvrr_stack+44716, dvrr_stack+7757, dvrr_stack+7487, dvrr_stack+39316);
 tmp = dvrr_stack + 45166;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+45841,dvrr_stack+45166,dvrr_stack+39676,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+47461,dvrr_stack+45841,dvrr_stack+40216,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+49981, dvrr_stack+47461, dvrr_stack+37627);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+51241, dvrr_stack+12681, dvrr_stack+19340, NULL, NULL, dvrr_stack+12636);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+51406, dvrr_stack+12736, dvrr_stack+51241, dvrr_stack+12077, dvrr_stack+12681, dvrr_stack+44311);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+51736, dvrr_stack+12901, dvrr_stack+51406, dvrr_stack+12187, dvrr_stack+12736, dvrr_stack+44446);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52286, dvrr_stack+13561, dvrr_stack+51736, dvrr_stack+13231, dvrr_stack+12901, dvrr_stack+44716);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+53111,dvrr_stack+52286,dvrr_stack+45166,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+55136,dvrr_stack+53111,dvrr_stack+45841,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+58376, dvrr_stack+55136, dvrr_stack+39676);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+59996, dvrr_stack+19395, dvrr_stack+27357, NULL, NULL, dvrr_stack+19340);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+60194, dvrr_stack+19461, dvrr_stack+59996, dvrr_stack+18701, dvrr_stack+19395, dvrr_stack+51241);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+60590, dvrr_stack+19659, dvrr_stack+60194, dvrr_stack+18833, dvrr_stack+19461, dvrr_stack+51406);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+61250, dvrr_stack+20451, dvrr_stack+60590, dvrr_stack+20055, dvrr_stack+19659, dvrr_stack+51736);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+62240,dvrr_stack+61250,dvrr_stack+52286,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+64715,dvrr_stack+62240,dvrr_stack+53111,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+68765, dvrr_stack+64715, dvrr_stack+45166);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+454, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1389, dvrr_stack+95, dvrr_stack+454, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+12397, dvrr_stack+497, dvrr_stack+1389, dvrr_stack+1190, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18701, dvrr_stack+18767, dvrr_stack+12397, dvrr_stack+6883, dvrr_stack+497, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+343, dvrr_stack+18777, dvrr_stack+18701, dvrr_stack+6889, dvrr_stack+18767, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+18701, dvrr_stack+18792, dvrr_stack+343, dvrr_stack+3000, dvrr_stack+18777, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+12132, dvrr_stack+18701, dvrr_stack+364, dvrr_stack+18792, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18701, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+6899, dvrr_stack+12132, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18746, dvrr_stack+12352, dvrr_stack+18701, dvrr_stack+7063, dvrr_stack+2835, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+19031, dvrr_stack+18746, dvrr_stack+19295, dvrr_stack+12352, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+2865, dvrr_stack+27357, dvrr_stack+2799, dvrr_stack+19340, dvrr_stack+19031, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+27423, dvrr_stack+2865, NULL, NULL, dvrr_stack+27357);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70790, dvrr_stack+27501, dvrr_stack+12077, dvrr_stack+19097, dvrr_stack+27423, dvrr_stack+59996);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+71258, dvrr_stack+27735, dvrr_stack+70790, dvrr_stack+26811, dvrr_stack+27501, dvrr_stack+60194);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+72038, dvrr_stack+28671, dvrr_stack+71258, dvrr_stack+28203, dvrr_stack+27735, dvrr_stack+60590);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+73208,dvrr_stack+72038,dvrr_stack+61250,15);


 /* compute (4 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+76178,dvrr_stack+73208,dvrr_stack+62240,15);


 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,825,dvrr_stack+81128, dvrr_stack+76178, dvrr_stack+52286);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+70790, dvrr_stack+4948, dvrr_stack+927);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+27423, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+83603, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+84683, dvrr_stack+22761, dvrr_stack+8027);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,550,dvrr_stack+86033, dvrr_stack+31431, dvrr_stack+13561);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+87683, dvrr_stack+41476, dvrr_stack+36780);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+88628, dvrr_stack+47461, dvrr_stack+37627);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+89888, dvrr_stack+55136, dvrr_stack+39676);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+91508, dvrr_stack+64715, dvrr_stack+45166);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,825,dvrr_stack+93533, dvrr_stack+76178, dvrr_stack+52286);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+96008, dvrr_stack+4948, dvrr_stack+927);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+4948, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+9557, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+15461, dvrr_stack+22761, dvrr_stack+8027);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,550,dvrr_stack+22761, dvrr_stack+31431, dvrr_stack+13561);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+31431, dvrr_stack+41476, dvrr_stack+36780);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+41476, dvrr_stack+47461, dvrr_stack+37627);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+47461, dvrr_stack+55136, dvrr_stack+39676);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+55136, dvrr_stack+64715, dvrr_stack+45166);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,825,dvrr_stack+64715, dvrr_stack+76178, dvrr_stack+52286);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+80, dvrr_stack+34, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+76178, dvrr_stack+104, dvrr_stack+40, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+76208, dvrr_stack+76178, dvrr_stack+50, dvrr_stack+104, dvrr_stack+40, dvrr_stack+80);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+18701, dvrr_stack+467, dvrr_stack+114, NULL, NULL, dvrr_stack+104);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+76268, dvrr_stack+18701, dvrr_stack+208, dvrr_stack+467, dvrr_stack+114, dvrr_stack+76178);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+2865, dvrr_stack+76268, dvrr_stack+253, dvrr_stack+18701, dvrr_stack+208, dvrr_stack+76208);

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+76358,dvrr_stack+927,dvrr_stack+2865,10);


 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+76808, dvrr_stack+76358, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+76958, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 76958;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+77238, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 77238;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+77448, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 77448;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+77808, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 77808;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+78258, dvrr_stack+21111, NULL);
 tmp = dvrr_stack + 78258;
 target_ptr = Libderiv->deriv_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+78808, dvrr_stack+29451, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+7099, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+4);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+208, dvrr_stack+80, dvrr_stack+19175, dvrr_stack+34, dvrr_stack+6, dvrr_stack+7099);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+79468, dvrr_stack+76208, dvrr_stack+19223, dvrr_stack+76178, dvrr_stack+50, dvrr_stack+208);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+6838, dvrr_stack+2865, dvrr_stack+27180, dvrr_stack+76268, dvrr_stack+253, dvrr_stack+79468);

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+79568,dvrr_stack+36780,dvrr_stack+6838,15);


 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+80243, dvrr_stack+79568, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+5788, dvrr_stack+40216, NULL);
 tmp = dvrr_stack + 5788;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+80468, dvrr_stack+38047, NULL);
 tmp = dvrr_stack + 80468;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+67190, dvrr_stack+45841, NULL);
 tmp = dvrr_stack + 67190;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+67730, dvrr_stack+53111, NULL);
 tmp = dvrr_stack + 67730;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+57161, dvrr_stack+62240, NULL);
 tmp = dvrr_stack + 57161;
 target_ptr = Libderiv->deriv_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+32376, dvrr_stack+73208, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+80783, dvrr_stack+76358, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+68405, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 68405;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+57986, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 57986;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+49081, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 49081;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+49441, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 49441;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+42736, dvrr_stack+21111, NULL);
 tmp = dvrr_stack + 42736;
 target_ptr = Libderiv->deriv_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+33366, dvrr_stack+29451, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+34026, dvrr_stack+79568, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+34251, dvrr_stack+40216, NULL);
 tmp = dvrr_stack + 34251;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+24411, dvrr_stack+38047, NULL);
 tmp = dvrr_stack + 24411;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+24726, dvrr_stack+45841, NULL);
 tmp = dvrr_stack + 24726;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+16811, dvrr_stack+53111, NULL);
 tmp = dvrr_stack + 16811;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+96638, dvrr_stack+62240, NULL);
 tmp = dvrr_stack + 96638;
 target_ptr = Libderiv->deriv_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+97463, dvrr_stack+73208, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+80933, dvrr_stack+76358, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+76358, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 76358;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+4108, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 4108;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+2169, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 2169;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+8477, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 8477;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+14111, dvrr_stack+21111, NULL);
 tmp = dvrr_stack + 14111;
 target_ptr = Libderiv->deriv_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+21111, dvrr_stack+29451, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+29451, dvrr_stack+79568, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+79568, dvrr_stack+40216, NULL);
 tmp = dvrr_stack + 79568;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+40216, dvrr_stack+38047, NULL);
 tmp = dvrr_stack + 40216;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+38047, dvrr_stack+45841, NULL);
 tmp = dvrr_stack + 38047;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+45841, dvrr_stack+53111, NULL);
 tmp = dvrr_stack + 45841;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+53111, dvrr_stack+62240, NULL);
 tmp = dvrr_stack + 53111;
 target_ptr = Libderiv->deriv_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+21771, dvrr_stack+73208, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+244, dvrr_stack+31, dvrr_stack+3, NULL, NULL, Data->F+3);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+73208, dvrr_stack+98, dvrr_stack+34, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+73226, dvrr_stack+73208, dvrr_stack+80, dvrr_stack+98, dvrr_stack+34, dvrr_stack+244);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+73262, dvrr_stack+457, dvrr_stack+104, NULL, NULL, dvrr_stack+98);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+34671, dvrr_stack+73262, dvrr_stack+76178, dvrr_stack+457, dvrr_stack+104, dvrr_stack+73208);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+73292, dvrr_stack+34671, dvrr_stack+76208, dvrr_stack+73262, dvrr_stack+76178, dvrr_stack+73226);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+73392, dvrr_stack+927, dvrr_stack+73292);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+73542, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 73542;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+73822, dvrr_stack+1889, dvrr_stack+2865);
 tmp = dvrr_stack + 73822;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+74032, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 74032;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+74392, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 74392;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+74842, dvrr_stack+20451, dvrr_stack+8027);
 tmp = dvrr_stack + 74842;
 target_ptr = Libderiv->deriv_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+75392, dvrr_stack+28671, dvrr_stack+13561);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+73262, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+73265, dvrr_stack+244, dvrr_stack+7099, dvrr_stack+31, dvrr_stack+3, dvrr_stack+73262);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+76052, dvrr_stack+73226, dvrr_stack+208, dvrr_stack+73208, dvrr_stack+80, dvrr_stack+73265);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+62240, dvrr_stack+73292, dvrr_stack+79468, dvrr_stack+34671, dvrr_stack+76208, dvrr_stack+76052);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+62390, dvrr_stack+36780, dvrr_stack+62240);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+62615, dvrr_stack+39676, dvrr_stack+36780);
 tmp = dvrr_stack + 62615;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+63035, dvrr_stack+37627, dvrr_stack+6838);
 tmp = dvrr_stack + 63035;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+63350, dvrr_stack+45166, dvrr_stack+37627);
 tmp = dvrr_stack + 63350;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+63890, dvrr_stack+52286, dvrr_stack+39676);
 tmp = dvrr_stack + 63890;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+53936, dvrr_stack+61250, dvrr_stack+45166);
 tmp = dvrr_stack + 53936;
 target_ptr = Libderiv->deriv_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+29676, dvrr_stack+72038, dvrr_stack+52286);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+64565, dvrr_stack+927, dvrr_stack+73292);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+54761, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 54761;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+46516, dvrr_stack+1889, dvrr_stack+2865);
 tmp = dvrr_stack + 46516;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+46726, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 46726;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+40531, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 40531;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+30666, dvrr_stack+20451, dvrr_stack+8027);
 tmp = dvrr_stack + 30666;
 target_ptr = Libderiv->deriv_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+14661, dvrr_stack+28671, dvrr_stack+13561);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+47086, dvrr_stack+36780, dvrr_stack+62240);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+40981, dvrr_stack+39676, dvrr_stack+36780);
 tmp = dvrr_stack + 40981;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+38587, dvrr_stack+37627, dvrr_stack+6838);
 tmp = dvrr_stack + 38587;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+8927, dvrr_stack+45166, dvrr_stack+37627);
 tmp = dvrr_stack + 8927;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+98453, dvrr_stack+52286, dvrr_stack+39676);
 tmp = dvrr_stack + 98453;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+99128, dvrr_stack+61250, dvrr_stack+45166);
 tmp = dvrr_stack + 99128;
 target_ptr = Libderiv->deriv_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+99953, dvrr_stack+72038, dvrr_stack+52286);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+47311, dvrr_stack+927, dvrr_stack+73292);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+4318, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 4318;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+79988, dvrr_stack+1889, dvrr_stack+2865);
 tmp = dvrr_stack + 79988;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+10637, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 10637;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+71420, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 71420;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+100943, dvrr_stack+20451, dvrr_stack+8027);
 tmp = dvrr_stack + 100943;
 target_ptr = Libderiv->deriv_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+101493, dvrr_stack+28671, dvrr_stack+13561);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+2529, dvrr_stack+36780, dvrr_stack+62240);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+28263, dvrr_stack+39676, dvrr_stack+36780);
 tmp = dvrr_stack + 28263;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+4598, dvrr_stack+37627, dvrr_stack+6838);
 tmp = dvrr_stack + 4598;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+28683, dvrr_stack+45166, dvrr_stack+37627);
 tmp = dvrr_stack + 28683;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+102153, dvrr_stack+52286, dvrr_stack+39676);
 tmp = dvrr_stack + 102153;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+102828, dvrr_stack+61250, dvrr_stack+45166);
 tmp = dvrr_stack + 102828;
 target_ptr = Libderiv->deriv_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+103653, dvrr_stack+72038, dvrr_stack+52286);

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+71870,dvrr_stack+1721,dvrr_stack+801,6);


 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+62240, dvrr_stack+71870, NULL);

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+72248,dvrr_stack+3532,dvrr_stack+1721,6);


 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+31216, dvrr_stack+72248, NULL);

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+104643,dvrr_stack+7757,dvrr_stack+3532,6);


 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+10997, dvrr_stack+104643, NULL);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+105291,dvrr_stack+13231,dvrr_stack+7757,6);


 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+72752, dvrr_stack+105291, NULL);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+106101,dvrr_stack+20055,dvrr_stack+13231,6);


 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+73022, dvrr_stack+106101, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+244, dvrr_stack+0, dvrr_stack+12, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+62366, dvrr_stack+15, dvrr_stack+132, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+76052, dvrr_stack+19175, dvrr_stack+62366, dvrr_stack+6, dvrr_stack+15, dvrr_stack+244);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+76088, dvrr_stack+138, dvrr_stack+566, NULL, NULL, dvrr_stack+132);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+34671, dvrr_stack+19193, dvrr_stack+76088, dvrr_stack+21, dvrr_stack+138, dvrr_stack+62366);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+15321, dvrr_stack+19223, dvrr_stack+34671, dvrr_stack+50, dvrr_stack+19193, dvrr_stack+76052);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+80198, dvrr_stack+576, dvrr_stack+1405, NULL, NULL, dvrr_stack+566);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+76118, dvrr_stack+27045, dvrr_stack+80198, dvrr_stack+148, dvrr_stack+576, dvrr_stack+76088);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+76638, dvrr_stack+27090, dvrr_stack+76118, dvrr_stack+163, dvrr_stack+27045, dvrr_stack+34671);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+26811, dvrr_stack+27180, dvrr_stack+76638, dvrr_stack+253, dvrr_stack+27090, dvrr_stack+15321);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+253, dvrr_stack+1420, dvrr_stack+3123, NULL, NULL, dvrr_stack+1405);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+316, dvrr_stack+36381, dvrr_stack+253, dvrr_stack+591, dvrr_stack+1420, dvrr_stack+80198);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+29223, dvrr_stack+36444, dvrr_stack+316, dvrr_stack+612, dvrr_stack+36381, dvrr_stack+76118);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+107091, dvrr_stack+36570, dvrr_stack+29223, dvrr_stack+675, dvrr_stack+36444, dvrr_stack+76638);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+107406, dvrr_stack+36780, dvrr_stack+107091, dvrr_stack+927, dvrr_stack+36570, dvrr_stack+26811);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+591, dvrr_stack+3144, dvrr_stack+7243, NULL, NULL, dvrr_stack+3123);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+58196, dvrr_stack+37095, dvrr_stack+591, dvrr_stack+1441, dvrr_stack+3144, dvrr_stack+253);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+107847, dvrr_stack+37179, dvrr_stack+58196, dvrr_stack+1469, dvrr_stack+37095, dvrr_stack+316);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+108127, dvrr_stack+37347, dvrr_stack+107847, dvrr_stack+1553, dvrr_stack+37179, dvrr_stack+29223);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+108547, dvrr_stack+37627, dvrr_stack+108127, dvrr_stack+1889, dvrr_stack+37347, dvrr_stack+107091);

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+109135,dvrr_stack+108547,dvrr_stack+107406,21);


 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+110458, dvrr_stack+109135, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1441, dvrr_stack+7271, dvrr_stack+12600, NULL, NULL, dvrr_stack+7243);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+38992, dvrr_stack+1441, dvrr_stack+3172, dvrr_stack+7271, dvrr_stack+591);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+110899, dvrr_stack+39100, dvrr_stack+12077, dvrr_stack+3208, dvrr_stack+38992, dvrr_stack+58196);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+111259, dvrr_stack+39316, dvrr_stack+110899, dvrr_stack+3316, dvrr_stack+39100, dvrr_stack+107847);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+111799, dvrr_stack+39676, dvrr_stack+111259, dvrr_stack+3748, dvrr_stack+39316, dvrr_stack+108127);

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+112555,dvrr_stack+111799,dvrr_stack+108547,21);


 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+114319, dvrr_stack+112555, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+17486, dvrr_stack+12636, dvrr_stack+19295, NULL, NULL, dvrr_stack+12600);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3172, dvrr_stack+44311, dvrr_stack+17486, dvrr_stack+7307, dvrr_stack+12636, dvrr_stack+1441);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+114907, dvrr_stack+44446, dvrr_stack+3172, dvrr_stack+7352, dvrr_stack+44311, dvrr_stack+12077);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+115357, dvrr_stack+44716, dvrr_stack+114907, dvrr_stack+7487, dvrr_stack+44446, dvrr_stack+110899);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+116032, dvrr_stack+45166, dvrr_stack+115357, dvrr_stack+8027, dvrr_stack+44716, dvrr_stack+111259);

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+116977,dvrr_stack+116032,dvrr_stack+111799,21);


 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+119245, dvrr_stack+116977, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7307, dvrr_stack+19340, dvrr_stack+19031, NULL, NULL, dvrr_stack+19295);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120001, dvrr_stack+51241, dvrr_stack+7307, dvrr_stack+12681, dvrr_stack+19340, dvrr_stack+17486);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120331, dvrr_stack+51406, dvrr_stack+120001, dvrr_stack+12736, dvrr_stack+51241, dvrr_stack+3172);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120881, dvrr_stack+51736, dvrr_stack+120331, dvrr_stack+12901, dvrr_stack+51406, dvrr_stack+114907);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+121706, dvrr_stack+52286, dvrr_stack+120881, dvrr_stack+13561, dvrr_stack+51736, dvrr_stack+115357);

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+122861,dvrr_stack+121706,dvrr_stack+116032,21);


 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+125696, dvrr_stack+122861, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12681, dvrr_stack+27357, dvrr_stack+2799, NULL, NULL, dvrr_stack+19031);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+126641, dvrr_stack+59996, dvrr_stack+12681, dvrr_stack+19395, dvrr_stack+27357, dvrr_stack+7307);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+127037, dvrr_stack+60194, dvrr_stack+126641, dvrr_stack+19461, dvrr_stack+59996, dvrr_stack+120001);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+127697, dvrr_stack+60590, dvrr_stack+127037, dvrr_stack+19659, dvrr_stack+60194, dvrr_stack+120331);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+128687, dvrr_stack+61250, dvrr_stack+127697, dvrr_stack+20451, dvrr_stack+60590, dvrr_stack+120881);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+130073,dvrr_stack+128687,dvrr_stack+121706,21);


 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+59996, dvrr_stack+130073, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+675, dvrr_stack+71870, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+20451, dvrr_stack+72248, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+20619, dvrr_stack+104643, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+20835, dvrr_stack+105291, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+61151, dvrr_stack+106101, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+61481, dvrr_stack+109135, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+126641, dvrr_stack+112555, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+127229, dvrr_stack+116977, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+133538, dvrr_stack+122861, NULL);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+134483, dvrr_stack+130073, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+61922, dvrr_stack+71870, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+71870, dvrr_stack+72248, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+72038, dvrr_stack+104643, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+104643, dvrr_stack+105291, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+104913, dvrr_stack+106101, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+105243, dvrr_stack+109135, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+109135, dvrr_stack+112555, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+112555, dvrr_stack+116977, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+116977, dvrr_stack+122861, NULL);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+122861, dvrr_stack+130073, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+130073, dvrr_stack+1721, dvrr_stack+76268);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+130199, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+130367, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+130583, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+130853, dvrr_stack+20055, dvrr_stack+7757);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+131183, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+29433, dvrr_stack+7099, dvrr_stack+244, dvrr_stack+3, dvrr_stack+0, dvrr_stack+131183);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+148, dvrr_stack+208, dvrr_stack+76052, dvrr_stack+80, dvrr_stack+19175, dvrr_stack+29433);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+131183, dvrr_stack+79468, dvrr_stack+15321, dvrr_stack+76208, dvrr_stack+19223, dvrr_stack+148);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+131333, dvrr_stack+6838, dvrr_stack+26811, dvrr_stack+2865, dvrr_stack+27180, dvrr_stack+131183);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+131648, dvrr_stack+108547, dvrr_stack+131333);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+132089, dvrr_stack+111799, dvrr_stack+107406);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+132677, dvrr_stack+116032, dvrr_stack+108547);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+124016, dvrr_stack+121706, dvrr_stack+111799);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+117922, dvrr_stack+128687, dvrr_stack+116032);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+131183, dvrr_stack+1721, dvrr_stack+76268);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+119077, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+6838, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+124961, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+125231, dvrr_stack+20055, dvrr_stack+7757);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+113311, dvrr_stack+108547, dvrr_stack+131333);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+109723, dvrr_stack+111799, dvrr_stack+107406);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+105684, dvrr_stack+116032, dvrr_stack+108547);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+135638, dvrr_stack+121706, dvrr_stack+111799);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+136583, dvrr_stack+128687, dvrr_stack+116032);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+125561, dvrr_stack+1721, dvrr_stack+76268);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+113752, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+113920, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+106440, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+106710, dvrr_stack+20055, dvrr_stack+7757);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+72254, dvrr_stack+108547, dvrr_stack+131333);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+127985, dvrr_stack+111799, dvrr_stack+107406);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+19395, dvrr_stack+116032, dvrr_stack+108547);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+137738, dvrr_stack+121706, dvrr_stack+111799);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+138683, dvrr_stack+128687, dvrr_stack+116032);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+131309, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+128573, dvrr_stack+107406, dvrr_stack+927);
 tmp = dvrr_stack + 128573;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+131435, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+128888, dvrr_stack+108547, dvrr_stack+1889);
 tmp = dvrr_stack + 128888;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+129308, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+129524, dvrr_stack+111799, dvrr_stack+3748);
 tmp = dvrr_stack + 129524;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+20151, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+139838, dvrr_stack+116032, dvrr_stack+8027);
 tmp = dvrr_stack + 139838;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+12681, dvrr_stack+13561, dvrr_stack+12407);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+140513, dvrr_stack+121706, dvrr_stack+13561);
 tmp = dvrr_stack + 140513;
 target_ptr = Libderiv->deriv_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+13011, dvrr_stack+36780, dvrr_stack+801);
 tmp = dvrr_stack + 13011;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+131603, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+7054, dvrr_stack+12, dvrr_stack+129, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+29433, dvrr_stack+244, dvrr_stack+7054, dvrr_stack+0, dvrr_stack+12, dvrr_stack+131603);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+131603, dvrr_stack+132, dvrr_stack+448, NULL, NULL, dvrr_stack+129);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+148, dvrr_stack+62366, dvrr_stack+131603, dvrr_stack+15, dvrr_stack+132, dvrr_stack+7054);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+0, dvrr_stack+76052, dvrr_stack+148, dvrr_stack+19175, dvrr_stack+62366, dvrr_stack+29433);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+20421, dvrr_stack+566, dvrr_stack+1395, NULL, NULL, dvrr_stack+448);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+60, dvrr_stack+76088, dvrr_stack+20421, dvrr_stack+138, dvrr_stack+566, dvrr_stack+131603);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+79468, dvrr_stack+34671, dvrr_stack+60, dvrr_stack+19193, dvrr_stack+76088, dvrr_stack+148);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+76208, dvrr_stack+15321, dvrr_stack+79468, dvrr_stack+19223, dvrr_stack+34671, dvrr_stack+0);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+131603, dvrr_stack+1405, dvrr_stack+482, NULL, NULL, dvrr_stack+1395);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+3442, dvrr_stack+80198, dvrr_stack+131603, dvrr_stack+576, dvrr_stack+1405, dvrr_stack+20421);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+114136, dvrr_stack+76118, dvrr_stack+3442, dvrr_stack+27045, dvrr_stack+80198, dvrr_stack+60);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+0, dvrr_stack+76638, dvrr_stack+114136, dvrr_stack+27090, dvrr_stack+76118, dvrr_stack+79468);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+141338, dvrr_stack+26811, dvrr_stack+0, dvrr_stack+27180, dvrr_stack+76638, dvrr_stack+76208);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+76638, dvrr_stack+3123, dvrr_stack+1277, NULL, NULL, dvrr_stack+482);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+26811, dvrr_stack+253, dvrr_stack+76638, dvrr_stack+1420, dvrr_stack+3123, dvrr_stack+131603);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+26937, dvrr_stack+316, dvrr_stack+26811, dvrr_stack+36381, dvrr_stack+253, dvrr_stack+3442);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+141653, dvrr_stack+29223, dvrr_stack+26937, dvrr_stack+36444, dvrr_stack+316, dvrr_stack+114136);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+141968, dvrr_stack+107091, dvrr_stack+141653, dvrr_stack+36570, dvrr_stack+29223, dvrr_stack+0);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+142409, dvrr_stack+107406, dvrr_stack+141968, dvrr_stack+36780, dvrr_stack+107091, dvrr_stack+141338);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+0, dvrr_stack+142409, dvrr_stack+36780);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+141338, dvrr_stack+37627, dvrr_stack+1721);
 tmp = dvrr_stack + 141338;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+29223, dvrr_stack+7243, dvrr_stack+12572, NULL, NULL, dvrr_stack+1277);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1137, dvrr_stack+591, dvrr_stack+29223, dvrr_stack+3144, dvrr_stack+7243, dvrr_stack+76638);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+36381, dvrr_stack+58196, dvrr_stack+1137, dvrr_stack+37095, dvrr_stack+591, dvrr_stack+26811);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+142997, dvrr_stack+107847, dvrr_stack+36381, dvrr_stack+37179, dvrr_stack+58196, dvrr_stack+26937);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+26811, dvrr_stack+108127, dvrr_stack+142997, dvrr_stack+37347, dvrr_stack+107847, dvrr_stack+141653);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+143417, dvrr_stack+108547, dvrr_stack+26811, dvrr_stack+37627, dvrr_stack+108127, dvrr_stack+141968);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+107847, dvrr_stack+143417, dvrr_stack+37627);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+37095, dvrr_stack+39676, dvrr_stack+3532);
 tmp = dvrr_stack + 37095;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+108435, dvrr_stack+12600, dvrr_stack+7063, NULL, NULL, dvrr_stack+12572);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+141618, dvrr_stack+1441, dvrr_stack+108435, dvrr_stack+7271, dvrr_stack+12600, dvrr_stack+29223);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+141834, dvrr_stack+12077, dvrr_stack+141618, dvrr_stack+38992, dvrr_stack+1441, dvrr_stack+1137);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+144201, dvrr_stack+110899, dvrr_stack+141834, dvrr_stack+39100, dvrr_stack+12077, dvrr_stack+36381);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+144741, dvrr_stack+111259, dvrr_stack+144201, dvrr_stack+39316, dvrr_stack+110899, dvrr_stack+142997);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+145497, dvrr_stack+111799, dvrr_stack+144741, dvrr_stack+39676, dvrr_stack+111259, dvrr_stack+26811);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+110899, dvrr_stack+145497, dvrr_stack+39676);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+26811, dvrr_stack+45166, dvrr_stack+7757);
 tmp = dvrr_stack + 26811;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+27261, dvrr_stack+19295, dvrr_stack+12352, NULL, NULL, dvrr_stack+7063);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+142997, dvrr_stack+17486, dvrr_stack+27261, dvrr_stack+12636, dvrr_stack+19295, dvrr_stack+108435);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38902, dvrr_stack+3172, dvrr_stack+142997, dvrr_stack+44311, dvrr_stack+17486, dvrr_stack+141618);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+146505, dvrr_stack+114907, dvrr_stack+38902, dvrr_stack+44446, dvrr_stack+3172, dvrr_stack+141834);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+147180, dvrr_stack+115357, dvrr_stack+146505, dvrr_stack+44716, dvrr_stack+114907, dvrr_stack+144201);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+148125, dvrr_stack+116032, dvrr_stack+147180, dvrr_stack+45166, dvrr_stack+115357, dvrr_stack+144741);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+144201, dvrr_stack+148125, dvrr_stack+45166);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+114907, dvrr_stack+52286, dvrr_stack+13231);
 tmp = dvrr_stack + 114907;
 target_ptr = Libderiv->deriv_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+145146, dvrr_stack+19031, dvrr_stack+18746, NULL, NULL, dvrr_stack+12352);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+7307, dvrr_stack+145146, dvrr_stack+19340, dvrr_stack+19031, dvrr_stack+27261);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+115457, dvrr_stack+120001, dvrr_stack+12077, dvrr_stack+51241, dvrr_stack+7307, dvrr_stack+142997);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+44311, dvrr_stack+120331, dvrr_stack+115457, dvrr_stack+51406, dvrr_stack+120001, dvrr_stack+38902);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+149385, dvrr_stack+120881, dvrr_stack+44311, dvrr_stack+51736, dvrr_stack+120331, dvrr_stack+146505);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+150540, dvrr_stack+121706, dvrr_stack+149385, dvrr_stack+52286, dvrr_stack+120881, dvrr_stack+147180);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+149385, dvrr_stack+150540, dvrr_stack+52286);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+146505, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+146631, dvrr_stack+107406, dvrr_stack+927);
 tmp = dvrr_stack + 146631;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+1137, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+142997, dvrr_stack+108547, dvrr_stack+1889);
 tmp = dvrr_stack + 142997;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+146946, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+147162, dvrr_stack+111799, dvrr_stack+3748);
 tmp = dvrr_stack + 147162;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+147702, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+44311, dvrr_stack+116032, dvrr_stack+8027);
 tmp = dvrr_stack + 44311;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+12077, dvrr_stack+13561, dvrr_stack+12407);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+120001, dvrr_stack+121706, dvrr_stack+13561);
 tmp = dvrr_stack + 120001;
 target_ptr = Libderiv->deriv_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+38902, dvrr_stack+36780, dvrr_stack+801);
 tmp = dvrr_stack + 38902;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+39112, dvrr_stack+142409, dvrr_stack+36780);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+120826, dvrr_stack+37627, dvrr_stack+1721);
 tmp = dvrr_stack + 120826;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+121106, dvrr_stack+143417, dvrr_stack+37627);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+115457, dvrr_stack+39676, dvrr_stack+3532);
 tmp = dvrr_stack + 115457;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+51241, dvrr_stack+145497, dvrr_stack+39676);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+141618, dvrr_stack+45166, dvrr_stack+7757);
 tmp = dvrr_stack + 141618;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+152080, dvrr_stack+148125, dvrr_stack+45166);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+18701, dvrr_stack+52286, dvrr_stack+13231);
 tmp = dvrr_stack + 18701;
 target_ptr = Libderiv->deriv_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+153025, dvrr_stack+150540, dvrr_stack+52286);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+147972, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+145146, dvrr_stack+107406, dvrr_stack+927);
 tmp = dvrr_stack + 145146;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+927, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+7243, dvrr_stack+108547, dvrr_stack+1889);
 tmp = dvrr_stack + 7243;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+1889, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+108435, dvrr_stack+111799, dvrr_stack+3748);
 tmp = dvrr_stack + 108435;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+3748, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+111655, dvrr_stack+116032, dvrr_stack+8027);
 tmp = dvrr_stack + 111655;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+8027, dvrr_stack+13561, dvrr_stack+12407);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+115817, dvrr_stack+121706, dvrr_stack+13561);
 tmp = dvrr_stack + 115817;
 target_ptr = Libderiv->deriv_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+13561, dvrr_stack+36780, dvrr_stack+801);
 tmp = dvrr_stack + 13561;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+121694, dvrr_stack+142409, dvrr_stack+36780);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+13771, dvrr_stack+37627, dvrr_stack+1721);
 tmp = dvrr_stack + 13771;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+122135, dvrr_stack+143417, dvrr_stack+37627);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+143417, dvrr_stack+39676, dvrr_stack+3532);
 tmp = dvrr_stack + 143417;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+142068, dvrr_stack+145497, dvrr_stack+39676);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+1305, dvrr_stack+45166, dvrr_stack+7757);
 tmp = dvrr_stack + 1305;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+145461, dvrr_stack+148125, dvrr_stack+45166);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+148098, dvrr_stack+52286, dvrr_stack+13231);
 tmp = dvrr_stack + 148098;
 target_ptr = Libderiv->deriv_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+154180, dvrr_stack+150540, dvrr_stack+52286);

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+150540, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 150540;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+150750, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 150750;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+151030, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 151030;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+151390, dvrr_stack+25461, NULL);
 tmp = dvrr_stack + 151390;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,550,dvrr_stack+148648, dvrr_stack+34731, NULL);
 tmp = dvrr_stack + 148648;
 target_ptr = Libderiv->deriv2_classes[3][9][143];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+143777, dvrr_stack+43366, NULL);
 tmp = dvrr_stack + 143777;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+44986, dvrr_stack+49981, NULL);
 tmp = dvrr_stack + 44986;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+39553, dvrr_stack+58376, NULL);
 tmp = dvrr_stack + 39553;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+51997, dvrr_stack+68765, NULL);
 tmp = dvrr_stack + 51997;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,825,dvrr_stack+2754, dvrr_stack+81128, NULL);
 tmp = dvrr_stack + 2754;
 target_ptr = Libderiv->deriv2_classes[4][9][143];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+151840, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 151840;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+45406, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 45406;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+52672, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 52672;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+36381, dvrr_stack+25461, NULL);
 tmp = dvrr_stack + 36381;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,550,dvrr_stack+37455, dvrr_stack+34731, NULL);
 tmp = dvrr_stack + 37455;
 target_ptr = Libderiv->deriv2_classes[3][9][131];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+116642, dvrr_stack+43366, NULL);
 tmp = dvrr_stack + 116642;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+107040, dvrr_stack+49981, NULL);
 tmp = dvrr_stack + 107040;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+155335, dvrr_stack+58376, NULL);
 tmp = dvrr_stack + 155335;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+155875, dvrr_stack+68765, NULL);
 tmp = dvrr_stack + 155875;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,825,dvrr_stack+156550, dvrr_stack+81128, NULL);
 tmp = dvrr_stack + 156550;
 target_ptr = Libderiv->deriv2_classes[4][9][131];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+12407, dvrr_stack+70790, NULL);
 tmp = dvrr_stack + 12407;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+7663, dvrr_stack+27423, NULL);
 tmp = dvrr_stack + 7663;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+107460, dvrr_stack+83603, NULL);
 tmp = dvrr_stack + 107460;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+157375, dvrr_stack+84683, NULL);
 tmp = dvrr_stack + 157375;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+157825, dvrr_stack+86033, NULL);
 tmp = dvrr_stack + 157825;
 target_ptr = Libderiv->deriv2_classes[3][9][130];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+13221, dvrr_stack+87683, NULL);
 tmp = dvrr_stack + 13221;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+158375, dvrr_stack+88628, NULL);
 tmp = dvrr_stack + 158375;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+158795, dvrr_stack+89888, NULL);
 tmp = dvrr_stack + 158795;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+159335, dvrr_stack+91508, NULL);
 tmp = dvrr_stack + 159335;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+160010, dvrr_stack+93533, NULL);
 tmp = dvrr_stack + 160010;
 target_ptr = Libderiv->deriv2_classes[4][9][130];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+112330, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 112330;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+6208, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 6208;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+11213, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 11213;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+17486, dvrr_stack+25461, NULL);
 tmp = dvrr_stack + 17486;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,550,dvrr_stack+17936, dvrr_stack+34731, NULL);
 tmp = dvrr_stack + 17936;
 target_ptr = Libderiv->deriv2_classes[3][9][119];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+6488, dvrr_stack+43366, NULL);
 tmp = dvrr_stack + 6488;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+34671, dvrr_stack+49981, NULL);
 tmp = dvrr_stack + 34671;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+35091, dvrr_stack+58376, NULL);
 tmp = dvrr_stack + 35091;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+58196, dvrr_stack+68765, NULL);
 tmp = dvrr_stack + 58196;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,825,dvrr_stack+58871, dvrr_stack+81128, NULL);
 tmp = dvrr_stack + 58871;
 target_ptr = Libderiv->deriv2_classes[4][9][119];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+18486, dvrr_stack+70790, NULL);
 tmp = dvrr_stack + 18486;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+59696, dvrr_stack+27423, NULL);
 tmp = dvrr_stack + 59696;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+27261, dvrr_stack+83603, NULL);
 tmp = dvrr_stack + 27261;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+27621, dvrr_stack+84683, NULL);
 tmp = dvrr_stack + 27621;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+35631, dvrr_stack+86033, NULL);
 tmp = dvrr_stack + 35631;
 target_ptr = Libderiv->deriv2_classes[3][9][118];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+81083, dvrr_stack+87683, NULL);
 tmp = dvrr_stack + 81083;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+81398, dvrr_stack+88628, NULL);
 tmp = dvrr_stack + 81398;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+81818, dvrr_stack+89888, NULL);
 tmp = dvrr_stack + 81818;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+82358, dvrr_stack+91508, NULL);
 tmp = dvrr_stack + 82358;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+83033, dvrr_stack+93533, NULL);
 tmp = dvrr_stack + 83033;
 target_ptr = Libderiv->deriv2_classes[4][9][118];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+36831, dvrr_stack+96008, NULL);
 tmp = dvrr_stack + 36831;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+76052, dvrr_stack+4948, NULL);
 tmp = dvrr_stack + 76052;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+4913, dvrr_stack+9557, NULL);
 tmp = dvrr_stack + 4913;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+9467, dvrr_stack+15461, NULL);
 tmp = dvrr_stack + 9467;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+15321, dvrr_stack+22761, NULL);
 tmp = dvrr_stack + 15321;
 target_ptr = Libderiv->deriv2_classes[3][9][117];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+22761, dvrr_stack+31431, NULL);
 tmp = dvrr_stack + 22761;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+23076, dvrr_stack+41476, NULL);
 tmp = dvrr_stack + 23076;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+23496, dvrr_stack+47461, NULL);
 tmp = dvrr_stack + 23496;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+47461, dvrr_stack+55136, NULL);
 tmp = dvrr_stack + 47461;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+48136, dvrr_stack+64715, NULL);
 tmp = dvrr_stack + 48136;
 target_ptr = Libderiv->deriv2_classes[4][9][117];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+64715, dvrr_stack+76958, dvrr_stack+76808);
 tmp = dvrr_stack + 64715;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+64925, dvrr_stack+77448, dvrr_stack+77238);
 tmp = dvrr_stack + 64925;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+65205, dvrr_stack+77808, dvrr_stack+76958);
 tmp = dvrr_stack + 65205;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+65565, dvrr_stack+78258, dvrr_stack+77448);
 tmp = dvrr_stack + 65565;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+66015, dvrr_stack+78808, dvrr_stack+77808);
 tmp = dvrr_stack + 66015;
 target_ptr = Libderiv->deriv2_classes[3][9][107];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+66565, dvrr_stack+5788, dvrr_stack+80243);
 tmp = dvrr_stack + 66565;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+15871, dvrr_stack+67190, dvrr_stack+80468);
 tmp = dvrr_stack + 15871;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+55041, dvrr_stack+67730, dvrr_stack+5788);
 tmp = dvrr_stack + 55041;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+55581, dvrr_stack+57161, dvrr_stack+67190);
 tmp = dvrr_stack + 55581;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+56256, dvrr_stack+32376, dvrr_stack+67730);
 tmp = dvrr_stack + 56256;
 target_ptr = Libderiv->deriv2_classes[4][9][107];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+66880, dvrr_stack+68405, dvrr_stack+80783);
 tmp = dvrr_stack + 66880;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+24036, dvrr_stack+49081, dvrr_stack+57986);
 tmp = dvrr_stack + 24036;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+16291, dvrr_stack+49441, dvrr_stack+68405);
 tmp = dvrr_stack + 16291;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+41401, dvrr_stack+42736, dvrr_stack+49081);
 tmp = dvrr_stack + 41401;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+41851, dvrr_stack+33366, dvrr_stack+49441);
 tmp = dvrr_stack + 41851;
 target_ptr = Libderiv->deriv2_classes[3][9][106];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+42401, dvrr_stack+34251, dvrr_stack+34026);
 tmp = dvrr_stack + 42401;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+31384, dvrr_stack+24726, dvrr_stack+24411);
 tmp = dvrr_stack + 31384;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+31804, dvrr_stack+16811, dvrr_stack+34251);
 tmp = dvrr_stack + 31804;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+9917, dvrr_stack+96638, dvrr_stack+24726);
 tmp = dvrr_stack + 9917;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+83858, dvrr_stack+97463, dvrr_stack+16811);
 tmp = dvrr_stack + 83858;
 target_ptr = Libderiv->deriv2_classes[4][9][106];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+29223, dvrr_stack+76358, dvrr_stack+80933);
 tmp = dvrr_stack + 29223;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+5273, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 5273;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+84683, dvrr_stack+8477, dvrr_stack+76358);
 tmp = dvrr_stack + 84683;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+85043, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 85043;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+85493, dvrr_stack+21111, dvrr_stack+8477);
 tmp = dvrr_stack + 85493;
 target_ptr = Libderiv->deriv2_classes[3][9][105];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+86043, dvrr_stack+79568, dvrr_stack+29451);
 tmp = dvrr_stack + 86043;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+86358, dvrr_stack+38047, dvrr_stack+40216);
 tmp = dvrr_stack + 86358;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+86778, dvrr_stack+45841, dvrr_stack+79568);
 tmp = dvrr_stack + 86778;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+87318, dvrr_stack+53111, dvrr_stack+38047);
 tmp = dvrr_stack + 87318;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+87993, dvrr_stack+21771, dvrr_stack+45841);
 tmp = dvrr_stack + 87993;
 target_ptr = Libderiv->deriv2_classes[4][9][105];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+441, dvrr_stack+73542, dvrr_stack+73392);
 tmp = dvrr_stack + 441;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+88818, dvrr_stack+74032, dvrr_stack+73822);
 tmp = dvrr_stack + 88818;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+89098, dvrr_stack+74392, dvrr_stack+73542);
 tmp = dvrr_stack + 89098;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+89458, dvrr_stack+74842, dvrr_stack+74032);
 tmp = dvrr_stack + 89458;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+89908, dvrr_stack+75392, dvrr_stack+74392);
 tmp = dvrr_stack + 89908;
 target_ptr = Libderiv->deriv2_classes[3][9][104];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+90458, dvrr_stack+62615, dvrr_stack+62390);
 tmp = dvrr_stack + 90458;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+90773, dvrr_stack+63350, dvrr_stack+63035);
 tmp = dvrr_stack + 90773;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+91193, dvrr_stack+63890, dvrr_stack+62615);
 tmp = dvrr_stack + 91193;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+91733, dvrr_stack+53936, dvrr_stack+63350);
 tmp = dvrr_stack + 91733;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+92408, dvrr_stack+29676, dvrr_stack+63890);
 tmp = dvrr_stack + 92408;
 target_ptr = Libderiv->deriv2_classes[4][9][104];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+5553, dvrr_stack+76958, dvrr_stack+76808);
 tmp = dvrr_stack + 5553;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+93233, dvrr_stack+77448, dvrr_stack+77238);
 tmp = dvrr_stack + 93233;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+93513, dvrr_stack+77808, dvrr_stack+76958);
 tmp = dvrr_stack + 93513;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+93873, dvrr_stack+78258, dvrr_stack+77448);
 tmp = dvrr_stack + 93873;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+94323, dvrr_stack+78808, dvrr_stack+77808);
 tmp = dvrr_stack + 94323;
 target_ptr = Libderiv->deriv2_classes[3][9][95];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+94873, dvrr_stack+5788, dvrr_stack+80243);
 tmp = dvrr_stack + 94873;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+95188, dvrr_stack+67190, dvrr_stack+80468);
 tmp = dvrr_stack + 95188;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+95608, dvrr_stack+67730, dvrr_stack+5788);
 tmp = dvrr_stack + 95608;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+68685, dvrr_stack+57161, dvrr_stack+67190);
 tmp = dvrr_stack + 68685;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+69360, dvrr_stack+32376, dvrr_stack+67730);
 tmp = dvrr_stack + 69360;
 target_ptr = Libderiv->deriv2_classes[4][9][95];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+96148, dvrr_stack+68405, dvrr_stack+80783);
 tmp = dvrr_stack + 96148;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+96358, dvrr_stack+49081, dvrr_stack+57986);
 tmp = dvrr_stack + 96358;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+70185, dvrr_stack+49441, dvrr_stack+68405);
 tmp = dvrr_stack + 70185;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+70545, dvrr_stack+42736, dvrr_stack+49081);
 tmp = dvrr_stack + 70545;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+49891, dvrr_stack+33366, dvrr_stack+49441);
 tmp = dvrr_stack + 49891;
 target_ptr = Libderiv->deriv2_classes[3][9][94];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+70995, dvrr_stack+34251, dvrr_stack+34026);
 tmp = dvrr_stack + 70995;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+50441, dvrr_stack+24726, dvrr_stack+24411);
 tmp = dvrr_stack + 50441;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+43286, dvrr_stack+16811, dvrr_stack+34251);
 tmp = dvrr_stack + 43286;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+25266, dvrr_stack+96638, dvrr_stack+24726);
 tmp = dvrr_stack + 25266;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+25941, dvrr_stack+97463, dvrr_stack+16811);
 tmp = dvrr_stack + 25941;
 target_ptr = Libderiv->deriv2_classes[4][9][94];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+50861, dvrr_stack+76358, dvrr_stack+80933);
 tmp = dvrr_stack + 50861;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+43826, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 43826;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+11573, dvrr_stack+8477, dvrr_stack+76358);
 tmp = dvrr_stack + 11573;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+160835, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 160835;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+161285, dvrr_stack+21111, dvrr_stack+8477);
 tmp = dvrr_stack + 161285;
 target_ptr = Libderiv->deriv2_classes[3][9][93];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+161835, dvrr_stack+79568, dvrr_stack+29451);
 tmp = dvrr_stack + 161835;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+162150, dvrr_stack+38047, dvrr_stack+40216);
 tmp = dvrr_stack + 162150;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+162570, dvrr_stack+45841, dvrr_stack+79568);
 tmp = dvrr_stack + 162570;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+163110, dvrr_stack+53111, dvrr_stack+38047);
 tmp = dvrr_stack + 163110;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+163785, dvrr_stack+21771, dvrr_stack+45841);
 tmp = dvrr_stack + 163785;
 target_ptr = Libderiv->deriv2_classes[4][9][93];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+164610, dvrr_stack+73542, dvrr_stack+73392);
 tmp = dvrr_stack + 164610;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+164820, dvrr_stack+74032, dvrr_stack+73822);
 tmp = dvrr_stack + 164820;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+165100, dvrr_stack+74392, dvrr_stack+73542);
 tmp = dvrr_stack + 165100;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+165460, dvrr_stack+74842, dvrr_stack+74032);
 tmp = dvrr_stack + 165460;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+165910, dvrr_stack+75392, dvrr_stack+74392);
 tmp = dvrr_stack + 165910;
 target_ptr = Libderiv->deriv2_classes[3][9][92];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+166460, dvrr_stack+62615, dvrr_stack+62390);
 tmp = dvrr_stack + 166460;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+166775, dvrr_stack+63350, dvrr_stack+63035);
 tmp = dvrr_stack + 166775;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+167195, dvrr_stack+63890, dvrr_stack+62615);
 tmp = dvrr_stack + 167195;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+167735, dvrr_stack+53936, dvrr_stack+63350);
 tmp = dvrr_stack + 167735;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+168410, dvrr_stack+29676, dvrr_stack+63890);
 tmp = dvrr_stack + 168410;
 target_ptr = Libderiv->deriv2_classes[4][9][92];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+169235, dvrr_stack+54761, dvrr_stack+64565);
 tmp = dvrr_stack + 169235;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+169445, dvrr_stack+46726, dvrr_stack+46516);
 tmp = dvrr_stack + 169445;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+169725, dvrr_stack+40531, dvrr_stack+54761);
 tmp = dvrr_stack + 169725;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+170085, dvrr_stack+30666, dvrr_stack+46726);
 tmp = dvrr_stack + 170085;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+170535, dvrr_stack+14661, dvrr_stack+40531);
 tmp = dvrr_stack + 170535;
 target_ptr = Libderiv->deriv2_classes[3][9][91];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+171085, dvrr_stack+40981, dvrr_stack+47086);
 tmp = dvrr_stack + 171085;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+171400, dvrr_stack+8927, dvrr_stack+38587);
 tmp = dvrr_stack + 171400;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+171820, dvrr_stack+98453, dvrr_stack+40981);
 tmp = dvrr_stack + 171820;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+172360, dvrr_stack+99128, dvrr_stack+8927);
 tmp = dvrr_stack + 172360;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+173035, dvrr_stack+99953, dvrr_stack+98453);
 tmp = dvrr_stack + 173035;
 target_ptr = Libderiv->deriv2_classes[4][9][91];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+173860, dvrr_stack+76958, dvrr_stack+76808);
 tmp = dvrr_stack + 173860;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+76638, dvrr_stack+77448, dvrr_stack+77238);
 tmp = dvrr_stack + 76638;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+174070, dvrr_stack+77808, dvrr_stack+76958);
 tmp = dvrr_stack + 174070;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+174430, dvrr_stack+78258, dvrr_stack+77448);
 tmp = dvrr_stack + 174430;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+174880, dvrr_stack+78808, dvrr_stack+77808);
 tmp = dvrr_stack + 174880;
 target_ptr = Libderiv->deriv2_classes[3][9][83];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+78808, dvrr_stack+5788, dvrr_stack+80243);
 tmp = dvrr_stack + 78808;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+79123, dvrr_stack+67190, dvrr_stack+80468);
 tmp = dvrr_stack + 79123;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+175430, dvrr_stack+67730, dvrr_stack+5788);
 tmp = dvrr_stack + 175430;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+175970, dvrr_stack+57161, dvrr_stack+67190);
 tmp = dvrr_stack + 175970;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+176645, dvrr_stack+32376, dvrr_stack+67730);
 tmp = dvrr_stack + 176645;
 target_ptr = Libderiv->deriv2_classes[4][9][83];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+80198, dvrr_stack+68405, dvrr_stack+80783);
 tmp = dvrr_stack + 80198;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+32344, dvrr_stack+49081, dvrr_stack+57986);
 tmp = dvrr_stack + 32344;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+32624, dvrr_stack+49441, dvrr_stack+68405);
 tmp = dvrr_stack + 32624;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+177470, dvrr_stack+42736, dvrr_stack+49081);
 tmp = dvrr_stack + 177470;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+177920, dvrr_stack+33366, dvrr_stack+49441);
 tmp = dvrr_stack + 177920;
 target_ptr = Libderiv->deriv2_classes[3][9][82];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+32984, dvrr_stack+34251, dvrr_stack+34026);
 tmp = dvrr_stack + 32984;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+33299, dvrr_stack+24726, dvrr_stack+24411);
 tmp = dvrr_stack + 33299;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+178470, dvrr_stack+16811, dvrr_stack+34251);
 tmp = dvrr_stack + 178470;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+179010, dvrr_stack+96638, dvrr_stack+24726);
 tmp = dvrr_stack + 179010;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+179685, dvrr_stack+97463, dvrr_stack+16811);
 tmp = dvrr_stack + 179685;
 target_ptr = Libderiv->deriv2_classes[4][9][82];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+97463, dvrr_stack+76358, dvrr_stack+80933);
 tmp = dvrr_stack + 97463;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+97673, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 97673;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+97953, dvrr_stack+8477, dvrr_stack+76358);
 tmp = dvrr_stack + 97953;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+33719, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 33719;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+180510, dvrr_stack+21111, dvrr_stack+8477);
 tmp = dvrr_stack + 180510;
 target_ptr = Libderiv->deriv2_classes[3][9][81];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+21105, dvrr_stack+79568, dvrr_stack+29451);
 tmp = dvrr_stack + 21105;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+181060, dvrr_stack+38047, dvrr_stack+40216);
 tmp = dvrr_stack + 181060;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+181480, dvrr_stack+45841, dvrr_stack+79568);
 tmp = dvrr_stack + 181480;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+182020, dvrr_stack+53111, dvrr_stack+38047);
 tmp = dvrr_stack + 182020;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+182695, dvrr_stack+21771, dvrr_stack+45841);
 tmp = dvrr_stack + 182695;
 target_ptr = Libderiv->deriv2_classes[4][9][81];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+80783, dvrr_stack+73542, dvrr_stack+73392);
 tmp = dvrr_stack + 80783;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+21420, dvrr_stack+74032, dvrr_stack+73822);
 tmp = dvrr_stack + 21420;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+21700, dvrr_stack+74392, dvrr_stack+73542);
 tmp = dvrr_stack + 21700;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+22060, dvrr_stack+74842, dvrr_stack+74032);
 tmp = dvrr_stack + 22060;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+183520, dvrr_stack+75392, dvrr_stack+74392);
 tmp = dvrr_stack + 183520;
 target_ptr = Libderiv->deriv2_classes[3][9][80];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+75392, dvrr_stack+62615, dvrr_stack+62390);
 tmp = dvrr_stack + 75392;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+184070, dvrr_stack+63350, dvrr_stack+63035);
 tmp = dvrr_stack + 184070;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+184490, dvrr_stack+63890, dvrr_stack+62615);
 tmp = dvrr_stack + 184490;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+185030, dvrr_stack+53936, dvrr_stack+63350);
 tmp = dvrr_stack + 185030;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+185705, dvrr_stack+29676, dvrr_stack+63890);
 tmp = dvrr_stack + 185705;
 target_ptr = Libderiv->deriv2_classes[4][9][80];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+75707, dvrr_stack+54761, dvrr_stack+64565);
 tmp = dvrr_stack + 75707;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+29433, dvrr_stack+46726, dvrr_stack+46516);
 tmp = dvrr_stack + 29433;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+29713, dvrr_stack+40531, dvrr_stack+54761);
 tmp = dvrr_stack + 29713;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+30073, dvrr_stack+30666, dvrr_stack+46726);
 tmp = dvrr_stack + 30073;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+186530, dvrr_stack+14661, dvrr_stack+40531);
 tmp = dvrr_stack + 186530;
 target_ptr = Libderiv->deriv2_classes[3][9][79];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+14661, dvrr_stack+40981, dvrr_stack+47086);
 tmp = dvrr_stack + 14661;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+187080, dvrr_stack+8927, dvrr_stack+38587);
 tmp = dvrr_stack + 187080;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+187500, dvrr_stack+98453, dvrr_stack+40981);
 tmp = dvrr_stack + 187500;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+188040, dvrr_stack+99128, dvrr_stack+8927);
 tmp = dvrr_stack + 188040;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+188715, dvrr_stack+99953, dvrr_stack+98453);
 tmp = dvrr_stack + 188715;
 target_ptr = Libderiv->deriv2_classes[4][9][79];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+99953, dvrr_stack+4318, dvrr_stack+47311);
 tmp = dvrr_stack + 99953;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+100163, dvrr_stack+10637, dvrr_stack+79988);
 tmp = dvrr_stack + 100163;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+100443, dvrr_stack+71420, dvrr_stack+4318);
 tmp = dvrr_stack + 100443;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+189540, dvrr_stack+100943, dvrr_stack+10637);
 tmp = dvrr_stack + 189540;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+189990, dvrr_stack+101493, dvrr_stack+71420);
 tmp = dvrr_stack + 189990;
 target_ptr = Libderiv->deriv2_classes[3][9][78];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+101493, dvrr_stack+28263, dvrr_stack+2529);
 tmp = dvrr_stack + 101493;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+190540, dvrr_stack+28683, dvrr_stack+4598);
 tmp = dvrr_stack + 190540;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+190960, dvrr_stack+102153, dvrr_stack+28263);
 tmp = dvrr_stack + 190960;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+191500, dvrr_stack+102828, dvrr_stack+28683);
 tmp = dvrr_stack + 191500;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+192175, dvrr_stack+103653, dvrr_stack+102153);
 tmp = dvrr_stack + 192175;
 target_ptr = Libderiv->deriv2_classes[4][9][78];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+103653, dvrr_stack+80468, dvrr_stack+62240);
 tmp = dvrr_stack + 103653;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+103863, dvrr_stack+5788, dvrr_stack+31216);
 tmp = dvrr_stack + 103863;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+104143, dvrr_stack+67190, dvrr_stack+10997);
 tmp = dvrr_stack + 104143;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+193000, dvrr_stack+67730, dvrr_stack+72752);
 tmp = dvrr_stack + 193000;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,55,dvrr_stack+193450, dvrr_stack+57161, dvrr_stack+73022);
 tmp = dvrr_stack + 193450;
 target_ptr = Libderiv->deriv2_classes[3][9][35];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+101808, dvrr_stack+110458, dvrr_stack+77238);
 tmp = dvrr_stack + 101808;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+194000, dvrr_stack+114319, dvrr_stack+76958);
 tmp = dvrr_stack + 194000;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+194420, dvrr_stack+119245, dvrr_stack+77448);
 tmp = dvrr_stack + 194420;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+194960, dvrr_stack+125696, dvrr_stack+77808);
 tmp = dvrr_stack + 194960;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,55,dvrr_stack+195635, dvrr_stack+59996, dvrr_stack+78258);
 tmp = dvrr_stack + 195635;
 target_ptr = Libderiv->deriv2_classes[4][9][35];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+2529, dvrr_stack+24411, dvrr_stack+675);
 tmp = dvrr_stack + 2529;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+47086, dvrr_stack+34251, dvrr_stack+20451);
 tmp = dvrr_stack + 47086;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+196460, dvrr_stack+24726, dvrr_stack+20619);
 tmp = dvrr_stack + 196460;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+196820, dvrr_stack+16811, dvrr_stack+20835);
 tmp = dvrr_stack + 196820;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+197270, dvrr_stack+96638, dvrr_stack+61151);
 tmp = dvrr_stack + 197270;
 target_ptr = Libderiv->deriv2_classes[3][9][34];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+14976, dvrr_stack+61481, dvrr_stack+57986);
 tmp = dvrr_stack + 14976;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+197820, dvrr_stack+126641, dvrr_stack+68405);
 tmp = dvrr_stack + 197820;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+198240, dvrr_stack+127229, dvrr_stack+49081);
 tmp = dvrr_stack + 198240;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+198780, dvrr_stack+133538, dvrr_stack+49441);
 tmp = dvrr_stack + 198780;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+199455, dvrr_stack+134483, dvrr_stack+42736);
 tmp = dvrr_stack + 199455;
 target_ptr = Libderiv->deriv2_classes[4][9][34];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+62366, dvrr_stack+40216, dvrr_stack+61922);
 tmp = dvrr_stack + 62366;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+200280, dvrr_stack+79568, dvrr_stack+71870);
 tmp = dvrr_stack + 200280;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+200560, dvrr_stack+38047, dvrr_stack+72038);
 tmp = dvrr_stack + 200560;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+200920, dvrr_stack+45841, dvrr_stack+104643);
 tmp = dvrr_stack + 200920;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+201370, dvrr_stack+53111, dvrr_stack+104913);
 tmp = dvrr_stack + 201370;
 target_ptr = Libderiv->deriv2_classes[3][9][33];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+201920, dvrr_stack+105243, dvrr_stack+4108);
 tmp = dvrr_stack + 201920;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+202235, dvrr_stack+109135, dvrr_stack+76358);
 tmp = dvrr_stack + 202235;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+202655, dvrr_stack+112555, dvrr_stack+2169);
 tmp = dvrr_stack + 202655;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+203195, dvrr_stack+116977, dvrr_stack+8477);
 tmp = dvrr_stack + 203195;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+203870, dvrr_stack+122861, dvrr_stack+14111);
 tmp = dvrr_stack + 203870;
 target_ptr = Libderiv->deriv2_classes[4][9][33];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+22510, dvrr_stack+63035, dvrr_stack+130073);
 tmp = dvrr_stack + 22510;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+204695, dvrr_stack+62615, dvrr_stack+130199);
 tmp = dvrr_stack + 204695;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+204975, dvrr_stack+63350, dvrr_stack+130367);
 tmp = dvrr_stack + 204975;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+205335, dvrr_stack+63890, dvrr_stack+130583);
 tmp = dvrr_stack + 205335;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+205785, dvrr_stack+53936, dvrr_stack+130853);
 tmp = dvrr_stack + 205785;
 target_ptr = Libderiv->deriv2_classes[3][9][32];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+206335, dvrr_stack+131648, dvrr_stack+73822);
 tmp = dvrr_stack + 206335;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+206650, dvrr_stack+132089, dvrr_stack+73542);
 tmp = dvrr_stack + 206650;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+207070, dvrr_stack+132677, dvrr_stack+74032);
 tmp = dvrr_stack + 207070;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+207610, dvrr_stack+124016, dvrr_stack+74392);
 tmp = dvrr_stack + 207610;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+208285, dvrr_stack+117922, dvrr_stack+74842);
 tmp = dvrr_stack + 208285;
 target_ptr = Libderiv->deriv2_classes[4][9][32];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+209110, dvrr_stack+38587, dvrr_stack+131183);
 tmp = dvrr_stack + 209110;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+209320, dvrr_stack+40981, dvrr_stack+119077);
 tmp = dvrr_stack + 209320;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+209600, dvrr_stack+8927, dvrr_stack+6838);
 tmp = dvrr_stack + 209600;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+209960, dvrr_stack+98453, dvrr_stack+124961);
 tmp = dvrr_stack + 209960;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+210410, dvrr_stack+99128, dvrr_stack+125231);
 tmp = dvrr_stack + 210410;
 target_ptr = Libderiv->deriv2_classes[3][9][31];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+210960, dvrr_stack+113311, dvrr_stack+46516);
 tmp = dvrr_stack + 210960;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+211275, dvrr_stack+109723, dvrr_stack+54761);
 tmp = dvrr_stack + 211275;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+211695, dvrr_stack+105684, dvrr_stack+46726);
 tmp = dvrr_stack + 211695;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+212235, dvrr_stack+135638, dvrr_stack+40531);
 tmp = dvrr_stack + 212235;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+212910, dvrr_stack+136583, dvrr_stack+30666);
 tmp = dvrr_stack + 212910;
 target_ptr = Libderiv->deriv2_classes[4][9][31];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+213735, dvrr_stack+4598, dvrr_stack+125561);
 tmp = dvrr_stack + 213735;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+213945, dvrr_stack+28263, dvrr_stack+113752);
 tmp = dvrr_stack + 213945;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+214225, dvrr_stack+28683, dvrr_stack+113920);
 tmp = dvrr_stack + 214225;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+214585, dvrr_stack+102153, dvrr_stack+106440);
 tmp = dvrr_stack + 214585;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+215035, dvrr_stack+102828, dvrr_stack+106710);
 tmp = dvrr_stack + 215035;
 target_ptr = Libderiv->deriv2_classes[3][9][30];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+215585, dvrr_stack+72254, dvrr_stack+79988);
 tmp = dvrr_stack + 215585;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+215900, dvrr_stack+127985, dvrr_stack+4318);
 tmp = dvrr_stack + 215900;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+216320, dvrr_stack+19395, dvrr_stack+10637);
 tmp = dvrr_stack + 216320;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+216860, dvrr_stack+137738, dvrr_stack+71420);
 tmp = dvrr_stack + 216860;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+217535, dvrr_stack+138683, dvrr_stack+100943);
 tmp = dvrr_stack + 217535;
 target_ptr = Libderiv->deriv2_classes[4][9][30];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+218360, dvrr_stack+128573, dvrr_stack+131309);
 tmp = dvrr_stack + 218360;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+218570, dvrr_stack+128888, dvrr_stack+131435);
 tmp = dvrr_stack + 218570;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+218850, dvrr_stack+129524, dvrr_stack+129308);
 tmp = dvrr_stack + 218850;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+219210, dvrr_stack+139838, dvrr_stack+20151);
 tmp = dvrr_stack + 219210;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+219660, dvrr_stack+140513, dvrr_stack+12681);
 tmp = dvrr_stack + 219660;
 target_ptr = Libderiv->deriv2_classes[3][9][26];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+220210, dvrr_stack+0, dvrr_stack+13011);
 tmp = dvrr_stack + 220210;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+220525, dvrr_stack+107847, dvrr_stack+141338);
 tmp = dvrr_stack + 220525;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+220945, dvrr_stack+110899, dvrr_stack+37095);
 tmp = dvrr_stack + 220945;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+221485, dvrr_stack+144201, dvrr_stack+26811);
 tmp = dvrr_stack + 221485;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+222160, dvrr_stack+149385, dvrr_stack+114907);
 tmp = dvrr_stack + 222160;
 target_ptr = Libderiv->deriv2_classes[4][9][26];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+222985, dvrr_stack+80468, dvrr_stack+62240);
 tmp = dvrr_stack + 222985;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+223195, dvrr_stack+5788, dvrr_stack+31216);
 tmp = dvrr_stack + 223195;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+223475, dvrr_stack+67190, dvrr_stack+10997);
 tmp = dvrr_stack + 223475;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+223835, dvrr_stack+67730, dvrr_stack+72752);
 tmp = dvrr_stack + 223835;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,55,dvrr_stack+224285, dvrr_stack+57161, dvrr_stack+73022);
 tmp = dvrr_stack + 224285;
 target_ptr = Libderiv->deriv2_classes[3][9][23];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+224835, dvrr_stack+110458, dvrr_stack+77238);
 tmp = dvrr_stack + 224835;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+225150, dvrr_stack+114319, dvrr_stack+76958);
 tmp = dvrr_stack + 225150;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+225570, dvrr_stack+119245, dvrr_stack+77448);
 tmp = dvrr_stack + 225570;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+226110, dvrr_stack+125696, dvrr_stack+77808);
 tmp = dvrr_stack + 226110;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,55,dvrr_stack+226785, dvrr_stack+59996, dvrr_stack+78258);
 tmp = dvrr_stack + 226785;
 target_ptr = Libderiv->deriv2_classes[4][9][23];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+227610, dvrr_stack+24411, dvrr_stack+675);
 tmp = dvrr_stack + 227610;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+227820, dvrr_stack+34251, dvrr_stack+20451);
 tmp = dvrr_stack + 227820;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+228100, dvrr_stack+24726, dvrr_stack+20619);
 tmp = dvrr_stack + 228100;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+228460, dvrr_stack+16811, dvrr_stack+20835);
 tmp = dvrr_stack + 228460;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+228910, dvrr_stack+96638, dvrr_stack+61151);
 tmp = dvrr_stack + 228910;
 target_ptr = Libderiv->deriv2_classes[3][9][22];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+229460, dvrr_stack+61481, dvrr_stack+57986);
 tmp = dvrr_stack + 229460;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+229775, dvrr_stack+126641, dvrr_stack+68405);
 tmp = dvrr_stack + 229775;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+230195, dvrr_stack+127229, dvrr_stack+49081);
 tmp = dvrr_stack + 230195;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+230735, dvrr_stack+133538, dvrr_stack+49441);
 tmp = dvrr_stack + 230735;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+231410, dvrr_stack+134483, dvrr_stack+42736);
 tmp = dvrr_stack + 231410;
 target_ptr = Libderiv->deriv2_classes[4][9][22];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+232235, dvrr_stack+40216, dvrr_stack+61922);
 tmp = dvrr_stack + 232235;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+232445, dvrr_stack+79568, dvrr_stack+71870);
 tmp = dvrr_stack + 232445;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+232725, dvrr_stack+38047, dvrr_stack+72038);
 tmp = dvrr_stack + 232725;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+233085, dvrr_stack+45841, dvrr_stack+104643);
 tmp = dvrr_stack + 233085;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+233535, dvrr_stack+53111, dvrr_stack+104913);
 tmp = dvrr_stack + 233535;
 target_ptr = Libderiv->deriv2_classes[3][9][21];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+234085, dvrr_stack+105243, dvrr_stack+4108);
 tmp = dvrr_stack + 234085;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+234400, dvrr_stack+109135, dvrr_stack+76358);
 tmp = dvrr_stack + 234400;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+234820, dvrr_stack+112555, dvrr_stack+2169);
 tmp = dvrr_stack + 234820;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+235360, dvrr_stack+116977, dvrr_stack+8477);
 tmp = dvrr_stack + 235360;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+236035, dvrr_stack+122861, dvrr_stack+14111);
 tmp = dvrr_stack + 236035;
 target_ptr = Libderiv->deriv2_classes[4][9][21];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+236860, dvrr_stack+63035, dvrr_stack+130073);
 tmp = dvrr_stack + 236860;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+237070, dvrr_stack+62615, dvrr_stack+130199);
 tmp = dvrr_stack + 237070;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+237350, dvrr_stack+63350, dvrr_stack+130367);
 tmp = dvrr_stack + 237350;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+237710, dvrr_stack+63890, dvrr_stack+130583);
 tmp = dvrr_stack + 237710;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+238160, dvrr_stack+53936, dvrr_stack+130853);
 tmp = dvrr_stack + 238160;
 target_ptr = Libderiv->deriv2_classes[3][9][20];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+238710, dvrr_stack+131648, dvrr_stack+73822);
 tmp = dvrr_stack + 238710;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+239025, dvrr_stack+132089, dvrr_stack+73542);
 tmp = dvrr_stack + 239025;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+239445, dvrr_stack+132677, dvrr_stack+74032);
 tmp = dvrr_stack + 239445;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+239985, dvrr_stack+124016, dvrr_stack+74392);
 tmp = dvrr_stack + 239985;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+240660, dvrr_stack+117922, dvrr_stack+74842);
 tmp = dvrr_stack + 240660;
 target_ptr = Libderiv->deriv2_classes[4][9][20];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+241485, dvrr_stack+38587, dvrr_stack+131183);
 tmp = dvrr_stack + 241485;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+241695, dvrr_stack+40981, dvrr_stack+119077);
 tmp = dvrr_stack + 241695;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+241975, dvrr_stack+8927, dvrr_stack+6838);
 tmp = dvrr_stack + 241975;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+242335, dvrr_stack+98453, dvrr_stack+124961);
 tmp = dvrr_stack + 242335;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+242785, dvrr_stack+99128, dvrr_stack+125231);
 tmp = dvrr_stack + 242785;
 target_ptr = Libderiv->deriv2_classes[3][9][19];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+243335, dvrr_stack+113311, dvrr_stack+46516);
 tmp = dvrr_stack + 243335;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+243650, dvrr_stack+109723, dvrr_stack+54761);
 tmp = dvrr_stack + 243650;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+244070, dvrr_stack+105684, dvrr_stack+46726);
 tmp = dvrr_stack + 244070;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+244610, dvrr_stack+135638, dvrr_stack+40531);
 tmp = dvrr_stack + 244610;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+245285, dvrr_stack+136583, dvrr_stack+30666);
 tmp = dvrr_stack + 245285;
 target_ptr = Libderiv->deriv2_classes[4][9][19];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+246110, dvrr_stack+4598, dvrr_stack+125561);
 tmp = dvrr_stack + 246110;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+246320, dvrr_stack+28263, dvrr_stack+113752);
 tmp = dvrr_stack + 246320;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+246600, dvrr_stack+28683, dvrr_stack+113920);
 tmp = dvrr_stack + 246600;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+246960, dvrr_stack+102153, dvrr_stack+106440);
 tmp = dvrr_stack + 246960;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+247410, dvrr_stack+102828, dvrr_stack+106710);
 tmp = dvrr_stack + 247410;
 target_ptr = Libderiv->deriv2_classes[3][9][18];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+247960, dvrr_stack+72254, dvrr_stack+79988);
 tmp = dvrr_stack + 247960;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+248275, dvrr_stack+127985, dvrr_stack+4318);
 tmp = dvrr_stack + 248275;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+248695, dvrr_stack+19395, dvrr_stack+10637);
 tmp = dvrr_stack + 248695;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+249235, dvrr_stack+137738, dvrr_stack+71420);
 tmp = dvrr_stack + 249235;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+249910, dvrr_stack+138683, dvrr_stack+100943);
 tmp = dvrr_stack + 249910;
 target_ptr = Libderiv->deriv2_classes[4][9][18];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+250735, dvrr_stack+128573, dvrr_stack+131309);
 tmp = dvrr_stack + 250735;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+250945, dvrr_stack+128888, dvrr_stack+131435);
 tmp = dvrr_stack + 250945;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+251225, dvrr_stack+129524, dvrr_stack+129308);
 tmp = dvrr_stack + 251225;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+251585, dvrr_stack+139838, dvrr_stack+20151);
 tmp = dvrr_stack + 251585;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+252035, dvrr_stack+140513, dvrr_stack+12681);
 tmp = dvrr_stack + 252035;
 target_ptr = Libderiv->deriv2_classes[3][9][14];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+252585, dvrr_stack+0, dvrr_stack+13011);
 tmp = dvrr_stack + 252585;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+252900, dvrr_stack+107847, dvrr_stack+141338);
 tmp = dvrr_stack + 252900;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+253320, dvrr_stack+110899, dvrr_stack+37095);
 tmp = dvrr_stack + 253320;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+253860, dvrr_stack+144201, dvrr_stack+26811);
 tmp = dvrr_stack + 253860;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+254535, dvrr_stack+149385, dvrr_stack+114907);
 tmp = dvrr_stack + 254535;
 target_ptr = Libderiv->deriv2_classes[4][9][14];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+255360, dvrr_stack+146631, dvrr_stack+146505);
 tmp = dvrr_stack + 255360;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+255570, dvrr_stack+142997, dvrr_stack+1137);
 tmp = dvrr_stack + 255570;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+255850, dvrr_stack+147162, dvrr_stack+146946);
 tmp = dvrr_stack + 255850;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+256210, dvrr_stack+44311, dvrr_stack+147702);
 tmp = dvrr_stack + 256210;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+256660, dvrr_stack+120001, dvrr_stack+12077);
 tmp = dvrr_stack + 256660;
 target_ptr = Libderiv->deriv2_classes[3][9][13];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+257210, dvrr_stack+39112, dvrr_stack+38902);
 tmp = dvrr_stack + 257210;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+257525, dvrr_stack+121106, dvrr_stack+120826);
 tmp = dvrr_stack + 257525;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+257945, dvrr_stack+51241, dvrr_stack+115457);
 tmp = dvrr_stack + 257945;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+258485, dvrr_stack+152080, dvrr_stack+141618);
 tmp = dvrr_stack + 258485;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+259160, dvrr_stack+153025, dvrr_stack+18701);
 tmp = dvrr_stack + 259160;
 target_ptr = Libderiv->deriv2_classes[4][9][13];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+259985, dvrr_stack+80468, dvrr_stack+62240);
 tmp = dvrr_stack + 259985;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+80408, dvrr_stack+5788, dvrr_stack+31216);
 tmp = dvrr_stack + 80408;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+5763, dvrr_stack+67190, dvrr_stack+10997);
 tmp = dvrr_stack + 5763;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+67090, dvrr_stack+67730, dvrr_stack+72752);
 tmp = dvrr_stack + 67090;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,55,dvrr_stack+67540, dvrr_stack+57161, dvrr_stack+73022);
 tmp = dvrr_stack + 67540;
 target_ptr = Libderiv->deriv2_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+68090, dvrr_stack+110458, dvrr_stack+77238);
 tmp = dvrr_stack + 68090;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+110311, dvrr_stack+114319, dvrr_stack+76958);
 tmp = dvrr_stack + 110311;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+114136, dvrr_stack+119245, dvrr_stack+77448);
 tmp = dvrr_stack + 114136;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+119245, dvrr_stack+125696, dvrr_stack+77808);
 tmp = dvrr_stack + 119245;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,55,dvrr_stack+76918, dvrr_stack+59996, dvrr_stack+78258);
 tmp = dvrr_stack + 76918;
 target_ptr = Libderiv->deriv2_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+10997, dvrr_stack+24411, dvrr_stack+675);
 tmp = dvrr_stack + 10997;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+24316, dvrr_stack+34251, dvrr_stack+20451);
 tmp = dvrr_stack + 24316;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+59976, dvrr_stack+24726, dvrr_stack+20619);
 tmp = dvrr_stack + 59976;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+24596, dvrr_stack+16811, dvrr_stack+20835);
 tmp = dvrr_stack + 24596;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+60336, dvrr_stack+96638, dvrr_stack+61151);
 tmp = dvrr_stack + 60336;
 target_ptr = Libderiv->deriv2_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+96638, dvrr_stack+61481, dvrr_stack+57986);
 tmp = dvrr_stack + 96638;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+96953, dvrr_stack+126641, dvrr_stack+68405);
 tmp = dvrr_stack + 96953;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+60886, dvrr_stack+127229, dvrr_stack+49081);
 tmp = dvrr_stack + 60886;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+77743, dvrr_stack+133538, dvrr_stack+49441);
 tmp = dvrr_stack + 77743;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+48961, dvrr_stack+134483, dvrr_stack+42736);
 tmp = dvrr_stack + 48961;
 target_ptr = Libderiv->deriv2_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+68405, dvrr_stack+40216, dvrr_stack+61922);
 tmp = dvrr_stack + 68405;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+40093, dvrr_stack+79568, dvrr_stack+71870);
 tmp = dvrr_stack + 40093;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+79543, dvrr_stack+38047, dvrr_stack+72038);
 tmp = dvrr_stack + 79543;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+61426, dvrr_stack+45841, dvrr_stack+104643);
 tmp = dvrr_stack + 61426;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+45686, dvrr_stack+53111, dvrr_stack+104913);
 tmp = dvrr_stack + 45686;
 target_ptr = Libderiv->deriv2_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+71870, dvrr_stack+105243, dvrr_stack+4108);
 tmp = dvrr_stack + 71870;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+104503, dvrr_stack+109135, dvrr_stack+76358);
 tmp = dvrr_stack + 104503;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+104923, dvrr_stack+112555, dvrr_stack+2169);
 tmp = dvrr_stack + 104923;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+53032, dvrr_stack+116977, dvrr_stack+8477);
 tmp = dvrr_stack + 53032;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+116957, dvrr_stack+122861, dvrr_stack+14111);
 tmp = dvrr_stack + 116957;
 target_ptr = Libderiv->deriv2_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+105463, dvrr_stack+63035, dvrr_stack+130073);
 tmp = dvrr_stack + 105463;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+46236, dvrr_stack+62615, dvrr_stack+130199);
 tmp = dvrr_stack + 46236;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+14051, dvrr_stack+63350, dvrr_stack+130367);
 tmp = dvrr_stack + 14051;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+8357, dvrr_stack+63890, dvrr_stack+130583);
 tmp = dvrr_stack + 8357;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+122723, dvrr_stack+53936, dvrr_stack+130853);
 tmp = dvrr_stack + 122723;
 target_ptr = Libderiv->deriv2_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+2105, dvrr_stack+131648, dvrr_stack+73822);
 tmp = dvrr_stack + 2105;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+123273, dvrr_stack+132089, dvrr_stack+73542);
 tmp = dvrr_stack + 123273;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+53707, dvrr_stack+132677, dvrr_stack+74032);
 tmp = dvrr_stack + 53707;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+108975, dvrr_stack+124016, dvrr_stack+74392);
 tmp = dvrr_stack + 108975;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+123693, dvrr_stack+117922, dvrr_stack+74842);
 tmp = dvrr_stack + 123693;
 target_ptr = Libderiv->deriv2_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+25046, dvrr_stack+38587, dvrr_stack+131183);
 tmp = dvrr_stack + 25046;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+4018, dvrr_stack+40981, dvrr_stack+119077);
 tmp = dvrr_stack + 4018;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+40981, dvrr_stack+8927, dvrr_stack+6838);
 tmp = dvrr_stack + 40981;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+8807, dvrr_stack+98453, dvrr_stack+124961);
 tmp = dvrr_stack + 8807;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+98313, dvrr_stack+99128, dvrr_stack+125231);
 tmp = dvrr_stack + 98313;
 target_ptr = Libderiv->deriv2_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+98863, dvrr_stack+113311, dvrr_stack+46516);
 tmp = dvrr_stack + 98863;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+99178, dvrr_stack+109723, dvrr_stack+54761);
 tmp = dvrr_stack + 99178;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+124518, dvrr_stack+105684, dvrr_stack+46726);
 tmp = dvrr_stack + 124518;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+105673, dvrr_stack+135638, dvrr_stack+40531);
 tmp = dvrr_stack + 105673;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+117782, dvrr_stack+136583, dvrr_stack+30666);
 tmp = dvrr_stack + 117782;
 target_ptr = Libderiv->deriv2_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+9257, dvrr_stack+4598, dvrr_stack+125561);
 tmp = dvrr_stack + 9257;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+4598, dvrr_stack+28263, dvrr_stack+113752);
 tmp = dvrr_stack + 4598;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+46516, dvrr_stack+28683, dvrr_stack+113920);
 tmp = dvrr_stack + 46516;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+40373, dvrr_stack+102153, dvrr_stack+106440);
 tmp = dvrr_stack + 40373;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+102123, dvrr_stack+102828, dvrr_stack+106710);
 tmp = dvrr_stack + 102123;
 target_ptr = Libderiv->deriv2_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+106348, dvrr_stack+72254, dvrr_stack+79988);
 tmp = dvrr_stack + 106348;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+72185, dvrr_stack+127985, dvrr_stack+4318);
 tmp = dvrr_stack + 72185;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+72605, dvrr_stack+19395, dvrr_stack+10637);
 tmp = dvrr_stack + 72605;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+73145, dvrr_stack+137738, dvrr_stack+71420);
 tmp = dvrr_stack + 73145;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+73820, dvrr_stack+138683, dvrr_stack+100943);
 tmp = dvrr_stack + 73820;
 target_ptr = Libderiv->deriv2_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+46876, dvrr_stack+128573, dvrr_stack+131309);
 tmp = dvrr_stack + 46876;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+74645, dvrr_stack+128888, dvrr_stack+131435);
 tmp = dvrr_stack + 74645;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+74925, dvrr_stack+129524, dvrr_stack+129308);
 tmp = dvrr_stack + 74925;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+102673, dvrr_stack+139838, dvrr_stack+20151);
 tmp = dvrr_stack + 102673;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+100803, dvrr_stack+140513, dvrr_stack+12681);
 tmp = dvrr_stack + 100803;
 target_ptr = Libderiv->deriv2_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+106663, dvrr_stack+0, dvrr_stack+13011);
 tmp = dvrr_stack + 106663;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+0, dvrr_stack+107847, dvrr_stack+141338);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+12617, dvrr_stack+110899, dvrr_stack+37095);
 tmp = dvrr_stack + 12617;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+125058, dvrr_stack+144201, dvrr_stack+26811);
 tmp = dvrr_stack + 125058;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+144092, dvrr_stack+149385, dvrr_stack+114907);
 tmp = dvrr_stack + 144092;
 target_ptr = Libderiv->deriv2_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+103123, dvrr_stack+146631, dvrr_stack+146505);
 tmp = dvrr_stack + 103123;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+103333, dvrr_stack+142997, dvrr_stack+1137);
 tmp = dvrr_stack + 103333;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+6803, dvrr_stack+147162, dvrr_stack+146946);
 tmp = dvrr_stack + 6803;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+149198, dvrr_stack+44311, dvrr_stack+147702);
 tmp = dvrr_stack + 149198;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+149648, dvrr_stack+120001, dvrr_stack+12077);
 tmp = dvrr_stack + 149648;
 target_ptr = Libderiv->deriv2_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+119920, dvrr_stack+39112, dvrr_stack+38902);
 tmp = dvrr_stack + 119920;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+120235, dvrr_stack+121106, dvrr_stack+120826);
 tmp = dvrr_stack + 120235;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+120655, dvrr_stack+51241, dvrr_stack+115457);
 tmp = dvrr_stack + 120655;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+125733, dvrr_stack+152080, dvrr_stack+141618);
 tmp = dvrr_stack + 125733;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+152050, dvrr_stack+153025, dvrr_stack+18701);
 tmp = dvrr_stack + 152050;
 target_ptr = Libderiv->deriv2_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+1095, dvrr_stack+145146, dvrr_stack+147972);
 tmp = dvrr_stack + 1095;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+121195, dvrr_stack+7243, dvrr_stack+927);
 tmp = dvrr_stack + 121195;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+7163, dvrr_stack+108435, dvrr_stack+1889);
 tmp = dvrr_stack + 7163;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+152875, dvrr_stack+111655, dvrr_stack+3748);
 tmp = dvrr_stack + 152875;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+153325, dvrr_stack+115817, dvrr_stack+8027);
 tmp = dvrr_stack + 153325;
 target_ptr = Libderiv->deriv2_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+99598, dvrr_stack+121694, dvrr_stack+13561);
 tmp = dvrr_stack + 99598;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+121475, dvrr_stack+122135, dvrr_stack+13771);
 tmp = dvrr_stack + 121475;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+121895, dvrr_stack+142068, dvrr_stack+143417);
 tmp = dvrr_stack + 121895;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+126408, dvrr_stack+145461, dvrr_stack+1305);
 tmp = dvrr_stack + 126408;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+144917, dvrr_stack+154180, dvrr_stack+148098);
 tmp = dvrr_stack + 144917;
 target_ptr = Libderiv->deriv2_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];


}

