/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hg|hg) integrals */

void d12vrr_order_hghg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+873, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+210, dvrr_stack+873, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+213, dvrr_stack+876, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+892, dvrr_stack+219, dvrr_stack+882, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+907, dvrr_stack+509, dvrr_stack+892, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+952, dvrr_stack+524, dvrr_stack+907, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1042, dvrr_stack+614, dvrr_stack+952, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1192, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1342, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1588, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1609, dvrr_stack+1588, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1672, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1693, dvrr_stack+1672, dvrr_stack+1588, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1756, dvrr_stack+509, dvrr_stack+892, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1777, dvrr_stack+1567, dvrr_stack+1756, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1840, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1966, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2092, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2302, dvrr_stack+593, dvrr_stack+1672, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2365, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2491, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2302, dvrr_stack+873, dvrr_stack+704, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+210, dvrr_stack+873, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2318, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2333, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+219, dvrr_stack+882, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2701, dvrr_stack+1756, dvrr_stack+2333, NULL, NULL, dvrr_stack+892);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2764, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+907);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2890, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+952);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3100, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1042);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3415, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+1192);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3730, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+1342);
 tmp = dvrr_stack + 3730;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2382, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4171, dvrr_stack+2382, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2410, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4255, dvrr_stack+2410, dvrr_stack+2382, NULL, NULL, dvrr_stack+1588);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+479, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+509, dvrr_stack+892, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4339, dvrr_stack+2354, dvrr_stack+479, NULL, NULL, dvrr_stack+1756);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4423, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1777);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4591, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1609);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4759, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+1840);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+1609, dvrr_stack+2410, NULL, NULL, dvrr_stack+1672);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+1693);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5291, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1966);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1966, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1969, dvrr_stack+704, dvrr_stack+1966, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1975, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+873, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+876, dvrr_stack+2302, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2021, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+892, dvrr_stack+2318, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+479, dvrr_stack+2021, NULL, NULL, dvrr_stack+2333);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5571, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+2701);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5739, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2764);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6019, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+2890);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6439, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+2092);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+6859, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+3100);
 tmp = dvrr_stack + 6859;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+7447,dvrr_stack+6859,dvrr_stack+3730,21);


 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+1567, dvrr_stack+1756, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5159, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1588, dvrr_stack+1567, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+5159, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5195, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1672, dvrr_stack+1588, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8878, dvrr_stack+5195, dvrr_stack+5159, NULL, NULL, dvrr_stack+2382);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+1756, dvrr_stack+2333, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8986, dvrr_stack+5123, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9094, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+4339);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9310, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+4171);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9526, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+4423);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+593, dvrr_stack+1672, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+4171, dvrr_stack+5195, NULL, NULL, dvrr_stack+2410);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+4255);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10102, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4591);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4591, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1603, dvrr_stack+1966, dvrr_stack+4591, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+4594, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+704, dvrr_stack+1966, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4604, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+2302, dvrr_stack+1969, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+2308, dvrr_stack+1975, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4619, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+2318, dvrr_stack+1985, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+2333, dvrr_stack+2000, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+1567, dvrr_stack+4647, NULL, NULL, dvrr_stack+2021);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+5039);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10678, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5571);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11038, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+5739);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11578, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+4759);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12118, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+6019);
 tmp = dvrr_stack + 12118;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+12874,dvrr_stack+12118,dvrr_stack+6859,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+14638,dvrr_stack+12874,dvrr_stack+7447,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+17284, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+2354, dvrr_stack+479, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9931, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+2382, dvrr_stack+2354, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+9931, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9976, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+2410, dvrr_stack+2382, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18742, dvrr_stack+9976, dvrr_stack+9931, NULL, NULL, dvrr_stack+5159);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+479, dvrr_stack+2021, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18877, dvrr_stack+9886, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19012, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+8986);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19282, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+8770);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19552, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9094);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+1609, dvrr_stack+2410, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+8770, dvrr_stack+9976, NULL, NULL, dvrr_stack+5195);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+8878);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20407, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+9310);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+9310, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9313, dvrr_stack+4591, dvrr_stack+9310, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+9319, dvrr_stack+1603, dvrr_stack+9313, dvrr_stack+1966, dvrr_stack+4591, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+9329, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+1969, dvrr_stack+1603, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+9344, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+1975, dvrr_stack+4594, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+1985, dvrr_stack+4604, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9365, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2021, dvrr_stack+4619, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+2354, dvrr_stack+9401, NULL, NULL, dvrr_stack+4647);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+1637);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21127, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+10462);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21577, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+10678);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22252, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+9526);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22927, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+11038);
 tmp = dvrr_stack + 22927;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+23872,dvrr_stack+22927,dvrr_stack+12118,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+26140,dvrr_stack+23872,dvrr_stack+12874,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+29668, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+5123, dvrr_stack+1567, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20192, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+5159, dvrr_stack+5123, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20192, dvrr_stack+20137, NULL, NULL, dvrr_stack+9886);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20247, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+5195, dvrr_stack+5159, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+20247, dvrr_stack+20192, NULL, NULL, dvrr_stack+9931);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+1567, dvrr_stack+4647, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+20137, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31762, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+18877);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32092, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+18607);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+19012);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+4171, dvrr_stack+5195, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+18607, dvrr_stack+20247, NULL, NULL, dvrr_stack+9976);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+18742);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33302, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+19282);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19282, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8980, dvrr_stack+9310, dvrr_stack+19282, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+19285, dvrr_stack+9313, dvrr_stack+8980, dvrr_stack+4591, dvrr_stack+9310, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19295, dvrr_stack+9319, dvrr_stack+19285, dvrr_stack+1603, dvrr_stack+9313, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19310, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+4594, dvrr_stack+9319, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19331, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+4604, dvrr_stack+9329, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+593, dvrr_stack+9344, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+4619, dvrr_stack+1609, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+4647, dvrr_stack+9365, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+5123, dvrr_stack+19440, NULL, NULL, dvrr_stack+9401);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+20002);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34182, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20857);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34732, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+21127);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+35557, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+19552);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36382, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+21577);
 tmp = dvrr_stack + 36382;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37537,dvrr_stack+36382,dvrr_stack+22927,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+40372,dvrr_stack+37537,dvrr_stack+23872,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+44908, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+9886, dvrr_stack+2354, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33038, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+9931, dvrr_stack+9886, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33104, dvrr_stack+33038, dvrr_stack+32972, NULL, NULL, dvrr_stack+20137);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+9976, dvrr_stack+9931, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+18662, dvrr_stack+33038, NULL, NULL, dvrr_stack+20192);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+2354, dvrr_stack+9401, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47374, dvrr_stack+32972, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47572, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+31597);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47968, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+8815);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48364, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+31762);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+8770, dvrr_stack+9976, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+8815, dvrr_stack+18662, NULL, NULL, dvrr_stack+20247);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49618, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+32092);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4336, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+32092, dvrr_stack+19282, dvrr_stack+4336, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+32098, dvrr_stack+8980, dvrr_stack+32092, dvrr_stack+9310, dvrr_stack+19282, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32108, dvrr_stack+19285, dvrr_stack+32098, dvrr_stack+9313, dvrr_stack+8980, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+32123, dvrr_stack+19295, dvrr_stack+32108, dvrr_stack+9319, dvrr_stack+19285, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+32144, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+9329, dvrr_stack+19295, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+32172, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+9344, dvrr_stack+19310, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+1609, dvrr_stack+19331, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32208, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+9365, dvrr_stack+19359, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32263, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+9401, dvrr_stack+19395, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+9886, dvrr_stack+32263, NULL, NULL, dvrr_stack+19440);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+4171);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50674, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33852);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51334, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+34182);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+52324, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+32422);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+53314, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+34732);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+54700,dvrr_stack+53314,dvrr_stack+36382,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+58165,dvrr_stack+54700,dvrr_stack+37537,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+63835, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+20137, dvrr_stack+5123, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+20192, dvrr_stack+20137, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49378, dvrr_stack+49300, dvrr_stack+49222, NULL, NULL, dvrr_stack+32972);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49612, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+20247, dvrr_stack+20192, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49690, dvrr_stack+49612, dvrr_stack+49300, NULL, NULL, dvrr_stack+33038);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+5123, dvrr_stack+19440, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49924, dvrr_stack+49222, dvrr_stack+32972, NULL, NULL, dvrr_stack+9886);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+49378, dvrr_stack+49924, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+47374);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67138, dvrr_stack+49690, dvrr_stack+49378, dvrr_stack+49612, dvrr_stack+49300, dvrr_stack+33104);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67606, dvrr_stack+67138, dvrr_stack+66670, dvrr_stack+49690, dvrr_stack+49378, dvrr_stack+47572);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+18607, dvrr_stack+20247, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33050, dvrr_stack+49300, dvrr_stack+49612, NULL, NULL, dvrr_stack+18662);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68386, dvrr_stack+33050, dvrr_stack+49690, dvrr_stack+49300, dvrr_stack+49612, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68854, dvrr_stack+68386, dvrr_stack+67138, dvrr_stack+33050, dvrr_stack+49690, dvrr_stack+47968);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+9310, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+47968, dvrr_stack+4336, dvrr_stack+9310, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+47974, dvrr_stack+32092, dvrr_stack+47968, dvrr_stack+19282, dvrr_stack+4336, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+47984, dvrr_stack+32098, dvrr_stack+47974, dvrr_stack+8980, dvrr_stack+32092, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+47999, dvrr_stack+32108, dvrr_stack+47984, dvrr_stack+19285, dvrr_stack+32098, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+48020, dvrr_stack+32123, dvrr_stack+47999, dvrr_stack+19295, dvrr_stack+32108, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48048, dvrr_stack+32144, dvrr_stack+48020, dvrr_stack+19310, dvrr_stack+32123, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+48084, dvrr_stack+32172, dvrr_stack+48048, dvrr_stack+19331, dvrr_stack+32144, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+48129, dvrr_stack+8770, dvrr_stack+48084, dvrr_stack+19359, dvrr_stack+32172, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48184, dvrr_stack+32208, dvrr_stack+48129, dvrr_stack+19395, dvrr_stack+8770, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+32263, dvrr_stack+48184, dvrr_stack+19440, dvrr_stack+32208, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33050, dvrr_stack+32972, dvrr_stack+49300, NULL, NULL, dvrr_stack+32263);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+69634, dvrr_stack+49924, dvrr_stack+33050, dvrr_stack+49222, dvrr_stack+32972, dvrr_stack+49024);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70102, dvrr_stack+66670, dvrr_stack+69634, dvrr_stack+49378, dvrr_stack+49924, dvrr_stack+50278);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70882, dvrr_stack+67606, dvrr_stack+70102, dvrr_stack+67138, dvrr_stack+66670, dvrr_stack+50674);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+72052, dvrr_stack+68854, dvrr_stack+67606, dvrr_stack+68386, dvrr_stack+67138, dvrr_stack+48364);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+73222, dvrr_stack+72052, dvrr_stack+70882, dvrr_stack+68854, dvrr_stack+67606, dvrr_stack+51334);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+74860,dvrr_stack+73222,dvrr_stack+53314,21);


 /* compute (5 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+79018,dvrr_stack+74860,dvrr_stack+54700,21);


 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+85948, dvrr_stack+79018, dvrr_stack+36382);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+19282, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+569, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+33284, dvrr_stack+6, dvrr_stack+569, dvrr_stack+3, dvrr_stack+0, dvrr_stack+19282);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+67138, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+67156, dvrr_stack+39, dvrr_stack+67138, dvrr_stack+15, dvrr_stack+33, dvrr_stack+569);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+67192, dvrr_stack+75, dvrr_stack+67156, dvrr_stack+57, dvrr_stack+39, dvrr_stack+33284);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+67252, dvrr_stack+219, dvrr_stack+882, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+67282, dvrr_stack+229, dvrr_stack+67252, dvrr_stack+111, dvrr_stack+219, dvrr_stack+67138);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+67342, dvrr_stack+259, dvrr_stack+67282, dvrr_stack+131, dvrr_stack+229, dvrr_stack+67156);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+9952, dvrr_stack+379, dvrr_stack+67342, dvrr_stack+319, dvrr_stack+259, dvrr_stack+67192);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+67442, dvrr_stack+892, dvrr_stack+2318, NULL, NULL, dvrr_stack+882);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+67487, dvrr_stack+907, dvrr_stack+67442, dvrr_stack+509, dvrr_stack+892, dvrr_stack+67252);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+68386, dvrr_stack+952, dvrr_stack+67487, dvrr_stack+524, dvrr_stack+907, dvrr_stack+67282);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+68536, dvrr_stack+1042, dvrr_stack+68386, dvrr_stack+614, dvrr_stack+952, dvrr_stack+67342);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+68761, dvrr_stack+1342, dvrr_stack+68536, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+9952);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2333, dvrr_stack+2000, NULL, NULL, dvrr_stack+2318);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+69076, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+67442);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+69202, dvrr_stack+2764, dvrr_stack+69076, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+67487);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+49378, dvrr_stack+2890, dvrr_stack+69202, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+68386);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+89413, dvrr_stack+3100, dvrr_stack+49378, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+68536);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+89854, dvrr_stack+3730, dvrr_stack+89413, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+68761);
 tmp = dvrr_stack + 89854;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+69412, dvrr_stack+2021, dvrr_stack+4619, NULL, NULL, dvrr_stack+2000);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+49693, dvrr_stack+5039, dvrr_stack+69412, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+90442, dvrr_stack+5571, dvrr_stack+49693, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+69076);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+90722, dvrr_stack+5739, dvrr_stack+90442, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+69202);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+91142, dvrr_stack+6019, dvrr_stack+90722, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+49378);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+91730, dvrr_stack+6859, dvrr_stack+91142, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+89413);
 tmp = dvrr_stack + 91730;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+92514,dvrr_stack+91730,dvrr_stack+89854,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4339, dvrr_stack+4647, dvrr_stack+9365, NULL, NULL, dvrr_stack+4619);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+69412);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94278, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+49693);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94638, dvrr_stack+10678, dvrr_stack+94278, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+90442);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95178, dvrr_stack+11038, dvrr_stack+94638, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+90722);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95934, dvrr_stack+12118, dvrr_stack+95178, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+91142);
 tmp = dvrr_stack + 95934;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+96942,dvrr_stack+95934,dvrr_stack+91730,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+99294,dvrr_stack+96942,dvrr_stack+92514,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+102822, dvrr_stack+99294, dvrr_stack+89854);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4447, dvrr_stack+9401, dvrr_stack+19395, NULL, NULL, dvrr_stack+9365);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+20002, dvrr_stack+4447, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+4339);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20857, dvrr_stack+20137, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+18607);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+104586, dvrr_stack+21127, dvrr_stack+8815, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+94278);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+105261, dvrr_stack+21577, dvrr_stack+104586, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+94638);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+106206, dvrr_stack+22927, dvrr_stack+105261, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+95178);
 tmp = dvrr_stack + 106206;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+107466,dvrr_stack+106206,dvrr_stack+95934,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+110490,dvrr_stack+107466,dvrr_stack+96942,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+115194, dvrr_stack+110490, dvrr_stack+91730);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+19440, dvrr_stack+32208, NULL, NULL, dvrr_stack+19395);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18823, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+4447);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+117546, dvrr_stack+33852, dvrr_stack+18823, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+20137);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+118096, dvrr_stack+34182, dvrr_stack+117546, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+8815);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+118921, dvrr_stack+34732, dvrr_stack+118096, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+104586);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120076, dvrr_stack+36382, dvrr_stack+118921, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+105261);
 tmp = dvrr_stack + 120076;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+121616,dvrr_stack+120076,dvrr_stack+106206,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+125396,dvrr_stack+121616,dvrr_stack+107466,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+131444, dvrr_stack+125396, dvrr_stack+95934);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+32263, dvrr_stack+48184, NULL, NULL, dvrr_stack+32208);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+134468, dvrr_stack+50278, dvrr_stack+31597, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+18823);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+135128, dvrr_stack+50674, dvrr_stack+134468, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+117546);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+136118, dvrr_stack+51334, dvrr_stack+135128, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+118096);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+137504, dvrr_stack+53314, dvrr_stack+136118, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+118921);

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+139352,dvrr_stack+137504,dvrr_stack+120076,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+143972,dvrr_stack+139352,dvrr_stack+121616,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+151532, dvrr_stack+143972, dvrr_stack+106206);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+47374, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+9310, dvrr_stack+47374, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+47968, dvrr_stack+15, dvrr_stack+4336, dvrr_stack+9310, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+47377, dvrr_stack+47974, dvrr_stack+111, dvrr_stack+32092, dvrr_stack+47968, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+47392, dvrr_stack+47984, dvrr_stack+47377, dvrr_stack+32098, dvrr_stack+47974, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+47413, dvrr_stack+47999, dvrr_stack+47392, dvrr_stack+32108, dvrr_stack+47984, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+48020, dvrr_stack+47413, dvrr_stack+32123, dvrr_stack+47999, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9265, dvrr_stack+48048, dvrr_stack+1567, dvrr_stack+32144, dvrr_stack+48020, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+47441, dvrr_stack+48084, dvrr_stack+9265, dvrr_stack+32172, dvrr_stack+48048, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47496, dvrr_stack+48129, dvrr_stack+47441, dvrr_stack+8770, dvrr_stack+48084, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+48184, dvrr_stack+47496, dvrr_stack+32208, dvrr_stack+48129, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47562, dvrr_stack+49300, dvrr_stack+49222, NULL, NULL, dvrr_stack+48184);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48250, dvrr_stack+33050, dvrr_stack+47562, dvrr_stack+32972, dvrr_stack+49300, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+155312, dvrr_stack+69634, dvrr_stack+48250, dvrr_stack+49924, dvrr_stack+33050, dvrr_stack+31597);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+156092, dvrr_stack+70102, dvrr_stack+155312, dvrr_stack+66670, dvrr_stack+69634, dvrr_stack+134468);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+157262, dvrr_stack+70882, dvrr_stack+156092, dvrr_stack+67606, dvrr_stack+70102, dvrr_stack+135128);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+158900, dvrr_stack+73222, dvrr_stack+157262, dvrr_stack+72052, dvrr_stack+70882, dvrr_stack+136118);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+161084,dvrr_stack+158900,dvrr_stack+137504,28);


 /* compute (6 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+166628,dvrr_stack+161084,dvrr_stack+139352,28);


 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+175868, dvrr_stack+166628, dvrr_stack+120076);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+4336, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+72052, dvrr_stack+19282, dvrr_stack+4336, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+4582, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+72058, dvrr_stack+569, dvrr_stack+4582, dvrr_stack+0, dvrr_stack+30, dvrr_stack+4336);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+33284, dvrr_stack+72058, dvrr_stack+6, dvrr_stack+569, dvrr_stack+72052);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+72076, dvrr_stack+213, dvrr_stack+876, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+72094, dvrr_stack+67138, dvrr_stack+72076, dvrr_stack+33, dvrr_stack+213, dvrr_stack+4582);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+72130, dvrr_stack+67156, dvrr_stack+72094, dvrr_stack+39, dvrr_stack+67138, dvrr_stack+72058);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+479, dvrr_stack+67192, dvrr_stack+72130, dvrr_stack+75, dvrr_stack+67156, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+72190, dvrr_stack+882, dvrr_stack+2308, NULL, NULL, dvrr_stack+876);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+72220, dvrr_stack+67252, dvrr_stack+72190, dvrr_stack+219, dvrr_stack+882, dvrr_stack+72076);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+72280, dvrr_stack+67282, dvrr_stack+72220, dvrr_stack+229, dvrr_stack+67252, dvrr_stack+72094);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+72380, dvrr_stack+67342, dvrr_stack+72280, dvrr_stack+259, dvrr_stack+67282, dvrr_stack+72130);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+72530, dvrr_stack+9952, dvrr_stack+72380, dvrr_stack+379, dvrr_stack+67342, dvrr_stack+479);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2318, dvrr_stack+1985, NULL, NULL, dvrr_stack+2308);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+72740, dvrr_stack+67442, dvrr_stack+219, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+72190);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+72830, dvrr_stack+67487, dvrr_stack+72740, dvrr_stack+907, dvrr_stack+67442, dvrr_stack+72220);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+72980, dvrr_stack+68386, dvrr_stack+72830, dvrr_stack+952, dvrr_stack+67487, dvrr_stack+72280);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+66670, dvrr_stack+68536, dvrr_stack+72980, dvrr_stack+1042, dvrr_stack+68386, dvrr_stack+72380);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+67577, dvrr_stack+68761, dvrr_stack+66670, dvrr_stack+1342, dvrr_stack+68536, dvrr_stack+72530);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+892, dvrr_stack+2000, dvrr_stack+593, NULL, NULL, dvrr_stack+1985);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+955, dvrr_stack+614, dvrr_stack+892, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+67997, dvrr_stack+69076, dvrr_stack+955, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+72740);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+49861, dvrr_stack+69202, dvrr_stack+67997, dvrr_stack+2764, dvrr_stack+69076, dvrr_stack+72830);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+32329, dvrr_stack+49378, dvrr_stack+49861, dvrr_stack+2890, dvrr_stack+69202, dvrr_stack+72980);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+180488, dvrr_stack+89413, dvrr_stack+32329, dvrr_stack+3100, dvrr_stack+49378, dvrr_stack+66670);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+181076, dvrr_stack+89854, dvrr_stack+180488, dvrr_stack+3730, dvrr_stack+89413, dvrr_stack+67577);
 tmp = dvrr_stack + 181076;
 target_ptr = Libderiv->dvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2701, dvrr_stack+4619, dvrr_stack+1609, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+69412, dvrr_stack+2701, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+892);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+32770, dvrr_stack+49693, dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+69412, dvrr_stack+955);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+2785, dvrr_stack+90442, dvrr_stack+32770, dvrr_stack+5571, dvrr_stack+49693, dvrr_stack+67997);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+181832, dvrr_stack+90722, dvrr_stack+2785, dvrr_stack+5739, dvrr_stack+90442, dvrr_stack+49861);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+182420, dvrr_stack+91142, dvrr_stack+181832, dvrr_stack+6019, dvrr_stack+90722, dvrr_stack+32329);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+183204, dvrr_stack+91730, dvrr_stack+182420, dvrr_stack+6859, dvrr_stack+91142, dvrr_stack+180488);
 tmp = dvrr_stack + 183204;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+184212,dvrr_stack+183204,dvrr_stack+181076,36);


 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+9365, dvrr_stack+19359, NULL, NULL, dvrr_stack+1609);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5679, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2701);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+18607, dvrr_stack+5679, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+5123);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5895, dvrr_stack+94278, dvrr_stack+4647, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+32770);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+186480, dvrr_stack+94638, dvrr_stack+5895, dvrr_stack+10678, dvrr_stack+94278, dvrr_stack+2785);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+187236, dvrr_stack+95178, dvrr_stack+186480, dvrr_stack+11038, dvrr_stack+94638, dvrr_stack+181832);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+188244, dvrr_stack+95934, dvrr_stack+187236, dvrr_stack+12118, dvrr_stack+95178, dvrr_stack+182420);
 tmp = dvrr_stack + 188244;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+189540,dvrr_stack+188244,dvrr_stack+183204,36);


 /* compute (7 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+192564,dvrr_stack+189540,dvrr_stack+184212,36);


 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+197100, dvrr_stack+192564, dvrr_stack+181076);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+19395, dvrr_stack+8770, NULL, NULL, dvrr_stack+19359);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10597, dvrr_stack+4447, dvrr_stack+10462, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+5571);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+20137, dvrr_stack+10597, dvrr_stack+20002, dvrr_stack+4447, dvrr_stack+5679);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10867, dvrr_stack+8815, dvrr_stack+9401, dvrr_stack+20857, dvrr_stack+20137, dvrr_stack+4647);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+199368, dvrr_stack+104586, dvrr_stack+10867, dvrr_stack+21127, dvrr_stack+8815, dvrr_stack+5895);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+200313, dvrr_stack+105261, dvrr_stack+199368, dvrr_stack+21577, dvrr_stack+104586, dvrr_stack+186480);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+201573, dvrr_stack+106206, dvrr_stack+200313, dvrr_stack+22927, dvrr_stack+105261, dvrr_stack+187236);
 tmp = dvrr_stack + 201573;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+203193,dvrr_stack+201573,dvrr_stack+188244,36);


 /* compute (7 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+207081,dvrr_stack+203193,dvrr_stack+189540,36);


 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+213129, dvrr_stack+207081, dvrr_stack+183204);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+32208, dvrr_stack+48129, NULL, NULL, dvrr_stack+8770);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21022, dvrr_stack+31432, dvrr_stack+20857, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+10462);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+18823, dvrr_stack+21022, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+10597);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21352, dvrr_stack+117546, dvrr_stack+19440, dvrr_stack+33852, dvrr_stack+18823, dvrr_stack+9401);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+216153, dvrr_stack+118096, dvrr_stack+21352, dvrr_stack+34182, dvrr_stack+117546, dvrr_stack+10867);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+217308, dvrr_stack+118921, dvrr_stack+216153, dvrr_stack+34732, dvrr_stack+118096, dvrr_stack+199368);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+218848, dvrr_stack+120076, dvrr_stack+217308, dvrr_stack+36382, dvrr_stack+118921, dvrr_stack+200313);
 tmp = dvrr_stack + 218848;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+220828,dvrr_stack+218848,dvrr_stack+201573,36);


 /* compute (7 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+225688,dvrr_stack+220828,dvrr_stack+203193,36);


 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1296,dvrr_stack+233464, dvrr_stack+225688, dvrr_stack+188244);

 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+48184, dvrr_stack+47496, NULL, NULL, dvrr_stack+48129);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34050, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+32263, dvrr_stack+48184, dvrr_stack+20857);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34446, dvrr_stack+31597, dvrr_stack+34050, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+21022);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+237352, dvrr_stack+134468, dvrr_stack+34446, dvrr_stack+50278, dvrr_stack+31597, dvrr_stack+19440);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+238342, dvrr_stack+135128, dvrr_stack+237352, dvrr_stack+50674, dvrr_stack+134468, dvrr_stack+21352);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+239728, dvrr_stack+136118, dvrr_stack+238342, dvrr_stack+51334, dvrr_stack+135128, dvrr_stack+216153);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+241576, dvrr_stack+137504, dvrr_stack+239728, dvrr_stack+53314, dvrr_stack+136118, dvrr_stack+217308);

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+243952,dvrr_stack+241576,dvrr_stack+218848,36);


 /* compute (7 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+249892,dvrr_stack+243952,dvrr_stack+220828,36);


 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+259612, dvrr_stack+249892, dvrr_stack+201573);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+32263, dvrr_stack+47374, dvrr_stack+0, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+32269, dvrr_stack+15, dvrr_stack+32263, dvrr_stack+9310, dvrr_stack+47374, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32279, dvrr_stack+111, dvrr_stack+32269, dvrr_stack+47968, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+32294, dvrr_stack+47377, dvrr_stack+32279, dvrr_stack+47974, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+35106, dvrr_stack+47392, dvrr_stack+32294, dvrr_stack+47984, dvrr_stack+47377, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11542, dvrr_stack+47413, dvrr_stack+35106, dvrr_stack+47999, dvrr_stack+47392, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+35134, dvrr_stack+1567, dvrr_stack+11542, dvrr_stack+48020, dvrr_stack+47413, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264, dvrr_stack+9265, dvrr_stack+35134, dvrr_stack+48048, dvrr_stack+1567, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35179, dvrr_stack+47441, dvrr_stack+264, dvrr_stack+48084, dvrr_stack+9265, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+35245, dvrr_stack+47496, dvrr_stack+35179, dvrr_stack+48129, dvrr_stack+47441, NULL);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+35323, dvrr_stack+49222, dvrr_stack+35245, NULL, NULL, dvrr_stack+47496);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50176, dvrr_stack+47562, dvrr_stack+35323, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+33852);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50644, dvrr_stack+48250, dvrr_stack+50176, dvrr_stack+33050, dvrr_stack+47562, dvrr_stack+34050);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+264472, dvrr_stack+155312, dvrr_stack+50644, dvrr_stack+69634, dvrr_stack+48250, dvrr_stack+34446);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+265642, dvrr_stack+156092, dvrr_stack+264472, dvrr_stack+70102, dvrr_stack+155312, dvrr_stack+237352);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+267280, dvrr_stack+157262, dvrr_stack+265642, dvrr_stack+70882, dvrr_stack+156092, dvrr_stack+238342);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+269464, dvrr_stack+158900, dvrr_stack+267280, dvrr_stack+73222, dvrr_stack+157262, dvrr_stack+239728);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+272272,dvrr_stack+269464,dvrr_stack+241576,36);


 /* compute (7 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+279400,dvrr_stack+272272,dvrr_stack+243952,36);


 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+291280, dvrr_stack+279400, dvrr_stack+218848);

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+9310, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+33050, dvrr_stack+4336, dvrr_stack+9310, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+33056, dvrr_stack+72052, dvrr_stack+33050, dvrr_stack+19282, dvrr_stack+4336, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+33066, dvrr_stack+210, dvrr_stack+873, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+33075, dvrr_stack+4582, dvrr_stack+33066, dvrr_stack+30, dvrr_stack+210, dvrr_stack+9310);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+33093, dvrr_stack+72058, dvrr_stack+33075, dvrr_stack+569, dvrr_stack+4582, dvrr_stack+33050);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+33123, dvrr_stack+131, dvrr_stack+33093, dvrr_stack+33284, dvrr_stack+72058, dvrr_stack+33056);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+30, dvrr_stack+876, dvrr_stack+2302, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+33168, dvrr_stack+72076, dvrr_stack+30, dvrr_stack+213, dvrr_stack+876, dvrr_stack+33066);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+33204, dvrr_stack+72094, dvrr_stack+33168, dvrr_stack+67138, dvrr_stack+72076, dvrr_stack+33075);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+4171, dvrr_stack+72130, dvrr_stack+33204, dvrr_stack+67156, dvrr_stack+72094, dvrr_stack+33093);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+19990, dvrr_stack+479, dvrr_stack+4171, dvrr_stack+67192, dvrr_stack+72130, dvrr_stack+33123);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+49300, dvrr_stack+2308, dvrr_stack+1975, NULL, NULL, dvrr_stack+2302);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+4261, dvrr_stack+72190, dvrr_stack+49300, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+30);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+9851, dvrr_stack+72220, dvrr_stack+4261, dvrr_stack+67252, dvrr_stack+72190, dvrr_stack+33168);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+1637, dvrr_stack+72280, dvrr_stack+9851, dvrr_stack+67282, dvrr_stack+72220, dvrr_stack+33204);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+3205, dvrr_stack+72380, dvrr_stack+1637, dvrr_stack+67342, dvrr_stack+72280, dvrr_stack+4171);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2021, dvrr_stack+72530, dvrr_stack+3205, dvrr_stack+9952, dvrr_stack+72380, dvrr_stack+19990);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+67252, dvrr_stack+1985, dvrr_stack+4604, NULL, NULL, dvrr_stack+1975);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+67297, dvrr_stack+219, dvrr_stack+67252, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+49300);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+2318, dvrr_stack+72740, dvrr_stack+67297, dvrr_stack+67442, dvrr_stack+219, dvrr_stack+4261);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+69496, dvrr_stack+72830, dvrr_stack+2318, dvrr_stack+67487, dvrr_stack+72740, dvrr_stack+9851);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+69721, dvrr_stack+72980, dvrr_stack+69496, dvrr_stack+68386, dvrr_stack+72830, dvrr_stack+1637);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+70036, dvrr_stack+66670, dvrr_stack+69721, dvrr_stack+68536, dvrr_stack+72980, dvrr_stack+3205);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+68207, dvrr_stack+67577, dvrr_stack+70036, dvrr_stack+68761, dvrr_stack+66670, dvrr_stack+2021);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+67387, dvrr_stack+593, dvrr_stack+9344, NULL, NULL, dvrr_stack+4604);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+67450, dvrr_stack+892, dvrr_stack+67387, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+67252);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+70456, dvrr_stack+955, dvrr_stack+67450, dvrr_stack+614, dvrr_stack+892, dvrr_stack+67297);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+70666, dvrr_stack+67997, dvrr_stack+70456, dvrr_stack+69076, dvrr_stack+955, dvrr_stack+2318);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+70981, dvrr_stack+49861, dvrr_stack+70666, dvrr_stack+69202, dvrr_stack+67997, dvrr_stack+69496);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+71422, dvrr_stack+32329, dvrr_stack+70981, dvrr_stack+49378, dvrr_stack+49861, dvrr_stack+69721);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+51424, dvrr_stack+180488, dvrr_stack+71422, dvrr_stack+89413, dvrr_stack+32329, dvrr_stack+70036);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+297220, dvrr_stack+181076, dvrr_stack+51424, dvrr_stack+89854, dvrr_stack+180488, dvrr_stack+68207);
 tmp = dvrr_stack + 297220;
 target_ptr = Libderiv->dvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+89413, dvrr_stack+1609, dvrr_stack+19331, NULL, NULL, dvrr_stack+9344);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+89497, dvrr_stack+2701, dvrr_stack+89413, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+67387);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+69076, dvrr_stack+5123, dvrr_stack+89497, dvrr_stack+69412, dvrr_stack+2701, dvrr_stack+67450);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+48718, dvrr_stack+32770, dvrr_stack+69076, dvrr_stack+49693, dvrr_stack+5123, dvrr_stack+70456);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+298165, dvrr_stack+2785, dvrr_stack+48718, dvrr_stack+90442, dvrr_stack+32770, dvrr_stack+70666);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+298753, dvrr_stack+181832, dvrr_stack+298165, dvrr_stack+90722, dvrr_stack+2785, dvrr_stack+70981);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+299537, dvrr_stack+182420, dvrr_stack+298753, dvrr_stack+91142, dvrr_stack+181832, dvrr_stack+71422);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+90442, dvrr_stack+183204, dvrr_stack+299537, dvrr_stack+91730, dvrr_stack+182420, dvrr_stack+51424);
 tmp = dvrr_stack + 90442;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+300545,dvrr_stack+90442,dvrr_stack+297220,45);


 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+89665, dvrr_stack+19359, dvrr_stack+32172, NULL, NULL, dvrr_stack+19331);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+49330, dvrr_stack+5571, dvrr_stack+89665, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+89413);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303380, dvrr_stack+5679, dvrr_stack+49330, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+89497);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303740, dvrr_stack+4647, dvrr_stack+303380, dvrr_stack+18607, dvrr_stack+5679, dvrr_stack+69076);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+304280, dvrr_stack+5895, dvrr_stack+303740, dvrr_stack+94278, dvrr_stack+4647, dvrr_stack+48718);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+305036, dvrr_stack+186480, dvrr_stack+304280, dvrr_stack+94638, dvrr_stack+5895, dvrr_stack+298165);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+306044, dvrr_stack+187236, dvrr_stack+305036, dvrr_stack+95178, dvrr_stack+186480, dvrr_stack+298753);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94278, dvrr_stack+188244, dvrr_stack+306044, dvrr_stack+95934, dvrr_stack+187236, dvrr_stack+299537);
 tmp = dvrr_stack + 94278;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+307340,dvrr_stack+94278,dvrr_stack+90442,45);


 /* compute (8 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+311120,dvrr_stack+307340,dvrr_stack+300545,45);


 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+316790, dvrr_stack+311120, dvrr_stack+297220);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+48084, NULL, NULL, dvrr_stack+32172);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+49546, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+89665);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+319625, dvrr_stack+10597, dvrr_stack+49546, dvrr_stack+4447, dvrr_stack+10462, dvrr_stack+49330);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320075, dvrr_stack+9401, dvrr_stack+319625, dvrr_stack+20137, dvrr_stack+10597, dvrr_stack+303380);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320750, dvrr_stack+10867, dvrr_stack+320075, dvrr_stack+8815, dvrr_stack+9401, dvrr_stack+303740);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+321695, dvrr_stack+199368, dvrr_stack+320750, dvrr_stack+104586, dvrr_stack+10867, dvrr_stack+304280);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+322955, dvrr_stack+200313, dvrr_stack+321695, dvrr_stack+105261, dvrr_stack+199368, dvrr_stack+305036);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+324575, dvrr_stack+201573, dvrr_stack+322955, dvrr_stack+106206, dvrr_stack+200313, dvrr_stack+306044);
 tmp = dvrr_stack + 324575;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+326600,dvrr_stack+324575,dvrr_stack+94278,45);


 /* compute (8 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+331460,dvrr_stack+326600,dvrr_stack+307340,45);


 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+339020, dvrr_stack+331460, dvrr_stack+90442);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+104586, dvrr_stack+48129, dvrr_stack+47441, NULL, NULL, dvrr_stack+48084);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+104751, dvrr_stack+20857, dvrr_stack+104586, dvrr_stack+32208, dvrr_stack+48129, dvrr_stack+18607);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+105081, dvrr_stack+21022, dvrr_stack+104751, dvrr_stack+31432, dvrr_stack+20857, dvrr_stack+49546);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+342800, dvrr_stack+19440, dvrr_stack+105081, dvrr_stack+18823, dvrr_stack+21022, dvrr_stack+319625);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+343625, dvrr_stack+21352, dvrr_stack+342800, dvrr_stack+117546, dvrr_stack+19440, dvrr_stack+320075);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+344780, dvrr_stack+216153, dvrr_stack+343625, dvrr_stack+118096, dvrr_stack+21352, dvrr_stack+320750);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+346320, dvrr_stack+217308, dvrr_stack+344780, dvrr_stack+118921, dvrr_stack+216153, dvrr_stack+321695);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+117546, dvrr_stack+218848, dvrr_stack+346320, dvrr_stack+120076, dvrr_stack+217308, dvrr_stack+322955);
 tmp = dvrr_stack + 117546;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+348300,dvrr_stack+117546,dvrr_stack+324575,45);


 /* compute (8 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+354375,dvrr_stack+348300,dvrr_stack+326600,45);


 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+364095, dvrr_stack+354375, dvrr_stack+94278);

 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+105631, dvrr_stack+47496, dvrr_stack+35179, NULL, NULL, dvrr_stack+47441);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+33852, dvrr_stack+105631, dvrr_stack+48184, dvrr_stack+47496, dvrr_stack+104586);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368955, dvrr_stack+34050, dvrr_stack+8815, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+104751);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+369615, dvrr_stack+34446, dvrr_stack+368955, dvrr_stack+31597, dvrr_stack+34050, dvrr_stack+105081);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+370605, dvrr_stack+237352, dvrr_stack+369615, dvrr_stack+134468, dvrr_stack+34446, dvrr_stack+342800);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+371991, dvrr_stack+238342, dvrr_stack+370605, dvrr_stack+135128, dvrr_stack+237352, dvrr_stack+343625);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+373839, dvrr_stack+239728, dvrr_stack+371991, dvrr_stack+136118, dvrr_stack+238342, dvrr_stack+344780);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+134468, dvrr_stack+241576, dvrr_stack+373839, dvrr_stack+137504, dvrr_stack+239728, dvrr_stack+346320);

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+376215,dvrr_stack+134468,dvrr_stack+117546,45);


 /* compute (8 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+383640,dvrr_stack+376215,dvrr_stack+348300,45);


 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2025,dvrr_stack+395790, dvrr_stack+383640, dvrr_stack+324575);

 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+137438, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+0, dvrr_stack+137438, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+32263, dvrr_stack+213, dvrr_stack+47374, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4321, dvrr_stack+32269, dvrr_stack+882, dvrr_stack+15, dvrr_stack+32263, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+32279, dvrr_stack+4321, dvrr_stack+111, dvrr_stack+32269, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+91702, dvrr_stack+32294, dvrr_stack+2000, dvrr_stack+47377, dvrr_stack+32279, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95898, dvrr_stack+35106, dvrr_stack+91702, dvrr_stack+47392, dvrr_stack+32294, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+11542, dvrr_stack+95898, dvrr_stack+47413, dvrr_stack+35106, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120021, dvrr_stack+35134, dvrr_stack+19395, dvrr_stack+1567, dvrr_stack+11542, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48184, dvrr_stack+264, dvrr_stack+120021, dvrr_stack+9265, dvrr_stack+35134, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+35179, dvrr_stack+48184, dvrr_stack+47441, dvrr_stack+264, NULL);

 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+35245, dvrr_stack+47176, NULL, NULL, dvrr_stack+35179);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18742, dvrr_stack+35323, dvrr_stack+31432, dvrr_stack+49222, dvrr_stack+35245, dvrr_stack+105631);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+401865, dvrr_stack+50176, dvrr_stack+18742, dvrr_stack+47562, dvrr_stack+35323, dvrr_stack+8815);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+402645, dvrr_stack+50644, dvrr_stack+401865, dvrr_stack+48250, dvrr_stack+50176, dvrr_stack+368955);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+403815, dvrr_stack+264472, dvrr_stack+402645, dvrr_stack+155312, dvrr_stack+50644, dvrr_stack+369615);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+405453, dvrr_stack+265642, dvrr_stack+403815, dvrr_stack+156092, dvrr_stack+264472, dvrr_stack+370605);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+407637, dvrr_stack+267280, dvrr_stack+405453, dvrr_stack+157262, dvrr_stack+265642, dvrr_stack+371991);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+155312, dvrr_stack+269464, dvrr_stack+407637, dvrr_stack+158900, dvrr_stack+267280, dvrr_stack+373839);

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+410445,dvrr_stack+155312,dvrr_stack+134468,45);


 /* compute (8 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+419355,dvrr_stack+410445,dvrr_stack+376215,45);


 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+434205, dvrr_stack+419355, dvrr_stack+117546);

 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+158822, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+15, dvrr_stack+9310, dvrr_stack+158822, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+111, dvrr_stack+33050, dvrr_stack+15, dvrr_stack+4336, dvrr_stack+9310, NULL);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+4336, dvrr_stack+33056, dvrr_stack+111, dvrr_stack+72052, dvrr_stack+33050, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+569, dvrr_stack+873, dvrr_stack+704, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+4351, dvrr_stack+33066, dvrr_stack+569, dvrr_stack+210, dvrr_stack+873, dvrr_stack+158822);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+4369, dvrr_stack+33075, dvrr_stack+4351, dvrr_stack+4582, dvrr_stack+33066, dvrr_stack+15);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+49816, dvrr_stack+33093, dvrr_stack+4369, dvrr_stack+72058, dvrr_stack+33075, dvrr_stack+111);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+137441, dvrr_stack+33123, dvrr_stack+49816, dvrr_stack+131, dvrr_stack+33093, dvrr_stack+4336);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+72058, dvrr_stack+2302, dvrr_stack+1969, NULL, NULL, dvrr_stack+704);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+9365, dvrr_stack+30, dvrr_stack+72058, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+569);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+4399, dvrr_stack+33168, dvrr_stack+9365, dvrr_stack+72076, dvrr_stack+30, dvrr_stack+4351);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+614, dvrr_stack+33204, dvrr_stack+4399, dvrr_stack+72094, dvrr_stack+33168, dvrr_stack+4369);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+4459, dvrr_stack+4171, dvrr_stack+614, dvrr_stack+72130, dvrr_stack+33204, dvrr_stack+49816);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+48250, dvrr_stack+19990, dvrr_stack+4459, dvrr_stack+479, dvrr_stack+4171, dvrr_stack+137441);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+72076, dvrr_stack+1975, dvrr_stack+4594, NULL, NULL, dvrr_stack+1969);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+72106, dvrr_stack+49300, dvrr_stack+72076, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+72058);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+48418, dvrr_stack+4261, dvrr_stack+72106, dvrr_stack+72190, dvrr_stack+49300, dvrr_stack+9365);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+48518, dvrr_stack+9851, dvrr_stack+48418, dvrr_stack+72220, dvrr_stack+4261, dvrr_stack+4399);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+47562, dvrr_stack+1637, dvrr_stack+48518, dvrr_stack+72280, dvrr_stack+9851, dvrr_stack+614);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+31666, dvrr_stack+3205, dvrr_stack+47562, dvrr_stack+72380, dvrr_stack+1637, dvrr_stack+4459);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+72166, dvrr_stack+2021, dvrr_stack+31666, dvrr_stack+72530, dvrr_stack+3205, dvrr_stack+48250);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+158825, dvrr_stack+4604, dvrr_stack+9329, NULL, NULL, dvrr_stack+4594);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+47772, dvrr_stack+67252, dvrr_stack+158825, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+72076);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+47254, dvrr_stack+67297, dvrr_stack+47772, dvrr_stack+219, dvrr_stack+67252, dvrr_stack+72106);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+105829, dvrr_stack+2318, dvrr_stack+47254, dvrr_stack+72740, dvrr_stack+67297, dvrr_stack+48418);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+441630, dvrr_stack+69496, dvrr_stack+105829, dvrr_stack+72830, dvrr_stack+2318, dvrr_stack+48518);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+441945, dvrr_stack+69721, dvrr_stack+441630, dvrr_stack+72980, dvrr_stack+69496, dvrr_stack+47562);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+442365, dvrr_stack+70036, dvrr_stack+441945, dvrr_stack+66670, dvrr_stack+69721, dvrr_stack+31666);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+442905, dvrr_stack+68207, dvrr_stack+442365, dvrr_stack+67577, dvrr_stack+70036, dvrr_stack+72166);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+66670, dvrr_stack+9344, dvrr_stack+19310, NULL, NULL, dvrr_stack+9329);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+66733, dvrr_stack+67387, dvrr_stack+66670, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+158825);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+66859, dvrr_stack+67450, dvrr_stack+66733, dvrr_stack+892, dvrr_stack+67387, dvrr_stack+47772);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+72740, dvrr_stack+70456, dvrr_stack+66859, dvrr_stack+955, dvrr_stack+67450, dvrr_stack+47254);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+443580, dvrr_stack+70666, dvrr_stack+72740, dvrr_stack+67997, dvrr_stack+70456, dvrr_stack+105829);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+444021, dvrr_stack+70981, dvrr_stack+443580, dvrr_stack+49861, dvrr_stack+70666, dvrr_stack+441630);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+444609, dvrr_stack+71422, dvrr_stack+444021, dvrr_stack+32329, dvrr_stack+70981, dvrr_stack+441945);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+445365, dvrr_stack+51424, dvrr_stack+444609, dvrr_stack+180488, dvrr_stack+71422, dvrr_stack+442365);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+446310, dvrr_stack+297220, dvrr_stack+445365, dvrr_stack+181076, dvrr_stack+51424, dvrr_stack+442905);
 tmp = dvrr_stack + 446310;
 target_ptr = Libderiv->dvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+180488, dvrr_stack+19331, dvrr_stack+32144, NULL, NULL, dvrr_stack+19310);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+180572, dvrr_stack+89413, dvrr_stack+180488, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+66670);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+180740, dvrr_stack+89497, dvrr_stack+180572, dvrr_stack+2701, dvrr_stack+89413, dvrr_stack+66733);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+32315, dvrr_stack+69076, dvrr_stack+180740, dvrr_stack+5123, dvrr_stack+89497, dvrr_stack+66859);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+447465, dvrr_stack+48718, dvrr_stack+32315, dvrr_stack+32770, dvrr_stack+69076, dvrr_stack+72740);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+448053, dvrr_stack+298165, dvrr_stack+447465, dvrr_stack+2785, dvrr_stack+48718, dvrr_stack+443580);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+448837, dvrr_stack+298753, dvrr_stack+448053, dvrr_stack+181832, dvrr_stack+298165, dvrr_stack+444021);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+449845, dvrr_stack+299537, dvrr_stack+448837, dvrr_stack+182420, dvrr_stack+298753, dvrr_stack+444609);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+451105, dvrr_stack+90442, dvrr_stack+449845, dvrr_stack+183204, dvrr_stack+299537, dvrr_stack+445365);
 tmp = dvrr_stack + 451105;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+452645,dvrr_stack+451105,dvrr_stack+446310,55);


 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+181832, dvrr_stack+32172, dvrr_stack+48048, NULL, NULL, dvrr_stack+32144);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+181940, dvrr_stack+89665, dvrr_stack+181832, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+180488);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+182156, dvrr_stack+49330, dvrr_stack+181940, dvrr_stack+5571, dvrr_stack+89665, dvrr_stack+180572);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+182516, dvrr_stack+303380, dvrr_stack+182156, dvrr_stack+5679, dvrr_stack+49330, dvrr_stack+180740);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+456110, dvrr_stack+303740, dvrr_stack+182516, dvrr_stack+4647, dvrr_stack+303380, dvrr_stack+32315);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+456866, dvrr_stack+304280, dvrr_stack+456110, dvrr_stack+5895, dvrr_stack+303740, dvrr_stack+447465);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+457874, dvrr_stack+305036, dvrr_stack+456866, dvrr_stack+186480, dvrr_stack+304280, dvrr_stack+448053);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+459170, dvrr_stack+306044, dvrr_stack+457874, dvrr_stack+187236, dvrr_stack+305036, dvrr_stack+448837);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+460790, dvrr_stack+94278, dvrr_stack+459170, dvrr_stack+188244, dvrr_stack+306044, dvrr_stack+449845);
 tmp = dvrr_stack + 460790;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+462770,dvrr_stack+460790,dvrr_stack+451105,55);


 /* compute (9 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+467390,dvrr_stack+462770,dvrr_stack+452645,55);


 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+474320, dvrr_stack+467390, dvrr_stack+446310);

 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+186480, dvrr_stack+48084, dvrr_stack+9265, NULL, NULL, dvrr_stack+48048);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+186615, dvrr_stack+18607, dvrr_stack+186480, dvrr_stack+8770, dvrr_stack+48084, dvrr_stack+181832);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+186885, dvrr_stack+49546, dvrr_stack+186615, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+181940);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+187335, dvrr_stack+319625, dvrr_stack+186885, dvrr_stack+10597, dvrr_stack+49546, dvrr_stack+182156);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+477785, dvrr_stack+320075, dvrr_stack+187335, dvrr_stack+9401, dvrr_stack+319625, dvrr_stack+182516);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+478730, dvrr_stack+320750, dvrr_stack+477785, dvrr_stack+10867, dvrr_stack+320075, dvrr_stack+456110);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+479990, dvrr_stack+321695, dvrr_stack+478730, dvrr_stack+199368, dvrr_stack+320750, dvrr_stack+456866);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+481610, dvrr_stack+322955, dvrr_stack+479990, dvrr_stack+200313, dvrr_stack+321695, dvrr_stack+457874);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+483635, dvrr_stack+324575, dvrr_stack+481610, dvrr_stack+201573, dvrr_stack+322955, dvrr_stack+459170);
 tmp = dvrr_stack + 483635;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+486110,dvrr_stack+483635,dvrr_stack+460790,55);


 /* compute (9 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+492050,dvrr_stack+486110,dvrr_stack+462770,55);


 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+501290, dvrr_stack+492050, dvrr_stack+451105);

 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+199368, dvrr_stack+47441, dvrr_stack+264, NULL, NULL, dvrr_stack+9265);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+199533, dvrr_stack+104586, dvrr_stack+199368, dvrr_stack+48129, dvrr_stack+47441, dvrr_stack+186480);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+199863, dvrr_stack+104751, dvrr_stack+199533, dvrr_stack+20857, dvrr_stack+104586, dvrr_stack+186615);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+200413, dvrr_stack+105081, dvrr_stack+199863, dvrr_stack+21022, dvrr_stack+104751, dvrr_stack+186885);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+505910, dvrr_stack+342800, dvrr_stack+200413, dvrr_stack+19440, dvrr_stack+105081, dvrr_stack+187335);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+507065, dvrr_stack+343625, dvrr_stack+505910, dvrr_stack+21352, dvrr_stack+342800, dvrr_stack+477785);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+508605, dvrr_stack+344780, dvrr_stack+507065, dvrr_stack+216153, dvrr_stack+343625, dvrr_stack+478730);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+510585, dvrr_stack+346320, dvrr_stack+508605, dvrr_stack+217308, dvrr_stack+344780, dvrr_stack+479990);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+513060, dvrr_stack+117546, dvrr_stack+510585, dvrr_stack+218848, dvrr_stack+346320, dvrr_stack+481610);

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+516085,dvrr_stack+513060,dvrr_stack+483635,55);


 /* compute (9 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+523510,dvrr_stack+516085,dvrr_stack+486110,55);


 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+535390, dvrr_stack+523510, dvrr_stack+460790);

 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+216153, dvrr_stack+35179, dvrr_stack+48184, NULL, NULL, dvrr_stack+264);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+216351, dvrr_stack+105631, dvrr_stack+216153, dvrr_stack+47496, dvrr_stack+35179, dvrr_stack+199368);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+216747, dvrr_stack+8815, dvrr_stack+216351, dvrr_stack+33852, dvrr_stack+105631, dvrr_stack+199533);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+217407, dvrr_stack+368955, dvrr_stack+216747, dvrr_stack+34050, dvrr_stack+8815, dvrr_stack+199863);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+369615, dvrr_stack+217407, dvrr_stack+34446, dvrr_stack+368955, dvrr_stack+200413);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+541330, dvrr_stack+370605, dvrr_stack+20857, dvrr_stack+237352, dvrr_stack+369615, dvrr_stack+505910);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+543178, dvrr_stack+371991, dvrr_stack+541330, dvrr_stack+238342, dvrr_stack+370605, dvrr_stack+507065);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+545554, dvrr_stack+373839, dvrr_stack+543178, dvrr_stack+239728, dvrr_stack+371991, dvrr_stack+508605);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+237352, dvrr_stack+134468, dvrr_stack+545554, dvrr_stack+241576, dvrr_stack+373839, dvrr_stack+510585);

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+548524,dvrr_stack+237352,dvrr_stack+513060,55);


 /* compute (9 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+557599,dvrr_stack+548524,dvrr_stack+516085,55);


 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+572449, dvrr_stack+557599, dvrr_stack+483635);

 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+137438, dvrr_stack+210, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, dvrr_stack+0, dvrr_stack+137438, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+32263, dvrr_stack+213, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+4321, dvrr_stack+1985, dvrr_stack+32269, dvrr_stack+882, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+32279, dvrr_stack+4321, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+91702, dvrr_stack+1609, dvrr_stack+32294, dvrr_stack+2000, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+95898, dvrr_stack+19359, dvrr_stack+35106, dvrr_stack+91702, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+48129, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+11542, dvrr_stack+95898, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47496, dvrr_stack+120021, dvrr_stack+48129, dvrr_stack+35134, dvrr_stack+19395, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+876, dvrr_stack+48184, dvrr_stack+47496, dvrr_stack+264, dvrr_stack+120021, NULL);

 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+188010, dvrr_stack+47176, dvrr_stack+876, NULL, NULL, dvrr_stack+48184);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+240982, dvrr_stack+31432, dvrr_stack+188010, dvrr_stack+35245, dvrr_stack+47176, dvrr_stack+216153);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+18742, dvrr_stack+240982, dvrr_stack+35323, dvrr_stack+31432, dvrr_stack+216351);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+579874, dvrr_stack+401865, dvrr_stack+33852, dvrr_stack+50176, dvrr_stack+18742, dvrr_stack+216747);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+581044, dvrr_stack+402645, dvrr_stack+579874, dvrr_stack+50644, dvrr_stack+401865, dvrr_stack+217407);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+582682, dvrr_stack+403815, dvrr_stack+581044, dvrr_stack+264472, dvrr_stack+402645, dvrr_stack+20857);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+579874, dvrr_stack+405453, dvrr_stack+582682, dvrr_stack+265642, dvrr_stack+403815, dvrr_stack+541330);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+401865, dvrr_stack+407637, dvrr_stack+579874, dvrr_stack+267280, dvrr_stack+405453, dvrr_stack+543178);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+579874, dvrr_stack+155312, dvrr_stack+401865, dvrr_stack+269464, dvrr_stack+407637, dvrr_stack+545554);

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+584164,dvrr_stack+579874,dvrr_stack+237352,55);


 /* compute (9 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+595054,dvrr_stack+584164,dvrr_stack+548524,55);


 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,3025,dvrr_stack+613204, dvrr_stack+595054, dvrr_stack+513060);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+401865, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+403188, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+404952, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+407220, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+264472, dvrr_stack+79018, dvrr_stack+36382);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+622279, dvrr_stack+99294, dvrr_stack+89854);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+624043, dvrr_stack+110490, dvrr_stack+91730);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+626395, dvrr_stack+125396, dvrr_stack+95934);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+629419, dvrr_stack+143972, dvrr_stack+106206);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+633199, dvrr_stack+166628, dvrr_stack+120076);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+637819, dvrr_stack+192564, dvrr_stack+181076);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+640087, dvrr_stack+207081, dvrr_stack+183204);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1296,dvrr_stack+643111, dvrr_stack+225688, dvrr_stack+188244);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+646999, dvrr_stack+249892, dvrr_stack+201573);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+651859, dvrr_stack+279400, dvrr_stack+218848);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+657799, dvrr_stack+311120, dvrr_stack+297220);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+660634, dvrr_stack+331460, dvrr_stack+90442);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+664414, dvrr_stack+354375, dvrr_stack+94278);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2025,dvrr_stack+669274, dvrr_stack+383640, dvrr_stack+324575);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+675349, dvrr_stack+419355, dvrr_stack+117546);

 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+682774, dvrr_stack+467390, dvrr_stack+446310);

 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+686239, dvrr_stack+492050, dvrr_stack+451105);

 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+690859, dvrr_stack+523510, dvrr_stack+460790);

 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+696799, dvrr_stack+557599, dvrr_stack+483635);

 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,3025,dvrr_stack+704224, dvrr_stack+595054, dvrr_stack+513060);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+267937, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+14638, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+26140, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+40372, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+58165, dvrr_stack+79018, dvrr_stack+36382);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+79018, dvrr_stack+99294, dvrr_stack+89854);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+99294, dvrr_stack+110490, dvrr_stack+91730);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+110490, dvrr_stack+125396, dvrr_stack+95934);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+125396, dvrr_stack+143972, dvrr_stack+106206);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+143972, dvrr_stack+166628, dvrr_stack+120076);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+129176, dvrr_stack+192564, dvrr_stack+181076);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+192564, dvrr_stack+207081, dvrr_stack+183204);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1296,dvrr_stack+207081, dvrr_stack+225688, dvrr_stack+188244);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+225688, dvrr_stack+249892, dvrr_stack+201573);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+249892, dvrr_stack+279400, dvrr_stack+218848);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+279400, dvrr_stack+311120, dvrr_stack+297220);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+255832, dvrr_stack+331460, dvrr_stack+90442);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+331460, dvrr_stack+354375, dvrr_stack+94278);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2025,dvrr_stack+354375, dvrr_stack+383640, dvrr_stack+324575);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+383640, dvrr_stack+419355, dvrr_stack+117546);

 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+419355, dvrr_stack+467390, dvrr_stack+446310);

 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+467390, dvrr_stack+492050, dvrr_stack+451105);

 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+492050, dvrr_stack+523510, dvrr_stack+460790);

 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+523510, dvrr_stack+557599, dvrr_stack+483635);

 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,3025,dvrr_stack+557599, dvrr_stack+595054, dvrr_stack+513060);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+137438, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22243, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+4);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+595054, dvrr_stack+22243, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+137438);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+595072, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+95898, dvrr_stack+595072, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+22243);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+595090, dvrr_stack+95898, dvrr_stack+75, dvrr_stack+595072, dvrr_stack+57, dvrr_stack+595054);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+158870, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+595150, dvrr_stack+158870, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+595072);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+595210, dvrr_stack+595150, dvrr_stack+319, dvrr_stack+158870, dvrr_stack+180, dvrr_stack+95898);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+595310, dvrr_stack+595210, dvrr_stack+379, dvrr_stack+595150, dvrr_stack+319, dvrr_stack+595090);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+8770, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+170, dvrr_stack+8770, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+158870);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+595460, dvrr_stack+170, dvrr_stack+783, dvrr_stack+8770, dvrr_stack+738, dvrr_stack+595150);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+595610, dvrr_stack+595460, dvrr_stack+1192, dvrr_stack+170, dvrr_stack+783, dvrr_stack+595210);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+32735, dvrr_stack+595610, dvrr_stack+1342, dvrr_stack+595460, dvrr_stack+1192, dvrr_stack+595310);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+595835,dvrr_stack+3730,dvrr_stack+32735,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+596780, dvrr_stack+595835, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+597095, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 597095;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+597683, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 597683;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+598124, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 598124;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+598880, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 598880;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+599825, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 599825;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+600980, dvrr_stack+74860, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+24, dvrr_stack+137438, dvrr_stack+19282, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+595460, dvrr_stack+595054, dvrr_stack+33284, dvrr_stack+22243, dvrr_stack+6, dvrr_stack+24);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+595490, dvrr_stack+595090, dvrr_stack+67192, dvrr_stack+95898, dvrr_stack+75, dvrr_stack+595460);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+67997, dvrr_stack+595310, dvrr_stack+9952, dvrr_stack+595210, dvrr_stack+379, dvrr_stack+595490);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+602366, dvrr_stack+32735, dvrr_stack+68761, dvrr_stack+595610, dvrr_stack+1342, dvrr_stack+67997);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+28408,dvrr_stack+89854,dvrr_stack+602366,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+602786, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+603206, dvrr_stack+96942, NULL);
 tmp = dvrr_stack + 603206;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+603990, dvrr_stack+92514, NULL);
 tmp = dvrr_stack + 603990;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+604578, dvrr_stack+107466, NULL);
 tmp = dvrr_stack + 604578;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+605586, dvrr_stack+121616, NULL);
 tmp = dvrr_stack + 605586;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+606846, dvrr_stack+139352, NULL);
 tmp = dvrr_stack + 606846;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+608386, dvrr_stack+161084, NULL);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+2308, dvrr_stack+24, dvrr_stack+72052, dvrr_stack+137438, dvrr_stack+19282, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+8770, dvrr_stack+595460, dvrr_stack+131, dvrr_stack+595054, dvrr_stack+33284, dvrr_stack+2308);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+723, dvrr_stack+595490, dvrr_stack+479, dvrr_stack+595090, dvrr_stack+67192, dvrr_stack+8770);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+610234, dvrr_stack+67997, dvrr_stack+72530, dvrr_stack+595310, dvrr_stack+9952, dvrr_stack+723);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+610514, dvrr_stack+602366, dvrr_stack+67577, dvrr_stack+32735, dvrr_stack+68761, dvrr_stack+610234);

 /* compute (7 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+611054,dvrr_stack+181076,dvrr_stack+610514,36);


 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+566674, dvrr_stack+611054, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+567214, dvrr_stack+189540, NULL);
 tmp = dvrr_stack + 567214;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+568222, dvrr_stack+184212, NULL);
 tmp = dvrr_stack + 568222;
 target_ptr = Libderiv->deriv_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+568978, dvrr_stack+203193, NULL);
 tmp = dvrr_stack + 568978;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+570274, dvrr_stack+220828, NULL);
 tmp = dvrr_stack + 570274;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+530935, dvrr_stack+243952, NULL);
 tmp = dvrr_stack + 530935;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+532915, dvrr_stack+272272, NULL);

 /* compute (4 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+4321, dvrr_stack+2308, dvrr_stack+33056, dvrr_stack+24, dvrr_stack+72052, NULL);

 /* compute (5 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+48, dvrr_stack+8770, dvrr_stack+33123, dvrr_stack+595460, dvrr_stack+131, dvrr_stack+4321);

 /* compute (6 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+612674, dvrr_stack+723, dvrr_stack+19990, dvrr_stack+595490, dvrr_stack+479, dvrr_stack+48);

 /* compute (7 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+612842, dvrr_stack+610234, dvrr_stack+2021, dvrr_stack+67997, dvrr_stack+72530, dvrr_stack+612674);

 /* compute (8 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+497990, dvrr_stack+610514, dvrr_stack+68207, dvrr_stack+602366, dvrr_stack+67577, dvrr_stack+612842);

 /* compute (8 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+498665,dvrr_stack+297220,dvrr_stack+497990,45);


 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+472010, dvrr_stack+498665, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+472685, dvrr_stack+307340, NULL);
 tmp = dvrr_stack + 472685;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+422820, dvrr_stack+300545, NULL);
 tmp = dvrr_stack + 422820;
 target_ptr = Libderiv->deriv_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+423765, dvrr_stack+326600, NULL);
 tmp = dvrr_stack + 423765;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+425385, dvrr_stack+348300, NULL);
 tmp = dvrr_stack + 425385;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+427410, dvrr_stack+376215, NULL);
 tmp = dvrr_stack + 427410;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+429885, dvrr_stack+410445, NULL);

 /* compute (5 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+131, dvrr_stack+4321, dvrr_stack+4336, dvrr_stack+2308, dvrr_stack+33056, NULL);

 /* compute (6 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+170, dvrr_stack+48, dvrr_stack+137441, dvrr_stack+8770, dvrr_stack+33123, dvrr_stack+131);

 /* compute (7 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+612674, dvrr_stack+48250, dvrr_stack+723, dvrr_stack+19990, dvrr_stack+170);

 /* compute (8 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+612842, dvrr_stack+72166, dvrr_stack+610234, dvrr_stack+2021, dvrr_stack+319);

 /* compute (9 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+432855, dvrr_stack+497990, dvrr_stack+442905, dvrr_stack+610514, dvrr_stack+68207, dvrr_stack+9401);

 /* compute (9 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+391065,dvrr_stack+446310,dvrr_stack+432855,55);


 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+393540, dvrr_stack+391065, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+360450, dvrr_stack+462770, NULL);
 tmp = dvrr_stack + 360450;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+394365, dvrr_stack+452645, NULL);
 tmp = dvrr_stack + 394365;
 target_ptr = Libderiv->deriv_classes[9][5][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+361990, dvrr_stack+486110, NULL);
 tmp = dvrr_stack + 361990;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+336320, dvrr_stack+516085, NULL);
 tmp = dvrr_stack + 336320;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+311120, dvrr_stack+548524, NULL);
 tmp = dvrr_stack + 311120;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+282235, dvrr_stack+584164, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+571894, dvrr_stack+595835, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+500690, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 500690;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+433680, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 433680;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+314145, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 314145;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+314901, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 314901;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+285865, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 285865;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+287020, dvrr_stack+74860, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+315846, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+288406, dvrr_stack+96942, NULL);
 tmp = dvrr_stack + 288406;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+289190, dvrr_stack+92514, NULL);
 tmp = dvrr_stack + 289190;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+289778, dvrr_stack+107466, NULL);
 tmp = dvrr_stack + 289778;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+230548, dvrr_stack+121616, NULL);
 tmp = dvrr_stack + 230548;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+231808, dvrr_stack+139352, NULL);
 tmp = dvrr_stack + 231808;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+210969, dvrr_stack+161084, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+195588, dvrr_stack+611054, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+166628, dvrr_stack+189540, NULL);
 tmp = dvrr_stack + 166628;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+196128, dvrr_stack+184212, NULL);
 tmp = dvrr_stack + 196128;
 target_ptr = Libderiv->deriv_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+167636, dvrr_stack+203193, NULL);
 tmp = dvrr_stack + 167636;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+168932, dvrr_stack+220828, NULL);
 tmp = dvrr_stack + 168932;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+170552, dvrr_stack+243952, NULL);
 tmp = dvrr_stack + 170552;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+172532, dvrr_stack+272272, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+174908, dvrr_stack+498665, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+148592, dvrr_stack+307340, NULL);
 tmp = dvrr_stack + 148592;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+149852, dvrr_stack+300545, NULL);
 tmp = dvrr_stack + 149852;
 target_ptr = Libderiv->deriv_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+113514, dvrr_stack+326600, NULL);
 tmp = dvrr_stack + 113514;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+80782, dvrr_stack+348300, NULL);
 tmp = dvrr_stack + 80782;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+82807, dvrr_stack+376215, NULL);
 tmp = dvrr_stack + 82807;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+713299, dvrr_stack+410445, NULL);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+101646, dvrr_stack+391065, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+61630, dvrr_stack+462770, NULL);
 tmp = dvrr_stack + 61630;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+43207, dvrr_stack+452645, NULL);
 tmp = dvrr_stack + 43207;
 target_ptr = Libderiv->deriv_classes[9][5][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+716269, dvrr_stack+486110, NULL);
 tmp = dvrr_stack + 716269;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+718249, dvrr_stack+516085, NULL);
 tmp = dvrr_stack + 718249;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+720724, dvrr_stack+548524, NULL);
 tmp = dvrr_stack + 720724;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+723749, dvrr_stack+584164, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+473945, dvrr_stack+595835, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+595835, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 595835;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+12874, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 12874;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+7447, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 7447;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+23872, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 23872;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+37537, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 37537;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+54700, dvrr_stack+74860, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+74860, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+28408, dvrr_stack+96942, NULL);
 tmp = dvrr_stack + 28408;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+96942, dvrr_stack+92514, NULL);
 tmp = dvrr_stack + 96942;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+92514, dvrr_stack+107466, NULL);
 tmp = dvrr_stack + 92514;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+107466, dvrr_stack+121616, NULL);
 tmp = dvrr_stack + 107466;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+121616, dvrr_stack+139352, NULL);
 tmp = dvrr_stack + 121616;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+139352, dvrr_stack+161084, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+161084, dvrr_stack+611054, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+611054, dvrr_stack+189540, NULL);
 tmp = dvrr_stack + 611054;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+93522, dvrr_stack+184212, NULL);
 tmp = dvrr_stack + 93522;
 target_ptr = Libderiv->deriv_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+184212, dvrr_stack+203193, NULL);
 tmp = dvrr_stack + 184212;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+203193, dvrr_stack+220828, NULL);
 tmp = dvrr_stack + 203193;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+220828, dvrr_stack+243952, NULL);
 tmp = dvrr_stack + 220828;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+243952, dvrr_stack+272272, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+272272, dvrr_stack+498665, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+498665, dvrr_stack+307340, NULL);
 tmp = dvrr_stack + 498665;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+307340, dvrr_stack+300545, NULL);
 tmp = dvrr_stack + 307340;
 target_ptr = Libderiv->deriv_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+300545, dvrr_stack+326600, NULL);
 tmp = dvrr_stack + 300545;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+326600, dvrr_stack+348300, NULL);
 tmp = dvrr_stack + 326600;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+348300, dvrr_stack+376215, NULL);
 tmp = dvrr_stack + 348300;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+376215, dvrr_stack+410445, NULL);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+379185, dvrr_stack+391065, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+391065, dvrr_stack+462770, NULL);
 tmp = dvrr_stack + 391065;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+462770, dvrr_stack+452645, NULL);
 tmp = dvrr_stack + 462770;
 target_ptr = Libderiv->deriv_classes[9][5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+452645, dvrr_stack+486110, NULL);
 tmp = dvrr_stack + 452645;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+486110, dvrr_stack+516085, NULL);
 tmp = dvrr_stack + 486110;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+516085, dvrr_stack+548524, NULL);
 tmp = dvrr_stack + 516085;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+380010, dvrr_stack+584164, NULL);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+584164, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+4585, dvrr_stack+584164, dvrr_stack+137438, Data->F+3, Data->F+4, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+152, dvrr_stack+161, dvrr_stack+21, NULL, NULL, Data->F+3);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+584167, dvrr_stack+152, dvrr_stack+22243, dvrr_stack+161, dvrr_stack+21, dvrr_stack+584164);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+595580, dvrr_stack+584167, dvrr_stack+595054, dvrr_stack+152, dvrr_stack+22243, dvrr_stack+4585);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+584185, dvrr_stack+707, dvrr_stack+164, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+578, dvrr_stack+584185, dvrr_stack+595072, dvrr_stack+707, dvrr_stack+164, dvrr_stack+152);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+474260, dvrr_stack+578, dvrr_stack+95898, dvrr_stack+584185, dvrr_stack+595072, dvrr_stack+584167);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+584203, dvrr_stack+474260, dvrr_stack+595090, dvrr_stack+578, dvrr_stack+95898, dvrr_stack+595580);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+95898, dvrr_stack+121, dvrr_stack+713, NULL, NULL, dvrr_stack+707);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+115134, dvrr_stack+95898, dvrr_stack+158870, dvrr_stack+121, dvrr_stack+713, dvrr_stack+584185);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+584293, dvrr_stack+115134, dvrr_stack+595150, dvrr_stack+95898, dvrr_stack+158870, dvrr_stack+578);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+584393, dvrr_stack+584293, dvrr_stack+595210, dvrr_stack+115134, dvrr_stack+595150, dvrr_stack+474260);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+584543, dvrr_stack+584393, dvrr_stack+595310, dvrr_stack+584293, dvrr_stack+595210, dvrr_stack+584203);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+584753, dvrr_stack+3730, dvrr_stack+584543);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+585068, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 585068;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+585656, dvrr_stack+6859, dvrr_stack+32735);
 tmp = dvrr_stack + 585656;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+586097, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 586097;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+586853, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 586853;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+587798, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 587798;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+588953, dvrr_stack+73222, dvrr_stack+36382);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+121, dvrr_stack+4585, dvrr_stack+24, dvrr_stack+584164, dvrr_stack+137438, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+584293, dvrr_stack+595580, dvrr_stack+595460, dvrr_stack+584167, dvrr_stack+595054, dvrr_stack+121);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+595150, dvrr_stack+584203, dvrr_stack+595490, dvrr_stack+474260, dvrr_stack+595090, dvrr_stack+584293);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+590339, dvrr_stack+584543, dvrr_stack+67997, dvrr_stack+584393, dvrr_stack+595310, dvrr_stack+595150);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+590619, dvrr_stack+89854, dvrr_stack+590339);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+591039, dvrr_stack+95934, dvrr_stack+89854);
 tmp = dvrr_stack + 591039;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+591823, dvrr_stack+91730, dvrr_stack+602366);
 tmp = dvrr_stack + 591823;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+592411, dvrr_stack+106206, dvrr_stack+91730);
 tmp = dvrr_stack + 592411;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+593419, dvrr_stack+120076, dvrr_stack+95934);
 tmp = dvrr_stack + 593419;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+548524, dvrr_stack+137504, dvrr_stack+106206);
 tmp = dvrr_stack + 548524;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+550064, dvrr_stack+158900, dvrr_stack+120076);

 /* compute (4 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+0, dvrr_stack+121, dvrr_stack+2308, dvrr_stack+4585, dvrr_stack+24, NULL);

 /* compute (5 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+584338, dvrr_stack+584293, dvrr_stack+8770, dvrr_stack+595580, dvrr_stack+595460, dvrr_stack+0);

 /* compute (6 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+595276, dvrr_stack+595150, dvrr_stack+723, dvrr_stack+584203, dvrr_stack+595490, dvrr_stack+584338);

 /* compute (7 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+594679, dvrr_stack+590339, dvrr_stack+610234, dvrr_stack+584543, dvrr_stack+67997, dvrr_stack+595276);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,36,1,dvrr_stack+551912, dvrr_stack+181076, dvrr_stack+594679);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+552452, dvrr_stack+188244, dvrr_stack+181076);
 tmp = dvrr_stack + 552452;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+553460, dvrr_stack+183204, dvrr_stack+610514);
 tmp = dvrr_stack + 553460;
 target_ptr = Libderiv->deriv_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+554216, dvrr_stack+201573, dvrr_stack+183204);
 tmp = dvrr_stack + 554216;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+555512, dvrr_stack+218848, dvrr_stack+188244);
 tmp = dvrr_stack + 555512;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+519110, dvrr_stack+241576, dvrr_stack+201573);
 tmp = dvrr_stack + 519110;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+521090, dvrr_stack+269464, dvrr_stack+218848);

 /* compute (5 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+474260, dvrr_stack+0, dvrr_stack+4321, dvrr_stack+121, dvrr_stack+2308, NULL);

 /* compute (6 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+434121, dvrr_stack+584338, dvrr_stack+48, dvrr_stack+584293, dvrr_stack+8770, dvrr_stack+474260);

 /* compute (7 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+196884, dvrr_stack+595276, dvrr_stack+612674, dvrr_stack+595150, dvrr_stack+723, dvrr_stack+434121);

 /* compute (8 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+557132, dvrr_stack+594679, dvrr_stack+612842, dvrr_stack+590339, dvrr_stack+610234, dvrr_stack+196884);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,45,1,dvrr_stack+488585, dvrr_stack+297220, dvrr_stack+557132);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+489260, dvrr_stack+94278, dvrr_stack+297220);
 tmp = dvrr_stack + 489260;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+490520, dvrr_stack+90442, dvrr_stack+497990);
 tmp = dvrr_stack + 490520;
 target_ptr = Libderiv->deriv_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+463925, dvrr_stack+324575, dvrr_stack+90442);
 tmp = dvrr_stack + 463925;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+350775, dvrr_stack+117546, dvrr_stack+94278);
 tmp = dvrr_stack + 350775;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+328625, dvrr_stack+134468, dvrr_stack+324575);
 tmp = dvrr_stack + 328625;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+272947, dvrr_stack+155312, dvrr_stack+117546);

 /* compute (6 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+91702, dvrr_stack+474260, dvrr_stack+131, dvrr_stack+0, dvrr_stack+4321, NULL);

 /* compute (7 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+610234, dvrr_stack+434121, dvrr_stack+170, dvrr_stack+584338, dvrr_stack+48, dvrr_stack+91702);

 /* compute (8 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+395520, dvrr_stack+196884, dvrr_stack+319, dvrr_stack+595276, dvrr_stack+612674, dvrr_stack+610234);

 /* compute (9 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+557132, dvrr_stack+9401, dvrr_stack+594679, dvrr_stack+612842, dvrr_stack+395520);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,55,1,dvrr_stack+454625, dvrr_stack+446310, dvrr_stack+19440);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+465545, dvrr_stack+460790, dvrr_stack+446310);
 tmp = dvrr_stack + 465545;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+352800, dvrr_stack+451105, dvrr_stack+432855);
 tmp = dvrr_stack + 352800;
 target_ptr = Libderiv->deriv_classes[9][5][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+308285, dvrr_stack+483635, dvrr_stack+451105);
 tmp = dvrr_stack + 308285;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+275917, dvrr_stack+513060, dvrr_stack+460790);
 tmp = dvrr_stack + 275917;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+246328, dvrr_stack+237352, dvrr_stack+483635);
 tmp = dvrr_stack + 246328;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+161624, dvrr_stack+579874, dvrr_stack+513060);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+584164, dvrr_stack+3730, dvrr_stack+584543);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+455450, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 455450;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+595039, dvrr_stack+6859, dvrr_stack+32735);
 tmp = dvrr_stack + 595039;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+392605, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 392605;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+302165, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 302165;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+222808, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 222808;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+223963, dvrr_stack+73222, dvrr_stack+36382);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+353955, dvrr_stack+89854, dvrr_stack+590339);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+310265, dvrr_stack+95934, dvrr_stack+89854);
 tmp = dvrr_stack + 310265;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+499925, dvrr_stack+91730, dvrr_stack+602366);
 tmp = dvrr_stack + 499925;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+278392, dvrr_stack+106206, dvrr_stack+91730);
 tmp = dvrr_stack + 278392;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+204813, dvrr_stack+120076, dvrr_stack+95934);
 tmp = dvrr_stack + 204813;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+189540, dvrr_stack+137504, dvrr_stack+106206);
 tmp = dvrr_stack + 189540;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+141200, dvrr_stack+158900, dvrr_stack+120076);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,36,1,dvrr_stack+491465, dvrr_stack+181076, dvrr_stack+594679);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+206073, dvrr_stack+188244, dvrr_stack+181076);
 tmp = dvrr_stack + 206073;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+185508, dvrr_stack+183204, dvrr_stack+610514);
 tmp = dvrr_stack + 185508;
 target_ptr = Libderiv->deriv_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+191080, dvrr_stack+201573, dvrr_stack+183204);
 tmp = dvrr_stack + 191080;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+123156, dvrr_stack+218848, dvrr_stack+188244);
 tmp = dvrr_stack + 123156;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+75280, dvrr_stack+241576, dvrr_stack+201573);
 tmp = dvrr_stack + 75280;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+410055, dvrr_stack+269464, dvrr_stack+218848);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,45,1,dvrr_stack+165254, dvrr_stack+297220, dvrr_stack+557132);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+108726, dvrr_stack+94278, dvrr_stack+297220);
 tmp = dvrr_stack + 108726;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+97530, dvrr_stack+90442, dvrr_stack+497990);
 tmp = dvrr_stack + 97530;
 target_ptr = Libderiv->deriv_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+77260, dvrr_stack+324575, dvrr_stack+90442);
 tmp = dvrr_stack + 77260;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+56086, dvrr_stack+117546, dvrr_stack+94278);
 tmp = dvrr_stack + 56086;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+412431, dvrr_stack+134468, dvrr_stack+324575);
 tmp = dvrr_stack + 412431;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+414906, dvrr_stack+155312, dvrr_stack+117546);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,55,1,dvrr_stack+143048, dvrr_stack+446310, dvrr_stack+19440);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+38692, dvrr_stack+460790, dvrr_stack+446310);
 tmp = dvrr_stack + 38692;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+24817, dvrr_stack+451105, dvrr_stack+432855);
 tmp = dvrr_stack + 24817;
 target_ptr = Libderiv->deriv_classes[9][5][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+727379, dvrr_stack+483635, dvrr_stack+451105);
 tmp = dvrr_stack + 727379;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+729359, dvrr_stack+513060, dvrr_stack+460790);
 tmp = dvrr_stack + 729359;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+731834, dvrr_stack+237352, dvrr_stack+483635);
 tmp = dvrr_stack + 731834;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+734859, dvrr_stack+579874, dvrr_stack+513060);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+331100, dvrr_stack+3730, dvrr_stack+584543);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+612062, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 612062;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+249353, dvrr_stack+6859, dvrr_stack+32735);
 tmp = dvrr_stack + 249353;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+98475, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 98475;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+13315, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 13315;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+417876, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 417876;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+53314, dvrr_stack+73222, dvrr_stack+36382);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+165929, dvrr_stack+89854, dvrr_stack+590339);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+16402, dvrr_stack+95934, dvrr_stack+89854);
 tmp = dvrr_stack + 16402;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+124776, dvrr_stack+91730, dvrr_stack+602366);
 tmp = dvrr_stack + 124776;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+33852, dvrr_stack+106206, dvrr_stack+91730);
 tmp = dvrr_stack + 33852;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+49861, dvrr_stack+120076, dvrr_stack+95934);
 tmp = dvrr_stack + 49861;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+73055, dvrr_stack+137504, dvrr_stack+106206);
 tmp = dvrr_stack + 73055;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+137504, dvrr_stack+158900, dvrr_stack+120076);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,36,1,dvrr_stack+158870, dvrr_stack+181076, dvrr_stack+594679);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+159410, dvrr_stack+188244, dvrr_stack+181076);
 tmp = dvrr_stack + 159410;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+10462, dvrr_stack+183204, dvrr_stack+610514);
 tmp = dvrr_stack + 10462;
 target_ptr = Libderiv->deriv_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+738489, dvrr_stack+201573, dvrr_stack+183204);
 tmp = dvrr_stack + 738489;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+739785, dvrr_stack+218848, dvrr_stack+188244);
 tmp = dvrr_stack + 739785;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+741405, dvrr_stack+241576, dvrr_stack+201573);
 tmp = dvrr_stack + 741405;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+240982, dvrr_stack+269464, dvrr_stack+218848);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,45,1,dvrr_stack+610234, dvrr_stack+297220, dvrr_stack+557132);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+269260, dvrr_stack+94278, dvrr_stack+297220);
 tmp = dvrr_stack + 269260;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+270520, dvrr_stack+90442, dvrr_stack+497990);
 tmp = dvrr_stack + 270520;
 target_ptr = Libderiv->deriv_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+743385, dvrr_stack+324575, dvrr_stack+90442);
 tmp = dvrr_stack + 743385;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+745005, dvrr_stack+117546, dvrr_stack+94278);
 tmp = dvrr_stack + 745005;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+747030, dvrr_stack+134468, dvrr_stack+324575);
 tmp = dvrr_stack + 747030;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+749505, dvrr_stack+155312, dvrr_stack+117546);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,55,1,dvrr_stack+155312, dvrr_stack+446310, dvrr_stack+19440);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+156137, dvrr_stack+460790, dvrr_stack+446310);
 tmp = dvrr_stack + 156137;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+752475, dvrr_stack+451105, dvrr_stack+432855);
 tmp = dvrr_stack + 752475;
 target_ptr = Libderiv->deriv_classes[9][5][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+753630, dvrr_stack+483635, dvrr_stack+451105);
 tmp = dvrr_stack + 753630;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+755610, dvrr_stack+513060, dvrr_stack+460790);
 tmp = dvrr_stack + 755610;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+758085, dvrr_stack+237352, dvrr_stack+483635);
 tmp = dvrr_stack + 758085;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+761110, dvrr_stack+579874, dvrr_stack+513060);

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+579874,dvrr_stack+6439,dvrr_stack+3415,15);


 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+32735, dvrr_stack+579874, NULL);

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+580819,dvrr_stack+11578,dvrr_stack+6439,15);


 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+602366, dvrr_stack+580819, NULL);

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+582079,dvrr_stack+22252,dvrr_stack+11578,15);


 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+19440, dvrr_stack+582079, NULL);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+764740,dvrr_stack+35557,dvrr_stack+22252,15);


 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+157677, dvrr_stack+764740, NULL);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+766765,dvrr_stack+52324,dvrr_stack+35557,15);


 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+5571, dvrr_stack+766765, NULL);

 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+137438, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+4585, dvrr_stack+158822, dvrr_stack+137438, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+19980, dvrr_stack+15, dvrr_stack+4585, dvrr_stack+9310, dvrr_stack+158822, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+0, dvrr_stack+111, dvrr_stack+19980, dvrr_stack+33050, dvrr_stack+15, NULL);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+583699, dvrr_stack+4336, dvrr_stack+0, dvrr_stack+33056, dvrr_stack+111, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22243, dvrr_stack+704, dvrr_stack+1966, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+152, dvrr_stack+569, dvrr_stack+22243, dvrr_stack+873, dvrr_stack+704, dvrr_stack+137438);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+583720, dvrr_stack+4351, dvrr_stack+152, dvrr_stack+33066, dvrr_stack+569, dvrr_stack+4585);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+492005, dvrr_stack+4369, dvrr_stack+583720, dvrr_stack+33075, dvrr_stack+4351, dvrr_stack+19980);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+99231, dvrr_stack+49816, dvrr_stack+492005, dvrr_stack+33093, dvrr_stack+4369, dvrr_stack+0);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+434121, dvrr_stack+137441, dvrr_stack+99231, dvrr_stack+33123, dvrr_stack+49816, dvrr_stack+583699);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+33050, dvrr_stack+1969, dvrr_stack+1603, NULL, NULL, dvrr_stack+1966);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+578, dvrr_stack+72058, dvrr_stack+33050, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+22243);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+474260, dvrr_stack+9365, dvrr_stack+578, dvrr_stack+30, dvrr_stack+72058, dvrr_stack+152);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+33068, dvrr_stack+4399, dvrr_stack+474260, dvrr_stack+33168, dvrr_stack+9365, dvrr_stack+583720);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+583750, dvrr_stack+614, dvrr_stack+33068, dvrr_stack+33204, dvrr_stack+4399, dvrr_stack+492005);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+25972, dvrr_stack+4459, dvrr_stack+583750, dvrr_stack+4171, dvrr_stack+614, dvrr_stack+99231);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+196884, dvrr_stack+48250, dvrr_stack+25972, dvrr_stack+19990, dvrr_stack+4459, dvrr_stack+434121);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+19990, dvrr_stack+4594, dvrr_stack+9319, NULL, NULL, dvrr_stack+1603);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+115134, dvrr_stack+72076, dvrr_stack+19990, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+33050);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+20020, dvrr_stack+72106, dvrr_stack+115134, dvrr_stack+49300, dvrr_stack+72076, dvrr_stack+578);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+20120, dvrr_stack+48418, dvrr_stack+20020, dvrr_stack+4261, dvrr_stack+72106, dvrr_stack+474260);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+583876, dvrr_stack+48518, dvrr_stack+20120, dvrr_stack+9851, dvrr_stack+48418, dvrr_stack+33068);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+590339, dvrr_stack+47562, dvrr_stack+583876, dvrr_stack+1637, dvrr_stack+48518, dvrr_stack+583750);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+594679, dvrr_stack+31666, dvrr_stack+590339, dvrr_stack+3205, dvrr_stack+47562, dvrr_stack+25972);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+158352, dvrr_stack+72166, dvrr_stack+594679, dvrr_stack+2021, dvrr_stack+31666, dvrr_stack+196884);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+331415, dvrr_stack+9329, dvrr_stack+19295, NULL, NULL, dvrr_stack+9319);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+9851, dvrr_stack+158825, dvrr_stack+331415, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+19990);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+4171, dvrr_stack+47772, dvrr_stack+9851, dvrr_stack+67252, dvrr_stack+158825, dvrr_stack+115134);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+338795, dvrr_stack+47254, dvrr_stack+4171, dvrr_stack+67297, dvrr_stack+47772, dvrr_stack+20020);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+4604, dvrr_stack+105829, dvrr_stack+338795, dvrr_stack+2318, dvrr_stack+47254, dvrr_stack+20120);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+1975, dvrr_stack+441630, dvrr_stack+4604, dvrr_stack+69496, dvrr_stack+105829, dvrr_stack+583876);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+160418, dvrr_stack+441945, dvrr_stack+1975, dvrr_stack+69721, dvrr_stack+441630, dvrr_stack+590339);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+707, dvrr_stack+442365, dvrr_stack+160418, dvrr_stack+70036, dvrr_stack+441945, dvrr_stack+594679);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+69356, dvrr_stack+442905, dvrr_stack+707, dvrr_stack+68207, dvrr_stack+442365, dvrr_stack+158352);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+4919, dvrr_stack+19310, dvrr_stack+32123, NULL, NULL, dvrr_stack+19295);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+160958, dvrr_stack+66670, dvrr_stack+4919, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+331415);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+4982, dvrr_stack+66733, dvrr_stack+160958, dvrr_stack+67387, dvrr_stack+66670, dvrr_stack+9851);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+557132, dvrr_stack+66859, dvrr_stack+4982, dvrr_stack+67450, dvrr_stack+66733, dvrr_stack+4171);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+109986, dvrr_stack+72740, dvrr_stack+557132, dvrr_stack+70456, dvrr_stack+66859, dvrr_stack+338795);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+8203, dvrr_stack+443580, dvrr_stack+109986, dvrr_stack+70666, dvrr_stack+72740, dvrr_stack+4604);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+769240, dvrr_stack+444021, dvrr_stack+8203, dvrr_stack+70981, dvrr_stack+443580, dvrr_stack+1975);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+67069, dvrr_stack+444609, dvrr_stack+769240, dvrr_stack+71422, dvrr_stack+444021, dvrr_stack+160418);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+70181, dvrr_stack+445365, dvrr_stack+67069, dvrr_stack+51424, dvrr_stack+444609, dvrr_stack+707);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+769996, dvrr_stack+446310, dvrr_stack+70181, dvrr_stack+297220, dvrr_stack+445365, dvrr_stack+69356);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5192, dvrr_stack+32144, dvrr_stack+48020, NULL, NULL, dvrr_stack+32123);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+395520, dvrr_stack+180488, dvrr_stack+5192, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+4919);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+467085, dvrr_stack+180572, dvrr_stack+395520, dvrr_stack+89413, dvrr_stack+180488, dvrr_stack+160958);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+29192, dvrr_stack+180740, dvrr_stack+467085, dvrr_stack+89497, dvrr_stack+180572, dvrr_stack+4982);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+150797, dvrr_stack+32315, dvrr_stack+29192, dvrr_stack+69076, dvrr_stack+180740, dvrr_stack+557132);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+271465, dvrr_stack+447465, dvrr_stack+150797, dvrr_stack+48718, dvrr_stack+32315, dvrr_stack+109986);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+51121, dvrr_stack+448053, dvrr_stack+271465, dvrr_stack+298165, dvrr_stack+447465, dvrr_stack+8203);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+68014, dvrr_stack+448837, dvrr_stack+51121, dvrr_stack+298753, dvrr_stack+448053, dvrr_stack+769240);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+771382, dvrr_stack+449845, dvrr_stack+68014, dvrr_stack+299537, dvrr_stack+448837, dvrr_stack+67069);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+298165, dvrr_stack+451105, dvrr_stack+771382, dvrr_stack+90442, dvrr_stack+449845, dvrr_stack+70181);

 /* compute (10 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+772922,dvrr_stack+298165,dvrr_stack+769996,66);


 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+777080, dvrr_stack+772922, NULL);

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+300013, dvrr_stack+48048, dvrr_stack+1567, NULL, NULL, dvrr_stack+48020);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+186264, dvrr_stack+181832, dvrr_stack+300013, dvrr_stack+32172, dvrr_stack+48048, dvrr_stack+5192);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+300121, dvrr_stack+181940, dvrr_stack+186264, dvrr_stack+89665, dvrr_stack+181832, dvrr_stack+395520);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+85282, dvrr_stack+182156, dvrr_stack+300121, dvrr_stack+49330, dvrr_stack+181940, dvrr_stack+467085);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48668, dvrr_stack+182516, dvrr_stack+85282, dvrr_stack+303380, dvrr_stack+182156, dvrr_stack+29192);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+778466, dvrr_stack+456110, dvrr_stack+48668, dvrr_stack+303740, dvrr_stack+182516, dvrr_stack+150797);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+779474, dvrr_stack+456866, dvrr_stack+778466, dvrr_stack+304280, dvrr_stack+456110, dvrr_stack+271465);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303110, dvrr_stack+457874, dvrr_stack+779474, dvrr_stack+305036, dvrr_stack+456866, dvrr_stack+51121);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+780770, dvrr_stack+459170, dvrr_stack+303110, dvrr_stack+306044, dvrr_stack+457874, dvrr_stack+68014);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+304730, dvrr_stack+460790, dvrr_stack+780770, dvrr_stack+94278, dvrr_stack+459170, dvrr_stack+771382);

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+782750,dvrr_stack+304730,dvrr_stack+298165,66);


 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+788294, dvrr_stack+782750, NULL);

 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32172, dvrr_stack+9265, dvrr_stack+35134, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+89413, dvrr_stack+186480, dvrr_stack+32172, dvrr_stack+48084, dvrr_stack+9265, dvrr_stack+300013);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+316266, dvrr_stack+186615, dvrr_stack+89413, dvrr_stack+18607, dvrr_stack+186480, dvrr_stack+186264);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+186885, dvrr_stack+316266, dvrr_stack+49546, dvrr_stack+186615, dvrr_stack+300121);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+790142, dvrr_stack+187335, dvrr_stack+18607, dvrr_stack+319625, dvrr_stack+186885, dvrr_stack+85282);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+791087, dvrr_stack+477785, dvrr_stack+790142, dvrr_stack+320075, dvrr_stack+187335, dvrr_stack+48668);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+792347, dvrr_stack+478730, dvrr_stack+791087, dvrr_stack+320750, dvrr_stack+477785, dvrr_stack+778466);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+319625, dvrr_stack+479990, dvrr_stack+792347, dvrr_stack+321695, dvrr_stack+478730, dvrr_stack+779474);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+793967, dvrr_stack+481610, dvrr_stack+319625, dvrr_stack+322955, dvrr_stack+479990, dvrr_stack+303110);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+796442, dvrr_stack+483635, dvrr_stack+793967, dvrr_stack+324575, dvrr_stack+481610, dvrr_stack+780770);

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+799412,dvrr_stack+796442,dvrr_stack+304730,66);


 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+321650, dvrr_stack+799412, NULL);

 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+324026, dvrr_stack+264, dvrr_stack+120021, NULL, NULL, dvrr_stack+35134);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+324191, dvrr_stack+199368, dvrr_stack+324026, dvrr_stack+47441, dvrr_stack+264, dvrr_stack+32172);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+63170, dvrr_stack+199533, dvrr_stack+324191, dvrr_stack+104586, dvrr_stack+199368, dvrr_stack+89413);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+806540, dvrr_stack+199863, dvrr_stack+63170, dvrr_stack+104751, dvrr_stack+199533, dvrr_stack+316266);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+807365, dvrr_stack+200413, dvrr_stack+806540, dvrr_stack+105081, dvrr_stack+199863, dvrr_stack+18607);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+808520, dvrr_stack+505910, dvrr_stack+807365, dvrr_stack+342800, dvrr_stack+200413, dvrr_stack+790142);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+810060, dvrr_stack+507065, dvrr_stack+808520, dvrr_stack+343625, dvrr_stack+505910, dvrr_stack+791087);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+812040, dvrr_stack+508605, dvrr_stack+810060, dvrr_stack+344780, dvrr_stack+507065, dvrr_stack+792347);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+342800, dvrr_stack+510585, dvrr_stack+812040, dvrr_stack+346320, dvrr_stack+508605, dvrr_stack+319625);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+814515, dvrr_stack+513060, dvrr_stack+342800, dvrr_stack+117546, dvrr_stack+510585, dvrr_stack+793967);

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+818145,dvrr_stack+814515,dvrr_stack+796442,66);


 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+827055, dvrr_stack+818145, NULL);

 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+345825, dvrr_stack+48184, dvrr_stack+47496, NULL, NULL, dvrr_stack+120021);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+346023, dvrr_stack+216153, dvrr_stack+345825, dvrr_stack+35179, dvrr_stack+48184, dvrr_stack+324026);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+346419, dvrr_stack+216351, dvrr_stack+346023, dvrr_stack+105631, dvrr_stack+216153, dvrr_stack+324191);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+347079, dvrr_stack+216747, dvrr_stack+346419, dvrr_stack+8815, dvrr_stack+216351, dvrr_stack+63170);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+830025, dvrr_stack+217407, dvrr_stack+347079, dvrr_stack+368955, dvrr_stack+216747, dvrr_stack+806540);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+345825, dvrr_stack+20857, dvrr_stack+830025, dvrr_stack+369615, dvrr_stack+217407, dvrr_stack+807365);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+216153, dvrr_stack+541330, dvrr_stack+345825, dvrr_stack+370605, dvrr_stack+20857, dvrr_stack+808520);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368955, dvrr_stack+543178, dvrr_stack+216153, dvrr_stack+371991, dvrr_stack+541330, dvrr_stack+810060);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+830025, dvrr_stack+545554, dvrr_stack+368955, dvrr_stack+373839, dvrr_stack+543178, dvrr_stack+812040);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368955, dvrr_stack+237352, dvrr_stack+830025, dvrr_stack+134468, dvrr_stack+545554, dvrr_stack+342800);

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+830025,dvrr_stack+368955,dvrr_stack+814515,66);


 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+237352, dvrr_stack+830025, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+134468, dvrr_stack+579874, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+134783, dvrr_stack+580819, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+135203, dvrr_stack+582079, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+135743, dvrr_stack+764740, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+136418, dvrr_stack+766765, NULL);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+20857, dvrr_stack+772922, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+373311, dvrr_stack+782750, NULL);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+541330, dvrr_stack+799412, NULL);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+543706, dvrr_stack+818145, NULL);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+840915, dvrr_stack+830025, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+844545, dvrr_stack+579874, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+579874, dvrr_stack+580819, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+580294, dvrr_stack+582079, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+580834, dvrr_stack+764740, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+764740, dvrr_stack+766765, NULL);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+765565, dvrr_stack+772922, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+546676, dvrr_stack+782750, NULL);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+782750, dvrr_stack+799412, NULL);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+799412, dvrr_stack+818145, NULL);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+818145, dvrr_stack+830025, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+830025, dvrr_stack+6439, dvrr_stack+595610);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+830340, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+830760, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+831300, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+831975, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (6 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+91702, dvrr_stack+131, dvrr_stack+583699, dvrr_stack+4321, dvrr_stack+4336, NULL);

 /* compute (7 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+832800, dvrr_stack+170, dvrr_stack+434121, dvrr_stack+48, dvrr_stack+137441, dvrr_stack+91702);

 /* compute (8 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+832908, dvrr_stack+319, dvrr_stack+196884, dvrr_stack+612674, dvrr_stack+48250, dvrr_stack+832800);

 /* compute (9 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+833178, dvrr_stack+9401, dvrr_stack+158352, dvrr_stack+612842, dvrr_stack+72166, dvrr_stack+832908);

 /* compute (10 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+833728, dvrr_stack+432855, dvrr_stack+69356, dvrr_stack+497990, dvrr_stack+442905, dvrr_stack+833178);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+834718, dvrr_stack+298165, dvrr_stack+833728);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+836104, dvrr_stack+304730, dvrr_stack+769996);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+837952, dvrr_stack+796442, dvrr_stack+298165);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+821775, dvrr_stack+814515, dvrr_stack+304730);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+802382, dvrr_stack+368955, dvrr_stack+796442);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+497990, dvrr_stack+6439, dvrr_stack+595610);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+432855, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+832800, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+824745, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+825420, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+785126, dvrr_stack+298165, dvrr_stack+833728);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+772922, dvrr_stack+304730, dvrr_stack+769996);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+216153, dvrr_stack+796442, dvrr_stack+298165);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+844860, dvrr_stack+814515, dvrr_stack+304730);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+847830, dvrr_stack+368955, dvrr_stack+796442);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+498305, dvrr_stack+6439, dvrr_stack+595610);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+9401, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+840328, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+826245, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+786512, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+774770, dvrr_stack+298165, dvrr_stack+833728);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+766951, dvrr_stack+304730, dvrr_stack+769996);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+345825, dvrr_stack+796442, dvrr_stack+298165);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+851460, dvrr_stack+814515, dvrr_stack+304730);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+854430, dvrr_stack+368955, dvrr_stack+796442);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+368955, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+369270, dvrr_stack+181076, dvrr_stack+3730);
 tmp = dvrr_stack + 369270;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+369858, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+370278, dvrr_stack+183204, dvrr_stack+6859);
 tmp = dvrr_stack + 370278;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+371062, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+371602, dvrr_stack+188244, dvrr_stack+12118);
 tmp = dvrr_stack + 371602;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+372610, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+833340, dvrr_stack+201573, dvrr_stack+22927);
 tmp = dvrr_stack + 833340;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+787337, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+581509, dvrr_stack+218848, dvrr_stack+36382);
 tmp = dvrr_stack + 581509;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+768799, dvrr_stack+89854, dvrr_stack+3415);
 tmp = dvrr_stack + 768799;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+776156, dvrr_stack+297220, dvrr_stack+89854);
 tmp = dvrr_stack + 776156;
 target_ptr = Libderiv->deriv_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+583049, dvrr_stack+91730, dvrr_stack+6439);
 tmp = dvrr_stack + 583049;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+375159, dvrr_stack+90442, dvrr_stack+91730);
 tmp = dvrr_stack + 375159;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+858060, dvrr_stack+95934, dvrr_stack+11578);
 tmp = dvrr_stack + 858060;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+858816, dvrr_stack+94278, dvrr_stack+95934);
 tmp = dvrr_stack + 858816;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+104586, dvrr_stack+106206, dvrr_stack+22252);
 tmp = dvrr_stack + 104586;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+860112, dvrr_stack+324575, dvrr_stack+106206);
 tmp = dvrr_stack + 860112;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+52129, dvrr_stack+120076, dvrr_stack+35557);
 tmp = dvrr_stack + 52129;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+861732, dvrr_stack+117546, dvrr_stack+120076);
 tmp = dvrr_stack + 861732;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+863712, dvrr_stack+446310, dvrr_stack+181076);
 tmp = dvrr_stack + 863712;
 target_ptr = Libderiv->deriv_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+864657, dvrr_stack+451105, dvrr_stack+183204);
 tmp = dvrr_stack + 864657;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+865917, dvrr_stack+460790, dvrr_stack+188244);
 tmp = dvrr_stack + 865917;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+867537, dvrr_stack+483635, dvrr_stack+201573);
 tmp = dvrr_stack + 867537;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+869562, dvrr_stack+513060, dvrr_stack+218848);
 tmp = dvrr_stack + 869562;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+872037, dvrr_stack+769996, dvrr_stack+297220);
 tmp = dvrr_stack + 872037;
 target_ptr = Libderiv->deriv_classes[9][5][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+873192, dvrr_stack+298165, dvrr_stack+90442);
 tmp = dvrr_stack + 873192;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+874732, dvrr_stack+304730, dvrr_stack+94278);
 tmp = dvrr_stack + 874732;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+876712, dvrr_stack+796442, dvrr_stack+324575);
 tmp = dvrr_stack + 876712;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+879187, dvrr_stack+814515, dvrr_stack+117546);
 tmp = dvrr_stack + 879187;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+19282, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+373285, dvrr_stack+137438, dvrr_stack+19282, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+373291, dvrr_stack+4585, dvrr_stack+373285, dvrr_stack+158822, dvrr_stack+137438, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+4321, dvrr_stack+19980, dvrr_stack+373291, dvrr_stack+15, dvrr_stack+4585, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+9344, dvrr_stack+0, dvrr_stack+4321, dvrr_stack+111, dvrr_stack+19980, NULL);

 /* compute (6 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+91702, dvrr_stack+583699, dvrr_stack+9344, dvrr_stack+4336, dvrr_stack+0, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+47404, dvrr_stack+1966, dvrr_stack+4591, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+0, dvrr_stack+22243, dvrr_stack+47404, dvrr_stack+704, dvrr_stack+1966, dvrr_stack+19282);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+9821, dvrr_stack+152, dvrr_stack+0, dvrr_stack+569, dvrr_stack+22243, dvrr_stack+373285);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+498620, dvrr_stack+583720, dvrr_stack+9821, dvrr_stack+4351, dvrr_stack+152, dvrr_stack+373291);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+110427, dvrr_stack+492005, dvrr_stack+498620, dvrr_stack+4369, dvrr_stack+583720, dvrr_stack+4321);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+18, dvrr_stack+99231, dvrr_stack+110427, dvrr_stack+49816, dvrr_stack+492005, dvrr_stack+9344);

 /* compute (7 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+102, dvrr_stack+434121, dvrr_stack+18, dvrr_stack+137441, dvrr_stack+99231, dvrr_stack+91702);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+91702, dvrr_stack+1603, dvrr_stack+9313, NULL, NULL, dvrr_stack+4591);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+95898, dvrr_stack+33050, dvrr_stack+91702, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+47404);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1603, dvrr_stack+578, dvrr_stack+95898, dvrr_stack+72058, dvrr_stack+33050, dvrr_stack+0);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+1663, dvrr_stack+474260, dvrr_stack+1603, dvrr_stack+9365, dvrr_stack+578, dvrr_stack+9821);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+85822, dvrr_stack+33068, dvrr_stack+1663, dvrr_stack+4399, dvrr_stack+474260, dvrr_stack+498620);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+776912, dvrr_stack+583750, dvrr_stack+85822, dvrr_stack+614, dvrr_stack+33068, dvrr_stack+110427);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+33050, dvrr_stack+25972, dvrr_stack+776912, dvrr_stack+4459, dvrr_stack+583750, dvrr_stack+18);

 /* compute (8 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+4321, dvrr_stack+196884, dvrr_stack+33050, dvrr_stack+48250, dvrr_stack+25972, dvrr_stack+102);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+9821, dvrr_stack+9319, dvrr_stack+19285, NULL, NULL, dvrr_stack+9313);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+474260, dvrr_stack+19990, dvrr_stack+9821, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+91702);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+25972, dvrr_stack+115134, dvrr_stack+474260, dvrr_stack+72076, dvrr_stack+19990, dvrr_stack+95898);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+196884, dvrr_stack+20020, dvrr_stack+25972, dvrr_stack+72106, dvrr_stack+115134, dvrr_stack+1603);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+0, dvrr_stack+20120, dvrr_stack+196884, dvrr_stack+48418, dvrr_stack+20020, dvrr_stack+1663);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+1603, dvrr_stack+583876, dvrr_stack+0, dvrr_stack+48518, dvrr_stack+20120, dvrr_stack+85822);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+19980, dvrr_stack+590339, dvrr_stack+1603, dvrr_stack+47562, dvrr_stack+583876, dvrr_stack+776912);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+806012, dvrr_stack+594679, dvrr_stack+19980, dvrr_stack+31666, dvrr_stack+590339, dvrr_stack+33050);

 /* compute (9 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+882212, dvrr_stack+158352, dvrr_stack+806012, dvrr_stack+72166, dvrr_stack+594679, dvrr_stack+4321);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+498620, dvrr_stack+19295, dvrr_stack+32108, NULL, NULL, dvrr_stack+19285);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+4321, dvrr_stack+331415, dvrr_stack+498620, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+9821);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+4411, dvrr_stack+9851, dvrr_stack+4321, dvrr_stack+158825, dvrr_stack+331415, dvrr_stack+474260);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+594679, dvrr_stack+4171, dvrr_stack+4411, dvrr_stack+47772, dvrr_stack+9851, dvrr_stack+25972);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+158352, dvrr_stack+338795, dvrr_stack+594679, dvrr_stack+47254, dvrr_stack+4171, dvrr_stack+196884);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+583637, dvrr_stack+4604, dvrr_stack+158352, dvrr_stack+105829, dvrr_stack+338795, dvrr_stack+0);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+105531, dvrr_stack+1975, dvrr_stack+583637, dvrr_stack+441630, dvrr_stack+4604, dvrr_stack+1603);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+160418, dvrr_stack+105531, dvrr_stack+441945, dvrr_stack+1975, dvrr_stack+19980);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1603, dvrr_stack+707, dvrr_stack+31432, dvrr_stack+442365, dvrr_stack+160418, dvrr_stack+806012);

 /* compute (10 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+441630, dvrr_stack+69356, dvrr_stack+1603, dvrr_stack+442905, dvrr_stack+707, dvrr_stack+882212);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2428, dvrr_stack+32123, dvrr_stack+47999, NULL, NULL, dvrr_stack+32108);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+85822, dvrr_stack+4919, dvrr_stack+2428, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+498620);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+882212, dvrr_stack+160958, dvrr_stack+85822, dvrr_stack+66670, dvrr_stack+4919, dvrr_stack+4321);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+882422, dvrr_stack+4982, dvrr_stack+882212, dvrr_stack+66733, dvrr_stack+160958, dvrr_stack+4411);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+806012, dvrr_stack+557132, dvrr_stack+882422, dvrr_stack+66859, dvrr_stack+4982, dvrr_stack+594679);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+160418, dvrr_stack+109986, dvrr_stack+806012, dvrr_stack+72740, dvrr_stack+557132, dvrr_stack+158352);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+442620, dvrr_stack+8203, dvrr_stack+160418, dvrr_stack+443580, dvrr_stack+109986, dvrr_stack+583637);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+769240, dvrr_stack+442620, dvrr_stack+444021, dvrr_stack+8203, dvrr_stack+105531);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+443376, dvrr_stack+67069, dvrr_stack+4171, dvrr_stack+444609, dvrr_stack+769240, dvrr_stack+31432);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+71336, dvrr_stack+70181, dvrr_stack+443376, dvrr_stack+445365, dvrr_stack+67069, dvrr_stack+1603);

 /* compute (11 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+444531, dvrr_stack+769996, dvrr_stack+71336, dvrr_stack+446310, dvrr_stack+70181, dvrr_stack+441630);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+69274, dvrr_stack+444531, dvrr_stack+446310);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+434121, dvrr_stack+48020, dvrr_stack+47413, NULL, NULL, dvrr_stack+47999);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+25972, dvrr_stack+5192, dvrr_stack+434121, dvrr_stack+32144, dvrr_stack+48020, dvrr_stack+2428);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+590339, dvrr_stack+395520, dvrr_stack+25972, dvrr_stack+180488, dvrr_stack+5192, dvrr_stack+85822);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+441630, dvrr_stack+467085, dvrr_stack+590339, dvrr_stack+180572, dvrr_stack+395520, dvrr_stack+882212);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+1603, dvrr_stack+29192, dvrr_stack+441630, dvrr_stack+180740, dvrr_stack+467085, dvrr_stack+882422);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+882212, dvrr_stack+150797, dvrr_stack+1603, dvrr_stack+32315, dvrr_stack+29192, dvrr_stack+806012);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+8203, dvrr_stack+271465, dvrr_stack+882212, dvrr_stack+447465, dvrr_stack+150797, dvrr_stack+160418);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+51121, dvrr_stack+8203, dvrr_stack+448053, dvrr_stack+271465, dvrr_stack+442620);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+882996, dvrr_stack+68014, dvrr_stack+66670, dvrr_stack+448837, dvrr_stack+51121, dvrr_stack+4171);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+447465, dvrr_stack+771382, dvrr_stack+882996, dvrr_stack+449845, dvrr_stack+68014, dvrr_stack+443376);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+442050, dvrr_stack+298165, dvrr_stack+447465, dvrr_stack+451105, dvrr_stack+771382, dvrr_stack+71336);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+70660, dvrr_stack+442050, dvrr_stack+451105);

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+771382, dvrr_stack+1567, dvrr_stack+11542, NULL, NULL, dvrr_stack+47413);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+196884, dvrr_stack+300013, dvrr_stack+771382, dvrr_stack+48048, dvrr_stack+1567, dvrr_stack+434121);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+594679, dvrr_stack+186264, dvrr_stack+196884, dvrr_stack+181832, dvrr_stack+300013, dvrr_stack+25972);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+771490, dvrr_stack+300121, dvrr_stack+594679, dvrr_stack+181940, dvrr_stack+186264, dvrr_stack+590339);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+769240, dvrr_stack+85282, dvrr_stack+771490, dvrr_stack+182156, dvrr_stack+300121, dvrr_stack+441630);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+51121, dvrr_stack+48668, dvrr_stack+769240, dvrr_stack+182516, dvrr_stack+85282, dvrr_stack+1603);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+181832, dvrr_stack+778466, dvrr_stack+51121, dvrr_stack+456110, dvrr_stack+48668, dvrr_stack+882212);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+449313, dvrr_stack+779474, dvrr_stack+181832, dvrr_stack+456866, dvrr_stack+778466, dvrr_stack+8203);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+303110, dvrr_stack+449313, dvrr_stack+457874, dvrr_stack+779474, dvrr_stack+66670);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+780770, dvrr_stack+319, dvrr_stack+459170, dvrr_stack+303110, dvrr_stack+882996);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+456038, dvrr_stack+304730, dvrr_stack+66670, dvrr_stack+460790, dvrr_stack+780770, dvrr_stack+447465);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+778466, dvrr_stack+456038, dvrr_stack+460790);

 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+826920, dvrr_stack+35134, dvrr_stack+19395, NULL, NULL, dvrr_stack+11542);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+395520, dvrr_stack+32172, dvrr_stack+826920, dvrr_stack+9265, dvrr_stack+35134, dvrr_stack+771382);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+447465, dvrr_stack+89413, dvrr_stack+395520, dvrr_stack+186480, dvrr_stack+32172, dvrr_stack+196884);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+105531, dvrr_stack+316266, dvrr_stack+447465, dvrr_stack+186615, dvrr_stack+89413, dvrr_stack+594679);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+447915, dvrr_stack+18607, dvrr_stack+105531, dvrr_stack+186885, dvrr_stack+316266, dvrr_stack+771490);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+771382, dvrr_stack+790142, dvrr_stack+447915, dvrr_stack+187335, dvrr_stack+18607, dvrr_stack+769240);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+303110, dvrr_stack+791087, dvrr_stack+771382, dvrr_stack+477785, dvrr_stack+790142, dvrr_stack+51121);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+882212, dvrr_stack+792347, dvrr_stack+303110, dvrr_stack+478730, dvrr_stack+791087, dvrr_stack+181832);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+884237, dvrr_stack+319625, dvrr_stack+882212, dvrr_stack+479990, dvrr_stack+792347, dvrr_stack+449313);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+790142, dvrr_stack+793967, dvrr_stack+884237, dvrr_stack+481610, dvrr_stack+319625, dvrr_stack+319);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+477785, dvrr_stack+796442, dvrr_stack+790142, dvrr_stack+483635, dvrr_stack+793967, dvrr_stack+66670);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+793112, dvrr_stack+477785, dvrr_stack+483635);

 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+120021, dvrr_stack+48129, NULL, NULL, dvrr_stack+19395);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66835, dvrr_stack+324026, dvrr_stack+66670, dvrr_stack+264, dvrr_stack+120021, dvrr_stack+826920);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67165, dvrr_stack+324191, dvrr_stack+66835, dvrr_stack+199368, dvrr_stack+324026, dvrr_stack+395520);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67715, dvrr_stack+63170, dvrr_stack+67165, dvrr_stack+199533, dvrr_stack+324191, dvrr_stack+447465);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+319625, dvrr_stack+806540, dvrr_stack+67715, dvrr_stack+199863, dvrr_stack+63170, dvrr_stack+105531);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+807365, dvrr_stack+319625, dvrr_stack+200413, dvrr_stack+806540, dvrr_stack+447915);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+186264, dvrr_stack+808520, dvrr_stack+66670, dvrr_stack+505910, dvrr_stack+807365, dvrr_stack+771382);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+810060, dvrr_stack+186264, dvrr_stack+507065, dvrr_stack+808520, dvrr_stack+303110);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+447465, dvrr_stack+812040, dvrr_stack+66670, dvrr_stack+508605, dvrr_stack+810060, dvrr_stack+882212);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+505910, dvrr_stack+342800, dvrr_stack+447465, dvrr_stack+510585, dvrr_stack+812040, dvrr_stack+884237);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+882212, dvrr_stack+814515, dvrr_stack+505910, dvrr_stack+513060, dvrr_stack+342800, dvrr_stack+790142);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+505910, dvrr_stack+882212, dvrr_stack+513060);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+790142, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+180488, dvrr_stack+181076, dvrr_stack+3730);
 tmp = dvrr_stack + 180488;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+441630, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+790457, dvrr_stack+183204, dvrr_stack+6859);
 tmp = dvrr_stack + 790457;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+791241, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+51121, dvrr_stack+188244, dvrr_stack+12118);
 tmp = dvrr_stack + 51121;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+105531, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+791781, dvrr_stack+201573, dvrr_stack+22927);
 tmp = dvrr_stack + 791781;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+342800, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+771382, dvrr_stack+218848, dvrr_stack+36382);
 tmp = dvrr_stack + 771382;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+89413, dvrr_stack+89854, dvrr_stack+3415);
 tmp = dvrr_stack + 89413;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+769240, dvrr_stack+297220, dvrr_stack+89854);
 tmp = dvrr_stack + 769240;
 target_ptr = Libderiv->deriv_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+343625, dvrr_stack+91730, dvrr_stack+6439);
 tmp = dvrr_stack + 343625;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+344213, dvrr_stack+90442, dvrr_stack+91730);
 tmp = dvrr_stack + 344213;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+509540, dvrr_stack+95934, dvrr_stack+11578);
 tmp = dvrr_stack + 509540;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+510296, dvrr_stack+94278, dvrr_stack+95934);
 tmp = dvrr_stack + 510296;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+511592, dvrr_stack+106206, dvrr_stack+22252);
 tmp = dvrr_stack + 511592;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+303110, dvrr_stack+324575, dvrr_stack+106206);
 tmp = dvrr_stack + 303110;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+447465, dvrr_stack+120076, dvrr_stack+35557);
 tmp = dvrr_stack + 447465;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+186264, dvrr_stack+117546, dvrr_stack+120076);
 tmp = dvrr_stack + 186264;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+448620, dvrr_stack+446310, dvrr_stack+181076);
 tmp = dvrr_stack + 448620;
 target_ptr = Libderiv->deriv_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+449565, dvrr_stack+451105, dvrr_stack+183204);
 tmp = dvrr_stack + 449565;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+66670, dvrr_stack+460790, dvrr_stack+188244);
 tmp = dvrr_stack + 66670;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+319625, dvrr_stack+483635, dvrr_stack+201573);
 tmp = dvrr_stack + 319625;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+806012, dvrr_stack+513060, dvrr_stack+218848);
 tmp = dvrr_stack + 806012;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+199368, dvrr_stack+769996, dvrr_stack+297220);
 tmp = dvrr_stack + 199368;
 target_ptr = Libderiv->deriv_classes[9][5][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+481295, dvrr_stack+298165, dvrr_stack+90442);
 tmp = dvrr_stack + 481295;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+808487, dvrr_stack+304730, dvrr_stack+94278);
 tmp = dvrr_stack + 808487;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+810467, dvrr_stack+796442, dvrr_stack+324575);
 tmp = dvrr_stack + 810467;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+886502, dvrr_stack+814515, dvrr_stack+117546);
 tmp = dvrr_stack + 886502;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+780842, dvrr_stack+444531, dvrr_stack+446310);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+0, dvrr_stack+442050, dvrr_stack+451105);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+47176, dvrr_stack+456038, dvrr_stack+460790);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+889527, dvrr_stack+477785, dvrr_stack+483635);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+892497, dvrr_stack+882212, dvrr_stack+513060);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+345221, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+896127, dvrr_stack+181076, dvrr_stack+3730);
 tmp = dvrr_stack + 896127;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+3730, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+4150, dvrr_stack+183204, dvrr_stack+6859);
 tmp = dvrr_stack + 4150;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+6859, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+200523, dvrr_stack+188244, dvrr_stack+12118);
 tmp = dvrr_stack + 200523;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+12118, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+181832, dvrr_stack+201573, dvrr_stack+22927);
 tmp = dvrr_stack + 181832;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+22927, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+812942, dvrr_stack+218848, dvrr_stack+36382);
 tmp = dvrr_stack + 812942;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+36382, dvrr_stack+89854, dvrr_stack+3415);
 tmp = dvrr_stack + 36382;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+68290, dvrr_stack+297220, dvrr_stack+89854);
 tmp = dvrr_stack + 68290;
 target_ptr = Libderiv->deriv_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+89854, dvrr_stack+91730, dvrr_stack+6439);
 tmp = dvrr_stack + 89854;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+8203, dvrr_stack+90442, dvrr_stack+91730);
 tmp = dvrr_stack + 8203;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+482835, dvrr_stack+95934, dvrr_stack+11578);
 tmp = dvrr_stack + 482835;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+31432, dvrr_stack+94278, dvrr_stack+95934);
 tmp = dvrr_stack + 31432;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1848, dvrr_stack+106206, dvrr_stack+22252);
 tmp = dvrr_stack + 1848;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+458846, dvrr_stack+324575, dvrr_stack+106206);
 tmp = dvrr_stack + 458846;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+106206, dvrr_stack+120076, dvrr_stack+35557);
 tmp = dvrr_stack + 106206;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+896715, dvrr_stack+117546, dvrr_stack+120076);
 tmp = dvrr_stack + 896715;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+120021, dvrr_stack+446310, dvrr_stack+181076);
 tmp = dvrr_stack + 120021;
 target_ptr = Libderiv->deriv_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+34860, dvrr_stack+451105, dvrr_stack+183204);
 tmp = dvrr_stack + 34860;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+898695, dvrr_stack+460790, dvrr_stack+188244);
 tmp = dvrr_stack + 898695;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+900315, dvrr_stack+483635, dvrr_stack+201573);
 tmp = dvrr_stack + 900315;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+902340, dvrr_stack+513060, dvrr_stack+218848);
 tmp = dvrr_stack + 902340;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+188244, dvrr_stack+769996, dvrr_stack+297220);
 tmp = dvrr_stack + 188244;
 target_ptr = Libderiv->deriv_classes[9][5][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+201531, dvrr_stack+298165, dvrr_stack+90442);
 tmp = dvrr_stack + 201531;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+90442, dvrr_stack+304730, dvrr_stack+94278);
 tmp = dvrr_stack + 90442;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+94278, dvrr_stack+796442, dvrr_stack+324575);
 tmp = dvrr_stack + 94278;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+297220, dvrr_stack+814515, dvrr_stack+117546);
 tmp = dvrr_stack + 297220;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+769996, dvrr_stack+444531, dvrr_stack+446310);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+117546, dvrr_stack+442050, dvrr_stack+451105);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+442050, dvrr_stack+456038, dvrr_stack+460790);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+444426, dvrr_stack+477785, dvrr_stack+483635);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+814482, dvrr_stack+882212, dvrr_stack+513060);

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+882212, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 882212;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+882653, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 882653;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+181076, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 181076;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+883241, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 883241;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+884186, dvrr_stack+85948, NULL);
 tmp = dvrr_stack + 884186;
 target_ptr = Libderiv->deriv2_classes[5][9][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+885341, dvrr_stack+102822, NULL);
 tmp = dvrr_stack + 885341;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+477785, dvrr_stack+115194, NULL);
 tmp = dvrr_stack + 477785;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+478569, dvrr_stack+131444, NULL);
 tmp = dvrr_stack + 478569;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+479577, dvrr_stack+151532, NULL);
 tmp = dvrr_stack + 479577;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+456038, dvrr_stack+175868, NULL);
 tmp = dvrr_stack + 456038;
 target_ptr = Libderiv->deriv2_classes[6][9][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+457578, dvrr_stack+197100, NULL);
 tmp = dvrr_stack + 457578;
 target_ptr = Libderiv->deriv2_classes[7][5][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+304730, dvrr_stack+213129, NULL);
 tmp = dvrr_stack + 304730;
 target_ptr = Libderiv->deriv2_classes[7][6][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+305738, dvrr_stack+233464, NULL);
 tmp = dvrr_stack + 305738;
 target_ptr = Libderiv->deriv2_classes[7][7][143];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+512537, dvrr_stack+259612, NULL);
 tmp = dvrr_stack + 512537;
 target_ptr = Libderiv->deriv2_classes[7][8][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+324026, dvrr_stack+291280, NULL);
 tmp = dvrr_stack + 324026;
 target_ptr = Libderiv->deriv2_classes[7][9][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+514157, dvrr_stack+316790, NULL);
 tmp = dvrr_stack + 514157;
 target_ptr = Libderiv->deriv2_classes[8][5][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+450825, dvrr_stack+339020, NULL);
 tmp = dvrr_stack + 450825;
 target_ptr = Libderiv->deriv2_classes[8][6][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+796082, dvrr_stack+364095, NULL);
 tmp = dvrr_stack + 796082;
 target_ptr = Libderiv->deriv2_classes[8][7][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+483591, dvrr_stack+395790, NULL);
 tmp = dvrr_stack + 483591;
 target_ptr = Libderiv->deriv2_classes[8][8][143];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+904815, dvrr_stack+434205, NULL);
 tmp = dvrr_stack + 904815;
 target_ptr = Libderiv->deriv2_classes[8][9][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+797702, dvrr_stack+474320, NULL);
 tmp = dvrr_stack + 797702;
 target_ptr = Libderiv->deriv2_classes[9][5][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+218529, dvrr_stack+501290, NULL);
 tmp = dvrr_stack + 218529;
 target_ptr = Libderiv->deriv2_classes[9][6][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+460466, dvrr_stack+535390, NULL);
 tmp = dvrr_stack + 460466;
 target_ptr = Libderiv->deriv2_classes[9][7][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+907290, dvrr_stack+572449, NULL);
 tmp = dvrr_stack + 907290;
 target_ptr = Libderiv->deriv2_classes[9][8][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+909765, dvrr_stack+613204, NULL);
 tmp = dvrr_stack + 909765;
 target_ptr = Libderiv->deriv2_classes[9][9][143];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+885929, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 885929;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+119394, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 119394;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+515102, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 515102;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+183092, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 183092;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+912790, dvrr_stack+85948, NULL);
 tmp = dvrr_stack + 912790;
 target_ptr = Libderiv->deriv2_classes[5][9][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+36823, dvrr_stack+102822, NULL);
 tmp = dvrr_stack + 36823;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+18607, dvrr_stack+115194, NULL);
 tmp = dvrr_stack + 18607;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+913945, dvrr_stack+131444, NULL);
 tmp = dvrr_stack + 913945;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+914953, dvrr_stack+151532, NULL);
 tmp = dvrr_stack + 914953;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+916213, dvrr_stack+175868, NULL);
 tmp = dvrr_stack + 916213;
 target_ptr = Libderiv->deriv2_classes[6][9][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+271465, dvrr_stack+197100, NULL);
 tmp = dvrr_stack + 271465;
 target_ptr = Libderiv->deriv2_classes[7][5][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+917753, dvrr_stack+213129, NULL);
 tmp = dvrr_stack + 917753;
 target_ptr = Libderiv->deriv2_classes[7][6][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1296,dvrr_stack+918761, dvrr_stack+233464, NULL);
 tmp = dvrr_stack + 918761;
 target_ptr = Libderiv->deriv2_classes[7][7][131];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+920057, dvrr_stack+259612, NULL);
 tmp = dvrr_stack + 920057;
 target_ptr = Libderiv->deriv2_classes[7][8][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+921677, dvrr_stack+291280, NULL);
 tmp = dvrr_stack + 921677;
 target_ptr = Libderiv->deriv2_classes[7][9][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+923657, dvrr_stack+316790, NULL);
 tmp = dvrr_stack + 923657;
 target_ptr = Libderiv->deriv2_classes[8][5][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+924602, dvrr_stack+339020, NULL);
 tmp = dvrr_stack + 924602;
 target_ptr = Libderiv->deriv2_classes[8][6][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+925862, dvrr_stack+364095, NULL);
 tmp = dvrr_stack + 925862;
 target_ptr = Libderiv->deriv2_classes[8][7][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2025,dvrr_stack+927482, dvrr_stack+395790, NULL);
 tmp = dvrr_stack + 927482;
 target_ptr = Libderiv->deriv2_classes[8][8][131];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+929507, dvrr_stack+434205, NULL);
 tmp = dvrr_stack + 929507;
 target_ptr = Libderiv->deriv2_classes[8][9][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+931982, dvrr_stack+474320, NULL);
 tmp = dvrr_stack + 931982;
 target_ptr = Libderiv->deriv2_classes[9][5][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+933137, dvrr_stack+501290, NULL);
 tmp = dvrr_stack + 933137;
 target_ptr = Libderiv->deriv2_classes[9][6][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+934677, dvrr_stack+535390, NULL);
 tmp = dvrr_stack + 934677;
 target_ptr = Libderiv->deriv2_classes[9][7][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+936657, dvrr_stack+572449, NULL);
 tmp = dvrr_stack + 936657;
 target_ptr = Libderiv->deriv2_classes[9][8][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,3025,dvrr_stack+939132, dvrr_stack+613204, NULL);
 tmp = dvrr_stack + 939132;
 target_ptr = Libderiv->deriv2_classes[9][9][131];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+480837, dvrr_stack+401865, NULL);
 tmp = dvrr_stack + 480837;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+4934, dvrr_stack+403188, NULL);
 tmp = dvrr_stack + 4934;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+942157, dvrr_stack+404952, NULL);
 tmp = dvrr_stack + 942157;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+942913, dvrr_stack+407220, NULL);
 tmp = dvrr_stack + 942913;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+943858, dvrr_stack+264472, NULL);
 tmp = dvrr_stack + 943858;
 target_ptr = Libderiv->deriv2_classes[5][9][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+945013, dvrr_stack+622279, NULL);
 tmp = dvrr_stack + 945013;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+19980, dvrr_stack+624043, NULL);
 tmp = dvrr_stack + 19980;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+945601, dvrr_stack+626395, NULL);
 tmp = dvrr_stack + 945601;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+946609, dvrr_stack+629419, NULL);
 tmp = dvrr_stack + 946609;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+947869, dvrr_stack+633199, NULL);
 tmp = dvrr_stack + 947869;
 target_ptr = Libderiv->deriv2_classes[6][9][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+2793, dvrr_stack+637819, NULL);
 tmp = dvrr_stack + 2793;
 target_ptr = Libderiv->deriv2_classes[7][5][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+949409, dvrr_stack+640087, NULL);
 tmp = dvrr_stack + 949409;
 target_ptr = Libderiv->deriv2_classes[7][6][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+950417, dvrr_stack+643111, NULL);
 tmp = dvrr_stack + 950417;
 target_ptr = Libderiv->deriv2_classes[7][7][130];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+951713, dvrr_stack+646999, NULL);
 tmp = dvrr_stack + 951713;
 target_ptr = Libderiv->deriv2_classes[7][8][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+953333, dvrr_stack+651859, NULL);
 tmp = dvrr_stack + 953333;
 target_ptr = Libderiv->deriv2_classes[7][9][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+955313, dvrr_stack+657799, NULL);
 tmp = dvrr_stack + 955313;
 target_ptr = Libderiv->deriv2_classes[8][5][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+956258, dvrr_stack+660634, NULL);
 tmp = dvrr_stack + 956258;
 target_ptr = Libderiv->deriv2_classes[8][6][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+957518, dvrr_stack+664414, NULL);
 tmp = dvrr_stack + 957518;
 target_ptr = Libderiv->deriv2_classes[8][7][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+959138, dvrr_stack+669274, NULL);
 tmp = dvrr_stack + 959138;
 target_ptr = Libderiv->deriv2_classes[8][8][130];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+961163, dvrr_stack+675349, NULL);
 tmp = dvrr_stack + 961163;
 target_ptr = Libderiv->deriv2_classes[8][9][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+963638, dvrr_stack+682774, NULL);
 tmp = dvrr_stack + 963638;
 target_ptr = Libderiv->deriv2_classes[9][5][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+964793, dvrr_stack+686239, NULL);
 tmp = dvrr_stack + 964793;
 target_ptr = Libderiv->deriv2_classes[9][6][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+966333, dvrr_stack+690859, NULL);
 tmp = dvrr_stack + 966333;
 target_ptr = Libderiv->deriv2_classes[9][7][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+968313, dvrr_stack+696799, NULL);
 tmp = dvrr_stack + 968313;
 target_ptr = Libderiv->deriv2_classes[9][8][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+970788, dvrr_stack+704224, NULL);
 tmp = dvrr_stack + 970788;
 target_ptr = Libderiv->deriv2_classes[9][9][130];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+458334, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 458334;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+63170, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 63170;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+29192, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 29192;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+29948, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 29948;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+63758, dvrr_stack+85948, NULL);
 tmp = dvrr_stack + 63758;
 target_ptr = Libderiv->deriv2_classes[5][9][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+64913, dvrr_stack+102822, NULL);
 tmp = dvrr_stack + 64913;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+65501, dvrr_stack+115194, NULL);
 tmp = dvrr_stack + 65501;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+85282, dvrr_stack+131444, NULL);
 tmp = dvrr_stack + 85282;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+131444, dvrr_stack+151532, NULL);
 tmp = dvrr_stack + 131444;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+132704, dvrr_stack+175868, NULL);
 tmp = dvrr_stack + 132704;
 target_ptr = Libderiv->deriv2_classes[6][9][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+86290, dvrr_stack+197100, NULL);
 tmp = dvrr_stack + 86290;
 target_ptr = Libderiv->deriv2_classes[7][5][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+196884, dvrr_stack+213129, NULL);
 tmp = dvrr_stack + 196884;
 target_ptr = Libderiv->deriv2_classes[7][6][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1296,dvrr_stack+197892, dvrr_stack+233464, NULL);
 tmp = dvrr_stack + 197892;
 target_ptr = Libderiv->deriv2_classes[7][7][119];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+87046, dvrr_stack+259612, NULL);
 tmp = dvrr_stack + 87046;
 target_ptr = Libderiv->deriv2_classes[7][8][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+259612, dvrr_stack+291280, NULL);
 tmp = dvrr_stack + 259612;
 target_ptr = Libderiv->deriv2_classes[7][9][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+261592, dvrr_stack+316790, NULL);
 tmp = dvrr_stack + 261592;
 target_ptr = Libderiv->deriv2_classes[8][5][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+262537, dvrr_stack+339020, NULL);
 tmp = dvrr_stack + 262537;
 target_ptr = Libderiv->deriv2_classes[8][6][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+316266, dvrr_stack+364095, NULL);
 tmp = dvrr_stack + 316266;
 target_ptr = Libderiv->deriv2_classes[8][7][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2025,dvrr_stack+150797, dvrr_stack+395790, NULL);
 tmp = dvrr_stack + 150797;
 target_ptr = Libderiv->deriv2_classes[8][8][119];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+395520, dvrr_stack+434205, NULL);
 tmp = dvrr_stack + 395520;
 target_ptr = Libderiv->deriv2_classes[8][9][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+397995, dvrr_stack+474320, NULL);
 tmp = dvrr_stack + 397995;
 target_ptr = Libderiv->deriv2_classes[9][5][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+399150, dvrr_stack+501290, NULL);
 tmp = dvrr_stack + 399150;
 target_ptr = Libderiv->deriv2_classes[9][6][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+434121, dvrr_stack+535390, NULL);
 tmp = dvrr_stack + 434121;
 target_ptr = Libderiv->deriv2_classes[9][7][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+436101, dvrr_stack+572449, NULL);
 tmp = dvrr_stack + 436101;
 target_ptr = Libderiv->deriv2_classes[9][8][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,3025,dvrr_stack+438576, dvrr_stack+613204, NULL);
 tmp = dvrr_stack + 438576;
 target_ptr = Libderiv->deriv2_classes[9][9][119];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+263797, dvrr_stack+401865, NULL);
 tmp = dvrr_stack + 263797;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+400690, dvrr_stack+403188, NULL);
 tmp = dvrr_stack + 400690;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+401278, dvrr_stack+404952, NULL);
 tmp = dvrr_stack + 401278;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+402034, dvrr_stack+407220, NULL);
 tmp = dvrr_stack + 402034;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+402979, dvrr_stack+264472, NULL);
 tmp = dvrr_stack + 402979;
 target_ptr = Libderiv->deriv2_classes[5][9][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+264238, dvrr_stack+622279, NULL);
 tmp = dvrr_stack + 264238;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+264826, dvrr_stack+624043, NULL);
 tmp = dvrr_stack + 264826;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+265610, dvrr_stack+626395, NULL);
 tmp = dvrr_stack + 265610;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+266618, dvrr_stack+629419, NULL);
 tmp = dvrr_stack + 266618;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+404134, dvrr_stack+633199, NULL);
 tmp = dvrr_stack + 404134;
 target_ptr = Libderiv->deriv2_classes[6][9][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+405674, dvrr_stack+637819, NULL);
 tmp = dvrr_stack + 405674;
 target_ptr = Libderiv->deriv2_classes[7][5][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+406430, dvrr_stack+640087, NULL);
 tmp = dvrr_stack + 406430;
 target_ptr = Libderiv->deriv2_classes[7][6][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+407438, dvrr_stack+643111, NULL);
 tmp = dvrr_stack + 407438;
 target_ptr = Libderiv->deriv2_classes[7][7][118];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+317886, dvrr_stack+646999, NULL);
 tmp = dvrr_stack + 317886;
 target_ptr = Libderiv->deriv2_classes[7][8][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+152822, dvrr_stack+651859, NULL);
 tmp = dvrr_stack + 152822;
 target_ptr = Libderiv->deriv2_classes[7][9][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+408734, dvrr_stack+657799, NULL);
 tmp = dvrr_stack + 408734;
 target_ptr = Libderiv->deriv2_classes[8][5][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+338795, dvrr_stack+660634, NULL);
 tmp = dvrr_stack + 338795;
 target_ptr = Libderiv->deriv2_classes[8][6][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+340055, dvrr_stack+664414, NULL);
 tmp = dvrr_stack + 340055;
 target_ptr = Libderiv->deriv2_classes[8][7][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+474260, dvrr_stack+669274, NULL);
 tmp = dvrr_stack + 474260;
 target_ptr = Libderiv->deriv2_classes[8][8][118];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+612650, dvrr_stack+675349, NULL);
 tmp = dvrr_stack + 612650;
 target_ptr = Libderiv->deriv2_classes[8][9][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+476285, dvrr_stack+682774, NULL);
 tmp = dvrr_stack + 476285;
 target_ptr = Libderiv->deriv2_classes[9][5][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+115134, dvrr_stack+686239, NULL);
 tmp = dvrr_stack + 115134;
 target_ptr = Libderiv->deriv2_classes[9][6][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+615125, dvrr_stack+690859, NULL);
 tmp = dvrr_stack + 615125;
 target_ptr = Libderiv->deriv2_classes[9][7][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+617105, dvrr_stack+696799, NULL);
 tmp = dvrr_stack + 617105;
 target_ptr = Libderiv->deriv2_classes[9][8][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+619580, dvrr_stack+704224, NULL);
 tmp = dvrr_stack + 619580;
 target_ptr = Libderiv->deriv2_classes[9][9][118];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+452085, dvrr_stack+267937, NULL);
 tmp = dvrr_stack + 452085;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+267878, dvrr_stack+14638, NULL);
 tmp = dvrr_stack + 267878;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+268466, dvrr_stack+26140, NULL);
 tmp = dvrr_stack + 268466;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+25972, dvrr_stack+40372, NULL);
 tmp = dvrr_stack + 25972;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+26917, dvrr_stack+58165, NULL);
 tmp = dvrr_stack + 26917;
 target_ptr = Libderiv->deriv2_classes[5][9][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+326006, dvrr_stack+79018, NULL);
 tmp = dvrr_stack + 326006;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+341675, dvrr_stack+99294, NULL);
 tmp = dvrr_stack + 341675;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+99231, dvrr_stack+110490, NULL);
 tmp = dvrr_stack + 99231;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+109986, dvrr_stack+125396, NULL);
 tmp = dvrr_stack + 109986;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+111246, dvrr_stack+143972, NULL);
 tmp = dvrr_stack + 111246;
 target_ptr = Libderiv->deriv2_classes[6][9][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+33050, dvrr_stack+129176, NULL);
 tmp = dvrr_stack + 33050;
 target_ptr = Libderiv->deriv2_classes[7][5][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+100239, dvrr_stack+192564, NULL);
 tmp = dvrr_stack + 100239;
 target_ptr = Libderiv->deriv2_classes[7][6][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+192376, dvrr_stack+207081, NULL);
 tmp = dvrr_stack + 192376;
 target_ptr = Libderiv->deriv2_classes[7][7][117];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+207081, dvrr_stack+225688, NULL);
 tmp = dvrr_stack + 207081;
 target_ptr = Libderiv->deriv2_classes[7][8][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+208701, dvrr_stack+249892, NULL);
 tmp = dvrr_stack + 208701;
 target_ptr = Libderiv->deriv2_classes[7][9][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+249794, dvrr_stack+279400, NULL);
 tmp = dvrr_stack + 249794;
 target_ptr = Libderiv->deriv2_classes[8][5][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+279400, dvrr_stack+255832, NULL);
 tmp = dvrr_stack + 279400;
 target_ptr = Libderiv->deriv2_classes[8][6][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+250739, dvrr_stack+331460, NULL);
 tmp = dvrr_stack + 250739;
 target_ptr = Libderiv->deriv2_classes[8][7][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+331415, dvrr_stack+354375, NULL);
 tmp = dvrr_stack + 331415;
 target_ptr = Libderiv->deriv2_classes[8][8][117];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+354375, dvrr_stack+383640, NULL);
 tmp = dvrr_stack + 354375;
 target_ptr = Libderiv->deriv2_classes[8][9][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+383640, dvrr_stack+419355, NULL);
 tmp = dvrr_stack + 383640;
 target_ptr = Libderiv->deriv2_classes[9][5][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+384795, dvrr_stack+467390, NULL);
 tmp = dvrr_stack + 384795;
 target_ptr = Libderiv->deriv2_classes[9][6][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+386335, dvrr_stack+492050, NULL);
 tmp = dvrr_stack + 386335;
 target_ptr = Libderiv->deriv2_classes[9][7][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+388315, dvrr_stack+523510, NULL);
 tmp = dvrr_stack + 388315;
 target_ptr = Libderiv->deriv2_classes[9][8][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+356850, dvrr_stack+557599, NULL);
 tmp = dvrr_stack + 356850;
 target_ptr = Libderiv->deriv2_classes[9][9][117];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+359875, dvrr_stack+597095, dvrr_stack+596780);
 tmp = dvrr_stack + 359875;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+280660, dvrr_stack+598124, dvrr_stack+597683);
 tmp = dvrr_stack + 280660;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+281248, dvrr_stack+598880, dvrr_stack+597095);
 tmp = dvrr_stack + 281248;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+467085, dvrr_stack+599825, dvrr_stack+598124);
 tmp = dvrr_stack + 467085;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+468030, dvrr_stack+600980, dvrr_stack+598880);
 tmp = dvrr_stack + 468030;
 target_ptr = Libderiv->deriv2_classes[5][9][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+120966, dvrr_stack+603206, dvrr_stack+602786);
 tmp = dvrr_stack + 120966;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+469185, dvrr_stack+604578, dvrr_stack+603990);
 tmp = dvrr_stack + 469185;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+469969, dvrr_stack+605586, dvrr_stack+603206);
 tmp = dvrr_stack + 469969;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+557132, dvrr_stack+606846, dvrr_stack+604578);
 tmp = dvrr_stack + 557132;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+558392, dvrr_stack+608386, dvrr_stack+605586);
 tmp = dvrr_stack + 558392;
 target_ptr = Libderiv->deriv2_classes[6][9][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+470977, dvrr_stack+567214, dvrr_stack+566674);
 tmp = dvrr_stack + 470977;
 target_ptr = Libderiv->deriv2_classes[7][5][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+559932, dvrr_stack+568978, dvrr_stack+568222);
 tmp = dvrr_stack + 559932;
 target_ptr = Libderiv->deriv2_classes[7][6][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+560940, dvrr_stack+570274, dvrr_stack+567214);
 tmp = dvrr_stack + 560940;
 target_ptr = Libderiv->deriv2_classes[7][7][107];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+562236, dvrr_stack+530935, dvrr_stack+568978);
 tmp = dvrr_stack + 562236;
 target_ptr = Libderiv->deriv2_classes[7][8][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+563856, dvrr_stack+532915, dvrr_stack+570274);
 tmp = dvrr_stack + 563856;
 target_ptr = Libderiv->deriv2_classes[7][9][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+333440, dvrr_stack+472685, dvrr_stack+472010);
 tmp = dvrr_stack + 333440;
 target_ptr = Libderiv->deriv2_classes[8][5][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+334385, dvrr_stack+423765, dvrr_stack+422820);
 tmp = dvrr_stack + 334385;
 target_ptr = Libderiv->deriv2_classes[8][6][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+492005, dvrr_stack+425385, dvrr_stack+472685);
 tmp = dvrr_stack + 492005;
 target_ptr = Libderiv->deriv2_classes[8][7][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+493625, dvrr_stack+427410, dvrr_stack+423765);
 tmp = dvrr_stack + 493625;
 target_ptr = Libderiv->deriv2_classes[8][8][107];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+523466, dvrr_stack+429885, dvrr_stack+425385);
 tmp = dvrr_stack + 523466;
 target_ptr = Libderiv->deriv2_classes[8][9][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+495650, dvrr_stack+360450, dvrr_stack+393540);
 tmp = dvrr_stack + 495650;
 target_ptr = Libderiv->deriv2_classes[9][5][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+525941, dvrr_stack+361990, dvrr_stack+394365);
 tmp = dvrr_stack + 525941;
 target_ptr = Libderiv->deriv2_classes[9][6][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+527481, dvrr_stack+336320, dvrr_stack+360450);
 tmp = dvrr_stack + 527481;
 target_ptr = Libderiv->deriv2_classes[9][7][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+252359, dvrr_stack+311120, dvrr_stack+361990);
 tmp = dvrr_stack + 252359;
 target_ptr = Libderiv->deriv2_classes[9][8][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+254834, dvrr_stack+282235, dvrr_stack+336320);
 tmp = dvrr_stack + 254834;
 target_ptr = Libderiv->deriv2_classes[9][9][107];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+798857, dvrr_stack+500690, dvrr_stack+571894);
 tmp = dvrr_stack + 798857;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+88666, dvrr_stack+314145, dvrr_stack+433680);
 tmp = dvrr_stack + 88666;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+565836, dvrr_stack+314901, dvrr_stack+500690);
 tmp = dvrr_stack + 565836;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+496805, dvrr_stack+285865, dvrr_stack+314145);
 tmp = dvrr_stack + 496805;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+529461, dvrr_stack+287020, dvrr_stack+314901);
 tmp = dvrr_stack + 529461;
 target_ptr = Libderiv->deriv2_classes[5][9][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+160418, dvrr_stack+288406, dvrr_stack+315846);
 tmp = dvrr_stack + 160418;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+116674, dvrr_stack+289778, dvrr_stack+289190);
 tmp = dvrr_stack + 116674;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+257859, dvrr_stack+230548, dvrr_stack+288406);
 tmp = dvrr_stack + 257859;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+225349, dvrr_stack+231808, dvrr_stack+289778);
 tmp = dvrr_stack + 225349;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+226609, dvrr_stack+210969, dvrr_stack+230548);
 tmp = dvrr_stack + 226609;
 target_ptr = Libderiv->deriv2_classes[6][9][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+220069, dvrr_stack+166628, dvrr_stack+195588);
 tmp = dvrr_stack + 220069;
 target_ptr = Libderiv->deriv2_classes[7][5][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+228149, dvrr_stack+167636, dvrr_stack+196128);
 tmp = dvrr_stack + 228149;
 target_ptr = Libderiv->deriv2_classes[7][6][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+229157, dvrr_stack+168932, dvrr_stack+166628);
 tmp = dvrr_stack + 229157;
 target_ptr = Libderiv->deriv2_classes[7][7][106];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+193672, dvrr_stack+170552, dvrr_stack+167636);
 tmp = dvrr_stack + 193672;
 target_ptr = Libderiv->deriv2_classes[7][8][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+622605, dvrr_stack+172532, dvrr_stack+168932);
 tmp = dvrr_stack + 622605;
 target_ptr = Libderiv->deriv2_classes[7][9][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+624585, dvrr_stack+148592, dvrr_stack+174908);
 tmp = dvrr_stack + 624585;
 target_ptr = Libderiv->deriv2_classes[8][5][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+625530, dvrr_stack+113514, dvrr_stack+149852);
 tmp = dvrr_stack + 625530;
 target_ptr = Libderiv->deriv2_classes[8][6][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+626790, dvrr_stack+80782, dvrr_stack+148592);
 tmp = dvrr_stack + 626790;
 target_ptr = Libderiv->deriv2_classes[8][7][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+628410, dvrr_stack+82807, dvrr_stack+113514);
 tmp = dvrr_stack + 628410;
 target_ptr = Libderiv->deriv2_classes[8][8][106];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+630435, dvrr_stack+713299, dvrr_stack+80782);
 tmp = dvrr_stack + 630435;
 target_ptr = Libderiv->deriv2_classes[8][9][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+632910, dvrr_stack+61630, dvrr_stack+101646);
 tmp = dvrr_stack + 632910;
 target_ptr = Libderiv->deriv2_classes[9][5][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+634065, dvrr_stack+716269, dvrr_stack+43207);
 tmp = dvrr_stack + 634065;
 target_ptr = Libderiv->deriv2_classes[9][6][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+635605, dvrr_stack+718249, dvrr_stack+61630);
 tmp = dvrr_stack + 635605;
 target_ptr = Libderiv->deriv2_classes[9][7][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+637585, dvrr_stack+720724, dvrr_stack+716269);
 tmp = dvrr_stack + 637585;
 target_ptr = Libderiv->deriv2_classes[9][8][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+640060, dvrr_stack+723749, dvrr_stack+718249);
 tmp = dvrr_stack + 640060;
 target_ptr = Libderiv->deriv2_classes[9][9][106];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+485616, dvrr_stack+595835, dvrr_stack+473945);
 tmp = dvrr_stack + 485616;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+112786, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 112786;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+643085, dvrr_stack+23872, dvrr_stack+595835);
 tmp = dvrr_stack + 643085;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+643841, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 643841;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+644786, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 644786;
 target_ptr = Libderiv->deriv2_classes[5][9][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+335645, dvrr_stack+28408, dvrr_stack+74860);
 tmp = dvrr_stack + 335645;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+645941, dvrr_stack+92514, dvrr_stack+96942);
 tmp = dvrr_stack + 645941;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+646725, dvrr_stack+107466, dvrr_stack+28408);
 tmp = dvrr_stack + 646725;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+647733, dvrr_stack+121616, dvrr_stack+92514);
 tmp = dvrr_stack + 647733;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+648993, dvrr_stack+139352, dvrr_stack+107466);
 tmp = dvrr_stack + 648993;
 target_ptr = Libderiv->deriv2_classes[6][9][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+650533, dvrr_stack+611054, dvrr_stack+161084);
 tmp = dvrr_stack + 650533;
 target_ptr = Libderiv->deriv2_classes[7][5][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+651289, dvrr_stack+184212, dvrr_stack+93522);
 tmp = dvrr_stack + 651289;
 target_ptr = Libderiv->deriv2_classes[7][6][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+652297, dvrr_stack+203193, dvrr_stack+611054);
 tmp = dvrr_stack + 652297;
 target_ptr = Libderiv->deriv2_classes[7][7][105];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+653593, dvrr_stack+220828, dvrr_stack+184212);
 tmp = dvrr_stack + 653593;
 target_ptr = Libderiv->deriv2_classes[7][8][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+655213, dvrr_stack+243952, dvrr_stack+203193);
 tmp = dvrr_stack + 655213;
 target_ptr = Libderiv->deriv2_classes[7][9][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+657193, dvrr_stack+498665, dvrr_stack+272272);
 tmp = dvrr_stack + 657193;
 target_ptr = Libderiv->deriv2_classes[8][5][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+658138, dvrr_stack+300545, dvrr_stack+307340);
 tmp = dvrr_stack + 658138;
 target_ptr = Libderiv->deriv2_classes[8][6][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+659398, dvrr_stack+326600, dvrr_stack+498665);
 tmp = dvrr_stack + 659398;
 target_ptr = Libderiv->deriv2_classes[8][7][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+661018, dvrr_stack+348300, dvrr_stack+300545);
 tmp = dvrr_stack + 661018;
 target_ptr = Libderiv->deriv2_classes[8][8][105];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+663043, dvrr_stack+376215, dvrr_stack+326600);
 tmp = dvrr_stack + 663043;
 target_ptr = Libderiv->deriv2_classes[8][9][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+665518, dvrr_stack+391065, dvrr_stack+379185);
 tmp = dvrr_stack + 665518;
 target_ptr = Libderiv->deriv2_classes[9][5][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+666673, dvrr_stack+452645, dvrr_stack+462770);
 tmp = dvrr_stack + 666673;
 target_ptr = Libderiv->deriv2_classes[9][6][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+668213, dvrr_stack+486110, dvrr_stack+391065);
 tmp = dvrr_stack + 668213;
 target_ptr = Libderiv->deriv2_classes[9][7][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+670193, dvrr_stack+516085, dvrr_stack+452645);
 tmp = dvrr_stack + 670193;
 target_ptr = Libderiv->deriv2_classes[9][8][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+672668, dvrr_stack+380010, dvrr_stack+486110);
 tmp = dvrr_stack + 672668;
 target_ptr = Libderiv->deriv2_classes[9][9][105];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+782228, dvrr_stack+585068, dvrr_stack+584753);
 tmp = dvrr_stack + 782228;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+9821, dvrr_stack+586097, dvrr_stack+585656);
 tmp = dvrr_stack + 9821;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+675693, dvrr_stack+586853, dvrr_stack+585068);
 tmp = dvrr_stack + 675693;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+676449, dvrr_stack+587798, dvrr_stack+586097);
 tmp = dvrr_stack + 676449;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+677394, dvrr_stack+588953, dvrr_stack+586853);
 tmp = dvrr_stack + 677394;
 target_ptr = Libderiv->deriv2_classes[5][9][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+22243, dvrr_stack+591039, dvrr_stack+590619);
 tmp = dvrr_stack + 22243;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+678549, dvrr_stack+592411, dvrr_stack+591823);
 tmp = dvrr_stack + 678549;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+679333, dvrr_stack+593419, dvrr_stack+591039);
 tmp = dvrr_stack + 679333;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+680341, dvrr_stack+548524, dvrr_stack+592411);
 tmp = dvrr_stack + 680341;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+681601, dvrr_stack+550064, dvrr_stack+593419);
 tmp = dvrr_stack + 681601;
 target_ptr = Libderiv->deriv2_classes[6][9][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+683141, dvrr_stack+552452, dvrr_stack+551912);
 tmp = dvrr_stack + 683141;
 target_ptr = Libderiv->deriv2_classes[7][5][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+683897, dvrr_stack+554216, dvrr_stack+553460);
 tmp = dvrr_stack + 683897;
 target_ptr = Libderiv->deriv2_classes[7][6][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+684905, dvrr_stack+555512, dvrr_stack+552452);
 tmp = dvrr_stack + 684905;
 target_ptr = Libderiv->deriv2_classes[7][7][104];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+686201, dvrr_stack+519110, dvrr_stack+554216);
 tmp = dvrr_stack + 686201;
 target_ptr = Libderiv->deriv2_classes[7][8][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+687821, dvrr_stack+521090, dvrr_stack+555512);
 tmp = dvrr_stack + 687821;
 target_ptr = Libderiv->deriv2_classes[7][9][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+689801, dvrr_stack+489260, dvrr_stack+488585);
 tmp = dvrr_stack + 689801;
 target_ptr = Libderiv->deriv2_classes[8][5][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+690746, dvrr_stack+463925, dvrr_stack+490520);
 tmp = dvrr_stack + 690746;
 target_ptr = Libderiv->deriv2_classes[8][6][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+692006, dvrr_stack+350775, dvrr_stack+489260);
 tmp = dvrr_stack + 692006;
 target_ptr = Libderiv->deriv2_classes[8][7][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+693626, dvrr_stack+328625, dvrr_stack+463925);
 tmp = dvrr_stack + 693626;
 target_ptr = Libderiv->deriv2_classes[8][8][104];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+695651, dvrr_stack+272947, dvrr_stack+350775);
 tmp = dvrr_stack + 695651;
 target_ptr = Libderiv->deriv2_classes[8][9][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+698126, dvrr_stack+465545, dvrr_stack+454625);
 tmp = dvrr_stack + 698126;
 target_ptr = Libderiv->deriv2_classes[9][5][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+699281, dvrr_stack+308285, dvrr_stack+352800);
 tmp = dvrr_stack + 699281;
 target_ptr = Libderiv->deriv2_classes[9][6][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+700821, dvrr_stack+275917, dvrr_stack+465545);
 tmp = dvrr_stack + 700821;
 target_ptr = Libderiv->deriv2_classes[9][7][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+702801, dvrr_stack+246328, dvrr_stack+308285);
 tmp = dvrr_stack + 702801;
 target_ptr = Libderiv->deriv2_classes[9][8][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+705276, dvrr_stack+161624, dvrr_stack+275917);
 tmp = dvrr_stack + 705276;
 target_ptr = Libderiv->deriv2_classes[9][9][104];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+154802, dvrr_stack+597095, dvrr_stack+596780);
 tmp = dvrr_stack + 154802;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+258867, dvrr_stack+598124, dvrr_stack+597683);
 tmp = dvrr_stack + 258867;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+708301, dvrr_stack+598880, dvrr_stack+597095);
 tmp = dvrr_stack + 708301;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+709057, dvrr_stack+599825, dvrr_stack+598124);
 tmp = dvrr_stack + 709057;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+710002, dvrr_stack+600980, dvrr_stack+598880);
 tmp = dvrr_stack + 710002;
 target_ptr = Libderiv->deriv2_classes[5][9][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+711157, dvrr_stack+603206, dvrr_stack+602786);
 tmp = dvrr_stack + 711157;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+711745, dvrr_stack+604578, dvrr_stack+603990);
 tmp = dvrr_stack + 711745;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+143873, dvrr_stack+605586, dvrr_stack+603206);
 tmp = dvrr_stack + 143873;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+144881, dvrr_stack+606846, dvrr_stack+604578);
 tmp = dvrr_stack + 144881;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+146141, dvrr_stack+608386, dvrr_stack+605586);
 tmp = dvrr_stack + 146141;
 target_ptr = Libderiv->deriv2_classes[6][9][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+712529, dvrr_stack+567214, dvrr_stack+566674);
 tmp = dvrr_stack + 712529;
 target_ptr = Libderiv->deriv2_classes[7][5][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+125364, dvrr_stack+568978, dvrr_stack+568222);
 tmp = dvrr_stack + 125364;
 target_ptr = Libderiv->deriv2_classes[7][6][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+126372, dvrr_stack+570274, dvrr_stack+567214);
 tmp = dvrr_stack + 126372;
 target_ptr = Libderiv->deriv2_classes[7][7][95];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+127668, dvrr_stack+530935, dvrr_stack+568978);
 tmp = dvrr_stack + 127668;
 target_ptr = Libderiv->deriv2_classes[7][8][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+129288, dvrr_stack+532915, dvrr_stack+570274);
 tmp = dvrr_stack + 129288;
 target_ptr = Libderiv->deriv2_classes[7][9][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+78880, dvrr_stack+472685, dvrr_stack+472010);
 tmp = dvrr_stack + 78880;
 target_ptr = Libderiv->deriv2_classes[8][5][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+58111, dvrr_stack+423765, dvrr_stack+422820);
 tmp = dvrr_stack + 58111;
 target_ptr = Libderiv->deriv2_classes[8][6][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+59371, dvrr_stack+425385, dvrr_stack+472685);
 tmp = dvrr_stack + 59371;
 target_ptr = Libderiv->deriv2_classes[8][7][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+40232, dvrr_stack+427410, dvrr_stack+423765);
 tmp = dvrr_stack + 40232;
 target_ptr = Libderiv->deriv2_classes[8][8][95];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+572209, dvrr_stack+429885, dvrr_stack+425385);
 tmp = dvrr_stack + 572209;
 target_ptr = Libderiv->deriv2_classes[8][9][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+14260, dvrr_stack+360450, dvrr_stack+393540);
 tmp = dvrr_stack + 14260;
 target_ptr = Libderiv->deriv2_classes[9][5][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+574684, dvrr_stack+361990, dvrr_stack+394365);
 tmp = dvrr_stack + 574684;
 target_ptr = Libderiv->deriv2_classes[9][6][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+576224, dvrr_stack+336320, dvrr_stack+360450);
 tmp = dvrr_stack + 576224;
 target_ptr = Libderiv->deriv2_classes[9][7][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+535291, dvrr_stack+311120, dvrr_stack+361990);
 tmp = dvrr_stack + 535291;
 target_ptr = Libderiv->deriv2_classes[9][8][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+537766, dvrr_stack+282235, dvrr_stack+336320);
 tmp = dvrr_stack + 537766;
 target_ptr = Libderiv->deriv2_classes[9][9][95];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+30893, dvrr_stack+500690, dvrr_stack+571894);
 tmp = dvrr_stack + 30893;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+147681, dvrr_stack+314145, dvrr_stack+433680);
 tmp = dvrr_stack + 147681;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+79825, dvrr_stack+314901, dvrr_stack+500690);
 tmp = dvrr_stack + 79825;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+42257, dvrr_stack+285865, dvrr_stack+314145);
 tmp = dvrr_stack + 42257;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+578204, dvrr_stack+287020, dvrr_stack+314901);
 tmp = dvrr_stack + 578204;
 target_ptr = Libderiv->deriv2_classes[5][9][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+60991, dvrr_stack+288406, dvrr_stack+315846);
 tmp = dvrr_stack + 60991;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+15415, dvrr_stack+289778, dvrr_stack+289190);
 tmp = dvrr_stack + 15415;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+501278, dvrr_stack+230548, dvrr_stack+288406);
 tmp = dvrr_stack + 501278;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+502286, dvrr_stack+231808, dvrr_stack+289778);
 tmp = dvrr_stack + 502286;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+503546, dvrr_stack+210969, dvrr_stack+230548);
 tmp = dvrr_stack + 503546;
 target_ptr = Libderiv->deriv2_classes[6][9][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+505086, dvrr_stack+166628, dvrr_stack+195588);
 tmp = dvrr_stack + 505086;
 target_ptr = Libderiv->deriv2_classes[7][5][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+363970, dvrr_stack+167636, dvrr_stack+196128);
 tmp = dvrr_stack + 363970;
 target_ptr = Libderiv->deriv2_classes[7][6][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+364978, dvrr_stack+168932, dvrr_stack+166628);
 tmp = dvrr_stack + 364978;
 target_ptr = Libderiv->deriv2_classes[7][7][94];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+366274, dvrr_stack+170552, dvrr_stack+167636);
 tmp = dvrr_stack + 366274;
 target_ptr = Libderiv->deriv2_classes[7][8][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+290786, dvrr_stack+172532, dvrr_stack+168932);
 tmp = dvrr_stack + 290786;
 target_ptr = Libderiv->deriv2_classes[7][9][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+367894, dvrr_stack+148592, dvrr_stack+174908);
 tmp = dvrr_stack + 367894;
 target_ptr = Libderiv->deriv2_classes[8][5][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+292766, dvrr_stack+113514, dvrr_stack+149852);
 tmp = dvrr_stack + 292766;
 target_ptr = Libderiv->deriv2_classes[8][6][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+294026, dvrr_stack+80782, dvrr_stack+148592);
 tmp = dvrr_stack + 294026;
 target_ptr = Libderiv->deriv2_classes[8][7][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+233348, dvrr_stack+82807, dvrr_stack+113514);
 tmp = dvrr_stack + 233348;
 target_ptr = Libderiv->deriv2_classes[8][8][94];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+212817, dvrr_stack+713299, dvrr_stack+80782);
 tmp = dvrr_stack + 212817;
 target_ptr = Libderiv->deriv2_classes[8][9][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+295646, dvrr_stack+61630, dvrr_stack+101646);
 tmp = dvrr_stack + 295646;
 target_ptr = Libderiv->deriv2_classes[9][5][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+235373, dvrr_stack+716269, dvrr_stack+43207);
 tmp = dvrr_stack + 235373;
 target_ptr = Libderiv->deriv2_classes[9][6][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+175583, dvrr_stack+718249, dvrr_stack+61630);
 tmp = dvrr_stack + 175583;
 target_ptr = Libderiv->deriv2_classes[9][7][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+177563, dvrr_stack+720724, dvrr_stack+716269);
 tmp = dvrr_stack + 177563;
 target_ptr = Libderiv->deriv2_classes[9][8][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+419031, dvrr_stack+723749, dvrr_stack+718249);
 tmp = dvrr_stack + 419031;
 target_ptr = Libderiv->deriv2_classes[9][9][94];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+583637, dvrr_stack+595835, dvrr_stack+473945);
 tmp = dvrr_stack + 583637;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+215292, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 215292;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+102471, dvrr_stack+23872, dvrr_stack+595835);
 tmp = dvrr_stack + 102471;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+103227, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 103227;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+44362, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 44362;
 target_ptr = Libderiv->deriv2_classes[5][9][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+45517, dvrr_stack+28408, dvrr_stack+74860);
 tmp = dvrr_stack + 45517;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+46105, dvrr_stack+92514, dvrr_stack+96942);
 tmp = dvrr_stack + 46105;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+17186, dvrr_stack+107466, dvrr_stack+28408);
 tmp = dvrr_stack + 17186;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+973813, dvrr_stack+121616, dvrr_stack+92514);
 tmp = dvrr_stack + 973813;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+975073, dvrr_stack+139352, dvrr_stack+107466);
 tmp = dvrr_stack + 975073;
 target_ptr = Libderiv->deriv2_classes[6][9][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+422056, dvrr_stack+611054, dvrr_stack+161084);
 tmp = dvrr_stack + 422056;
 target_ptr = Libderiv->deriv2_classes[7][5][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+976613, dvrr_stack+184212, dvrr_stack+93522);
 tmp = dvrr_stack + 976613;
 target_ptr = Libderiv->deriv2_classes[7][6][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+977621, dvrr_stack+203193, dvrr_stack+611054);
 tmp = dvrr_stack + 977621;
 target_ptr = Libderiv->deriv2_classes[7][7][93];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+978917, dvrr_stack+220828, dvrr_stack+184212);
 tmp = dvrr_stack + 978917;
 target_ptr = Libderiv->deriv2_classes[7][8][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+980537, dvrr_stack+243952, dvrr_stack+203193);
 tmp = dvrr_stack + 980537;
 target_ptr = Libderiv->deriv2_classes[7][9][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+982517, dvrr_stack+498665, dvrr_stack+272272);
 tmp = dvrr_stack + 982517;
 target_ptr = Libderiv->deriv2_classes[8][5][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+983462, dvrr_stack+300545, dvrr_stack+307340);
 tmp = dvrr_stack + 983462;
 target_ptr = Libderiv->deriv2_classes[8][6][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+984722, dvrr_stack+326600, dvrr_stack+498665);
 tmp = dvrr_stack + 984722;
 target_ptr = Libderiv->deriv2_classes[8][7][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+986342, dvrr_stack+348300, dvrr_stack+300545);
 tmp = dvrr_stack + 986342;
 target_ptr = Libderiv->deriv2_classes[8][8][93];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+988367, dvrr_stack+376215, dvrr_stack+326600);
 tmp = dvrr_stack + 988367;
 target_ptr = Libderiv->deriv2_classes[8][9][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+990842, dvrr_stack+391065, dvrr_stack+379185);
 tmp = dvrr_stack + 990842;
 target_ptr = Libderiv->deriv2_classes[9][5][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+991997, dvrr_stack+452645, dvrr_stack+462770);
 tmp = dvrr_stack + 991997;
 target_ptr = Libderiv->deriv2_classes[9][6][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+993537, dvrr_stack+486110, dvrr_stack+391065);
 tmp = dvrr_stack + 993537;
 target_ptr = Libderiv->deriv2_classes[9][7][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+995517, dvrr_stack+516085, dvrr_stack+452645);
 tmp = dvrr_stack + 995517;
 target_ptr = Libderiv->deriv2_classes[9][8][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+997992, dvrr_stack+380010, dvrr_stack+486110);
 tmp = dvrr_stack + 997992;
 target_ptr = Libderiv->deriv2_classes[9][9][93];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+1001017, dvrr_stack+585068, dvrr_stack+584753);
 tmp = dvrr_stack + 1001017;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+243358, dvrr_stack+586097, dvrr_stack+585656);
 tmp = dvrr_stack + 243358;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+11218, dvrr_stack+586853, dvrr_stack+585068);
 tmp = dvrr_stack + 11218;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+1001458, dvrr_stack+587798, dvrr_stack+586097);
 tmp = dvrr_stack + 1001458;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+1002403, dvrr_stack+588953, dvrr_stack+586853);
 tmp = dvrr_stack + 1002403;
 target_ptr = Libderiv->deriv2_classes[5][9][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+1003558, dvrr_stack+591039, dvrr_stack+590619);
 tmp = dvrr_stack + 1003558;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+1004146, dvrr_stack+592411, dvrr_stack+591823);
 tmp = dvrr_stack + 1004146;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+1004930, dvrr_stack+593419, dvrr_stack+591039);
 tmp = dvrr_stack + 1004930;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1005938, dvrr_stack+548524, dvrr_stack+592411);
 tmp = dvrr_stack + 1005938;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1007198, dvrr_stack+550064, dvrr_stack+593419);
 tmp = dvrr_stack + 1007198;
 target_ptr = Libderiv->deriv2_classes[6][9][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1008738, dvrr_stack+552452, dvrr_stack+551912);
 tmp = dvrr_stack + 1008738;
 target_ptr = Libderiv->deriv2_classes[7][5][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1009494, dvrr_stack+554216, dvrr_stack+553460);
 tmp = dvrr_stack + 1009494;
 target_ptr = Libderiv->deriv2_classes[7][6][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1010502, dvrr_stack+555512, dvrr_stack+552452);
 tmp = dvrr_stack + 1010502;
 target_ptr = Libderiv->deriv2_classes[7][7][92];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1011798, dvrr_stack+519110, dvrr_stack+554216);
 tmp = dvrr_stack + 1011798;
 target_ptr = Libderiv->deriv2_classes[7][8][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1013418, dvrr_stack+521090, dvrr_stack+555512);
 tmp = dvrr_stack + 1013418;
 target_ptr = Libderiv->deriv2_classes[7][9][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1015398, dvrr_stack+489260, dvrr_stack+488585);
 tmp = dvrr_stack + 1015398;
 target_ptr = Libderiv->deriv2_classes[8][5][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1016343, dvrr_stack+463925, dvrr_stack+490520);
 tmp = dvrr_stack + 1016343;
 target_ptr = Libderiv->deriv2_classes[8][6][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1017603, dvrr_stack+350775, dvrr_stack+489260);
 tmp = dvrr_stack + 1017603;
 target_ptr = Libderiv->deriv2_classes[8][7][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1019223, dvrr_stack+328625, dvrr_stack+463925);
 tmp = dvrr_stack + 1019223;
 target_ptr = Libderiv->deriv2_classes[8][8][92];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1021248, dvrr_stack+272947, dvrr_stack+350775);
 tmp = dvrr_stack + 1021248;
 target_ptr = Libderiv->deriv2_classes[8][9][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1023723, dvrr_stack+465545, dvrr_stack+454625);
 tmp = dvrr_stack + 1023723;
 target_ptr = Libderiv->deriv2_classes[9][5][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1024878, dvrr_stack+308285, dvrr_stack+352800);
 tmp = dvrr_stack + 1024878;
 target_ptr = Libderiv->deriv2_classes[9][6][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1026418, dvrr_stack+275917, dvrr_stack+465545);
 tmp = dvrr_stack + 1026418;
 target_ptr = Libderiv->deriv2_classes[9][7][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1028398, dvrr_stack+246328, dvrr_stack+308285);
 tmp = dvrr_stack + 1028398;
 target_ptr = Libderiv->deriv2_classes[9][8][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1030873, dvrr_stack+161624, dvrr_stack+275917);
 tmp = dvrr_stack + 1030873;
 target_ptr = Libderiv->deriv2_classes[9][9][92];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+158352, dvrr_stack+455450, dvrr_stack+584164);
 tmp = dvrr_stack + 158352;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+1033898, dvrr_stack+392605, dvrr_stack+595039);
 tmp = dvrr_stack + 1033898;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+1034486, dvrr_stack+302165, dvrr_stack+455450);
 tmp = dvrr_stack + 1034486;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+1035242, dvrr_stack+222808, dvrr_stack+392605);
 tmp = dvrr_stack + 1035242;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+1036187, dvrr_stack+223963, dvrr_stack+302165);
 tmp = dvrr_stack + 1036187;
 target_ptr = Libderiv->deriv2_classes[5][9][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+1037342, dvrr_stack+310265, dvrr_stack+353955);
 tmp = dvrr_stack + 1037342;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+1037930, dvrr_stack+278392, dvrr_stack+499925);
 tmp = dvrr_stack + 1037930;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+1038714, dvrr_stack+204813, dvrr_stack+310265);
 tmp = dvrr_stack + 1038714;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1039722, dvrr_stack+189540, dvrr_stack+278392);
 tmp = dvrr_stack + 1039722;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1040982, dvrr_stack+141200, dvrr_stack+204813);
 tmp = dvrr_stack + 1040982;
 target_ptr = Libderiv->deriv2_classes[6][9][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1042522, dvrr_stack+206073, dvrr_stack+491465);
 tmp = dvrr_stack + 1042522;
 target_ptr = Libderiv->deriv2_classes[7][5][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1043278, dvrr_stack+191080, dvrr_stack+185508);
 tmp = dvrr_stack + 1043278;
 target_ptr = Libderiv->deriv2_classes[7][6][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1044286, dvrr_stack+123156, dvrr_stack+206073);
 tmp = dvrr_stack + 1044286;
 target_ptr = Libderiv->deriv2_classes[7][7][91];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1045582, dvrr_stack+75280, dvrr_stack+191080);
 tmp = dvrr_stack + 1045582;
 target_ptr = Libderiv->deriv2_classes[7][8][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1047202, dvrr_stack+410055, dvrr_stack+123156);
 tmp = dvrr_stack + 1047202;
 target_ptr = Libderiv->deriv2_classes[7][9][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1049182, dvrr_stack+108726, dvrr_stack+165254);
 tmp = dvrr_stack + 1049182;
 target_ptr = Libderiv->deriv2_classes[8][5][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1050127, dvrr_stack+77260, dvrr_stack+97530);
 tmp = dvrr_stack + 1050127;
 target_ptr = Libderiv->deriv2_classes[8][6][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1051387, dvrr_stack+56086, dvrr_stack+108726);
 tmp = dvrr_stack + 1051387;
 target_ptr = Libderiv->deriv2_classes[8][7][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1053007, dvrr_stack+412431, dvrr_stack+77260);
 tmp = dvrr_stack + 1053007;
 target_ptr = Libderiv->deriv2_classes[8][8][91];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1055032, dvrr_stack+414906, dvrr_stack+56086);
 tmp = dvrr_stack + 1055032;
 target_ptr = Libderiv->deriv2_classes[8][9][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1057507, dvrr_stack+38692, dvrr_stack+143048);
 tmp = dvrr_stack + 1057507;
 target_ptr = Libderiv->deriv2_classes[9][5][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1058662, dvrr_stack+727379, dvrr_stack+24817);
 tmp = dvrr_stack + 1058662;
 target_ptr = Libderiv->deriv2_classes[9][6][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1060202, dvrr_stack+729359, dvrr_stack+38692);
 tmp = dvrr_stack + 1060202;
 target_ptr = Libderiv->deriv2_classes[9][7][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1062182, dvrr_stack+731834, dvrr_stack+727379);
 tmp = dvrr_stack + 1062182;
 target_ptr = Libderiv->deriv2_classes[9][8][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1064657, dvrr_stack+734859, dvrr_stack+729359);
 tmp = dvrr_stack + 1064657;
 target_ptr = Libderiv->deriv2_classes[9][9][91];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+579359, dvrr_stack+597095, dvrr_stack+596780);
 tmp = dvrr_stack + 579359;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+596423, dvrr_stack+598124, dvrr_stack+597683);
 tmp = dvrr_stack + 596423;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1067682, dvrr_stack+598880, dvrr_stack+597095);
 tmp = dvrr_stack + 1067682;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+1068438, dvrr_stack+599825, dvrr_stack+598124);
 tmp = dvrr_stack + 1068438;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1069383, dvrr_stack+600980, dvrr_stack+598880);
 tmp = dvrr_stack + 1069383;
 target_ptr = Libderiv->deriv2_classes[5][9][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+600980, dvrr_stack+603206, dvrr_stack+602786);
 tmp = dvrr_stack + 600980;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+601568, dvrr_stack+604578, dvrr_stack+603990);
 tmp = dvrr_stack + 601568;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1070538, dvrr_stack+605586, dvrr_stack+603206);
 tmp = dvrr_stack + 1070538;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1071546, dvrr_stack+606846, dvrr_stack+604578);
 tmp = dvrr_stack + 1071546;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1072806, dvrr_stack+608386, dvrr_stack+605586);
 tmp = dvrr_stack + 1072806;
 target_ptr = Libderiv->deriv2_classes[6][9][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+608386, dvrr_stack+567214, dvrr_stack+566674);
 tmp = dvrr_stack + 608386;
 target_ptr = Libderiv->deriv2_classes[7][5][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+609142, dvrr_stack+568978, dvrr_stack+568222);
 tmp = dvrr_stack + 609142;
 target_ptr = Libderiv->deriv2_classes[7][6][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1074346, dvrr_stack+570274, dvrr_stack+567214);
 tmp = dvrr_stack + 1074346;
 target_ptr = Libderiv->deriv2_classes[7][7][83];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1075642, dvrr_stack+530935, dvrr_stack+568978);
 tmp = dvrr_stack + 1075642;
 target_ptr = Libderiv->deriv2_classes[7][8][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1077262, dvrr_stack+532915, dvrr_stack+570274);
 tmp = dvrr_stack + 1077262;
 target_ptr = Libderiv->deriv2_classes[7][9][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+532915, dvrr_stack+472685, dvrr_stack+472010);
 tmp = dvrr_stack + 532915;
 target_ptr = Libderiv->deriv2_classes[8][5][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+533860, dvrr_stack+423765, dvrr_stack+422820);
 tmp = dvrr_stack + 533860;
 target_ptr = Libderiv->deriv2_classes[8][6][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1079242, dvrr_stack+425385, dvrr_stack+472685);
 tmp = dvrr_stack + 1079242;
 target_ptr = Libderiv->deriv2_classes[8][7][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1080862, dvrr_stack+427410, dvrr_stack+423765);
 tmp = dvrr_stack + 1080862;
 target_ptr = Libderiv->deriv2_classes[8][8][83];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1082887, dvrr_stack+429885, dvrr_stack+425385);
 tmp = dvrr_stack + 1082887;
 target_ptr = Libderiv->deriv2_classes[8][9][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+429885, dvrr_stack+360450, dvrr_stack+393540);
 tmp = dvrr_stack + 429885;
 target_ptr = Libderiv->deriv2_classes[9][5][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+431040, dvrr_stack+361990, dvrr_stack+394365);
 tmp = dvrr_stack + 431040;
 target_ptr = Libderiv->deriv2_classes[9][6][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1085362, dvrr_stack+336320, dvrr_stack+360450);
 tmp = dvrr_stack + 1085362;
 target_ptr = Libderiv->deriv2_classes[9][7][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1087342, dvrr_stack+311120, dvrr_stack+361990);
 tmp = dvrr_stack + 1087342;
 target_ptr = Libderiv->deriv2_classes[9][8][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1089817, dvrr_stack+282235, dvrr_stack+336320);
 tmp = dvrr_stack + 1089817;
 target_ptr = Libderiv->deriv2_classes[9][9][83];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+282004, dvrr_stack+500690, dvrr_stack+571894);
 tmp = dvrr_stack + 282004;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+282445, dvrr_stack+314145, dvrr_stack+433680);
 tmp = dvrr_stack + 282445;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+283033, dvrr_stack+314901, dvrr_stack+500690);
 tmp = dvrr_stack + 283033;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+283789, dvrr_stack+285865, dvrr_stack+314145);
 tmp = dvrr_stack + 283789;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1092842, dvrr_stack+287020, dvrr_stack+314901);
 tmp = dvrr_stack + 1092842;
 target_ptr = Libderiv->deriv2_classes[5][9][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+287020, dvrr_stack+288406, dvrr_stack+315846);
 tmp = dvrr_stack + 287020;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+287608, dvrr_stack+289778, dvrr_stack+289190);
 tmp = dvrr_stack + 287608;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+284734, dvrr_stack+230548, dvrr_stack+288406);
 tmp = dvrr_stack + 284734;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1093997, dvrr_stack+231808, dvrr_stack+289778);
 tmp = dvrr_stack + 1093997;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1095257, dvrr_stack+210969, dvrr_stack+230548);
 tmp = dvrr_stack + 1095257;
 target_ptr = Libderiv->deriv2_classes[6][9][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+210681, dvrr_stack+166628, dvrr_stack+195588);
 tmp = dvrr_stack + 210681;
 target_ptr = Libderiv->deriv2_classes[7][5][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+211437, dvrr_stack+167636, dvrr_stack+196128);
 tmp = dvrr_stack + 211437;
 target_ptr = Libderiv->deriv2_classes[7][6][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1096797, dvrr_stack+168932, dvrr_stack+166628);
 tmp = dvrr_stack + 1096797;
 target_ptr = Libderiv->deriv2_classes[7][7][82];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1098093, dvrr_stack+170552, dvrr_stack+167636);
 tmp = dvrr_stack + 1098093;
 target_ptr = Libderiv->deriv2_classes[7][8][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1099713, dvrr_stack+172532, dvrr_stack+168932);
 tmp = dvrr_stack + 1099713;
 target_ptr = Libderiv->deriv2_classes[7][9][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+172532, dvrr_stack+148592, dvrr_stack+174908);
 tmp = dvrr_stack + 172532;
 target_ptr = Libderiv->deriv2_classes[8][5][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+173477, dvrr_stack+113514, dvrr_stack+149852);
 tmp = dvrr_stack + 173477;
 target_ptr = Libderiv->deriv2_classes[8][6][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1101693, dvrr_stack+80782, dvrr_stack+148592);
 tmp = dvrr_stack + 1101693;
 target_ptr = Libderiv->deriv2_classes[8][7][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1103313, dvrr_stack+82807, dvrr_stack+113514);
 tmp = dvrr_stack + 1103313;
 target_ptr = Libderiv->deriv2_classes[8][8][82];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1105338, dvrr_stack+713299, dvrr_stack+80782);
 tmp = dvrr_stack + 1105338;
 target_ptr = Libderiv->deriv2_classes[8][9][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+713285, dvrr_stack+61630, dvrr_stack+101646);
 tmp = dvrr_stack + 713285;
 target_ptr = Libderiv->deriv2_classes[9][5][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+714440, dvrr_stack+716269, dvrr_stack+43207);
 tmp = dvrr_stack + 714440;
 target_ptr = Libderiv->deriv2_classes[9][6][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1107813, dvrr_stack+718249, dvrr_stack+61630);
 tmp = dvrr_stack + 1107813;
 target_ptr = Libderiv->deriv2_classes[9][7][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1109793, dvrr_stack+720724, dvrr_stack+716269);
 tmp = dvrr_stack + 1109793;
 target_ptr = Libderiv->deriv2_classes[9][8][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1112268, dvrr_stack+723749, dvrr_stack+718249);
 tmp = dvrr_stack + 1112268;
 target_ptr = Libderiv->deriv2_classes[9][9][82];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+723749, dvrr_stack+595835, dvrr_stack+473945);
 tmp = dvrr_stack + 723749;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+724190, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 724190;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+724778, dvrr_stack+23872, dvrr_stack+595835);
 tmp = dvrr_stack + 724778;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+725534, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 725534;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+101247, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 101247;
 target_ptr = Libderiv->deriv2_classes[5][9][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+54700, dvrr_stack+28408, dvrr_stack+74860);
 tmp = dvrr_stack + 54700;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+55288, dvrr_stack+92514, dvrr_stack+96942);
 tmp = dvrr_stack + 55288;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1115293, dvrr_stack+107466, dvrr_stack+28408);
 tmp = dvrr_stack + 1115293;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1116301, dvrr_stack+121616, dvrr_stack+92514);
 tmp = dvrr_stack + 1116301;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1117561, dvrr_stack+139352, dvrr_stack+107466);
 tmp = dvrr_stack + 1117561;
 target_ptr = Libderiv->deriv2_classes[6][9][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+139352, dvrr_stack+611054, dvrr_stack+161084);
 tmp = dvrr_stack + 139352;
 target_ptr = Libderiv->deriv2_classes[7][5][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+140108, dvrr_stack+184212, dvrr_stack+93522);
 tmp = dvrr_stack + 140108;
 target_ptr = Libderiv->deriv2_classes[7][6][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1119101, dvrr_stack+203193, dvrr_stack+611054);
 tmp = dvrr_stack + 1119101;
 target_ptr = Libderiv->deriv2_classes[7][7][81];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1120397, dvrr_stack+220828, dvrr_stack+184212);
 tmp = dvrr_stack + 1120397;
 target_ptr = Libderiv->deriv2_classes[7][8][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1122017, dvrr_stack+243952, dvrr_stack+203193);
 tmp = dvrr_stack + 1122017;
 target_ptr = Libderiv->deriv2_classes[7][9][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+471733, dvrr_stack+498665, dvrr_stack+272272);
 tmp = dvrr_stack + 471733;
 target_ptr = Libderiv->deriv2_classes[8][5][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+243946, dvrr_stack+300545, dvrr_stack+307340);
 tmp = dvrr_stack + 243946;
 target_ptr = Libderiv->deriv2_classes[8][6][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1123997, dvrr_stack+326600, dvrr_stack+498665);
 tmp = dvrr_stack + 1123997;
 target_ptr = Libderiv->deriv2_classes[8][7][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1125617, dvrr_stack+348300, dvrr_stack+300545);
 tmp = dvrr_stack + 1125617;
 target_ptr = Libderiv->deriv2_classes[8][8][81];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1127642, dvrr_stack+376215, dvrr_stack+326600);
 tmp = dvrr_stack + 1127642;
 target_ptr = Libderiv->deriv2_classes[8][9][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+376167, dvrr_stack+391065, dvrr_stack+379185);
 tmp = dvrr_stack + 376167;
 target_ptr = Libderiv->deriv2_classes[9][5][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+377322, dvrr_stack+452645, dvrr_stack+462770);
 tmp = dvrr_stack + 377322;
 target_ptr = Libderiv->deriv2_classes[9][6][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1130117, dvrr_stack+486110, dvrr_stack+391065);
 tmp = dvrr_stack + 1130117;
 target_ptr = Libderiv->deriv2_classes[9][7][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1132097, dvrr_stack+516085, dvrr_stack+452645);
 tmp = dvrr_stack + 1132097;
 target_ptr = Libderiv->deriv2_classes[9][8][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1134572, dvrr_stack+380010, dvrr_stack+486110);
 tmp = dvrr_stack + 1134572;
 target_ptr = Libderiv->deriv2_classes[9][9][81];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+726479, dvrr_stack+585068, dvrr_stack+584753);
 tmp = dvrr_stack + 726479;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+174737, dvrr_stack+586097, dvrr_stack+585656);
 tmp = dvrr_stack + 174737;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+378862, dvrr_stack+586853, dvrr_stack+585068);
 tmp = dvrr_stack + 378862;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+379618, dvrr_stack+587798, dvrr_stack+586097);
 tmp = dvrr_stack + 379618;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+380563, dvrr_stack+588953, dvrr_stack+586853);
 tmp = dvrr_stack + 380563;
 target_ptr = Libderiv->deriv2_classes[5][9][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+588953, dvrr_stack+591039, dvrr_stack+590619);
 tmp = dvrr_stack + 588953;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+589541, dvrr_stack+592411, dvrr_stack+591823);
 tmp = dvrr_stack + 589541;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+381718, dvrr_stack+593419, dvrr_stack+591039);
 tmp = dvrr_stack + 381718;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1137597, dvrr_stack+548524, dvrr_stack+592411);
 tmp = dvrr_stack + 1137597;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1138857, dvrr_stack+550064, dvrr_stack+593419);
 tmp = dvrr_stack + 1138857;
 target_ptr = Libderiv->deriv2_classes[6][9][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+550064, dvrr_stack+552452, dvrr_stack+551912);
 tmp = dvrr_stack + 550064;
 target_ptr = Libderiv->deriv2_classes[7][5][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+550820, dvrr_stack+554216, dvrr_stack+553460);
 tmp = dvrr_stack + 550820;
 target_ptr = Libderiv->deriv2_classes[7][6][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1140397, dvrr_stack+555512, dvrr_stack+552452);
 tmp = dvrr_stack + 1140397;
 target_ptr = Libderiv->deriv2_classes[7][7][80];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1141693, dvrr_stack+519110, dvrr_stack+554216);
 tmp = dvrr_stack + 1141693;
 target_ptr = Libderiv->deriv2_classes[7][8][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1143313, dvrr_stack+521090, dvrr_stack+555512);
 tmp = dvrr_stack + 1143313;
 target_ptr = Libderiv->deriv2_classes[7][9][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+521090, dvrr_stack+489260, dvrr_stack+488585);
 tmp = dvrr_stack + 521090;
 target_ptr = Libderiv->deriv2_classes[8][5][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+522035, dvrr_stack+463925, dvrr_stack+490520);
 tmp = dvrr_stack + 522035;
 target_ptr = Libderiv->deriv2_classes[8][6][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1145293, dvrr_stack+350775, dvrr_stack+489260);
 tmp = dvrr_stack + 1145293;
 target_ptr = Libderiv->deriv2_classes[8][7][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1146913, dvrr_stack+328625, dvrr_stack+463925);
 tmp = dvrr_stack + 1146913;
 target_ptr = Libderiv->deriv2_classes[8][8][80];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1148938, dvrr_stack+272947, dvrr_stack+350775);
 tmp = dvrr_stack + 1148938;
 target_ptr = Libderiv->deriv2_classes[8][9][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+272221, dvrr_stack+465545, dvrr_stack+454625);
 tmp = dvrr_stack + 272221;
 target_ptr = Libderiv->deriv2_classes[9][5][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+273376, dvrr_stack+308285, dvrr_stack+352800);
 tmp = dvrr_stack + 273376;
 target_ptr = Libderiv->deriv2_classes[9][6][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1151413, dvrr_stack+275917, dvrr_stack+465545);
 tmp = dvrr_stack + 1151413;
 target_ptr = Libderiv->deriv2_classes[9][7][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1153393, dvrr_stack+246328, dvrr_stack+308285);
 tmp = dvrr_stack + 1153393;
 target_ptr = Libderiv->deriv2_classes[9][8][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1155868, dvrr_stack+161624, dvrr_stack+275917);
 tmp = dvrr_stack + 1155868;
 target_ptr = Libderiv->deriv2_classes[9][9][80];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+454625, dvrr_stack+455450, dvrr_stack+584164);
 tmp = dvrr_stack + 454625;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+488585, dvrr_stack+392605, dvrr_stack+595039);
 tmp = dvrr_stack + 488585;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+274916, dvrr_stack+302165, dvrr_stack+455450);
 tmp = dvrr_stack + 274916;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+161006, dvrr_stack+222808, dvrr_stack+392605);
 tmp = dvrr_stack + 161006;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+161951, dvrr_stack+223963, dvrr_stack+302165);
 tmp = dvrr_stack + 161951;
 target_ptr = Libderiv->deriv2_classes[5][9][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+223963, dvrr_stack+310265, dvrr_stack+353955);
 tmp = dvrr_stack + 223963;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+224551, dvrr_stack+278392, dvrr_stack+499925);
 tmp = dvrr_stack + 224551;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+163106, dvrr_stack+204813, dvrr_stack+310265);
 tmp = dvrr_stack + 163106;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1158893, dvrr_stack+189540, dvrr_stack+278392);
 tmp = dvrr_stack + 1158893;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1160153, dvrr_stack+141200, dvrr_stack+204813);
 tmp = dvrr_stack + 1160153;
 target_ptr = Libderiv->deriv2_classes[6][9][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+141116, dvrr_stack+206073, dvrr_stack+491465);
 tmp = dvrr_stack + 141116;
 target_ptr = Libderiv->deriv2_classes[7][5][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+141872, dvrr_stack+191080, dvrr_stack+185508);
 tmp = dvrr_stack + 141872;
 target_ptr = Libderiv->deriv2_classes[7][6][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1161693, dvrr_stack+123156, dvrr_stack+206073);
 tmp = dvrr_stack + 1161693;
 target_ptr = Libderiv->deriv2_classes[7][7][79];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1162989, dvrr_stack+75280, dvrr_stack+191080);
 tmp = dvrr_stack + 1162989;
 target_ptr = Libderiv->deriv2_classes[7][8][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1164609, dvrr_stack+410055, dvrr_stack+123156);
 tmp = dvrr_stack + 1164609;
 target_ptr = Libderiv->deriv2_classes[7][9][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+409679, dvrr_stack+108726, dvrr_stack+165254);
 tmp = dvrr_stack + 409679;
 target_ptr = Libderiv->deriv2_classes[8][5][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+410624, dvrr_stack+77260, dvrr_stack+97530);
 tmp = dvrr_stack + 410624;
 target_ptr = Libderiv->deriv2_classes[8][6][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+164114, dvrr_stack+56086, dvrr_stack+108726);
 tmp = dvrr_stack + 164114;
 target_ptr = Libderiv->deriv2_classes[8][7][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1166589, dvrr_stack+412431, dvrr_stack+77260);
 tmp = dvrr_stack + 1166589;
 target_ptr = Libderiv->deriv2_classes[8][8][79];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1168614, dvrr_stack+414906, dvrr_stack+56086);
 tmp = dvrr_stack + 1168614;
 target_ptr = Libderiv->deriv2_classes[8][9][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+414906, dvrr_stack+38692, dvrr_stack+143048);
 tmp = dvrr_stack + 414906;
 target_ptr = Libderiv->deriv2_classes[9][5][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+416061, dvrr_stack+727379, dvrr_stack+24817);
 tmp = dvrr_stack + 416061;
 target_ptr = Libderiv->deriv2_classes[9][6][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1171089, dvrr_stack+729359, dvrr_stack+38692);
 tmp = dvrr_stack + 1171089;
 target_ptr = Libderiv->deriv2_classes[9][7][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1173069, dvrr_stack+731834, dvrr_stack+727379);
 tmp = dvrr_stack + 1173069;
 target_ptr = Libderiv->deriv2_classes[9][8][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1175544, dvrr_stack+734859, dvrr_stack+729359);
 tmp = dvrr_stack + 1175544;
 target_ptr = Libderiv->deriv2_classes[9][9][79];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+734859, dvrr_stack+612062, dvrr_stack+331100);
 tmp = dvrr_stack + 734859;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+735300, dvrr_stack+98475, dvrr_stack+249353);
 tmp = dvrr_stack + 735300;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+735888, dvrr_stack+13315, dvrr_stack+612062);
 tmp = dvrr_stack + 735888;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+736644, dvrr_stack+417876, dvrr_stack+98475);
 tmp = dvrr_stack + 736644;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1178569, dvrr_stack+53314, dvrr_stack+13315);
 tmp = dvrr_stack + 1178569;
 target_ptr = Libderiv->deriv2_classes[5][9][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+737589, dvrr_stack+16402, dvrr_stack+165929);
 tmp = dvrr_stack + 737589;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+142880, dvrr_stack+33852, dvrr_stack+124776);
 tmp = dvrr_stack + 142880;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+245206, dvrr_stack+49861, dvrr_stack+16402);
 tmp = dvrr_stack + 245206;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+53284, dvrr_stack+73055, dvrr_stack+33852);
 tmp = dvrr_stack + 53284;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1179724, dvrr_stack+137504, dvrr_stack+49861);
 tmp = dvrr_stack + 1179724;
 target_ptr = Libderiv->deriv2_classes[6][9][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+165734, dvrr_stack+159410, dvrr_stack+158870);
 tmp = dvrr_stack + 165734;
 target_ptr = Libderiv->deriv2_classes[7][5][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+137243, dvrr_stack+738489, dvrr_stack+10462);
 tmp = dvrr_stack + 137243;
 target_ptr = Libderiv->deriv2_classes[7][6][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1181264, dvrr_stack+739785, dvrr_stack+159410);
 tmp = dvrr_stack + 1181264;
 target_ptr = Libderiv->deriv2_classes[7][7][78];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1182560, dvrr_stack+741405, dvrr_stack+738489);
 tmp = dvrr_stack + 1182560;
 target_ptr = Libderiv->deriv2_classes[7][8][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1184180, dvrr_stack+240982, dvrr_stack+739785);
 tmp = dvrr_stack + 1184180;
 target_ptr = Libderiv->deriv2_classes[7][9][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+240982, dvrr_stack+269260, dvrr_stack+610234);
 tmp = dvrr_stack + 240982;
 target_ptr = Libderiv->deriv2_classes[8][5][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+241927, dvrr_stack+743385, dvrr_stack+270520);
 tmp = dvrr_stack + 241927;
 target_ptr = Libderiv->deriv2_classes[8][6][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1186160, dvrr_stack+745005, dvrr_stack+269260);
 tmp = dvrr_stack + 1186160;
 target_ptr = Libderiv->deriv2_classes[8][7][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1187780, dvrr_stack+747030, dvrr_stack+743385);
 tmp = dvrr_stack + 1187780;
 target_ptr = Libderiv->deriv2_classes[8][8][78];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1189805, dvrr_stack+749505, dvrr_stack+745005);
 tmp = dvrr_stack + 1189805;
 target_ptr = Libderiv->deriv2_classes[8][9][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+749505, dvrr_stack+156137, dvrr_stack+155312);
 tmp = dvrr_stack + 749505;
 target_ptr = Libderiv->deriv2_classes[9][5][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+750660, dvrr_stack+753630, dvrr_stack+752475);
 tmp = dvrr_stack + 750660;
 target_ptr = Libderiv->deriv2_classes[9][6][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1192280, dvrr_stack+755610, dvrr_stack+156137);
 tmp = dvrr_stack + 1192280;
 target_ptr = Libderiv->deriv2_classes[9][7][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1194260, dvrr_stack+758085, dvrr_stack+753630);
 tmp = dvrr_stack + 1194260;
 target_ptr = Libderiv->deriv2_classes[9][8][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1196735, dvrr_stack+761110, dvrr_stack+755610);
 tmp = dvrr_stack + 1196735;
 target_ptr = Libderiv->deriv2_classes[9][9][78];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+761110, dvrr_stack+603990, dvrr_stack+32735);
 tmp = dvrr_stack + 761110;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+761551, dvrr_stack+603206, dvrr_stack+602366);
 tmp = dvrr_stack + 761551;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+762139, dvrr_stack+604578, dvrr_stack+19440);
 tmp = dvrr_stack + 762139;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+762895, dvrr_stack+605586, dvrr_stack+157677);
 tmp = dvrr_stack + 762895;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1199760, dvrr_stack+606846, dvrr_stack+5571);
 tmp = dvrr_stack + 1199760;
 target_ptr = Libderiv->deriv2_classes[5][9][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+763840, dvrr_stack+568222, dvrr_stack+597683);
 tmp = dvrr_stack + 763840;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+610150, dvrr_stack+567214, dvrr_stack+597095);
 tmp = dvrr_stack + 610150;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+138251, dvrr_stack+568978, dvrr_stack+598124);
 tmp = dvrr_stack + 138251;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1200915, dvrr_stack+570274, dvrr_stack+598880);
 tmp = dvrr_stack + 1200915;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1202175, dvrr_stack+530935, dvrr_stack+599825);
 tmp = dvrr_stack + 1202175;
 target_ptr = Libderiv->deriv2_classes[6][9][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,21,dvrr_stack+155243, dvrr_stack+422820, dvrr_stack+603990);
 tmp = dvrr_stack + 155243;
 target_ptr = Libderiv->deriv2_classes[7][5][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1203715, dvrr_stack+472685, dvrr_stack+603206);
 tmp = dvrr_stack + 1203715;
 target_ptr = Libderiv->deriv2_classes[7][6][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1204723, dvrr_stack+423765, dvrr_stack+604578);
 tmp = dvrr_stack + 1204723;
 target_ptr = Libderiv->deriv2_classes[7][7][35];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1206019, dvrr_stack+425385, dvrr_stack+605586);
 tmp = dvrr_stack + 1206019;
 target_ptr = Libderiv->deriv2_classes[7][8][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1207639, dvrr_stack+427410, dvrr_stack+606846);
 tmp = dvrr_stack + 1207639;
 target_ptr = Libderiv->deriv2_classes[7][9][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,21,dvrr_stack+584078, dvrr_stack+394365, dvrr_stack+568222);
 tmp = dvrr_stack + 584078;
 target_ptr = Libderiv->deriv2_classes[8][5][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1209619, dvrr_stack+360450, dvrr_stack+567214);
 tmp = dvrr_stack + 1209619;
 target_ptr = Libderiv->deriv2_classes[8][6][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1210879, dvrr_stack+361990, dvrr_stack+568978);
 tmp = dvrr_stack + 1210879;
 target_ptr = Libderiv->deriv2_classes[8][7][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1212499, dvrr_stack+336320, dvrr_stack+570274);
 tmp = dvrr_stack + 1212499;
 target_ptr = Libderiv->deriv2_classes[8][8][35];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1214524, dvrr_stack+311120, dvrr_stack+530935);
 tmp = dvrr_stack + 1214524;
 target_ptr = Libderiv->deriv2_classes[8][9][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1216999, dvrr_stack+777080, dvrr_stack+422820);
 tmp = dvrr_stack + 1216999;
 target_ptr = Libderiv->deriv2_classes[9][5][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1218154, dvrr_stack+788294, dvrr_stack+472685);
 tmp = dvrr_stack + 1218154;
 target_ptr = Libderiv->deriv2_classes[9][6][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1219694, dvrr_stack+321650, dvrr_stack+423765);
 tmp = dvrr_stack + 1219694;
 target_ptr = Libderiv->deriv2_classes[9][7][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1221674, dvrr_stack+827055, dvrr_stack+425385);
 tmp = dvrr_stack + 1221674;
 target_ptr = Libderiv->deriv2_classes[9][8][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1224149, dvrr_stack+237352, dvrr_stack+427410);
 tmp = dvrr_stack + 1224149;
 target_ptr = Libderiv->deriv2_classes[9][9][35];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+491465, dvrr_stack+289190, dvrr_stack+134468);
 tmp = dvrr_stack + 491465;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+551828, dvrr_stack+288406, dvrr_stack+134783);
 tmp = dvrr_stack + 551828;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1227174, dvrr_stack+289778, dvrr_stack+135203);
 tmp = dvrr_stack + 1227174;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+393361, dvrr_stack+230548, dvrr_stack+135743);
 tmp = dvrr_stack + 393361;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1227930, dvrr_stack+231808, dvrr_stack+136418);
 tmp = dvrr_stack + 1227930;
 target_ptr = Libderiv->deriv2_classes[5][9][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+590325, dvrr_stack+196128, dvrr_stack+433680);
 tmp = dvrr_stack + 590325;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1229085, dvrr_stack+166628, dvrr_stack+500690);
 tmp = dvrr_stack + 1229085;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1229869, dvrr_stack+167636, dvrr_stack+314145);
 tmp = dvrr_stack + 1229869;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1230877, dvrr_stack+168932, dvrr_stack+314901);
 tmp = dvrr_stack + 1230877;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1232137, dvrr_stack+170552, dvrr_stack+285865);
 tmp = dvrr_stack + 1232137;
 target_ptr = Libderiv->deriv2_classes[6][9][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+382726, dvrr_stack+149852, dvrr_stack+289190);
 tmp = dvrr_stack + 382726;
 target_ptr = Libderiv->deriv2_classes[7][5][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1233677, dvrr_stack+148592, dvrr_stack+288406);
 tmp = dvrr_stack + 1233677;
 target_ptr = Libderiv->deriv2_classes[7][6][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1234685, dvrr_stack+113514, dvrr_stack+289778);
 tmp = dvrr_stack + 1234685;
 target_ptr = Libderiv->deriv2_classes[7][7][34];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1235981, dvrr_stack+80782, dvrr_stack+230548);
 tmp = dvrr_stack + 1235981;
 target_ptr = Libderiv->deriv2_classes[7][8][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1237601, dvrr_stack+82807, dvrr_stack+231808);
 tmp = dvrr_stack + 1237601;
 target_ptr = Libderiv->deriv2_classes[7][9][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1239581, dvrr_stack+43207, dvrr_stack+196128);
 tmp = dvrr_stack + 1239581;
 target_ptr = Libderiv->deriv2_classes[8][5][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1240526, dvrr_stack+61630, dvrr_stack+166628);
 tmp = dvrr_stack + 1240526;
 target_ptr = Libderiv->deriv2_classes[8][6][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1241786, dvrr_stack+716269, dvrr_stack+167636);
 tmp = dvrr_stack + 1241786;
 target_ptr = Libderiv->deriv2_classes[8][7][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1243406, dvrr_stack+718249, dvrr_stack+168932);
 tmp = dvrr_stack + 1243406;
 target_ptr = Libderiv->deriv2_classes[8][8][34];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1245431, dvrr_stack+720724, dvrr_stack+170552);
 tmp = dvrr_stack + 1245431;
 target_ptr = Libderiv->deriv2_classes[8][9][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1247906, dvrr_stack+20857, dvrr_stack+149852);
 tmp = dvrr_stack + 1247906;
 target_ptr = Libderiv->deriv2_classes[9][5][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1249061, dvrr_stack+373311, dvrr_stack+148592);
 tmp = dvrr_stack + 1249061;
 target_ptr = Libderiv->deriv2_classes[9][6][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1250601, dvrr_stack+541330, dvrr_stack+113514);
 tmp = dvrr_stack + 1250601;
 target_ptr = Libderiv->deriv2_classes[9][7][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1252581, dvrr_stack+543706, dvrr_stack+80782);
 tmp = dvrr_stack + 1252581;
 target_ptr = Libderiv->deriv2_classes[9][8][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1255056, dvrr_stack+840915, dvrr_stack+82807);
 tmp = dvrr_stack + 1255056;
 target_ptr = Libderiv->deriv2_classes[9][9][34];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+726920, dvrr_stack+96942, dvrr_stack+844545);
 tmp = dvrr_stack + 726920;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1258081, dvrr_stack+28408, dvrr_stack+579874);
 tmp = dvrr_stack + 1258081;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+195292, dvrr_stack+92514, dvrr_stack+580294);
 tmp = dvrr_stack + 195292;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1258669, dvrr_stack+107466, dvrr_stack+580834);
 tmp = dvrr_stack + 1258669;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1259614, dvrr_stack+121616, dvrr_stack+764740);
 tmp = dvrr_stack + 1259614;
 target_ptr = Libderiv->deriv2_classes[5][9][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+158793, dvrr_stack+93522, dvrr_stack+12874);
 tmp = dvrr_stack + 158793;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1260769, dvrr_stack+611054, dvrr_stack+595835);
 tmp = dvrr_stack + 1260769;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1261553, dvrr_stack+184212, dvrr_stack+7447);
 tmp = dvrr_stack + 1261553;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1262561, dvrr_stack+203193, dvrr_stack+23872);
 tmp = dvrr_stack + 1262561;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1263821, dvrr_stack+220828, dvrr_stack+37537);
 tmp = dvrr_stack + 1263821;
 target_ptr = Libderiv->deriv2_classes[6][9][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1265361, dvrr_stack+307340, dvrr_stack+96942);
 tmp = dvrr_stack + 1265361;
 target_ptr = Libderiv->deriv2_classes[7][5][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1266117, dvrr_stack+498665, dvrr_stack+28408);
 tmp = dvrr_stack + 1266117;
 target_ptr = Libderiv->deriv2_classes[7][6][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1267125, dvrr_stack+300545, dvrr_stack+92514);
 tmp = dvrr_stack + 1267125;
 target_ptr = Libderiv->deriv2_classes[7][7][33];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1268421, dvrr_stack+326600, dvrr_stack+107466);
 tmp = dvrr_stack + 1268421;
 target_ptr = Libderiv->deriv2_classes[7][8][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1270041, dvrr_stack+348300, dvrr_stack+121616);
 tmp = dvrr_stack + 1270041;
 target_ptr = Libderiv->deriv2_classes[7][9][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1272021, dvrr_stack+462770, dvrr_stack+93522);
 tmp = dvrr_stack + 1272021;
 target_ptr = Libderiv->deriv2_classes[8][5][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1272966, dvrr_stack+391065, dvrr_stack+611054);
 tmp = dvrr_stack + 1272966;
 target_ptr = Libderiv->deriv2_classes[8][6][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1274226, dvrr_stack+452645, dvrr_stack+184212);
 tmp = dvrr_stack + 1274226;
 target_ptr = Libderiv->deriv2_classes[8][7][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1275846, dvrr_stack+486110, dvrr_stack+203193);
 tmp = dvrr_stack + 1275846;
 target_ptr = Libderiv->deriv2_classes[8][8][33];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1277871, dvrr_stack+516085, dvrr_stack+220828);
 tmp = dvrr_stack + 1277871;
 target_ptr = Libderiv->deriv2_classes[8][9][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1280346, dvrr_stack+765565, dvrr_stack+307340);
 tmp = dvrr_stack + 1280346;
 target_ptr = Libderiv->deriv2_classes[9][5][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1281501, dvrr_stack+546676, dvrr_stack+498665);
 tmp = dvrr_stack + 1281501;
 target_ptr = Libderiv->deriv2_classes[9][6][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1283041, dvrr_stack+782750, dvrr_stack+300545);
 tmp = dvrr_stack + 1283041;
 target_ptr = Libderiv->deriv2_classes[9][7][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1285021, dvrr_stack+799412, dvrr_stack+326600);
 tmp = dvrr_stack + 1285021;
 target_ptr = Libderiv->deriv2_classes[9][8][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1287496, dvrr_stack+818145, dvrr_stack+348300);
 tmp = dvrr_stack + 1287496;
 target_ptr = Libderiv->deriv2_classes[9][9][33];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1290521, dvrr_stack+591823, dvrr_stack+830025);
 tmp = dvrr_stack + 1290521;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+566592, dvrr_stack+591039, dvrr_stack+830340);
 tmp = dvrr_stack + 566592;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1290962, dvrr_stack+592411, dvrr_stack+830760);
 tmp = dvrr_stack + 1290962;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1291718, dvrr_stack+593419, dvrr_stack+831300);
 tmp = dvrr_stack + 1291718;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1292663, dvrr_stack+548524, dvrr_stack+831975);
 tmp = dvrr_stack + 1292663;
 target_ptr = Libderiv->deriv2_classes[5][9][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+74595, dvrr_stack+553460, dvrr_stack+585656);
 tmp = dvrr_stack + 74595;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1293818, dvrr_stack+552452, dvrr_stack+585068);
 tmp = dvrr_stack + 1293818;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1294602, dvrr_stack+554216, dvrr_stack+586097);
 tmp = dvrr_stack + 1294602;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1295610, dvrr_stack+555512, dvrr_stack+586853);
 tmp = dvrr_stack + 1295610;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1296870, dvrr_stack+519110, dvrr_stack+587798);
 tmp = dvrr_stack + 1296870;
 target_ptr = Libderiv->deriv2_classes[6][9][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1298410, dvrr_stack+490520, dvrr_stack+591823);
 tmp = dvrr_stack + 1298410;
 target_ptr = Libderiv->deriv2_classes[7][5][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1299166, dvrr_stack+489260, dvrr_stack+591039);
 tmp = dvrr_stack + 1299166;
 target_ptr = Libderiv->deriv2_classes[7][6][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1300174, dvrr_stack+463925, dvrr_stack+592411);
 tmp = dvrr_stack + 1300174;
 target_ptr = Libderiv->deriv2_classes[7][7][32];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1301470, dvrr_stack+350775, dvrr_stack+593419);
 tmp = dvrr_stack + 1301470;
 target_ptr = Libderiv->deriv2_classes[7][8][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1303090, dvrr_stack+328625, dvrr_stack+548524);
 tmp = dvrr_stack + 1303090;
 target_ptr = Libderiv->deriv2_classes[7][9][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1305070, dvrr_stack+352800, dvrr_stack+553460);
 tmp = dvrr_stack + 1305070;
 target_ptr = Libderiv->deriv2_classes[8][5][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1306015, dvrr_stack+465545, dvrr_stack+552452);
 tmp = dvrr_stack + 1306015;
 target_ptr = Libderiv->deriv2_classes[8][6][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1307275, dvrr_stack+308285, dvrr_stack+554216);
 tmp = dvrr_stack + 1307275;
 target_ptr = Libderiv->deriv2_classes[8][7][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1308895, dvrr_stack+275917, dvrr_stack+555512);
 tmp = dvrr_stack + 1308895;
 target_ptr = Libderiv->deriv2_classes[8][8][32];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1310920, dvrr_stack+246328, dvrr_stack+519110);
 tmp = dvrr_stack + 1310920;
 target_ptr = Libderiv->deriv2_classes[8][9][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1313395, dvrr_stack+834718, dvrr_stack+490520);
 tmp = dvrr_stack + 1313395;
 target_ptr = Libderiv->deriv2_classes[9][5][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1314550, dvrr_stack+836104, dvrr_stack+489260);
 tmp = dvrr_stack + 1314550;
 target_ptr = Libderiv->deriv2_classes[9][6][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1316090, dvrr_stack+837952, dvrr_stack+463925);
 tmp = dvrr_stack + 1316090;
 target_ptr = Libderiv->deriv2_classes[9][7][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1318070, dvrr_stack+821775, dvrr_stack+350775);
 tmp = dvrr_stack + 1318070;
 target_ptr = Libderiv->deriv2_classes[9][8][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1320545, dvrr_stack+802382, dvrr_stack+328625);
 tmp = dvrr_stack + 1320545;
 target_ptr = Libderiv->deriv2_classes[9][9][32];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+411884, dvrr_stack+499925, dvrr_stack+497990);
 tmp = dvrr_stack + 411884;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1323570, dvrr_stack+310265, dvrr_stack+432855);
 tmp = dvrr_stack + 1323570;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1324158, dvrr_stack+278392, dvrr_stack+832800);
 tmp = dvrr_stack + 1324158;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1324914, dvrr_stack+204813, dvrr_stack+824745);
 tmp = dvrr_stack + 1324914;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1325859, dvrr_stack+189540, dvrr_stack+825420);
 tmp = dvrr_stack + 1325859;
 target_ptr = Libderiv->deriv2_classes[5][9][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1327014, dvrr_stack+185508, dvrr_stack+595039);
 tmp = dvrr_stack + 1327014;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1327602, dvrr_stack+206073, dvrr_stack+455450);
 tmp = dvrr_stack + 1327602;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1328386, dvrr_stack+191080, dvrr_stack+392605);
 tmp = dvrr_stack + 1328386;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1329394, dvrr_stack+123156, dvrr_stack+302165);
 tmp = dvrr_stack + 1329394;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1330654, dvrr_stack+75280, dvrr_stack+222808);
 tmp = dvrr_stack + 1330654;
 target_ptr = Libderiv->deriv2_classes[6][9][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1332194, dvrr_stack+97530, dvrr_stack+499925);
 tmp = dvrr_stack + 1332194;
 target_ptr = Libderiv->deriv2_classes[7][5][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1332950, dvrr_stack+108726, dvrr_stack+310265);
 tmp = dvrr_stack + 1332950;
 target_ptr = Libderiv->deriv2_classes[7][6][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1333958, dvrr_stack+77260, dvrr_stack+278392);
 tmp = dvrr_stack + 1333958;
 target_ptr = Libderiv->deriv2_classes[7][7][31];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1335254, dvrr_stack+56086, dvrr_stack+204813);
 tmp = dvrr_stack + 1335254;
 target_ptr = Libderiv->deriv2_classes[7][8][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1336874, dvrr_stack+412431, dvrr_stack+189540);
 tmp = dvrr_stack + 1336874;
 target_ptr = Libderiv->deriv2_classes[7][9][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1338854, dvrr_stack+24817, dvrr_stack+185508);
 tmp = dvrr_stack + 1338854;
 target_ptr = Libderiv->deriv2_classes[8][5][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1339799, dvrr_stack+38692, dvrr_stack+206073);
 tmp = dvrr_stack + 1339799;
 target_ptr = Libderiv->deriv2_classes[8][6][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1341059, dvrr_stack+727379, dvrr_stack+191080);
 tmp = dvrr_stack + 1341059;
 target_ptr = Libderiv->deriv2_classes[8][7][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1342679, dvrr_stack+729359, dvrr_stack+123156);
 tmp = dvrr_stack + 1342679;
 target_ptr = Libderiv->deriv2_classes[8][8][31];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1344704, dvrr_stack+731834, dvrr_stack+75280);
 tmp = dvrr_stack + 1344704;
 target_ptr = Libderiv->deriv2_classes[8][9][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1347179, dvrr_stack+785126, dvrr_stack+97530);
 tmp = dvrr_stack + 1347179;
 target_ptr = Libderiv->deriv2_classes[9][5][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1348334, dvrr_stack+772922, dvrr_stack+108726);
 tmp = dvrr_stack + 1348334;
 target_ptr = Libderiv->deriv2_classes[9][6][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1349874, dvrr_stack+216153, dvrr_stack+77260);
 tmp = dvrr_stack + 1349874;
 target_ptr = Libderiv->deriv2_classes[9][7][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1351854, dvrr_stack+844860, dvrr_stack+56086);
 tmp = dvrr_stack + 1351854;
 target_ptr = Libderiv->deriv2_classes[9][8][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1354329, dvrr_stack+847830, dvrr_stack+412431);
 tmp = dvrr_stack + 1354329;
 target_ptr = Libderiv->deriv2_classes[9][9][31];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1357354, dvrr_stack+124776, dvrr_stack+498305);
 tmp = dvrr_stack + 1357354;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1357795, dvrr_stack+16402, dvrr_stack+9401);
 tmp = dvrr_stack + 1357795;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1358383, dvrr_stack+33852, dvrr_stack+840328);
 tmp = dvrr_stack + 1358383;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1359139, dvrr_stack+49861, dvrr_stack+826245);
 tmp = dvrr_stack + 1359139;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1360084, dvrr_stack+73055, dvrr_stack+786512);
 tmp = dvrr_stack + 1360084;
 target_ptr = Libderiv->deriv2_classes[5][9][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1361239, dvrr_stack+10462, dvrr_stack+249353);
 tmp = dvrr_stack + 1361239;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1361827, dvrr_stack+159410, dvrr_stack+612062);
 tmp = dvrr_stack + 1361827;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1362611, dvrr_stack+738489, dvrr_stack+98475);
 tmp = dvrr_stack + 1362611;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1363619, dvrr_stack+739785, dvrr_stack+13315);
 tmp = dvrr_stack + 1363619;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1364879, dvrr_stack+741405, dvrr_stack+417876);
 tmp = dvrr_stack + 1364879;
 target_ptr = Libderiv->deriv2_classes[6][9][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1366419, dvrr_stack+270520, dvrr_stack+124776);
 tmp = dvrr_stack + 1366419;
 target_ptr = Libderiv->deriv2_classes[7][5][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1367175, dvrr_stack+269260, dvrr_stack+16402);
 tmp = dvrr_stack + 1367175;
 target_ptr = Libderiv->deriv2_classes[7][6][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1368183, dvrr_stack+743385, dvrr_stack+33852);
 tmp = dvrr_stack + 1368183;
 target_ptr = Libderiv->deriv2_classes[7][7][30];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1369479, dvrr_stack+745005, dvrr_stack+49861);
 tmp = dvrr_stack + 1369479;
 target_ptr = Libderiv->deriv2_classes[7][8][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1371099, dvrr_stack+747030, dvrr_stack+73055);
 tmp = dvrr_stack + 1371099;
 target_ptr = Libderiv->deriv2_classes[7][9][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1373079, dvrr_stack+752475, dvrr_stack+10462);
 tmp = dvrr_stack + 1373079;
 target_ptr = Libderiv->deriv2_classes[8][5][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1374024, dvrr_stack+156137, dvrr_stack+159410);
 tmp = dvrr_stack + 1374024;
 target_ptr = Libderiv->deriv2_classes[8][6][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1375284, dvrr_stack+753630, dvrr_stack+738489);
 tmp = dvrr_stack + 1375284;
 target_ptr = Libderiv->deriv2_classes[8][7][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1376904, dvrr_stack+755610, dvrr_stack+739785);
 tmp = dvrr_stack + 1376904;
 target_ptr = Libderiv->deriv2_classes[8][8][30];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1378929, dvrr_stack+758085, dvrr_stack+741405);
 tmp = dvrr_stack + 1378929;
 target_ptr = Libderiv->deriv2_classes[8][9][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1381404, dvrr_stack+774770, dvrr_stack+270520);
 tmp = dvrr_stack + 1381404;
 target_ptr = Libderiv->deriv2_classes[9][5][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1382559, dvrr_stack+766951, dvrr_stack+269260);
 tmp = dvrr_stack + 1382559;
 target_ptr = Libderiv->deriv2_classes[9][6][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1384099, dvrr_stack+345825, dvrr_stack+743385);
 tmp = dvrr_stack + 1384099;
 target_ptr = Libderiv->deriv2_classes[9][7][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1386079, dvrr_stack+851460, dvrr_stack+745005);
 tmp = dvrr_stack + 1386079;
 target_ptr = Libderiv->deriv2_classes[9][8][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1388554, dvrr_stack+854430, dvrr_stack+747030);
 tmp = dvrr_stack + 1388554;
 target_ptr = Libderiv->deriv2_classes[9][9][30];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+540791, dvrr_stack+369270, dvrr_stack+368955);
 tmp = dvrr_stack + 540791;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1391579, dvrr_stack+370278, dvrr_stack+369858);
 tmp = dvrr_stack + 1391579;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1392167, dvrr_stack+371602, dvrr_stack+371062);
 tmp = dvrr_stack + 1392167;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1392923, dvrr_stack+833340, dvrr_stack+372610);
 tmp = dvrr_stack + 1392923;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1393868, dvrr_stack+581509, dvrr_stack+787337);
 tmp = dvrr_stack + 1393868;
 target_ptr = Libderiv->deriv2_classes[5][9][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1395023, dvrr_stack+776156, dvrr_stack+768799);
 tmp = dvrr_stack + 1395023;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1395611, dvrr_stack+375159, dvrr_stack+583049);
 tmp = dvrr_stack + 1395611;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1396395, dvrr_stack+858816, dvrr_stack+858060);
 tmp = dvrr_stack + 1396395;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1397403, dvrr_stack+860112, dvrr_stack+104586);
 tmp = dvrr_stack + 1397403;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1398663, dvrr_stack+861732, dvrr_stack+52129);
 tmp = dvrr_stack + 1398663;
 target_ptr = Libderiv->deriv2_classes[6][9][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1400203, dvrr_stack+863712, dvrr_stack+369270);
 tmp = dvrr_stack + 1400203;
 target_ptr = Libderiv->deriv2_classes[7][5][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1400959, dvrr_stack+864657, dvrr_stack+370278);
 tmp = dvrr_stack + 1400959;
 target_ptr = Libderiv->deriv2_classes[7][6][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1401967, dvrr_stack+865917, dvrr_stack+371602);
 tmp = dvrr_stack + 1401967;
 target_ptr = Libderiv->deriv2_classes[7][7][26];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1403263, dvrr_stack+867537, dvrr_stack+833340);
 tmp = dvrr_stack + 1403263;
 target_ptr = Libderiv->deriv2_classes[7][8][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1404883, dvrr_stack+869562, dvrr_stack+581509);
 tmp = dvrr_stack + 1404883;
 target_ptr = Libderiv->deriv2_classes[7][9][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1406863, dvrr_stack+872037, dvrr_stack+776156);
 tmp = dvrr_stack + 1406863;
 target_ptr = Libderiv->deriv2_classes[8][5][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1407808, dvrr_stack+873192, dvrr_stack+375159);
 tmp = dvrr_stack + 1407808;
 target_ptr = Libderiv->deriv2_classes[8][6][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1409068, dvrr_stack+874732, dvrr_stack+858816);
 tmp = dvrr_stack + 1409068;
 target_ptr = Libderiv->deriv2_classes[8][7][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1410688, dvrr_stack+876712, dvrr_stack+860112);
 tmp = dvrr_stack + 1410688;
 target_ptr = Libderiv->deriv2_classes[8][8][26];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1412713, dvrr_stack+879187, dvrr_stack+861732);
 tmp = dvrr_stack + 1412713;
 target_ptr = Libderiv->deriv2_classes[8][9][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1415188, dvrr_stack+69274, dvrr_stack+863712);
 tmp = dvrr_stack + 1415188;
 target_ptr = Libderiv->deriv2_classes[9][5][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1416343, dvrr_stack+70660, dvrr_stack+864657);
 tmp = dvrr_stack + 1416343;
 target_ptr = Libderiv->deriv2_classes[9][6][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1417883, dvrr_stack+778466, dvrr_stack+865917);
 tmp = dvrr_stack + 1417883;
 target_ptr = Libderiv->deriv2_classes[9][7][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1419863, dvrr_stack+793112, dvrr_stack+867537);
 tmp = dvrr_stack + 1419863;
 target_ptr = Libderiv->deriv2_classes[9][8][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1422338, dvrr_stack+505910, dvrr_stack+869562);
 tmp = dvrr_stack + 1422338;
 target_ptr = Libderiv->deriv2_classes[9][9][26];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+1425363, dvrr_stack+603990, dvrr_stack+32735);
 tmp = dvrr_stack + 1425363;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+1425804, dvrr_stack+603206, dvrr_stack+602366);
 tmp = dvrr_stack + 1425804;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+1426392, dvrr_stack+604578, dvrr_stack+19440);
 tmp = dvrr_stack + 1426392;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+1427148, dvrr_stack+605586, dvrr_stack+157677);
 tmp = dvrr_stack + 1427148;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,55,dvrr_stack+1428093, dvrr_stack+606846, dvrr_stack+5571);
 tmp = dvrr_stack + 1428093;
 target_ptr = Libderiv->deriv2_classes[5][9][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+1429248, dvrr_stack+568222, dvrr_stack+597683);
 tmp = dvrr_stack + 1429248;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+1429836, dvrr_stack+567214, dvrr_stack+597095);
 tmp = dvrr_stack + 1429836;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+1430620, dvrr_stack+568978, dvrr_stack+598124);
 tmp = dvrr_stack + 1430620;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+1431628, dvrr_stack+570274, dvrr_stack+598880);
 tmp = dvrr_stack + 1431628;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,55,dvrr_stack+1432888, dvrr_stack+530935, dvrr_stack+599825);
 tmp = dvrr_stack + 1432888;
 target_ptr = Libderiv->deriv2_classes[6][9][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,21,dvrr_stack+1434428, dvrr_stack+422820, dvrr_stack+603990);
 tmp = dvrr_stack + 1434428;
 target_ptr = Libderiv->deriv2_classes[7][5][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,28,dvrr_stack+1435184, dvrr_stack+472685, dvrr_stack+603206);
 tmp = dvrr_stack + 1435184;
 target_ptr = Libderiv->deriv2_classes[7][6][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,36,dvrr_stack+1436192, dvrr_stack+423765, dvrr_stack+604578);
 tmp = dvrr_stack + 1436192;
 target_ptr = Libderiv->deriv2_classes[7][7][23];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,45,dvrr_stack+1437488, dvrr_stack+425385, dvrr_stack+605586);
 tmp = dvrr_stack + 1437488;
 target_ptr = Libderiv->deriv2_classes[7][8][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,55,dvrr_stack+1439108, dvrr_stack+427410, dvrr_stack+606846);
 tmp = dvrr_stack + 1439108;
 target_ptr = Libderiv->deriv2_classes[7][9][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,21,dvrr_stack+1441088, dvrr_stack+394365, dvrr_stack+568222);
 tmp = dvrr_stack + 1441088;
 target_ptr = Libderiv->deriv2_classes[8][5][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,28,dvrr_stack+1442033, dvrr_stack+360450, dvrr_stack+567214);
 tmp = dvrr_stack + 1442033;
 target_ptr = Libderiv->deriv2_classes[8][6][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,36,dvrr_stack+1443293, dvrr_stack+361990, dvrr_stack+568978);
 tmp = dvrr_stack + 1443293;
 target_ptr = Libderiv->deriv2_classes[8][7][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,45,dvrr_stack+1444913, dvrr_stack+336320, dvrr_stack+570274);
 tmp = dvrr_stack + 1444913;
 target_ptr = Libderiv->deriv2_classes[8][8][23];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,55,dvrr_stack+1446938, dvrr_stack+311120, dvrr_stack+530935);
 tmp = dvrr_stack + 1446938;
 target_ptr = Libderiv->deriv2_classes[8][9][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,21,dvrr_stack+1449413, dvrr_stack+777080, dvrr_stack+422820);
 tmp = dvrr_stack + 1449413;
 target_ptr = Libderiv->deriv2_classes[9][5][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,28,dvrr_stack+1450568, dvrr_stack+788294, dvrr_stack+472685);
 tmp = dvrr_stack + 1450568;
 target_ptr = Libderiv->deriv2_classes[9][6][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,36,dvrr_stack+1452108, dvrr_stack+321650, dvrr_stack+423765);
 tmp = dvrr_stack + 1452108;
 target_ptr = Libderiv->deriv2_classes[9][7][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,45,dvrr_stack+1454088, dvrr_stack+827055, dvrr_stack+425385);
 tmp = dvrr_stack + 1454088;
 target_ptr = Libderiv->deriv2_classes[9][8][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,55,dvrr_stack+1456563, dvrr_stack+237352, dvrr_stack+427410);
 tmp = dvrr_stack + 1456563;
 target_ptr = Libderiv->deriv2_classes[9][9][23];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+180038, dvrr_stack+289190, dvrr_stack+134468);
 tmp = dvrr_stack + 180038;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1459588, dvrr_stack+288406, dvrr_stack+134783);
 tmp = dvrr_stack + 1459588;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1460176, dvrr_stack+289778, dvrr_stack+135203);
 tmp = dvrr_stack + 1460176;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1460932, dvrr_stack+230548, dvrr_stack+135743);
 tmp = dvrr_stack + 1460932;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1461877, dvrr_stack+231808, dvrr_stack+136418);
 tmp = dvrr_stack + 1461877;
 target_ptr = Libderiv->deriv2_classes[5][9][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1463032, dvrr_stack+196128, dvrr_stack+433680);
 tmp = dvrr_stack + 1463032;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1463620, dvrr_stack+166628, dvrr_stack+500690);
 tmp = dvrr_stack + 1463620;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1464404, dvrr_stack+167636, dvrr_stack+314145);
 tmp = dvrr_stack + 1464404;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1465412, dvrr_stack+168932, dvrr_stack+314901);
 tmp = dvrr_stack + 1465412;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1466672, dvrr_stack+170552, dvrr_stack+285865);
 tmp = dvrr_stack + 1466672;
 target_ptr = Libderiv->deriv2_classes[6][9][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1468212, dvrr_stack+149852, dvrr_stack+289190);
 tmp = dvrr_stack + 1468212;
 target_ptr = Libderiv->deriv2_classes[7][5][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1468968, dvrr_stack+148592, dvrr_stack+288406);
 tmp = dvrr_stack + 1468968;
 target_ptr = Libderiv->deriv2_classes[7][6][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1469976, dvrr_stack+113514, dvrr_stack+289778);
 tmp = dvrr_stack + 1469976;
 target_ptr = Libderiv->deriv2_classes[7][7][22];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1471272, dvrr_stack+80782, dvrr_stack+230548);
 tmp = dvrr_stack + 1471272;
 target_ptr = Libderiv->deriv2_classes[7][8][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1472892, dvrr_stack+82807, dvrr_stack+231808);
 tmp = dvrr_stack + 1472892;
 target_ptr = Libderiv->deriv2_classes[7][9][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1474872, dvrr_stack+43207, dvrr_stack+196128);
 tmp = dvrr_stack + 1474872;
 target_ptr = Libderiv->deriv2_classes[8][5][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1475817, dvrr_stack+61630, dvrr_stack+166628);
 tmp = dvrr_stack + 1475817;
 target_ptr = Libderiv->deriv2_classes[8][6][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1477077, dvrr_stack+716269, dvrr_stack+167636);
 tmp = dvrr_stack + 1477077;
 target_ptr = Libderiv->deriv2_classes[8][7][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1478697, dvrr_stack+718249, dvrr_stack+168932);
 tmp = dvrr_stack + 1478697;
 target_ptr = Libderiv->deriv2_classes[8][8][22];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1480722, dvrr_stack+720724, dvrr_stack+170552);
 tmp = dvrr_stack + 1480722;
 target_ptr = Libderiv->deriv2_classes[8][9][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1483197, dvrr_stack+20857, dvrr_stack+149852);
 tmp = dvrr_stack + 1483197;
 target_ptr = Libderiv->deriv2_classes[9][5][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1484352, dvrr_stack+373311, dvrr_stack+148592);
 tmp = dvrr_stack + 1484352;
 target_ptr = Libderiv->deriv2_classes[9][6][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1485892, dvrr_stack+541330, dvrr_stack+113514);
 tmp = dvrr_stack + 1485892;
 target_ptr = Libderiv->deriv2_classes[9][7][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1487872, dvrr_stack+543706, dvrr_stack+80782);
 tmp = dvrr_stack + 1487872;
 target_ptr = Libderiv->deriv2_classes[9][8][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1490347, dvrr_stack+840915, dvrr_stack+82807);
 tmp = dvrr_stack + 1490347;
 target_ptr = Libderiv->deriv2_classes[9][9][22];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1493372, dvrr_stack+96942, dvrr_stack+844545);
 tmp = dvrr_stack + 1493372;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1493813, dvrr_stack+28408, dvrr_stack+579874);
 tmp = dvrr_stack + 1493813;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1494401, dvrr_stack+92514, dvrr_stack+580294);
 tmp = dvrr_stack + 1494401;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1495157, dvrr_stack+107466, dvrr_stack+580834);
 tmp = dvrr_stack + 1495157;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1496102, dvrr_stack+121616, dvrr_stack+764740);
 tmp = dvrr_stack + 1496102;
 target_ptr = Libderiv->deriv2_classes[5][9][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1497257, dvrr_stack+93522, dvrr_stack+12874);
 tmp = dvrr_stack + 1497257;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1497845, dvrr_stack+611054, dvrr_stack+595835);
 tmp = dvrr_stack + 1497845;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1498629, dvrr_stack+184212, dvrr_stack+7447);
 tmp = dvrr_stack + 1498629;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1499637, dvrr_stack+203193, dvrr_stack+23872);
 tmp = dvrr_stack + 1499637;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1500897, dvrr_stack+220828, dvrr_stack+37537);
 tmp = dvrr_stack + 1500897;
 target_ptr = Libderiv->deriv2_classes[6][9][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1502437, dvrr_stack+307340, dvrr_stack+96942);
 tmp = dvrr_stack + 1502437;
 target_ptr = Libderiv->deriv2_classes[7][5][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1503193, dvrr_stack+498665, dvrr_stack+28408);
 tmp = dvrr_stack + 1503193;
 target_ptr = Libderiv->deriv2_classes[7][6][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1504201, dvrr_stack+300545, dvrr_stack+92514);
 tmp = dvrr_stack + 1504201;
 target_ptr = Libderiv->deriv2_classes[7][7][21];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1505497, dvrr_stack+326600, dvrr_stack+107466);
 tmp = dvrr_stack + 1505497;
 target_ptr = Libderiv->deriv2_classes[7][8][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1507117, dvrr_stack+348300, dvrr_stack+121616);
 tmp = dvrr_stack + 1507117;
 target_ptr = Libderiv->deriv2_classes[7][9][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1509097, dvrr_stack+462770, dvrr_stack+93522);
 tmp = dvrr_stack + 1509097;
 target_ptr = Libderiv->deriv2_classes[8][5][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1510042, dvrr_stack+391065, dvrr_stack+611054);
 tmp = dvrr_stack + 1510042;
 target_ptr = Libderiv->deriv2_classes[8][6][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1511302, dvrr_stack+452645, dvrr_stack+184212);
 tmp = dvrr_stack + 1511302;
 target_ptr = Libderiv->deriv2_classes[8][7][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1512922, dvrr_stack+486110, dvrr_stack+203193);
 tmp = dvrr_stack + 1512922;
 target_ptr = Libderiv->deriv2_classes[8][8][21];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1514947, dvrr_stack+516085, dvrr_stack+220828);
 tmp = dvrr_stack + 1514947;
 target_ptr = Libderiv->deriv2_classes[8][9][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1517422, dvrr_stack+765565, dvrr_stack+307340);
 tmp = dvrr_stack + 1517422;
 target_ptr = Libderiv->deriv2_classes[9][5][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1518577, dvrr_stack+546676, dvrr_stack+498665);
 tmp = dvrr_stack + 1518577;
 target_ptr = Libderiv->deriv2_classes[9][6][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1520117, dvrr_stack+782750, dvrr_stack+300545);
 tmp = dvrr_stack + 1520117;
 target_ptr = Libderiv->deriv2_classes[9][7][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1522097, dvrr_stack+799412, dvrr_stack+326600);
 tmp = dvrr_stack + 1522097;
 target_ptr = Libderiv->deriv2_classes[9][8][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1524572, dvrr_stack+818145, dvrr_stack+348300);
 tmp = dvrr_stack + 1524572;
 target_ptr = Libderiv->deriv2_classes[9][9][21];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+6396, dvrr_stack+591823, dvrr_stack+830025);
 tmp = dvrr_stack + 6396;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1527597, dvrr_stack+591039, dvrr_stack+830340);
 tmp = dvrr_stack + 1527597;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1528185, dvrr_stack+592411, dvrr_stack+830760);
 tmp = dvrr_stack + 1528185;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1528941, dvrr_stack+593419, dvrr_stack+831300);
 tmp = dvrr_stack + 1528941;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1529886, dvrr_stack+548524, dvrr_stack+831975);
 tmp = dvrr_stack + 1529886;
 target_ptr = Libderiv->deriv2_classes[5][9][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1531041, dvrr_stack+553460, dvrr_stack+585656);
 tmp = dvrr_stack + 1531041;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1531629, dvrr_stack+552452, dvrr_stack+585068);
 tmp = dvrr_stack + 1531629;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1532413, dvrr_stack+554216, dvrr_stack+586097);
 tmp = dvrr_stack + 1532413;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1533421, dvrr_stack+555512, dvrr_stack+586853);
 tmp = dvrr_stack + 1533421;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1534681, dvrr_stack+519110, dvrr_stack+587798);
 tmp = dvrr_stack + 1534681;
 target_ptr = Libderiv->deriv2_classes[6][9][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1536221, dvrr_stack+490520, dvrr_stack+591823);
 tmp = dvrr_stack + 1536221;
 target_ptr = Libderiv->deriv2_classes[7][5][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1536977, dvrr_stack+489260, dvrr_stack+591039);
 tmp = dvrr_stack + 1536977;
 target_ptr = Libderiv->deriv2_classes[7][6][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1537985, dvrr_stack+463925, dvrr_stack+592411);
 tmp = dvrr_stack + 1537985;
 target_ptr = Libderiv->deriv2_classes[7][7][20];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1539281, dvrr_stack+350775, dvrr_stack+593419);
 tmp = dvrr_stack + 1539281;
 target_ptr = Libderiv->deriv2_classes[7][8][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1540901, dvrr_stack+328625, dvrr_stack+548524);
 tmp = dvrr_stack + 1540901;
 target_ptr = Libderiv->deriv2_classes[7][9][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1542881, dvrr_stack+352800, dvrr_stack+553460);
 tmp = dvrr_stack + 1542881;
 target_ptr = Libderiv->deriv2_classes[8][5][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1543826, dvrr_stack+465545, dvrr_stack+552452);
 tmp = dvrr_stack + 1543826;
 target_ptr = Libderiv->deriv2_classes[8][6][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1545086, dvrr_stack+308285, dvrr_stack+554216);
 tmp = dvrr_stack + 1545086;
 target_ptr = Libderiv->deriv2_classes[8][7][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1546706, dvrr_stack+275917, dvrr_stack+555512);
 tmp = dvrr_stack + 1546706;
 target_ptr = Libderiv->deriv2_classes[8][8][20];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1548731, dvrr_stack+246328, dvrr_stack+519110);
 tmp = dvrr_stack + 1548731;
 target_ptr = Libderiv->deriv2_classes[8][9][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1551206, dvrr_stack+834718, dvrr_stack+490520);
 tmp = dvrr_stack + 1551206;
 target_ptr = Libderiv->deriv2_classes[9][5][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1552361, dvrr_stack+836104, dvrr_stack+489260);
 tmp = dvrr_stack + 1552361;
 target_ptr = Libderiv->deriv2_classes[9][6][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1553901, dvrr_stack+837952, dvrr_stack+463925);
 tmp = dvrr_stack + 1553901;
 target_ptr = Libderiv->deriv2_classes[9][7][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1555881, dvrr_stack+821775, dvrr_stack+350775);
 tmp = dvrr_stack + 1555881;
 target_ptr = Libderiv->deriv2_classes[9][8][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1558356, dvrr_stack+802382, dvrr_stack+328625);
 tmp = dvrr_stack + 1558356;
 target_ptr = Libderiv->deriv2_classes[9][9][20];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1561381, dvrr_stack+499925, dvrr_stack+497990);
 tmp = dvrr_stack + 1561381;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1561822, dvrr_stack+310265, dvrr_stack+432855);
 tmp = dvrr_stack + 1561822;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1562410, dvrr_stack+278392, dvrr_stack+832800);
 tmp = dvrr_stack + 1562410;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1563166, dvrr_stack+204813, dvrr_stack+824745);
 tmp = dvrr_stack + 1563166;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1564111, dvrr_stack+189540, dvrr_stack+825420);
 tmp = dvrr_stack + 1564111;
 target_ptr = Libderiv->deriv2_classes[5][9][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1565266, dvrr_stack+185508, dvrr_stack+595039);
 tmp = dvrr_stack + 1565266;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1565854, dvrr_stack+206073, dvrr_stack+455450);
 tmp = dvrr_stack + 1565854;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1566638, dvrr_stack+191080, dvrr_stack+392605);
 tmp = dvrr_stack + 1566638;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1567646, dvrr_stack+123156, dvrr_stack+302165);
 tmp = dvrr_stack + 1567646;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1568906, dvrr_stack+75280, dvrr_stack+222808);
 tmp = dvrr_stack + 1568906;
 target_ptr = Libderiv->deriv2_classes[6][9][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1570446, dvrr_stack+97530, dvrr_stack+499925);
 tmp = dvrr_stack + 1570446;
 target_ptr = Libderiv->deriv2_classes[7][5][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1571202, dvrr_stack+108726, dvrr_stack+310265);
 tmp = dvrr_stack + 1571202;
 target_ptr = Libderiv->deriv2_classes[7][6][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1572210, dvrr_stack+77260, dvrr_stack+278392);
 tmp = dvrr_stack + 1572210;
 target_ptr = Libderiv->deriv2_classes[7][7][19];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1573506, dvrr_stack+56086, dvrr_stack+204813);
 tmp = dvrr_stack + 1573506;
 target_ptr = Libderiv->deriv2_classes[7][8][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1575126, dvrr_stack+412431, dvrr_stack+189540);
 tmp = dvrr_stack + 1575126;
 target_ptr = Libderiv->deriv2_classes[7][9][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1577106, dvrr_stack+24817, dvrr_stack+185508);
 tmp = dvrr_stack + 1577106;
 target_ptr = Libderiv->deriv2_classes[8][5][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1578051, dvrr_stack+38692, dvrr_stack+206073);
 tmp = dvrr_stack + 1578051;
 target_ptr = Libderiv->deriv2_classes[8][6][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1579311, dvrr_stack+727379, dvrr_stack+191080);
 tmp = dvrr_stack + 1579311;
 target_ptr = Libderiv->deriv2_classes[8][7][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1580931, dvrr_stack+729359, dvrr_stack+123156);
 tmp = dvrr_stack + 1580931;
 target_ptr = Libderiv->deriv2_classes[8][8][19];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1582956, dvrr_stack+731834, dvrr_stack+75280);
 tmp = dvrr_stack + 1582956;
 target_ptr = Libderiv->deriv2_classes[8][9][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1585431, dvrr_stack+785126, dvrr_stack+97530);
 tmp = dvrr_stack + 1585431;
 target_ptr = Libderiv->deriv2_classes[9][5][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1586586, dvrr_stack+772922, dvrr_stack+108726);
 tmp = dvrr_stack + 1586586;
 target_ptr = Libderiv->deriv2_classes[9][6][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1588126, dvrr_stack+216153, dvrr_stack+77260);
 tmp = dvrr_stack + 1588126;
 target_ptr = Libderiv->deriv2_classes[9][7][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1590106, dvrr_stack+844860, dvrr_stack+56086);
 tmp = dvrr_stack + 1590106;
 target_ptr = Libderiv->deriv2_classes[9][8][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1592581, dvrr_stack+847830, dvrr_stack+412431);
 tmp = dvrr_stack + 1592581;
 target_ptr = Libderiv->deriv2_classes[9][9][19];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+72508, dvrr_stack+124776, dvrr_stack+498305);
 tmp = dvrr_stack + 72508;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1595606, dvrr_stack+16402, dvrr_stack+9401);
 tmp = dvrr_stack + 1595606;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1596194, dvrr_stack+33852, dvrr_stack+840328);
 tmp = dvrr_stack + 1596194;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1596950, dvrr_stack+49861, dvrr_stack+826245);
 tmp = dvrr_stack + 1596950;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1597895, dvrr_stack+73055, dvrr_stack+786512);
 tmp = dvrr_stack + 1597895;
 target_ptr = Libderiv->deriv2_classes[5][9][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1599050, dvrr_stack+10462, dvrr_stack+249353);
 tmp = dvrr_stack + 1599050;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1599638, dvrr_stack+159410, dvrr_stack+612062);
 tmp = dvrr_stack + 1599638;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1600422, dvrr_stack+738489, dvrr_stack+98475);
 tmp = dvrr_stack + 1600422;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1601430, dvrr_stack+739785, dvrr_stack+13315);
 tmp = dvrr_stack + 1601430;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1602690, dvrr_stack+741405, dvrr_stack+417876);
 tmp = dvrr_stack + 1602690;
 target_ptr = Libderiv->deriv2_classes[6][9][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1604230, dvrr_stack+270520, dvrr_stack+124776);
 tmp = dvrr_stack + 1604230;
 target_ptr = Libderiv->deriv2_classes[7][5][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1604986, dvrr_stack+269260, dvrr_stack+16402);
 tmp = dvrr_stack + 1604986;
 target_ptr = Libderiv->deriv2_classes[7][6][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1605994, dvrr_stack+743385, dvrr_stack+33852);
 tmp = dvrr_stack + 1605994;
 target_ptr = Libderiv->deriv2_classes[7][7][18];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1607290, dvrr_stack+745005, dvrr_stack+49861);
 tmp = dvrr_stack + 1607290;
 target_ptr = Libderiv->deriv2_classes[7][8][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1608910, dvrr_stack+747030, dvrr_stack+73055);
 tmp = dvrr_stack + 1608910;
 target_ptr = Libderiv->deriv2_classes[7][9][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1610890, dvrr_stack+752475, dvrr_stack+10462);
 tmp = dvrr_stack + 1610890;
 target_ptr = Libderiv->deriv2_classes[8][5][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1611835, dvrr_stack+156137, dvrr_stack+159410);
 tmp = dvrr_stack + 1611835;
 target_ptr = Libderiv->deriv2_classes[8][6][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1613095, dvrr_stack+753630, dvrr_stack+738489);
 tmp = dvrr_stack + 1613095;
 target_ptr = Libderiv->deriv2_classes[8][7][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1614715, dvrr_stack+755610, dvrr_stack+739785);
 tmp = dvrr_stack + 1614715;
 target_ptr = Libderiv->deriv2_classes[8][8][18];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1616740, dvrr_stack+758085, dvrr_stack+741405);
 tmp = dvrr_stack + 1616740;
 target_ptr = Libderiv->deriv2_classes[8][9][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1619215, dvrr_stack+774770, dvrr_stack+270520);
 tmp = dvrr_stack + 1619215;
 target_ptr = Libderiv->deriv2_classes[9][5][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1620370, dvrr_stack+766951, dvrr_stack+269260);
 tmp = dvrr_stack + 1620370;
 target_ptr = Libderiv->deriv2_classes[9][6][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1621910, dvrr_stack+345825, dvrr_stack+743385);
 tmp = dvrr_stack + 1621910;
 target_ptr = Libderiv->deriv2_classes[9][7][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1623890, dvrr_stack+851460, dvrr_stack+745005);
 tmp = dvrr_stack + 1623890;
 target_ptr = Libderiv->deriv2_classes[9][8][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1626365, dvrr_stack+854430, dvrr_stack+747030);
 tmp = dvrr_stack + 1626365;
 target_ptr = Libderiv->deriv2_classes[9][9][18];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1629390, dvrr_stack+369270, dvrr_stack+368955);
 tmp = dvrr_stack + 1629390;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1629831, dvrr_stack+370278, dvrr_stack+369858);
 tmp = dvrr_stack + 1629831;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1630419, dvrr_stack+371602, dvrr_stack+371062);
 tmp = dvrr_stack + 1630419;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1631175, dvrr_stack+833340, dvrr_stack+372610);
 tmp = dvrr_stack + 1631175;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1632120, dvrr_stack+581509, dvrr_stack+787337);
 tmp = dvrr_stack + 1632120;
 target_ptr = Libderiv->deriv2_classes[5][9][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1633275, dvrr_stack+776156, dvrr_stack+768799);
 tmp = dvrr_stack + 1633275;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1633863, dvrr_stack+375159, dvrr_stack+583049);
 tmp = dvrr_stack + 1633863;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1634647, dvrr_stack+858816, dvrr_stack+858060);
 tmp = dvrr_stack + 1634647;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1635655, dvrr_stack+860112, dvrr_stack+104586);
 tmp = dvrr_stack + 1635655;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1636915, dvrr_stack+861732, dvrr_stack+52129);
 tmp = dvrr_stack + 1636915;
 target_ptr = Libderiv->deriv2_classes[6][9][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1638455, dvrr_stack+863712, dvrr_stack+369270);
 tmp = dvrr_stack + 1638455;
 target_ptr = Libderiv->deriv2_classes[7][5][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1639211, dvrr_stack+864657, dvrr_stack+370278);
 tmp = dvrr_stack + 1639211;
 target_ptr = Libderiv->deriv2_classes[7][6][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1640219, dvrr_stack+865917, dvrr_stack+371602);
 tmp = dvrr_stack + 1640219;
 target_ptr = Libderiv->deriv2_classes[7][7][14];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1641515, dvrr_stack+867537, dvrr_stack+833340);
 tmp = dvrr_stack + 1641515;
 target_ptr = Libderiv->deriv2_classes[7][8][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1643135, dvrr_stack+869562, dvrr_stack+581509);
 tmp = dvrr_stack + 1643135;
 target_ptr = Libderiv->deriv2_classes[7][9][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1645115, dvrr_stack+872037, dvrr_stack+776156);
 tmp = dvrr_stack + 1645115;
 target_ptr = Libderiv->deriv2_classes[8][5][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1646060, dvrr_stack+873192, dvrr_stack+375159);
 tmp = dvrr_stack + 1646060;
 target_ptr = Libderiv->deriv2_classes[8][6][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1647320, dvrr_stack+874732, dvrr_stack+858816);
 tmp = dvrr_stack + 1647320;
 target_ptr = Libderiv->deriv2_classes[8][7][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1648940, dvrr_stack+876712, dvrr_stack+860112);
 tmp = dvrr_stack + 1648940;
 target_ptr = Libderiv->deriv2_classes[8][8][14];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1650965, dvrr_stack+879187, dvrr_stack+861732);
 tmp = dvrr_stack + 1650965;
 target_ptr = Libderiv->deriv2_classes[8][9][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1653440, dvrr_stack+69274, dvrr_stack+863712);
 tmp = dvrr_stack + 1653440;
 target_ptr = Libderiv->deriv2_classes[9][5][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1654595, dvrr_stack+70660, dvrr_stack+864657);
 tmp = dvrr_stack + 1654595;
 target_ptr = Libderiv->deriv2_classes[9][6][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1656135, dvrr_stack+778466, dvrr_stack+865917);
 tmp = dvrr_stack + 1656135;
 target_ptr = Libderiv->deriv2_classes[9][7][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1658115, dvrr_stack+793112, dvrr_stack+867537);
 tmp = dvrr_stack + 1658115;
 target_ptr = Libderiv->deriv2_classes[9][8][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1660590, dvrr_stack+505910, dvrr_stack+869562);
 tmp = dvrr_stack + 1660590;
 target_ptr = Libderiv->deriv2_classes[9][9][14];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1663615, dvrr_stack+180488, dvrr_stack+790142);
 tmp = dvrr_stack + 1663615;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1664056, dvrr_stack+790457, dvrr_stack+441630);
 tmp = dvrr_stack + 1664056;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1664644, dvrr_stack+51121, dvrr_stack+791241);
 tmp = dvrr_stack + 1664644;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1665400, dvrr_stack+791781, dvrr_stack+105531);
 tmp = dvrr_stack + 1665400;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1666345, dvrr_stack+771382, dvrr_stack+342800);
 tmp = dvrr_stack + 1666345;
 target_ptr = Libderiv->deriv2_classes[5][9][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1667500, dvrr_stack+769240, dvrr_stack+89413);
 tmp = dvrr_stack + 1667500;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1668088, dvrr_stack+344213, dvrr_stack+343625);
 tmp = dvrr_stack + 1668088;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1668872, dvrr_stack+510296, dvrr_stack+509540);
 tmp = dvrr_stack + 1668872;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1669880, dvrr_stack+303110, dvrr_stack+511592);
 tmp = dvrr_stack + 1669880;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1671140, dvrr_stack+186264, dvrr_stack+447465);
 tmp = dvrr_stack + 1671140;
 target_ptr = Libderiv->deriv2_classes[6][9][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1672680, dvrr_stack+448620, dvrr_stack+180488);
 tmp = dvrr_stack + 1672680;
 target_ptr = Libderiv->deriv2_classes[7][5][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1673436, dvrr_stack+449565, dvrr_stack+790457);
 tmp = dvrr_stack + 1673436;
 target_ptr = Libderiv->deriv2_classes[7][6][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1674444, dvrr_stack+66670, dvrr_stack+51121);
 tmp = dvrr_stack + 1674444;
 target_ptr = Libderiv->deriv2_classes[7][7][13];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1675740, dvrr_stack+319625, dvrr_stack+791781);
 tmp = dvrr_stack + 1675740;
 target_ptr = Libderiv->deriv2_classes[7][8][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1677360, dvrr_stack+806012, dvrr_stack+771382);
 tmp = dvrr_stack + 1677360;
 target_ptr = Libderiv->deriv2_classes[7][9][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1679340, dvrr_stack+199368, dvrr_stack+769240);
 tmp = dvrr_stack + 1679340;
 target_ptr = Libderiv->deriv2_classes[8][5][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1680285, dvrr_stack+481295, dvrr_stack+344213);
 tmp = dvrr_stack + 1680285;
 target_ptr = Libderiv->deriv2_classes[8][6][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1681545, dvrr_stack+808487, dvrr_stack+510296);
 tmp = dvrr_stack + 1681545;
 target_ptr = Libderiv->deriv2_classes[8][7][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1683165, dvrr_stack+810467, dvrr_stack+303110);
 tmp = dvrr_stack + 1683165;
 target_ptr = Libderiv->deriv2_classes[8][8][13];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1685190, dvrr_stack+886502, dvrr_stack+186264);
 tmp = dvrr_stack + 1685190;
 target_ptr = Libderiv->deriv2_classes[8][9][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+1687665, dvrr_stack+780842, dvrr_stack+448620);
 tmp = dvrr_stack + 1687665;
 target_ptr = Libderiv->deriv2_classes[9][5][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1688820, dvrr_stack+0, dvrr_stack+449565);
 tmp = dvrr_stack + 1688820;
 target_ptr = Libderiv->deriv2_classes[9][6][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1690360, dvrr_stack+47176, dvrr_stack+66670);
 tmp = dvrr_stack + 1690360;
 target_ptr = Libderiv->deriv2_classes[9][7][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1692340, dvrr_stack+889527, dvrr_stack+319625);
 tmp = dvrr_stack + 1692340;
 target_ptr = Libderiv->deriv2_classes[9][8][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1694815, dvrr_stack+892497, dvrr_stack+806012);
 tmp = dvrr_stack + 1694815;
 target_ptr = Libderiv->deriv2_classes[9][9][13];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+1697840, dvrr_stack+603990, dvrr_stack+32735);
 tmp = dvrr_stack + 1697840;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+1698281, dvrr_stack+603206, dvrr_stack+602366);
 tmp = dvrr_stack + 1698281;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+602352, dvrr_stack+604578, dvrr_stack+19440);
 tmp = dvrr_stack + 602352;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+1698869, dvrr_stack+605586, dvrr_stack+157677);
 tmp = dvrr_stack + 1698869;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,55,dvrr_stack+1699814, dvrr_stack+606846, dvrr_stack+5571);
 tmp = dvrr_stack + 1699814;
 target_ptr = Libderiv->deriv2_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+157677, dvrr_stack+568222, dvrr_stack+597683);
 tmp = dvrr_stack + 157677;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+5522, dvrr_stack+567214, dvrr_stack+597095);
 tmp = dvrr_stack + 5522;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+597011, dvrr_stack+568978, dvrr_stack+598124);
 tmp = dvrr_stack + 597011;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+1700969, dvrr_stack+570274, dvrr_stack+598880);
 tmp = dvrr_stack + 1700969;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,55,dvrr_stack+598019, dvrr_stack+530935, dvrr_stack+599825);
 tmp = dvrr_stack + 598019;
 target_ptr = Libderiv->deriv2_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,21,dvrr_stack+1702229, dvrr_stack+422820, dvrr_stack+603990);
 tmp = dvrr_stack + 1702229;
 target_ptr = Libderiv->deriv2_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,28,dvrr_stack+599559, dvrr_stack+472685, dvrr_stack+603206);
 tmp = dvrr_stack + 599559;
 target_ptr = Libderiv->deriv2_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,36,dvrr_stack+603108, dvrr_stack+423765, dvrr_stack+604578);
 tmp = dvrr_stack + 603108;
 target_ptr = Libderiv->deriv2_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,45,dvrr_stack+1702985, dvrr_stack+425385, dvrr_stack+605586);
 tmp = dvrr_stack + 1702985;
 target_ptr = Libderiv->deriv2_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,55,dvrr_stack+604404, dvrr_stack+427410, dvrr_stack+606846);
 tmp = dvrr_stack + 604404;
 target_ptr = Libderiv->deriv2_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,21,dvrr_stack+606384, dvrr_stack+394365, dvrr_stack+568222);
 tmp = dvrr_stack + 606384;
 target_ptr = Libderiv->deriv2_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,28,dvrr_stack+1704605, dvrr_stack+360450, dvrr_stack+567214);
 tmp = dvrr_stack + 1704605;
 target_ptr = Libderiv->deriv2_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,36,dvrr_stack+360316, dvrr_stack+361990, dvrr_stack+568978);
 tmp = dvrr_stack + 360316;
 target_ptr = Libderiv->deriv2_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,45,dvrr_stack+361936, dvrr_stack+336320, dvrr_stack+570274);
 tmp = dvrr_stack + 361936;
 target_ptr = Libderiv->deriv2_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,55,dvrr_stack+567180, dvrr_stack+311120, dvrr_stack+530935);
 tmp = dvrr_stack + 567180;
 target_ptr = Libderiv->deriv2_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,21,dvrr_stack+569655, dvrr_stack+777080, dvrr_stack+422820);
 tmp = dvrr_stack + 569655;
 target_ptr = Libderiv->deriv2_classes[9][5][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,28,dvrr_stack+336233, dvrr_stack+788294, dvrr_stack+472685);
 tmp = dvrr_stack + 336233;
 target_ptr = Libderiv->deriv2_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,36,dvrr_stack+788162, dvrr_stack+321650, dvrr_stack+423765);
 tmp = dvrr_stack + 788162;
 target_ptr = Libderiv->deriv2_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,45,dvrr_stack+311049, dvrr_stack+827055, dvrr_stack+425385);
 tmp = dvrr_stack + 311049;
 target_ptr = Libderiv->deriv2_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,55,dvrr_stack+826920, dvrr_stack+237352, dvrr_stack+427410);
 tmp = dvrr_stack + 826920;
 target_ptr = Libderiv->deriv2_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+321650, dvrr_stack+289190, dvrr_stack+134468);
 tmp = dvrr_stack + 321650;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+322091, dvrr_stack+288406, dvrr_stack+134783);
 tmp = dvrr_stack + 322091;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+322679, dvrr_stack+289778, dvrr_stack+135203);
 tmp = dvrr_stack + 322679;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+607329, dvrr_stack+230548, dvrr_stack+135743);
 tmp = dvrr_stack + 607329;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+134244, dvrr_stack+231808, dvrr_stack+136418);
 tmp = dvrr_stack + 134244;
 target_ptr = Libderiv->deriv2_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+323435, dvrr_stack+196128, dvrr_stack+433680);
 tmp = dvrr_stack + 323435;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+135399, dvrr_stack+166628, dvrr_stack+500690);
 tmp = dvrr_stack + 135399;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+136183, dvrr_stack+167636, dvrr_stack+314145);
 tmp = dvrr_stack + 136183;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+472678, dvrr_stack+168932, dvrr_stack+314901);
 tmp = dvrr_stack + 472678;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+776912, dvrr_stack+170552, dvrr_stack+285865);
 tmp = dvrr_stack + 776912;
 target_ptr = Libderiv->deriv2_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+285742, dvrr_stack+149852, dvrr_stack+289190);
 tmp = dvrr_stack + 285742;
 target_ptr = Libderiv->deriv2_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+570810, dvrr_stack+148592, dvrr_stack+288406);
 tmp = dvrr_stack + 570810;
 target_ptr = Libderiv->deriv2_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+288392, dvrr_stack+113514, dvrr_stack+289778);
 tmp = dvrr_stack + 288392;
 target_ptr = Libderiv->deriv2_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+530616, dvrr_stack+80782, dvrr_stack+230548);
 tmp = dvrr_stack + 530616;
 target_ptr = Libderiv->deriv2_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+313524, dvrr_stack+82807, dvrr_stack+231808);
 tmp = dvrr_stack + 313524;
 target_ptr = Libderiv->deriv2_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+289688, dvrr_stack+43207, dvrr_stack+196128);
 tmp = dvrr_stack + 289688;
 target_ptr = Libderiv->deriv2_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+230453, dvrr_stack+61630, dvrr_stack+166628);
 tmp = dvrr_stack + 230453;
 target_ptr = Libderiv->deriv2_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+231713, dvrr_stack+716269, dvrr_stack+167636);
 tmp = dvrr_stack + 231713;
 target_ptr = Libderiv->deriv2_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+166490, dvrr_stack+718249, dvrr_stack+168932);
 tmp = dvrr_stack + 166490;
 target_ptr = Libderiv->deriv2_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+715980, dvrr_stack+720724, dvrr_stack+170552);
 tmp = dvrr_stack + 715980;
 target_ptr = Libderiv->deriv2_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+168515, dvrr_stack+20857, dvrr_stack+149852);
 tmp = dvrr_stack + 168515;
 target_ptr = Libderiv->deriv2_classes[9][5][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+169670, dvrr_stack+373311, dvrr_stack+148592);
 tmp = dvrr_stack + 169670;
 target_ptr = Libderiv->deriv2_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+718455, dvrr_stack+541330, dvrr_stack+113514);
 tmp = dvrr_stack + 718455;
 target_ptr = Libderiv->deriv2_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+720435, dvrr_stack+543706, dvrr_stack+80782);
 tmp = dvrr_stack + 720435;
 target_ptr = Libderiv->deriv2_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+541232, dvrr_stack+840915, dvrr_stack+82807);
 tmp = dvrr_stack + 541232;
 target_ptr = Libderiv->deriv2_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+286498, dvrr_stack+96942, dvrr_stack+844545);
 tmp = dvrr_stack + 286498;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+19391, dvrr_stack+28408, dvrr_stack+579874);
 tmp = dvrr_stack + 19391;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+171210, dvrr_stack+92514, dvrr_stack+580294);
 tmp = dvrr_stack + 171210;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+113374, dvrr_stack+107466, dvrr_stack+580834);
 tmp = dvrr_stack + 113374;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+20764, dvrr_stack+121616, dvrr_stack+764740);
 tmp = dvrr_stack + 20764;
 target_ptr = Libderiv->deriv2_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+764428, dvrr_stack+93522, dvrr_stack+12874);
 tmp = dvrr_stack + 764428;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+114319, dvrr_stack+611054, dvrr_stack+595835);
 tmp = dvrr_stack + 114319;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+337773, dvrr_stack+184212, dvrr_stack+7447);
 tmp = dvrr_stack + 337773;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+373285, dvrr_stack+203193, dvrr_stack+23872);
 tmp = dvrr_stack + 373285;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+840868, dvrr_stack+220828, dvrr_stack+37537);
 tmp = dvrr_stack + 840868;
 target_ptr = Libderiv->deriv2_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+37411, dvrr_stack+307340, dvrr_stack+96942);
 tmp = dvrr_stack + 37411;
 target_ptr = Libderiv->deriv2_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+23752, dvrr_stack+498665, dvrr_stack+28408);
 tmp = dvrr_stack + 23752;
 target_ptr = Libderiv->deriv2_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+842408, dvrr_stack+300545, dvrr_stack+92514);
 tmp = dvrr_stack + 842408;
 target_ptr = Libderiv->deriv2_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+148269, dvrr_stack+326600, dvrr_stack+107466);
 tmp = dvrr_stack + 148269;
 target_ptr = Libderiv->deriv2_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+80581, dvrr_stack+348300, dvrr_stack+121616);
 tmp = dvrr_stack + 80581;
 target_ptr = Libderiv->deriv2_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+92422, dvrr_stack+462770, dvrr_stack+93522);
 tmp = dvrr_stack + 92422;
 target_ptr = Libderiv->deriv2_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+107361, dvrr_stack+391065, dvrr_stack+611054);
 tmp = dvrr_stack + 107361;
 target_ptr = Libderiv->deriv2_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+390790, dvrr_stack+452645, dvrr_stack+184212);
 tmp = dvrr_stack + 390790;
 target_ptr = Libderiv->deriv2_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+452526, dvrr_stack+486110, dvrr_stack+203193);
 tmp = dvrr_stack + 452526;
 target_ptr = Libderiv->deriv2_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+486057, dvrr_stack+516085, dvrr_stack+220828);
 tmp = dvrr_stack + 486057;
 target_ptr = Libderiv->deriv2_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+515858, dvrr_stack+765565, dvrr_stack+307340);
 tmp = dvrr_stack + 515858;
 target_ptr = Libderiv->deriv2_classes[9][5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+765016, dvrr_stack+546676, dvrr_stack+498665);
 tmp = dvrr_stack + 765016;
 target_ptr = Libderiv->deriv2_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+517013, dvrr_stack+782750, dvrr_stack+300545);
 tmp = dvrr_stack + 517013;
 target_ptr = Libderiv->deriv2_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+82561, dvrr_stack+799412, dvrr_stack+326600);
 tmp = dvrr_stack + 82561;
 target_ptr = Libderiv->deriv2_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+799298, dvrr_stack+818145, dvrr_stack+348300);
 tmp = dvrr_stack + 799298;
 target_ptr = Libderiv->deriv2_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+610934, dvrr_stack+591823, dvrr_stack+830025);
 tmp = dvrr_stack + 610934;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+611375, dvrr_stack+591039, dvrr_stack+830340);
 tmp = dvrr_stack + 611375;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+96753, dvrr_stack+592411, dvrr_stack+830760);
 tmp = dvrr_stack + 96753;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+307034, dvrr_stack+593419, dvrr_stack+831300);
 tmp = dvrr_stack + 307034;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+300245, dvrr_stack+548524, dvrr_stack+831975);
 tmp = dvrr_stack + 300245;
 target_ptr = Libderiv->deriv2_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+93367, dvrr_stack+553460, dvrr_stack+585656);
 tmp = dvrr_stack + 93367;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+7399, dvrr_stack+552452, dvrr_stack+585068);
 tmp = dvrr_stack + 7399;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+326594, dvrr_stack+554216, dvrr_stack+586097);
 tmp = dvrr_stack + 326594;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+203071, dvrr_stack+555512, dvrr_stack+586853);
 tmp = dvrr_stack + 203071;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+829945, dvrr_stack+519110, dvrr_stack+587798);
 tmp = dvrr_stack + 829945;
 target_ptr = Libderiv->deriv2_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+301400, dvrr_stack+490520, dvrr_stack+591823);
 tmp = dvrr_stack + 301400;
 target_ptr = Libderiv->deriv2_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+327602, dvrr_stack+489260, dvrr_stack+591039);
 tmp = dvrr_stack + 327602;
 target_ptr = Libderiv->deriv2_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+590913, dvrr_stack+463925, dvrr_stack+592411);
 tmp = dvrr_stack + 590913;
 target_ptr = Libderiv->deriv2_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+782669, dvrr_stack+350775, dvrr_stack+593419);
 tmp = dvrr_stack + 782669;
 target_ptr = Libderiv->deriv2_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+592209, dvrr_stack+328625, dvrr_stack+548524);
 tmp = dvrr_stack + 592209;
 target_ptr = Libderiv->deriv2_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+831485, dvrr_stack+352800, dvrr_stack+553460);
 tmp = dvrr_stack + 831485;
 target_ptr = Libderiv->deriv2_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+352800, dvrr_stack+465545, dvrr_stack+552452);
 tmp = dvrr_stack + 352800;
 target_ptr = Libderiv->deriv2_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+552416, dvrr_stack+308285, dvrr_stack+554216);
 tmp = dvrr_stack + 552416;
 target_ptr = Libderiv->deriv2_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+307979, dvrr_stack+275917, dvrr_stack+555512);
 tmp = dvrr_stack + 307979;
 target_ptr = Libderiv->deriv2_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+554036, dvrr_stack+246328, dvrr_stack+519110);
 tmp = dvrr_stack + 554036;
 target_ptr = Libderiv->deriv2_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+465545, dvrr_stack+834718, dvrr_stack+490520);
 tmp = dvrr_stack + 465545;
 target_ptr = Libderiv->deriv2_classes[9][5][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+518993, dvrr_stack+836104, dvrr_stack+489260);
 tmp = dvrr_stack + 518993;
 target_ptr = Libderiv->deriv2_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+489173, dvrr_stack+837952, dvrr_stack+463925);
 tmp = dvrr_stack + 489173;
 target_ptr = Libderiv->deriv2_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+275672, dvrr_stack+821775, dvrr_stack+350775);
 tmp = dvrr_stack + 275672;
 target_ptr = Libderiv->deriv2_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+818112, dvrr_stack+802382, dvrr_stack+328625);
 tmp = dvrr_stack + 818112;
 target_ptr = Libderiv->deriv2_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+556511, dvrr_stack+499925, dvrr_stack+497990);
 tmp = dvrr_stack + 556511;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+594189, dvrr_stack+310265, dvrr_stack+432855);
 tmp = dvrr_stack + 594189;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+432580, dvrr_stack+278392, dvrr_stack+832800);
 tmp = dvrr_stack + 432580;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+328610, dvrr_stack+204813, dvrr_stack+824745);
 tmp = dvrr_stack + 328610;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+329555, dvrr_stack+189540, dvrr_stack+825420);
 tmp = dvrr_stack + 329555;
 target_ptr = Libderiv->deriv2_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+433336, dvrr_stack+185508, dvrr_stack+595039);
 tmp = dvrr_stack + 433336;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+594777, dvrr_stack+206073, dvrr_stack+455450);
 tmp = dvrr_stack + 594777;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+121554, dvrr_stack+191080, dvrr_stack+392605);
 tmp = dvrr_stack + 121554;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+184037, dvrr_stack+123156, dvrr_stack+302165);
 tmp = dvrr_stack + 184037;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+802323, dvrr_stack+75280, dvrr_stack+222808);
 tmp = dvrr_stack + 802323;
 target_ptr = Libderiv->deriv2_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+455066, dvrr_stack+97530, dvrr_stack+499925);
 tmp = dvrr_stack + 455066;
 target_ptr = Libderiv->deriv2_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+803863, dvrr_stack+108726, dvrr_stack+310265);
 tmp = dvrr_stack + 803863;
 target_ptr = Libderiv->deriv2_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+821137, dvrr_stack+77260, dvrr_stack+278392);
 tmp = dvrr_stack + 821137;
 target_ptr = Libderiv->deriv2_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+822433, dvrr_stack+56086, dvrr_stack+204813);
 tmp = dvrr_stack + 822433;
 target_ptr = Libderiv->deriv2_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+824053, dvrr_stack+412431, dvrr_stack+189540);
 tmp = dvrr_stack + 824053;
 target_ptr = Libderiv->deriv2_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+392410, dvrr_stack+24817, dvrr_stack+185508);
 tmp = dvrr_stack + 392410;
 target_ptr = Libderiv->deriv2_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+189399, dvrr_stack+38692, dvrr_stack+206073);
 tmp = dvrr_stack + 189399;
 target_ptr = Libderiv->deriv2_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+38167, dvrr_stack+727379, dvrr_stack+191080);
 tmp = dvrr_stack + 38167;
 target_ptr = Libderiv->deriv2_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+204331, dvrr_stack+729359, dvrr_stack+123156);
 tmp = dvrr_stack + 204331;
 target_ptr = Libderiv->deriv2_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+727361, dvrr_stack+731834, dvrr_stack+75280);
 tmp = dvrr_stack + 727361;
 target_ptr = Libderiv->deriv2_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+729836, dvrr_stack+785126, dvrr_stack+97530);
 tmp = dvrr_stack + 729836;
 target_ptr = Libderiv->deriv2_classes[9][5][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+730991, dvrr_stack+772922, dvrr_stack+108726);
 tmp = dvrr_stack + 730991;
 target_ptr = Libderiv->deriv2_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+732531, dvrr_stack+216153, dvrr_stack+77260);
 tmp = dvrr_stack + 732531;
 target_ptr = Libderiv->deriv2_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+585023, dvrr_stack+844860, dvrr_stack+56086);
 tmp = dvrr_stack + 585023;
 target_ptr = Libderiv->deriv2_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+834600, dvrr_stack+847830, dvrr_stack+412431);
 tmp = dvrr_stack + 834600;
 target_ptr = Libderiv->deriv2_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+772922, dvrr_stack+124776, dvrr_stack+498305);
 tmp = dvrr_stack + 772922;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+773363, dvrr_stack+16402, dvrr_stack+9401);
 tmp = dvrr_stack + 773363;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+773951, dvrr_stack+33852, dvrr_stack+840328);
 tmp = dvrr_stack + 773951;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+56072, dvrr_stack+49861, dvrr_stack+826245);
 tmp = dvrr_stack + 56072;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+190659, dvrr_stack+73055, dvrr_stack+786512);
 tmp = dvrr_stack + 190659;
 target_ptr = Libderiv->deriv2_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+595561, dvrr_stack+10462, dvrr_stack+249353);
 tmp = dvrr_stack + 595561;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+57017, dvrr_stack+159410, dvrr_stack+612062);
 tmp = dvrr_stack + 57017;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+310004, dvrr_stack+738489, dvrr_stack+98475);
 tmp = dvrr_stack + 310004;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+97509, dvrr_stack+739785, dvrr_stack+13315);
 tmp = dvrr_stack + 97509;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+412325, dvrr_stack+741405, dvrr_stack+417876);
 tmp = dvrr_stack + 412325;
 target_ptr = Libderiv->deriv2_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+417601, dvrr_stack+270520, dvrr_stack+124776);
 tmp = dvrr_stack + 417601;
 target_ptr = Libderiv->deriv2_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+108621, dvrr_stack+269260, dvrr_stack+16402);
 tmp = dvrr_stack + 108621;
 target_ptr = Libderiv->deriv2_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+12793, dvrr_stack+743385, dvrr_stack+33852);
 tmp = dvrr_stack + 12793;
 target_ptr = Libderiv->deriv2_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+122562, dvrr_stack+745005, dvrr_stack+49861);
 tmp = dvrr_stack + 122562;
 target_ptr = Libderiv->deriv2_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+784289, dvrr_stack+747030, dvrr_stack+73055);
 tmp = dvrr_stack + 784289;
 target_ptr = Libderiv->deriv2_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+302156, dvrr_stack+752475, dvrr_stack+10462);
 tmp = dvrr_stack + 302156;
 target_ptr = Libderiv->deriv2_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+752200, dvrr_stack+156137, dvrr_stack+159410);
 tmp = dvrr_stack + 752200;
 target_ptr = Libderiv->deriv2_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+155999, dvrr_stack+753630, dvrr_stack+738489);
 tmp = dvrr_stack + 155999;
 target_ptr = Libderiv->deriv2_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+753460, dvrr_stack+755610, dvrr_stack+739785);
 tmp = dvrr_stack + 753460;
 target_ptr = Libderiv->deriv2_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+755485, dvrr_stack+758085, dvrr_stack+741405);
 tmp = dvrr_stack + 755485;
 target_ptr = Libderiv->deriv2_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+757960, dvrr_stack+774770, dvrr_stack+270520);
 tmp = dvrr_stack + 757960;
 target_ptr = Libderiv->deriv2_classes[9][5][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+759115, dvrr_stack+766951, dvrr_stack+269260);
 tmp = dvrr_stack + 759115;
 target_ptr = Libderiv->deriv2_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+766556, dvrr_stack+345825, dvrr_stack+743385);
 tmp = dvrr_stack + 766556;
 target_ptr = Libderiv->deriv2_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+738177, dvrr_stack+851460, dvrr_stack+745005);
 tmp = dvrr_stack + 738177;
 target_ptr = Libderiv->deriv2_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+740652, dvrr_stack+854430, dvrr_stack+747030);
 tmp = dvrr_stack + 740652;
 target_ptr = Libderiv->deriv2_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+774707, dvrr_stack+369270, dvrr_stack+368955);
 tmp = dvrr_stack + 774707;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+775148, dvrr_stack+370278, dvrr_stack+369858);
 tmp = dvrr_stack + 775148;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+743677, dvrr_stack+371602, dvrr_stack+371062);
 tmp = dvrr_stack + 743677;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+744433, dvrr_stack+833340, dvrr_stack+372610);
 tmp = dvrr_stack + 744433;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+745378, dvrr_stack+581509, dvrr_stack+787337);
 tmp = dvrr_stack + 745378;
 target_ptr = Libderiv->deriv2_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+372610, dvrr_stack+776156, dvrr_stack+768799);
 tmp = dvrr_stack + 372610;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+746533, dvrr_stack+375159, dvrr_stack+583049);
 tmp = dvrr_stack + 746533;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+747317, dvrr_stack+858816, dvrr_stack+858060);
 tmp = dvrr_stack + 747317;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+269222, dvrr_stack+860112, dvrr_stack+104586);
 tmp = dvrr_stack + 269222;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+345536, dvrr_stack+861732, dvrr_stack+52129);
 tmp = dvrr_stack + 345536;
 target_ptr = Libderiv->deriv2_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+52129, dvrr_stack+863712, dvrr_stack+369270);
 tmp = dvrr_stack + 52129;
 target_ptr = Libderiv->deriv2_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+748325, dvrr_stack+864657, dvrr_stack+370278);
 tmp = dvrr_stack + 748325;
 target_ptr = Libderiv->deriv2_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+347076, dvrr_stack+865917, dvrr_stack+371602);
 tmp = dvrr_stack + 347076;
 target_ptr = Libderiv->deriv2_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+348372, dvrr_stack+867537, dvrr_stack+833340);
 tmp = dvrr_stack + 348372;
 target_ptr = Libderiv->deriv2_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+349992, dvrr_stack+869562, dvrr_stack+581509);
 tmp = dvrr_stack + 349992;
 target_ptr = Libderiv->deriv2_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+270482, dvrr_stack+872037, dvrr_stack+776156);
 tmp = dvrr_stack + 270482;
 target_ptr = Libderiv->deriv2_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+832430, dvrr_stack+873192, dvrr_stack+375159);
 tmp = dvrr_stack + 832430;
 target_ptr = Libderiv->deriv2_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+872037, dvrr_stack+874732, dvrr_stack+858816);
 tmp = dvrr_stack + 872037;
 target_ptr = Libderiv->deriv2_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+873657, dvrr_stack+876712, dvrr_stack+860112);
 tmp = dvrr_stack + 873657;
 target_ptr = Libderiv->deriv2_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+875682, dvrr_stack+879187, dvrr_stack+861732);
 tmp = dvrr_stack + 875682;
 target_ptr = Libderiv->deriv2_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+878157, dvrr_stack+69274, dvrr_stack+863712);
 tmp = dvrr_stack + 878157;
 target_ptr = Libderiv->deriv2_classes[9][5][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+879312, dvrr_stack+70660, dvrr_stack+864657);
 tmp = dvrr_stack + 879312;
 target_ptr = Libderiv->deriv2_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+69046, dvrr_stack+778466, dvrr_stack+865917);
 tmp = dvrr_stack + 69046;
 target_ptr = Libderiv->deriv2_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+497750, dvrr_stack+793112, dvrr_stack+867537);
 tmp = dvrr_stack + 497750;
 target_ptr = Libderiv->deriv2_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+793041, dvrr_stack+505910, dvrr_stack+869562);
 tmp = dvrr_stack + 793041;
 target_ptr = Libderiv->deriv2_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+880852, dvrr_stack+180488, dvrr_stack+790142);
 tmp = dvrr_stack + 880852;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+881293, dvrr_stack+790457, dvrr_stack+441630);
 tmp = dvrr_stack + 881293;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+775736, dvrr_stack+51121, dvrr_stack+791241);
 tmp = dvrr_stack + 775736;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+24760, dvrr_stack+791781, dvrr_stack+105531);
 tmp = dvrr_stack + 24760;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+71026, dvrr_stack+771382, dvrr_stack+342800);
 tmp = dvrr_stack + 71026;
 target_ptr = Libderiv->deriv2_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+768536, dvrr_stack+769240, dvrr_stack+89413);
 tmp = dvrr_stack + 768536;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+351972, dvrr_stack+344213, dvrr_stack+343625);
 tmp = dvrr_stack + 351972;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+413865, dvrr_stack+510296, dvrr_stack+509540);
 tmp = dvrr_stack + 413865;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+786269, dvrr_stack+303110, dvrr_stack+511592);
 tmp = dvrr_stack + 786269;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+342459, dvrr_stack+186264, dvrr_stack+447465);
 tmp = dvrr_stack + 342459;
 target_ptr = Libderiv->deriv2_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+511592, dvrr_stack+448620, dvrr_stack+180488);
 tmp = dvrr_stack + 511592;
 target_ptr = Libderiv->deriv2_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+447396, dvrr_stack+449565, dvrr_stack+790457);
 tmp = dvrr_stack + 447396;
 target_ptr = Libderiv->deriv2_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+790142, dvrr_stack+66670, dvrr_stack+51121);
 tmp = dvrr_stack + 790142;
 target_ptr = Libderiv->deriv2_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+778452, dvrr_stack+319625, dvrr_stack+791781);
 tmp = dvrr_stack + 778452;
 target_ptr = Libderiv->deriv2_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+837625, dvrr_stack+806012, dvrr_stack+771382);
 tmp = dvrr_stack + 837625;
 target_ptr = Libderiv->deriv2_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+771382, dvrr_stack+199368, dvrr_stack+769240);
 tmp = dvrr_stack + 771382;
 target_ptr = Libderiv->deriv2_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+791438, dvrr_stack+481295, dvrr_stack+344213);
 tmp = dvrr_stack + 791438;
 target_ptr = Libderiv->deriv2_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+374545, dvrr_stack+808487, dvrr_stack+510296);
 tmp = dvrr_stack + 374545;
 target_ptr = Libderiv->deriv2_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+843704, dvrr_stack+810467, dvrr_stack+303110);
 tmp = dvrr_stack + 843704;
 target_ptr = Libderiv->deriv2_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+808487, dvrr_stack+886502, dvrr_stack+186264);
 tmp = dvrr_stack + 808487;
 target_ptr = Libderiv->deriv2_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+810962, dvrr_stack+780842, dvrr_stack+448620);
 tmp = dvrr_stack + 810962;
 target_ptr = Libderiv->deriv2_classes[9][5][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+886370, dvrr_stack+0, dvrr_stack+449565);
 tmp = dvrr_stack + 886370;
 target_ptr = Libderiv->deriv2_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+448404, dvrr_stack+47176, dvrr_stack+66670);
 tmp = dvrr_stack + 448404;
 target_ptr = Libderiv->deriv2_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+185297, dvrr_stack+889527, dvrr_stack+319625);
 tmp = dvrr_stack + 185297;
 target_ptr = Libderiv->deriv2_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+887910, dvrr_stack+892497, dvrr_stack+806012);
 tmp = dvrr_stack + 887910;
 target_ptr = Libderiv->deriv2_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+450384, dvrr_stack+896127, dvrr_stack+345221);
 tmp = dvrr_stack + 450384;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+0, dvrr_stack+4150, dvrr_stack+3730);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+588, dvrr_stack+200523, dvrr_stack+6859);
 tmp = dvrr_stack + 588;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+890935, dvrr_stack+181832, dvrr_stack+12118);
 tmp = dvrr_stack + 890935;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+891880, dvrr_stack+812942, dvrr_stack+22927);
 tmp = dvrr_stack + 891880;
 target_ptr = Libderiv->deriv2_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+812117, dvrr_stack+68290, dvrr_stack+36382);
 tmp = dvrr_stack + 812117;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+769124, dvrr_stack+8203, dvrr_stack+89854);
 tmp = dvrr_stack + 769124;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+893035, dvrr_stack+31432, dvrr_stack+482835);
 tmp = dvrr_stack + 893035;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+894043, dvrr_stack+458846, dvrr_stack+1848);
 tmp = dvrr_stack + 894043;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+481278, dvrr_stack+896715, dvrr_stack+106206);
 tmp = dvrr_stack + 481278;
 target_ptr = Libderiv->deriv2_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+1344, dvrr_stack+120021, dvrr_stack+896127);
 tmp = dvrr_stack + 1344;
 target_ptr = Libderiv->deriv2_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+895303, dvrr_stack+34860, dvrr_stack+4150);
 tmp = dvrr_stack + 895303;
 target_ptr = Libderiv->deriv2_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+303101, dvrr_stack+898695, dvrr_stack+200523);
 tmp = dvrr_stack + 303101;
 target_ptr = Libderiv->deriv2_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+66285, dvrr_stack+900315, dvrr_stack+181832);
 tmp = dvrr_stack + 66285;
 target_ptr = Libderiv->deriv2_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+804871, dvrr_stack+902340, dvrr_stack+812942);
 tmp = dvrr_stack + 804871;
 target_ptr = Libderiv->deriv2_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+181832, dvrr_stack+188244, dvrr_stack+68290);
 tmp = dvrr_stack + 181832;
 target_ptr = Libderiv->deriv2_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+812705, dvrr_stack+201531, dvrr_stack+8203);
 tmp = dvrr_stack + 812705;
 target_ptr = Libderiv->deriv2_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+8183, dvrr_stack+90442, dvrr_stack+31432);
 tmp = dvrr_stack + 8183;
 target_ptr = Libderiv->deriv2_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+319506, dvrr_stack+94278, dvrr_stack+458846);
 tmp = dvrr_stack + 319506;
 target_ptr = Libderiv->deriv2_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+93955, dvrr_stack+297220, dvrr_stack+896715);
 tmp = dvrr_stack + 93955;
 target_ptr = Libderiv->deriv2_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+896311, dvrr_stack+769996, dvrr_stack+120021);
 tmp = dvrr_stack + 896311;
 target_ptr = Libderiv->deriv2_classes[9][5][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+458775, dvrr_stack+117546, dvrr_stack+34860);
 tmp = dvrr_stack + 458775;
 target_ptr = Libderiv->deriv2_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+199188, dvrr_stack+442050, dvrr_stack+898695);
 tmp = dvrr_stack + 199188;
 target_ptr = Libderiv->deriv2_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+897466, dvrr_stack+444426, dvrr_stack+900315);
 tmp = dvrr_stack + 897466;
 target_ptr = Libderiv->deriv2_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+89254, dvrr_stack+814482, dvrr_stack+902340);
 tmp = dvrr_stack + 89254;
 target_ptr = Libderiv->deriv2_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];


}

