/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hh|hh) integrals */

void d12vrr_order_hhhh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+873, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+210, dvrr_stack+873, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+213, dvrr_stack+876, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+892, dvrr_stack+219, dvrr_stack+882, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+907, dvrr_stack+509, dvrr_stack+892, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+952, dvrr_stack+524, dvrr_stack+907, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1042, dvrr_stack+614, dvrr_stack+952, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1192, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1342, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1588, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1609, dvrr_stack+1588, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1672, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1693, dvrr_stack+1672, dvrr_stack+1588, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1756, dvrr_stack+509, dvrr_stack+892, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1777, dvrr_stack+1567, dvrr_stack+1756, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1840, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1966, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2092, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2302, dvrr_stack+593, dvrr_stack+1672, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2365, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2491, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2302, dvrr_stack+873, dvrr_stack+704, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+210, dvrr_stack+873, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2318, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2333, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+219, dvrr_stack+882, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2701, dvrr_stack+1756, dvrr_stack+2333, NULL, NULL, dvrr_stack+892);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2764, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+907);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2890, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+952);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3100, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1042);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3415, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+1192);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3730, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+1342);
 tmp = dvrr_stack + 3730;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2382, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4171, dvrr_stack+2382, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2410, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4255, dvrr_stack+2410, dvrr_stack+2382, NULL, NULL, dvrr_stack+1588);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+479, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+509, dvrr_stack+892, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4339, dvrr_stack+2354, dvrr_stack+479, NULL, NULL, dvrr_stack+1756);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4423, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1777);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4591, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1609);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4759, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+1840);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+1609, dvrr_stack+2410, NULL, NULL, dvrr_stack+1672);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+1693);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5291, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1966);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1966, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1969, dvrr_stack+704, dvrr_stack+1966, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1975, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+873, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+876, dvrr_stack+2302, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2021, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+892, dvrr_stack+2318, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+479, dvrr_stack+2021, NULL, NULL, dvrr_stack+2333);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5571, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+2701);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5739, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2764);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6019, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+2890);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6439, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+2092);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+6859, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+3100);
 tmp = dvrr_stack + 6859;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+7447,dvrr_stack+6859,dvrr_stack+3730,21);


 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+1567, dvrr_stack+1756, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5159, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1588, dvrr_stack+1567, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+5159, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5195, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1672, dvrr_stack+1588, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8878, dvrr_stack+5195, dvrr_stack+5159, NULL, NULL, dvrr_stack+2382);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+1756, dvrr_stack+2333, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8986, dvrr_stack+5123, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9094, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+4339);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9310, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+4171);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9526, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+4423);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+593, dvrr_stack+1672, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+4171, dvrr_stack+5195, NULL, NULL, dvrr_stack+2410);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+4255);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10102, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4591);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4591, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1603, dvrr_stack+1966, dvrr_stack+4591, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+4594, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+704, dvrr_stack+1966, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4604, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+2302, dvrr_stack+1969, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+2308, dvrr_stack+1975, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4619, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+2318, dvrr_stack+1985, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+2333, dvrr_stack+2000, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+1567, dvrr_stack+4647, NULL, NULL, dvrr_stack+2021);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+5039);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10678, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5571);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11038, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+5739);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11578, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+4759);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12118, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+6019);
 tmp = dvrr_stack + 12118;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+12874,dvrr_stack+12118,dvrr_stack+6859,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+14638,dvrr_stack+12874,dvrr_stack+7447,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+17284, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+2354, dvrr_stack+479, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9931, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+2382, dvrr_stack+2354, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+9931, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9976, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+2410, dvrr_stack+2382, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18742, dvrr_stack+9976, dvrr_stack+9931, NULL, NULL, dvrr_stack+5159);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+479, dvrr_stack+2021, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18877, dvrr_stack+9886, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19012, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+8986);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19282, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+8770);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19552, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9094);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+1609, dvrr_stack+2410, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+8770, dvrr_stack+9976, NULL, NULL, dvrr_stack+5195);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+8878);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20407, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+9310);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+9310, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9313, dvrr_stack+4591, dvrr_stack+9310, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+9319, dvrr_stack+1603, dvrr_stack+9313, dvrr_stack+1966, dvrr_stack+4591, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+9329, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+1969, dvrr_stack+1603, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+9344, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+1975, dvrr_stack+4594, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+1985, dvrr_stack+4604, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9365, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2021, dvrr_stack+4619, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+2354, dvrr_stack+9401, NULL, NULL, dvrr_stack+4647);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+1637);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21127, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+10462);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21577, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+10678);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22252, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+9526);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22927, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+11038);
 tmp = dvrr_stack + 22927;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+23872,dvrr_stack+22927,dvrr_stack+12118,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+26140,dvrr_stack+23872,dvrr_stack+12874,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+29668, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+5123, dvrr_stack+1567, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20192, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+5159, dvrr_stack+5123, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20192, dvrr_stack+20137, NULL, NULL, dvrr_stack+9886);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20247, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+5195, dvrr_stack+5159, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+20247, dvrr_stack+20192, NULL, NULL, dvrr_stack+9931);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+1567, dvrr_stack+4647, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+20137, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31762, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+18877);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32092, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+18607);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+19012);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+4171, dvrr_stack+5195, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+18607, dvrr_stack+20247, NULL, NULL, dvrr_stack+9976);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+18742);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33302, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+19282);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19282, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8980, dvrr_stack+9310, dvrr_stack+19282, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+19285, dvrr_stack+9313, dvrr_stack+8980, dvrr_stack+4591, dvrr_stack+9310, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19295, dvrr_stack+9319, dvrr_stack+19285, dvrr_stack+1603, dvrr_stack+9313, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19310, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+4594, dvrr_stack+9319, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19331, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+4604, dvrr_stack+9329, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+593, dvrr_stack+9344, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+4619, dvrr_stack+1609, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+4647, dvrr_stack+9365, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+5123, dvrr_stack+19440, NULL, NULL, dvrr_stack+9401);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+20002);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34182, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20857);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34732, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+21127);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+35557, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+19552);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36382, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+21577);
 tmp = dvrr_stack + 36382;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37537,dvrr_stack+36382,dvrr_stack+22927,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+40372,dvrr_stack+37537,dvrr_stack+23872,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+44908, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+9886, dvrr_stack+2354, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33038, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+9931, dvrr_stack+9886, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33104, dvrr_stack+33038, dvrr_stack+32972, NULL, NULL, dvrr_stack+20137);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+9976, dvrr_stack+9931, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+18662, dvrr_stack+33038, NULL, NULL, dvrr_stack+20192);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+2354, dvrr_stack+9401, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47374, dvrr_stack+32972, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47572, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+31597);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47968, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+8815);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48364, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+31762);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+8770, dvrr_stack+9976, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+8815, dvrr_stack+18662, NULL, NULL, dvrr_stack+20247);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49618, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+32092);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4336, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+32092, dvrr_stack+19282, dvrr_stack+4336, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+32098, dvrr_stack+8980, dvrr_stack+32092, dvrr_stack+9310, dvrr_stack+19282, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32108, dvrr_stack+19285, dvrr_stack+32098, dvrr_stack+9313, dvrr_stack+8980, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+32123, dvrr_stack+19295, dvrr_stack+32108, dvrr_stack+9319, dvrr_stack+19285, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+32144, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+9329, dvrr_stack+19295, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+32172, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+9344, dvrr_stack+19310, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+1609, dvrr_stack+19331, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32208, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+9365, dvrr_stack+19359, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32263, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+9401, dvrr_stack+19395, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+9886, dvrr_stack+32263, NULL, NULL, dvrr_stack+19440);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+4171);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50674, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33852);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51334, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+34182);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+52324, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+32422);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+53314, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+34732);
 tmp = dvrr_stack + 53314;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+54700,dvrr_stack+53314,dvrr_stack+36382,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+58165,dvrr_stack+54700,dvrr_stack+37537,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+63835, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+20137, dvrr_stack+5123, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+20192, dvrr_stack+20137, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49378, dvrr_stack+49300, dvrr_stack+49222, NULL, NULL, dvrr_stack+32972);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32329, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+20247, dvrr_stack+20192, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+32329, dvrr_stack+49300, NULL, NULL, dvrr_stack+33038);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+5123, dvrr_stack+19440, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66904, dvrr_stack+49222, dvrr_stack+20137, NULL, NULL, dvrr_stack+9886);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67138, dvrr_stack+49378, dvrr_stack+66904, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+47374);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67606, dvrr_stack+66670, dvrr_stack+49378, dvrr_stack+32329, dvrr_stack+49300, dvrr_stack+33104);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68074, dvrr_stack+67606, dvrr_stack+67138, dvrr_stack+66670, dvrr_stack+49378, dvrr_stack+47572);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33104, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+18607, dvrr_stack+20247, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68854, dvrr_stack+33104, dvrr_stack+32329, NULL, NULL, dvrr_stack+18662);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+68854, dvrr_stack+66670, dvrr_stack+33104, dvrr_stack+32329, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+69556, dvrr_stack+69088, dvrr_stack+67606, dvrr_stack+68854, dvrr_stack+66670, dvrr_stack+47968);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+47968, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+49612, dvrr_stack+4336, dvrr_stack+47968, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+47971, dvrr_stack+32092, dvrr_stack+49612, dvrr_stack+19282, dvrr_stack+4336, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32407, dvrr_stack+32098, dvrr_stack+47971, dvrr_stack+8980, dvrr_stack+32092, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+47981, dvrr_stack+32108, dvrr_stack+32407, dvrr_stack+19285, dvrr_stack+32098, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+48002, dvrr_stack+32123, dvrr_stack+47981, dvrr_stack+19295, dvrr_stack+32108, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48030, dvrr_stack+32144, dvrr_stack+48002, dvrr_stack+19310, dvrr_stack+32123, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+48066, dvrr_stack+32172, dvrr_stack+48030, dvrr_stack+19331, dvrr_stack+32144, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+48066, dvrr_stack+19359, dvrr_stack+32172, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48111, dvrr_stack+32208, dvrr_stack+18607, dvrr_stack+19395, dvrr_stack+8770, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48177, dvrr_stack+32263, dvrr_stack+48111, dvrr_stack+19440, dvrr_stack+32208, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68854, dvrr_stack+20137, dvrr_stack+48177, NULL, NULL, dvrr_stack+32263);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70336, dvrr_stack+66904, dvrr_stack+68854, dvrr_stack+49222, dvrr_stack+20137, dvrr_stack+49024);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70804, dvrr_stack+67138, dvrr_stack+70336, dvrr_stack+49378, dvrr_stack+66904, dvrr_stack+50278);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+71584, dvrr_stack+68074, dvrr_stack+70804, dvrr_stack+67606, dvrr_stack+67138, dvrr_stack+50674);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+72754, dvrr_stack+69556, dvrr_stack+68074, dvrr_stack+69088, dvrr_stack+67606, dvrr_stack+48364);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+73924, dvrr_stack+72754, dvrr_stack+71584, dvrr_stack+69556, dvrr_stack+68074, dvrr_stack+51334);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+75562,dvrr_stack+73924,dvrr_stack+53314,21);


 /* compute (5 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+79720,dvrr_stack+75562,dvrr_stack+54700,21);


 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+86650, dvrr_stack+79720, dvrr_stack+36382);

 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+49222, dvrr_stack+20137, dvrr_stack+32972, dvrr_stack+9886, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+33038, dvrr_stack+32972, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69270, dvrr_stack+69179, dvrr_stack+69088, NULL, NULL, dvrr_stack+49222);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69543, dvrr_stack+32329, dvrr_stack+49300, dvrr_stack+18662, dvrr_stack+33038, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69634, dvrr_stack+69543, dvrr_stack+69179, NULL, NULL, dvrr_stack+49300);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+20137, dvrr_stack+48177, dvrr_stack+9886, dvrr_stack+32263, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69907, dvrr_stack+69088, dvrr_stack+49222, NULL, NULL, dvrr_stack+20137);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+90115, dvrr_stack+69270, dvrr_stack+69907, dvrr_stack+69179, dvrr_stack+69088, dvrr_stack+66904);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+90661, dvrr_stack+69634, dvrr_stack+69270, dvrr_stack+69543, dvrr_stack+69179, dvrr_stack+49378);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+91207, dvrr_stack+90661, dvrr_stack+90115, dvrr_stack+69634, dvrr_stack+69270, dvrr_stack+67138);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+33104, dvrr_stack+32329, dvrr_stack+8815, dvrr_stack+18662, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49313, dvrr_stack+69179, dvrr_stack+69543, NULL, NULL, dvrr_stack+32329);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+92117, dvrr_stack+49313, dvrr_stack+69634, dvrr_stack+69179, dvrr_stack+69543, dvrr_stack+66670);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+92663, dvrr_stack+92117, dvrr_stack+90661, dvrr_stack+49313, dvrr_stack+69634, dvrr_stack+67606);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19282, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+67606, dvrr_stack+47968, dvrr_stack+19282, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+67612, dvrr_stack+49612, dvrr_stack+67606, dvrr_stack+4336, dvrr_stack+47968, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+67622, dvrr_stack+47971, dvrr_stack+67612, dvrr_stack+32092, dvrr_stack+49612, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+67637, dvrr_stack+32407, dvrr_stack+67622, dvrr_stack+32098, dvrr_stack+47971, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+67658, dvrr_stack+47981, dvrr_stack+67637, dvrr_stack+32108, dvrr_stack+32407, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+67686, dvrr_stack+48002, dvrr_stack+67658, dvrr_stack+32123, dvrr_stack+47981, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+67722, dvrr_stack+48030, dvrr_stack+67686, dvrr_stack+32144, dvrr_stack+48002, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67767, dvrr_stack+48066, dvrr_stack+67722, dvrr_stack+32172, dvrr_stack+48030, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+67822, dvrr_stack+18607, dvrr_stack+67767, dvrr_stack+8770, dvrr_stack+48066, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32329, dvrr_stack+48111, dvrr_stack+67822, dvrr_stack+32208, dvrr_stack+18607, NULL);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+48177, dvrr_stack+32329, dvrr_stack+32263, dvrr_stack+48111, NULL);

 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49313, dvrr_stack+49222, dvrr_stack+69179, NULL, NULL, dvrr_stack+48177);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+93573, dvrr_stack+69907, dvrr_stack+49313, dvrr_stack+69088, dvrr_stack+49222, dvrr_stack+68854);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+94119, dvrr_stack+90115, dvrr_stack+93573, dvrr_stack+69270, dvrr_stack+69907, dvrr_stack+70336);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+95029, dvrr_stack+91207, dvrr_stack+94119, dvrr_stack+90661, dvrr_stack+90115, dvrr_stack+70804);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+96394, dvrr_stack+92663, dvrr_stack+91207, dvrr_stack+92117, dvrr_stack+90661, dvrr_stack+68074);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+97759, dvrr_stack+96394, dvrr_stack+95029, dvrr_stack+92663, dvrr_stack+91207, dvrr_stack+71584);

 /* compute (5 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+99670,dvrr_stack+97759,dvrr_stack+73924,21);


 /* compute (5 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+104584,dvrr_stack+99670,dvrr_stack+75562,21);


 /* compute (5 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1386,dvrr_stack+112900, dvrr_stack+104584, dvrr_stack+53314);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+4336, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+569, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+90661, dvrr_stack+6, dvrr_stack+569, dvrr_stack+3, dvrr_stack+0, dvrr_stack+4336);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+90679, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+90697, dvrr_stack+39, dvrr_stack+90679, dvrr_stack+15, dvrr_stack+33, dvrr_stack+569);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+90733, dvrr_stack+75, dvrr_stack+90697, dvrr_stack+57, dvrr_stack+39, dvrr_stack+90661);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+90793, dvrr_stack+219, dvrr_stack+882, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+90823, dvrr_stack+229, dvrr_stack+90793, dvrr_stack+111, dvrr_stack+219, dvrr_stack+90679);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+90883, dvrr_stack+259, dvrr_stack+90823, dvrr_stack+131, dvrr_stack+229, dvrr_stack+90697);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+9952, dvrr_stack+379, dvrr_stack+90883, dvrr_stack+319, dvrr_stack+259, dvrr_stack+90733);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+90983, dvrr_stack+892, dvrr_stack+2318, NULL, NULL, dvrr_stack+882);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+91028, dvrr_stack+907, dvrr_stack+90983, dvrr_stack+509, dvrr_stack+892, dvrr_stack+90793);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+92117, dvrr_stack+952, dvrr_stack+91028, dvrr_stack+524, dvrr_stack+907, dvrr_stack+90823);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+92267, dvrr_stack+1042, dvrr_stack+92117, dvrr_stack+614, dvrr_stack+952, dvrr_stack+90883);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+92492, dvrr_stack+1342, dvrr_stack+92267, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+9952);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2333, dvrr_stack+2000, NULL, NULL, dvrr_stack+2318);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+92807, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+90983);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+92933, dvrr_stack+2764, dvrr_stack+92807, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+91028);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+93143, dvrr_stack+2890, dvrr_stack+92933, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+92117);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+69270, dvrr_stack+3100, dvrr_stack+93143, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+92267);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+117058, dvrr_stack+3730, dvrr_stack+69270, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+92492);
 tmp = dvrr_stack + 117058;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+91118, dvrr_stack+2021, dvrr_stack+4619, NULL, NULL, dvrr_stack+2000);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+69711, dvrr_stack+5039, dvrr_stack+91118, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+32972, dvrr_stack+5571, dvrr_stack+69711, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+92807);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+117646, dvrr_stack+5739, dvrr_stack+32972, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+92933);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+118066, dvrr_stack+6019, dvrr_stack+117646, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+93143);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+118654, dvrr_stack+6859, dvrr_stack+118066, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+69270);
 tmp = dvrr_stack + 118654;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+119438,dvrr_stack+118654,dvrr_stack+117058,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4339, dvrr_stack+4647, dvrr_stack+9365, NULL, NULL, dvrr_stack+4619);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+91118);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121202, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+69711);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121562, dvrr_stack+10678, dvrr_stack+121202, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+32972);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122102, dvrr_stack+11038, dvrr_stack+121562, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+117646);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122858, dvrr_stack+12118, dvrr_stack+122102, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+118066);
 tmp = dvrr_stack + 122858;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+123866,dvrr_stack+122858,dvrr_stack+118654,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+126218,dvrr_stack+123866,dvrr_stack+119438,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+129746, dvrr_stack+126218, dvrr_stack+117058);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8986, dvrr_stack+9401, dvrr_stack+19395, NULL, NULL, dvrr_stack+9365);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9446, dvrr_stack+20002, dvrr_stack+8986, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+4339);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131510, dvrr_stack+20857, dvrr_stack+9446, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+66670);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131960, dvrr_stack+21127, dvrr_stack+131510, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+121202);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+132635, dvrr_stack+21577, dvrr_stack+131960, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+121562);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+133580, dvrr_stack+22927, dvrr_stack+132635, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+122102);
 tmp = dvrr_stack + 133580;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+134840,dvrr_stack+133580,dvrr_stack+122858,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+137864,dvrr_stack+134840,dvrr_stack+123866,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+142568, dvrr_stack+137864, dvrr_stack+118654);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+19440, dvrr_stack+32208, NULL, NULL, dvrr_stack+19395);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+4171, dvrr_stack+8815, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+8986);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+144920, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+9446);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+145470, dvrr_stack+34182, dvrr_stack+144920, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+131510);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+146295, dvrr_stack+34732, dvrr_stack+145470, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+131960);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+147450, dvrr_stack+36382, dvrr_stack+146295, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+132635);
 tmp = dvrr_stack + 147450;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+148990,dvrr_stack+147450,dvrr_stack+133580,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+152770,dvrr_stack+148990,dvrr_stack+134840,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+158818, dvrr_stack+152770, dvrr_stack+122858);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+32263, dvrr_stack+48111, NULL, NULL, dvrr_stack+32208);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+8815);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+50278, dvrr_stack+32422, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+18662);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+161842, dvrr_stack+50674, dvrr_stack+31432, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+144920);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+162832, dvrr_stack+51334, dvrr_stack+161842, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+145470);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+164218, dvrr_stack+53314, dvrr_stack+162832, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+146295);
 tmp = dvrr_stack + 164218;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+166066,dvrr_stack+164218,dvrr_stack+147450,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+170686,dvrr_stack+166066,dvrr_stack+148990,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+178246, dvrr_stack+170686, dvrr_stack+133580);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47374, dvrr_stack+48177, dvrr_stack+32329, NULL, NULL, dvrr_stack+48111);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48255, dvrr_stack+68854, dvrr_stack+47374, dvrr_stack+20137, dvrr_stack+48177, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182026, dvrr_stack+70336, dvrr_stack+48255, dvrr_stack+66904, dvrr_stack+68854, dvrr_stack+32422);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182806, dvrr_stack+70804, dvrr_stack+182026, dvrr_stack+67138, dvrr_stack+70336, dvrr_stack+31432);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+183976, dvrr_stack+71584, dvrr_stack+182806, dvrr_stack+68074, dvrr_stack+70804, dvrr_stack+161842);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+185614, dvrr_stack+73924, dvrr_stack+183976, dvrr_stack+72754, dvrr_stack+71584, dvrr_stack+162832);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+187798,dvrr_stack+185614,dvrr_stack+164218,28);


 /* compute (6 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+193342,dvrr_stack+187798,dvrr_stack+166066,28);


 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+202582, dvrr_stack+193342, dvrr_stack+147450);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+20137, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+19282, dvrr_stack+20137, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+67606, dvrr_stack+15, dvrr_stack+47968, dvrr_stack+19282, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+20140, dvrr_stack+67612, dvrr_stack+111, dvrr_stack+49612, dvrr_stack+67606, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+20155, dvrr_stack+67622, dvrr_stack+20140, dvrr_stack+47971, dvrr_stack+67612, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+69879, dvrr_stack+67637, dvrr_stack+20155, dvrr_stack+32407, dvrr_stack+67622, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+67658, dvrr_stack+69879, dvrr_stack+47981, dvrr_stack+67637, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20176, dvrr_stack+67686, dvrr_stack+1567, dvrr_stack+48002, dvrr_stack+67658, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20221, dvrr_stack+67722, dvrr_stack+20176, dvrr_stack+48030, dvrr_stack+67686, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20276, dvrr_stack+67767, dvrr_stack+20221, dvrr_stack+48066, dvrr_stack+67722, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47608, dvrr_stack+67822, dvrr_stack+20276, dvrr_stack+18607, dvrr_stack+67767, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+32329, dvrr_stack+47608, dvrr_stack+48111, dvrr_stack+67822, NULL);

 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+47686, dvrr_stack+69179, dvrr_stack+69088, NULL, NULL, dvrr_stack+32329);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+67888, dvrr_stack+49313, dvrr_stack+47686, dvrr_stack+49222, dvrr_stack+69179, dvrr_stack+47374);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+207202, dvrr_stack+93573, dvrr_stack+67888, dvrr_stack+69907, dvrr_stack+49313, dvrr_stack+48255);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+208112, dvrr_stack+94119, dvrr_stack+207202, dvrr_stack+90115, dvrr_stack+93573, dvrr_stack+182026);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+209477, dvrr_stack+95029, dvrr_stack+208112, dvrr_stack+91207, dvrr_stack+94119, dvrr_stack+182806);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+211388, dvrr_stack+97759, dvrr_stack+209477, dvrr_stack+96394, dvrr_stack+95029, dvrr_stack+183976);

 /* compute (6 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+213936,dvrr_stack+211388,dvrr_stack+185614,28);


 /* compute (6 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+220488,dvrr_stack+213936,dvrr_stack+187798,28);


 /* compute (6 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1848,dvrr_stack+231576, dvrr_stack+220488, dvrr_stack+164218);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+96394, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+32092, dvrr_stack+4336, dvrr_stack+96394, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+96397, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+96406, dvrr_stack+569, dvrr_stack+96397, dvrr_stack+0, dvrr_stack+30, dvrr_stack+96394);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+90661, dvrr_stack+96406, dvrr_stack+6, dvrr_stack+569, dvrr_stack+32092);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+96424, dvrr_stack+213, dvrr_stack+876, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+96442, dvrr_stack+90679, dvrr_stack+96424, dvrr_stack+33, dvrr_stack+213, dvrr_stack+96397);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+96478, dvrr_stack+90697, dvrr_stack+96442, dvrr_stack+39, dvrr_stack+90679, dvrr_stack+96406);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+479, dvrr_stack+90733, dvrr_stack+96478, dvrr_stack+75, dvrr_stack+90697, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+96538, dvrr_stack+882, dvrr_stack+2308, NULL, NULL, dvrr_stack+876);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+96568, dvrr_stack+90793, dvrr_stack+96538, dvrr_stack+219, dvrr_stack+882, dvrr_stack+96424);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+96628, dvrr_stack+90823, dvrr_stack+96568, dvrr_stack+229, dvrr_stack+90793, dvrr_stack+96442);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+96728, dvrr_stack+90883, dvrr_stack+96628, dvrr_stack+259, dvrr_stack+90823, dvrr_stack+96478);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+96878, dvrr_stack+9952, dvrr_stack+96728, dvrr_stack+379, dvrr_stack+90883, dvrr_stack+479);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2318, dvrr_stack+1985, NULL, NULL, dvrr_stack+2308);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+97088, dvrr_stack+90983, dvrr_stack+219, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+96538);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+97178, dvrr_stack+91028, dvrr_stack+97088, dvrr_stack+907, dvrr_stack+90983, dvrr_stack+96568);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+97328, dvrr_stack+92117, dvrr_stack+97178, dvrr_stack+952, dvrr_stack+91028, dvrr_stack+96628);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+90115, dvrr_stack+92267, dvrr_stack+97328, dvrr_stack+1042, dvrr_stack+92117, dvrr_stack+96728);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+68434, dvrr_stack+92492, dvrr_stack+90115, dvrr_stack+1342, dvrr_stack+92267, dvrr_stack+96878);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+892, dvrr_stack+2000, dvrr_stack+593, NULL, NULL, dvrr_stack+1985);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+955, dvrr_stack+614, dvrr_stack+892, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+90430, dvrr_stack+92807, dvrr_stack+955, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+97088);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+69907, dvrr_stack+92933, dvrr_stack+90430, dvrr_stack+2764, dvrr_stack+92807, dvrr_stack+97178);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+91202, dvrr_stack+93143, dvrr_stack+69907, dvrr_stack+2890, dvrr_stack+92933, dvrr_stack+97328);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+66886, dvrr_stack+69270, dvrr_stack+91202, dvrr_stack+3100, dvrr_stack+93143, dvrr_stack+90115);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+237120, dvrr_stack+117058, dvrr_stack+66886, dvrr_stack+3730, dvrr_stack+69270, dvrr_stack+68434);
 tmp = dvrr_stack + 237120;
 target_ptr = Libderiv->dvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2701, dvrr_stack+4619, dvrr_stack+1609, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+91118, dvrr_stack+2701, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+892);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2021, dvrr_stack+69711, dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+91118, dvrr_stack+955);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+2785, dvrr_stack+32972, dvrr_stack+2021, dvrr_stack+5571, dvrr_stack+69711, dvrr_stack+90430);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+237876, dvrr_stack+117646, dvrr_stack+2785, dvrr_stack+5739, dvrr_stack+32972, dvrr_stack+69907);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+238464, dvrr_stack+118066, dvrr_stack+237876, dvrr_stack+6019, dvrr_stack+117646, dvrr_stack+91202);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+239248, dvrr_stack+118654, dvrr_stack+238464, dvrr_stack+6859, dvrr_stack+118066, dvrr_stack+66886);
 tmp = dvrr_stack + 239248;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+240256,dvrr_stack+239248,dvrr_stack+237120,36);


 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+9365, dvrr_stack+19359, NULL, NULL, dvrr_stack+1609);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5679, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2701);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+66670, dvrr_stack+5679, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+5123);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5895, dvrr_stack+121202, dvrr_stack+4647, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+2021);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+242524, dvrr_stack+121562, dvrr_stack+5895, dvrr_stack+10678, dvrr_stack+121202, dvrr_stack+2785);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+243280, dvrr_stack+122102, dvrr_stack+242524, dvrr_stack+11038, dvrr_stack+121562, dvrr_stack+237876);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+244288, dvrr_stack+122858, dvrr_stack+243280, dvrr_stack+12118, dvrr_stack+122102, dvrr_stack+238464);
 tmp = dvrr_stack + 244288;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+245584,dvrr_stack+244288,dvrr_stack+239248,36);


 /* compute (7 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+248608,dvrr_stack+245584,dvrr_stack+240256,36);


 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+253144, dvrr_stack+248608, dvrr_stack+237120);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+19395, dvrr_stack+8770, NULL, NULL, dvrr_stack+19359);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10597, dvrr_stack+8986, dvrr_stack+10462, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+5571);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10867, dvrr_stack+9446, dvrr_stack+10597, dvrr_stack+20002, dvrr_stack+8986, dvrr_stack+5679);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+255412, dvrr_stack+131510, dvrr_stack+10867, dvrr_stack+20857, dvrr_stack+9446, dvrr_stack+4647);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+256087, dvrr_stack+131960, dvrr_stack+255412, dvrr_stack+21127, dvrr_stack+131510, dvrr_stack+5895);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+257032, dvrr_stack+132635, dvrr_stack+256087, dvrr_stack+21577, dvrr_stack+131960, dvrr_stack+242524);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+258292, dvrr_stack+133580, dvrr_stack+257032, dvrr_stack+22927, dvrr_stack+132635, dvrr_stack+243280);
 tmp = dvrr_stack + 258292;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+259912,dvrr_stack+258292,dvrr_stack+244288,36);


 /* compute (7 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+263800,dvrr_stack+259912,dvrr_stack+245584,36);


 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+269848, dvrr_stack+263800, dvrr_stack+239248);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+32208, dvrr_stack+18607, NULL, NULL, dvrr_stack+8770);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21022, dvrr_stack+8815, dvrr_stack+20857, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+10462);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+18662, dvrr_stack+21022, dvrr_stack+4171, dvrr_stack+8815, dvrr_stack+10597);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21352, dvrr_stack+144920, dvrr_stack+19440, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+10867);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+272872, dvrr_stack+145470, dvrr_stack+21352, dvrr_stack+34182, dvrr_stack+144920, dvrr_stack+255412);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+274027, dvrr_stack+146295, dvrr_stack+272872, dvrr_stack+34732, dvrr_stack+145470, dvrr_stack+256087);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+275567, dvrr_stack+147450, dvrr_stack+274027, dvrr_stack+36382, dvrr_stack+146295, dvrr_stack+257032);
 tmp = dvrr_stack + 275567;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+277547,dvrr_stack+275567,dvrr_stack+258292,36);


 /* compute (7 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+282407,dvrr_stack+277547,dvrr_stack+259912,36);


 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1296,dvrr_stack+290183, dvrr_stack+282407, dvrr_stack+244288);

 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+48111, dvrr_stack+67822, NULL, NULL, dvrr_stack+18607);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34050, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+32263, dvrr_stack+48111, dvrr_stack+20857);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34446, dvrr_stack+32422, dvrr_stack+34050, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+21022);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+294071, dvrr_stack+31432, dvrr_stack+34446, dvrr_stack+50278, dvrr_stack+32422, dvrr_stack+19440);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+295061, dvrr_stack+161842, dvrr_stack+294071, dvrr_stack+50674, dvrr_stack+31432, dvrr_stack+21352);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+296447, dvrr_stack+162832, dvrr_stack+295061, dvrr_stack+51334, dvrr_stack+161842, dvrr_stack+272872);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+298295, dvrr_stack+164218, dvrr_stack+296447, dvrr_stack+53314, dvrr_stack+162832, dvrr_stack+274027);
 tmp = dvrr_stack + 298295;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+300671,dvrr_stack+298295,dvrr_stack+275567,36);


 /* compute (7 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+306611,dvrr_stack+300671,dvrr_stack+277547,36);


 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+316331, dvrr_stack+306611, dvrr_stack+258292);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+32329, dvrr_stack+47608, NULL, NULL, dvrr_stack+67822);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50512, dvrr_stack+47374, dvrr_stack+50278, dvrr_stack+48177, dvrr_stack+32329, dvrr_stack+33852);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50980, dvrr_stack+48255, dvrr_stack+50512, dvrr_stack+68854, dvrr_stack+47374, dvrr_stack+34050);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+321191, dvrr_stack+182026, dvrr_stack+50980, dvrr_stack+70336, dvrr_stack+48255, dvrr_stack+34446);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+322361, dvrr_stack+182806, dvrr_stack+321191, dvrr_stack+70804, dvrr_stack+182026, dvrr_stack+294071);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+323999, dvrr_stack+183976, dvrr_stack+322361, dvrr_stack+71584, dvrr_stack+182806, dvrr_stack+295061);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+326183, dvrr_stack+185614, dvrr_stack+323999, dvrr_stack+73924, dvrr_stack+183976, dvrr_stack+296447);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+328991,dvrr_stack+326183,dvrr_stack+298295,36);


 /* compute (7 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+336119,dvrr_stack+328991,dvrr_stack+300671,36);


 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+347999, dvrr_stack+336119, dvrr_stack+275567);

 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68854, dvrr_stack+20137, dvrr_stack+0, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+68860, dvrr_stack+15, dvrr_stack+68854, dvrr_stack+19282, dvrr_stack+20137, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+68870, dvrr_stack+111, dvrr_stack+68860, dvrr_stack+67606, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+90640, dvrr_stack+20140, dvrr_stack+68870, dvrr_stack+67612, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+68885, dvrr_stack+20155, dvrr_stack+90640, dvrr_stack+67622, dvrr_stack+20140, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+68913, dvrr_stack+69879, dvrr_stack+68885, dvrr_stack+67637, dvrr_stack+20155, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+1567, dvrr_stack+68913, dvrr_stack+67658, dvrr_stack+69879, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264, dvrr_stack+20176, dvrr_stack+9401, dvrr_stack+67686, dvrr_stack+1567, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32263, dvrr_stack+20221, dvrr_stack+264, dvrr_stack+67722, dvrr_stack+20176, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48177, dvrr_stack+20276, dvrr_stack+32263, dvrr_stack+67767, dvrr_stack+20221, NULL);

 /* compute (0 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+68949, dvrr_stack+47608, dvrr_stack+48177, dvrr_stack+67822, dvrr_stack+20276, NULL);

 /* compute (1 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51760, dvrr_stack+69088, dvrr_stack+68949, NULL, NULL, dvrr_stack+47608);

 /* compute (2 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+70222, dvrr_stack+47686, dvrr_stack+51760, dvrr_stack+69179, dvrr_stack+69088, dvrr_stack+50278);

 /* compute (3 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+70768, dvrr_stack+67888, dvrr_stack+70222, dvrr_stack+49313, dvrr_stack+47686, dvrr_stack+50512);

 /* compute (4 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+353939, dvrr_stack+207202, dvrr_stack+70768, dvrr_stack+93573, dvrr_stack+67888, dvrr_stack+50980);

 /* compute (5 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+355304, dvrr_stack+208112, dvrr_stack+353939, dvrr_stack+94119, dvrr_stack+207202, dvrr_stack+321191);

 /* compute (6 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+357215, dvrr_stack+209477, dvrr_stack+355304, dvrr_stack+95029, dvrr_stack+208112, dvrr_stack+322361);

 /* compute (7 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+359763, dvrr_stack+211388, dvrr_stack+357215, dvrr_stack+97759, dvrr_stack+209477, dvrr_stack+323999);

 /* compute (7 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+363039,dvrr_stack+359763,dvrr_stack+326183,36);


 /* compute (7 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+371463,dvrr_stack+363039,dvrr_stack+328991,36);


 /* compute (7 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2376,dvrr_stack+385719, dvrr_stack+371463, dvrr_stack+298295);

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+69179, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+69182, dvrr_stack+96394, dvrr_stack+69179, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+69188, dvrr_stack+32092, dvrr_stack+69182, dvrr_stack+4336, dvrr_stack+96394, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+69198, dvrr_stack+210, dvrr_stack+873, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+69207, dvrr_stack+96397, dvrr_stack+69198, dvrr_stack+30, dvrr_stack+210, dvrr_stack+69179);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+69225, dvrr_stack+96406, dvrr_stack+69207, dvrr_stack+569, dvrr_stack+96397, dvrr_stack+69182);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+69040, dvrr_stack+131, dvrr_stack+69225, dvrr_stack+90661, dvrr_stack+96406, dvrr_stack+69188);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+30, dvrr_stack+876, dvrr_stack+2302, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+52033, dvrr_stack+96424, dvrr_stack+30, dvrr_stack+213, dvrr_stack+876, dvrr_stack+69198);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+52069, dvrr_stack+96442, dvrr_stack+52033, dvrr_stack+90679, dvrr_stack+96424, dvrr_stack+69207);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+52129, dvrr_stack+96478, dvrr_stack+52069, dvrr_stack+90697, dvrr_stack+96442, dvrr_stack+69225);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+35106, dvrr_stack+479, dvrr_stack+52129, dvrr_stack+90733, dvrr_stack+96478, dvrr_stack+69040);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+90679, dvrr_stack+2308, dvrr_stack+1975, NULL, NULL, dvrr_stack+2302);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+52219, dvrr_stack+96538, dvrr_stack+90679, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+30);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+35232, dvrr_stack+96568, dvrr_stack+52219, dvrr_stack+90793, dvrr_stack+96538, dvrr_stack+52033);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+35332, dvrr_stack+96628, dvrr_stack+35232, dvrr_stack+90823, dvrr_stack+96568, dvrr_stack+52069);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+3205, dvrr_stack+96728, dvrr_stack+35332, dvrr_stack+90883, dvrr_stack+96628, dvrr_stack+52129);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+1637, dvrr_stack+96878, dvrr_stack+3205, dvrr_stack+9952, dvrr_stack+96728, dvrr_stack+35106);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+52279, dvrr_stack+1985, dvrr_stack+4604, NULL, NULL, dvrr_stack+1975);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+90793, dvrr_stack+219, dvrr_stack+52279, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+90679);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+2318, dvrr_stack+97088, dvrr_stack+90793, dvrr_stack+90983, dvrr_stack+219, dvrr_stack+52219);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+11317, dvrr_stack+97178, dvrr_stack+2318, dvrr_stack+91028, dvrr_stack+97088, dvrr_stack+35232);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+71678, dvrr_stack+97328, dvrr_stack+11317, dvrr_stack+92117, dvrr_stack+97178, dvrr_stack+35332);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+71993, dvrr_stack+90115, dvrr_stack+71678, dvrr_stack+92267, dvrr_stack+97328, dvrr_stack+3205);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+91643, dvrr_stack+68434, dvrr_stack+71993, dvrr_stack+92492, dvrr_stack+90115, dvrr_stack+1637);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+90883, dvrr_stack+593, dvrr_stack+9344, NULL, NULL, dvrr_stack+4604);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+90946, dvrr_stack+892, dvrr_stack+90883, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+52279);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+72413, dvrr_stack+955, dvrr_stack+90946, dvrr_stack+614, dvrr_stack+892, dvrr_stack+90793);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+93458, dvrr_stack+90430, dvrr_stack+72413, dvrr_stack+92807, dvrr_stack+955, dvrr_stack+2318);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+93773, dvrr_stack+69907, dvrr_stack+93458, dvrr_stack+92933, dvrr_stack+90430, dvrr_stack+11317);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+94214, dvrr_stack+91202, dvrr_stack+93773, dvrr_stack+93143, dvrr_stack+69907, dvrr_stack+71678);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+94802, dvrr_stack+66886, dvrr_stack+94214, dvrr_stack+69270, dvrr_stack+91202, dvrr_stack+71993);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+392847, dvrr_stack+237120, dvrr_stack+94802, dvrr_stack+117058, dvrr_stack+66886, dvrr_stack+91643);
 tmp = dvrr_stack + 392847;
 target_ptr = Libderiv->dvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+92807, dvrr_stack+1609, dvrr_stack+19331, NULL, NULL, dvrr_stack+9344);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+92891, dvrr_stack+2701, dvrr_stack+92807, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+90883);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+93059, dvrr_stack+5123, dvrr_stack+92891, dvrr_stack+91118, dvrr_stack+2701, dvrr_stack+90946);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+69255, dvrr_stack+2021, dvrr_stack+93059, dvrr_stack+69711, dvrr_stack+5123, dvrr_stack+72413);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+95558, dvrr_stack+2785, dvrr_stack+69255, dvrr_stack+32972, dvrr_stack+2021, dvrr_stack+93458);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+48723, dvrr_stack+237876, dvrr_stack+95558, dvrr_stack+117646, dvrr_stack+2785, dvrr_stack+93773);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+393792, dvrr_stack+238464, dvrr_stack+48723, dvrr_stack+118066, dvrr_stack+237876, dvrr_stack+94214);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+394800, dvrr_stack+239248, dvrr_stack+393792, dvrr_stack+118654, dvrr_stack+238464, dvrr_stack+94802);
 tmp = dvrr_stack + 394800;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+396060,dvrr_stack+394800,dvrr_stack+392847,45);


 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117646, dvrr_stack+19359, dvrr_stack+32172, NULL, NULL, dvrr_stack+19331);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117754, dvrr_stack+5571, dvrr_stack+117646, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+92807);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117970, dvrr_stack+5679, dvrr_stack+117754, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+92891);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+398895, dvrr_stack+4647, dvrr_stack+117970, dvrr_stack+66670, dvrr_stack+5679, dvrr_stack+93059);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+399435, dvrr_stack+5895, dvrr_stack+398895, dvrr_stack+121202, dvrr_stack+4647, dvrr_stack+69255);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+400191, dvrr_stack+242524, dvrr_stack+399435, dvrr_stack+121562, dvrr_stack+5895, dvrr_stack+95558);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+401199, dvrr_stack+243280, dvrr_stack+400191, dvrr_stack+122102, dvrr_stack+242524, dvrr_stack+48723);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121202, dvrr_stack+244288, dvrr_stack+401199, dvrr_stack+122858, dvrr_stack+243280, dvrr_stack+393792);
 tmp = dvrr_stack + 121202;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+402495,dvrr_stack+121202,dvrr_stack+394800,45);


 /* compute (8 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+406275,dvrr_stack+402495,dvrr_stack+396060,45);


 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+411945, dvrr_stack+406275, dvrr_stack+392847);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+8770, dvrr_stack+48066, NULL, NULL, dvrr_stack+32172);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+118330, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+117646);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32818, dvrr_stack+10597, dvrr_stack+118330, dvrr_stack+8986, dvrr_stack+10462, dvrr_stack+117754);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+414780, dvrr_stack+10867, dvrr_stack+32818, dvrr_stack+9446, dvrr_stack+10597, dvrr_stack+117970);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+415455, dvrr_stack+255412, dvrr_stack+414780, dvrr_stack+131510, dvrr_stack+10867, dvrr_stack+398895);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+416400, dvrr_stack+256087, dvrr_stack+415455, dvrr_stack+131960, dvrr_stack+255412, dvrr_stack+399435);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+417660, dvrr_stack+257032, dvrr_stack+416400, dvrr_stack+132635, dvrr_stack+256087, dvrr_stack+400191);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131510, dvrr_stack+258292, dvrr_stack+417660, dvrr_stack+133580, dvrr_stack+257032, dvrr_stack+401199);
 tmp = dvrr_stack + 131510;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+419280,dvrr_stack+131510,dvrr_stack+121202,45);


 /* compute (8 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+424140,dvrr_stack+419280,dvrr_stack+402495,45);


 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+431700, dvrr_stack+424140, dvrr_stack+394800);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+18607, dvrr_stack+67767, NULL, NULL, dvrr_stack+48066);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9446, dvrr_stack+20857, dvrr_stack+4171, dvrr_stack+32208, dvrr_stack+18607, dvrr_stack+66670);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+435480, dvrr_stack+21022, dvrr_stack+9446, dvrr_stack+8815, dvrr_stack+20857, dvrr_stack+118330);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+436030, dvrr_stack+19440, dvrr_stack+435480, dvrr_stack+18662, dvrr_stack+21022, dvrr_stack+32818);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+436855, dvrr_stack+21352, dvrr_stack+436030, dvrr_stack+144920, dvrr_stack+19440, dvrr_stack+414780);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+438010, dvrr_stack+272872, dvrr_stack+436855, dvrr_stack+145470, dvrr_stack+21352, dvrr_stack+415455);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+439550, dvrr_stack+274027, dvrr_stack+438010, dvrr_stack+146295, dvrr_stack+272872, dvrr_stack+416400);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+144920, dvrr_stack+275567, dvrr_stack+439550, dvrr_stack+147450, dvrr_stack+274027, dvrr_stack+417660);
 tmp = dvrr_stack + 144920;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+441530,dvrr_stack+144920,dvrr_stack+131510,45);


 /* compute (8 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+447605,dvrr_stack+441530,dvrr_stack+419280,45);


 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+457325, dvrr_stack+447605, dvrr_stack+121202);

 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+67822, dvrr_stack+20276, NULL, NULL, dvrr_stack+67767);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18860, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+48111, dvrr_stack+67822, dvrr_stack+4171);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+462185, dvrr_stack+34050, dvrr_stack+18860, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+9446);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+462845, dvrr_stack+34446, dvrr_stack+462185, dvrr_stack+32422, dvrr_stack+34050, dvrr_stack+435480);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+463835, dvrr_stack+294071, dvrr_stack+462845, dvrr_stack+31432, dvrr_stack+34446, dvrr_stack+436030);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+465221, dvrr_stack+295061, dvrr_stack+463835, dvrr_stack+161842, dvrr_stack+294071, dvrr_stack+436855);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+467069, dvrr_stack+296447, dvrr_stack+465221, dvrr_stack+162832, dvrr_stack+295061, dvrr_stack+438010);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+469445, dvrr_stack+298295, dvrr_stack+467069, dvrr_stack+164218, dvrr_stack+296447, dvrr_stack+439550);
 tmp = dvrr_stack + 469445;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+472415,dvrr_stack+469445,dvrr_stack+144920,45);


 /* compute (8 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+479840,dvrr_stack+472415,dvrr_stack+441530,45);


 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2025,dvrr_stack+491990, dvrr_stack+479840, dvrr_stack+131510);

 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+161842, dvrr_stack+47608, dvrr_stack+48177, NULL, NULL, dvrr_stack+20276);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+162076, dvrr_stack+50278, dvrr_stack+161842, dvrr_stack+32329, dvrr_stack+47608, dvrr_stack+18662);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+162544, dvrr_stack+50512, dvrr_stack+162076, dvrr_stack+47374, dvrr_stack+50278, dvrr_stack+18860);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+498065, dvrr_stack+50980, dvrr_stack+162544, dvrr_stack+48255, dvrr_stack+50512, dvrr_stack+462185);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+499235, dvrr_stack+321191, dvrr_stack+498065, dvrr_stack+182026, dvrr_stack+50980, dvrr_stack+462845);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+500873, dvrr_stack+322361, dvrr_stack+499235, dvrr_stack+182806, dvrr_stack+321191, dvrr_stack+463835);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+503057, dvrr_stack+323999, dvrr_stack+500873, dvrr_stack+183976, dvrr_stack+322361, dvrr_stack+465221);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182026, dvrr_stack+326183, dvrr_stack+503057, dvrr_stack+185614, dvrr_stack+323999, dvrr_stack+467069);

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+505865,dvrr_stack+182026,dvrr_stack+469445,45);


 /* compute (8 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+514775,dvrr_stack+505865,dvrr_stack+472415,45);


 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+529625, dvrr_stack+514775, dvrr_stack+144920);

 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+69085, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+0, dvrr_stack+69085, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+68854, dvrr_stack+213, dvrr_stack+20137, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+185536, dvrr_stack+68860, dvrr_stack+882, dvrr_stack+15, dvrr_stack+68854, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+68870, dvrr_stack+185536, dvrr_stack+111, dvrr_stack+68860, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4619, dvrr_stack+90640, dvrr_stack+2000, dvrr_stack+20140, dvrr_stack+68870, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122822, dvrr_stack+68885, dvrr_stack+4619, dvrr_stack+20155, dvrr_stack+90640, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+133535, dvrr_stack+68913, dvrr_stack+122822, dvrr_stack+69879, dvrr_stack+68885, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+147395, dvrr_stack+9401, dvrr_stack+133535, dvrr_stack+1567, dvrr_stack+68913, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48111, dvrr_stack+264, dvrr_stack+147395, dvrr_stack+20176, dvrr_stack+9401, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32329, dvrr_stack+32263, dvrr_stack+48111, dvrr_stack+20221, dvrr_stack+264, NULL);

 /* compute (0 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+48255, dvrr_stack+48177, dvrr_stack+32329, dvrr_stack+20276, dvrr_stack+32263, NULL);

 /* compute (1 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+48346, dvrr_stack+68949, dvrr_stack+48255, NULL, NULL, dvrr_stack+48177);

 /* compute (2 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+163324, dvrr_stack+51760, dvrr_stack+48346, dvrr_stack+69088, dvrr_stack+68949, dvrr_stack+161842);

 /* compute (3 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+537050, dvrr_stack+70222, dvrr_stack+163324, dvrr_stack+47686, dvrr_stack+51760, dvrr_stack+162076);

 /* compute (4 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+537960, dvrr_stack+70768, dvrr_stack+537050, dvrr_stack+67888, dvrr_stack+70222, dvrr_stack+162544);

 /* compute (5 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+539325, dvrr_stack+353939, dvrr_stack+537960, dvrr_stack+207202, dvrr_stack+70768, dvrr_stack+498065);

 /* compute (6 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+541236, dvrr_stack+355304, dvrr_stack+539325, dvrr_stack+208112, dvrr_stack+353939, dvrr_stack+499235);

 /* compute (7 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+543784, dvrr_stack+357215, dvrr_stack+541236, dvrr_stack+209477, dvrr_stack+355304, dvrr_stack+500873);

 /* compute (8 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+207202, dvrr_stack+359763, dvrr_stack+543784, dvrr_stack+211388, dvrr_stack+357215, dvrr_stack+503057);

 /* compute (8 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+547060,dvrr_stack+207202,dvrr_stack+182026,45);


 /* compute (8 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+557590,dvrr_stack+547060,dvrr_stack+505865,45);


 /* compute (8 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2970,dvrr_stack+575410, dvrr_stack+557590, dvrr_stack+469445);

 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+211297, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+15, dvrr_stack+69179, dvrr_stack+211297, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+111, dvrr_stack+69182, dvrr_stack+15, dvrr_stack+96394, dvrr_stack+69179, NULL);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+211300, dvrr_stack+69188, dvrr_stack+111, dvrr_stack+32092, dvrr_stack+69182, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+569, dvrr_stack+873, dvrr_stack+704, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+211315, dvrr_stack+69198, dvrr_stack+569, dvrr_stack+210, dvrr_stack+873, dvrr_stack+211297);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+211333, dvrr_stack+69207, dvrr_stack+211315, dvrr_stack+96397, dvrr_stack+69198, dvrr_stack+15);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+19395, dvrr_stack+69225, dvrr_stack+211333, dvrr_stack+96406, dvrr_stack+69207, dvrr_stack+111);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+185551, dvrr_stack+69040, dvrr_stack+19395, dvrr_stack+131, dvrr_stack+69225, dvrr_stack+211300);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+211363, dvrr_stack+2302, dvrr_stack+1969, NULL, NULL, dvrr_stack+704);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+9365, dvrr_stack+30, dvrr_stack+211363, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+569);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+67888, dvrr_stack+52033, dvrr_stack+9365, dvrr_stack+96424, dvrr_stack+30, dvrr_stack+211315);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+614, dvrr_stack+52069, dvrr_stack+67888, dvrr_stack+96442, dvrr_stack+52033, dvrr_stack+211333);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+67948, dvrr_stack+52129, dvrr_stack+614, dvrr_stack+96478, dvrr_stack+52069, dvrr_stack+19395);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+68074, dvrr_stack+35106, dvrr_stack+67948, dvrr_stack+479, dvrr_stack+52129, dvrr_stack+185551);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+68242, dvrr_stack+1975, dvrr_stack+4594, NULL, NULL, dvrr_stack+1969);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+68272, dvrr_stack+90679, dvrr_stack+68242, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+211363);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+68332, dvrr_stack+52219, dvrr_stack+68272, dvrr_stack+96538, dvrr_stack+90679, dvrr_stack+9365);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+47686, dvrr_stack+35232, dvrr_stack+68332, dvrr_stack+96568, dvrr_stack+52219, dvrr_stack+67888);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+163870, dvrr_stack+35332, dvrr_stack+47686, dvrr_stack+96628, dvrr_stack+35232, dvrr_stack+614);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+31432, dvrr_stack+3205, dvrr_stack+163870, dvrr_stack+96728, dvrr_stack+35332, dvrr_stack+67948);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+31712, dvrr_stack+1637, dvrr_stack+31432, dvrr_stack+96878, dvrr_stack+3205, dvrr_stack+68074);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+47836, dvrr_stack+4604, dvrr_stack+9329, NULL, NULL, dvrr_stack+4594);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+47881, dvrr_stack+52279, dvrr_stack+47836, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+68242);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+32422, dvrr_stack+90793, dvrr_stack+47881, dvrr_stack+219, dvrr_stack+52279, dvrr_stack+68272);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+32572, dvrr_stack+2318, dvrr_stack+32422, dvrr_stack+97088, dvrr_stack+90793, dvrr_stack+68332);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+47176, dvrr_stack+11317, dvrr_stack+32572, dvrr_stack+97178, dvrr_stack+2318, dvrr_stack+47686);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+96146, dvrr_stack+71678, dvrr_stack+47176, dvrr_stack+97328, dvrr_stack+11317, dvrr_stack+163870);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+97088, dvrr_stack+71993, dvrr_stack+96146, dvrr_stack+90115, dvrr_stack+71678, dvrr_stack+31432);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+584320, dvrr_stack+91643, dvrr_stack+97088, dvrr_stack+68434, dvrr_stack+71993, dvrr_stack+31712);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+90115, dvrr_stack+9344, dvrr_stack+19310, NULL, NULL, dvrr_stack+9329);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+90178, dvrr_stack+90883, dvrr_stack+90115, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+47836);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+8986, dvrr_stack+90946, dvrr_stack+90178, dvrr_stack+892, dvrr_stack+90883, dvrr_stack+47881);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+584995, dvrr_stack+72413, dvrr_stack+8986, dvrr_stack+955, dvrr_stack+90946, dvrr_stack+32422);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+585310, dvrr_stack+93458, dvrr_stack+584995, dvrr_stack+90430, dvrr_stack+72413, dvrr_stack+32572);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+585751, dvrr_stack+93773, dvrr_stack+585310, dvrr_stack+69907, dvrr_stack+93458, dvrr_stack+47176);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+586339, dvrr_stack+94214, dvrr_stack+585751, dvrr_stack+91202, dvrr_stack+93773, dvrr_stack+96146);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+587095, dvrr_stack+94802, dvrr_stack+586339, dvrr_stack+66886, dvrr_stack+94214, dvrr_stack+97088);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+588040, dvrr_stack+392847, dvrr_stack+587095, dvrr_stack+237120, dvrr_stack+94802, dvrr_stack+584320);
 tmp = dvrr_stack + 588040;
 target_ptr = Libderiv->dvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+69907, dvrr_stack+19331, dvrr_stack+32144, NULL, NULL, dvrr_stack+19310);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+69991, dvrr_stack+92807, dvrr_stack+69907, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+90115);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+892, dvrr_stack+92891, dvrr_stack+69991, dvrr_stack+2701, dvrr_stack+92807, dvrr_stack+90178);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+66805, dvrr_stack+93059, dvrr_stack+892, dvrr_stack+5123, dvrr_stack+92891, dvrr_stack+8986);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+589195, dvrr_stack+69255, dvrr_stack+66805, dvrr_stack+2021, dvrr_stack+93059, dvrr_stack+584995);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+589783, dvrr_stack+95558, dvrr_stack+589195, dvrr_stack+2785, dvrr_stack+69255, dvrr_stack+585310);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+590567, dvrr_stack+48723, dvrr_stack+589783, dvrr_stack+237876, dvrr_stack+95558, dvrr_stack+585751);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+591575, dvrr_stack+393792, dvrr_stack+590567, dvrr_stack+238464, dvrr_stack+48723, dvrr_stack+586339);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+592835, dvrr_stack+394800, dvrr_stack+591575, dvrr_stack+239248, dvrr_stack+393792, dvrr_stack+587095);
 tmp = dvrr_stack + 592835;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+594375,dvrr_stack+592835,dvrr_stack+588040,55);


 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+237876, dvrr_stack+32172, dvrr_stack+48030, NULL, NULL, dvrr_stack+32144);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+237984, dvrr_stack+117646, dvrr_stack+237876, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+69907);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238200, dvrr_stack+117754, dvrr_stack+237984, dvrr_stack+5571, dvrr_stack+117646, dvrr_stack+69991);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238560, dvrr_stack+117970, dvrr_stack+238200, dvrr_stack+5679, dvrr_stack+117754, dvrr_stack+892);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+597840, dvrr_stack+398895, dvrr_stack+238560, dvrr_stack+4647, dvrr_stack+117970, dvrr_stack+66805);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+598596, dvrr_stack+399435, dvrr_stack+597840, dvrr_stack+5895, dvrr_stack+398895, dvrr_stack+589195);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+599604, dvrr_stack+400191, dvrr_stack+598596, dvrr_stack+242524, dvrr_stack+399435, dvrr_stack+589783);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+600900, dvrr_stack+401199, dvrr_stack+599604, dvrr_stack+243280, dvrr_stack+400191, dvrr_stack+590567);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+602520, dvrr_stack+121202, dvrr_stack+600900, dvrr_stack+244288, dvrr_stack+401199, dvrr_stack+591575);
 tmp = dvrr_stack + 602520;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+604500,dvrr_stack+602520,dvrr_stack+592835,55);


 /* compute (9 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+609120,dvrr_stack+604500,dvrr_stack+594375,55);


 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+616050, dvrr_stack+609120, dvrr_stack+588040);

 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242524, dvrr_stack+48066, dvrr_stack+67722, NULL, NULL, dvrr_stack+48030);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242659, dvrr_stack+66670, dvrr_stack+242524, dvrr_stack+8770, dvrr_stack+48066, dvrr_stack+237876);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242929, dvrr_stack+118330, dvrr_stack+242659, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+237984);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+243379, dvrr_stack+32818, dvrr_stack+242929, dvrr_stack+10597, dvrr_stack+118330, dvrr_stack+238200);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+619515, dvrr_stack+414780, dvrr_stack+243379, dvrr_stack+10867, dvrr_stack+32818, dvrr_stack+238560);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+620460, dvrr_stack+415455, dvrr_stack+619515, dvrr_stack+255412, dvrr_stack+414780, dvrr_stack+597840);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+621720, dvrr_stack+416400, dvrr_stack+620460, dvrr_stack+256087, dvrr_stack+415455, dvrr_stack+598596);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+623340, dvrr_stack+417660, dvrr_stack+621720, dvrr_stack+257032, dvrr_stack+416400, dvrr_stack+599604);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+255412, dvrr_stack+131510, dvrr_stack+623340, dvrr_stack+258292, dvrr_stack+417660, dvrr_stack+600900);
 tmp = dvrr_stack + 255412;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+625365,dvrr_stack+255412,dvrr_stack+602520,55);


 /* compute (9 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+631305,dvrr_stack+625365,dvrr_stack+604500,55);


 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+640545, dvrr_stack+631305, dvrr_stack+592835);

 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+257887, dvrr_stack+67767, dvrr_stack+20221, NULL, NULL, dvrr_stack+67722);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+4171, dvrr_stack+257887, dvrr_stack+18607, dvrr_stack+67767, dvrr_stack+242524);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+9446, dvrr_stack+10462, dvrr_stack+20857, dvrr_stack+4171, dvrr_stack+242659);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+435480, dvrr_stack+4647, dvrr_stack+21022, dvrr_stack+9446, dvrr_stack+242929);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+645165, dvrr_stack+436030, dvrr_stack+5571, dvrr_stack+19440, dvrr_stack+435480, dvrr_stack+243379);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+646320, dvrr_stack+436855, dvrr_stack+645165, dvrr_stack+21352, dvrr_stack+436030, dvrr_stack+619515);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+647860, dvrr_stack+438010, dvrr_stack+646320, dvrr_stack+272872, dvrr_stack+436855, dvrr_stack+620460);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+649840, dvrr_stack+439550, dvrr_stack+647860, dvrr_stack+274027, dvrr_stack+438010, dvrr_stack+621720);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+652315, dvrr_stack+144920, dvrr_stack+649840, dvrr_stack+275567, dvrr_stack+439550, dvrr_stack+623340);
 tmp = dvrr_stack + 652315;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+655340,dvrr_stack+652315,dvrr_stack+255412,55);


 /* compute (9 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+662765,dvrr_stack+655340,dvrr_stack+625365,55);


 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+674645, dvrr_stack+662765, dvrr_stack+602520);

 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+272872, dvrr_stack+20276, dvrr_stack+32263, NULL, NULL, dvrr_stack+20221);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+273070, dvrr_stack+18662, dvrr_stack+272872, dvrr_stack+67822, dvrr_stack+20276, dvrr_stack+257887);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+273466, dvrr_stack+18860, dvrr_stack+273070, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+10462);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+274126, dvrr_stack+462185, dvrr_stack+273466, dvrr_stack+34050, dvrr_stack+18860, dvrr_stack+4647);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+462845, dvrr_stack+274126, dvrr_stack+34446, dvrr_stack+462185, dvrr_stack+5571);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+680585, dvrr_stack+463835, dvrr_stack+20857, dvrr_stack+294071, dvrr_stack+462845, dvrr_stack+645165);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+682433, dvrr_stack+465221, dvrr_stack+680585, dvrr_stack+295061, dvrr_stack+463835, dvrr_stack+646320);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+684809, dvrr_stack+467069, dvrr_stack+682433, dvrr_stack+296447, dvrr_stack+465221, dvrr_stack+647860);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+294071, dvrr_stack+469445, dvrr_stack+684809, dvrr_stack+298295, dvrr_stack+467069, dvrr_stack+649840);
 tmp = dvrr_stack + 294071;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+687779,dvrr_stack+294071,dvrr_stack+652315,55);


 /* compute (9 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+696854,dvrr_stack+687779,dvrr_stack+655340,55);


 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+711704, dvrr_stack+696854, dvrr_stack+255412);

 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+244054, dvrr_stack+48177, dvrr_stack+32329, NULL, NULL, dvrr_stack+32263);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+297701, dvrr_stack+161842, dvrr_stack+244054, dvrr_stack+47608, dvrr_stack+48177, dvrr_stack+272872);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+162076, dvrr_stack+297701, dvrr_stack+50278, dvrr_stack+161842, dvrr_stack+273070);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+719129, dvrr_stack+162544, dvrr_stack+33852, dvrr_stack+50512, dvrr_stack+162076, dvrr_stack+273466);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+720299, dvrr_stack+498065, dvrr_stack+719129, dvrr_stack+50980, dvrr_stack+162544, dvrr_stack+274126);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+721937, dvrr_stack+499235, dvrr_stack+720299, dvrr_stack+321191, dvrr_stack+498065, dvrr_stack+20857);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+724121, dvrr_stack+500873, dvrr_stack+721937, dvrr_stack+322361, dvrr_stack+499235, dvrr_stack+680585);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+726929, dvrr_stack+503057, dvrr_stack+724121, dvrr_stack+323999, dvrr_stack+500873, dvrr_stack+682433);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+321191, dvrr_stack+182026, dvrr_stack+726929, dvrr_stack+326183, dvrr_stack+503057, dvrr_stack+684809);

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+730439,dvrr_stack+321191,dvrr_stack+294071,55);


 /* compute (9 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+741329,dvrr_stack+730439,dvrr_stack+687779,55);


 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,3025,dvrr_stack+759479, dvrr_stack+741329, dvrr_stack+652315);

 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+69085, dvrr_stack+210, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, dvrr_stack+0, dvrr_stack+69085, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+68854, dvrr_stack+213, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+185536, dvrr_stack+1985, dvrr_stack+68860, dvrr_stack+882, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+68870, dvrr_stack+185536, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+90640, dvrr_stack+2000, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+219, dvrr_stack+122822, dvrr_stack+19359, dvrr_stack+68885, dvrr_stack+4619, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+133535, dvrr_stack+219, dvrr_stack+68913, dvrr_stack+122822, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+67822, dvrr_stack+147395, dvrr_stack+18607, dvrr_stack+9401, dvrr_stack+133535, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+325481, dvrr_stack+48111, dvrr_stack+67822, dvrr_stack+264, dvrr_stack+147395, NULL);

 /* compute (0 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+32329, dvrr_stack+325481, dvrr_stack+32263, dvrr_stack+48111, NULL);

 /* compute (1 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+325559, dvrr_stack+48255, dvrr_stack+69088, NULL, NULL, dvrr_stack+32329);

 /* compute (2 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+48346, dvrr_stack+325559, dvrr_stack+68949, dvrr_stack+48255, dvrr_stack+244054);

 /* compute (3 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50824, dvrr_stack+163324, dvrr_stack+50278, dvrr_stack+51760, dvrr_stack+48346, dvrr_stack+297701);

 /* compute (4 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+768554, dvrr_stack+537050, dvrr_stack+50824, dvrr_stack+70222, dvrr_stack+163324, dvrr_stack+33852);

 /* compute (5 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+769919, dvrr_stack+537960, dvrr_stack+768554, dvrr_stack+70768, dvrr_stack+537050, dvrr_stack+719129);

 /* compute (6 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+771830, dvrr_stack+539325, dvrr_stack+769919, dvrr_stack+353939, dvrr_stack+537960, dvrr_stack+720299);

 /* compute (7 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+774378, dvrr_stack+541236, dvrr_stack+771830, dvrr_stack+355304, dvrr_stack+539325, dvrr_stack+721937);

 /* compute (8 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+777654, dvrr_stack+543784, dvrr_stack+774378, dvrr_stack+357215, dvrr_stack+541236, dvrr_stack+724121);

 /* compute (9 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+353939, dvrr_stack+207202, dvrr_stack+777654, dvrr_stack+359763, dvrr_stack+543784, dvrr_stack+726929);

 /* compute (9 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+781749,dvrr_stack+353939,dvrr_stack+321191,55);


 /* compute (9 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+794619,dvrr_stack+781749,dvrr_stack+730439,55);


 /* compute (9 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,3630,dvrr_stack+816399, dvrr_stack+794619, dvrr_stack+294071);

 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+358944, dvrr_stack+211297, dvrr_stack+0, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+47971, dvrr_stack+15, dvrr_stack+358944, dvrr_stack+69179, dvrr_stack+211297, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+358950, dvrr_stack+111, dvrr_stack+47971, dvrr_stack+69182, dvrr_stack+15, NULL);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+32797, dvrr_stack+211300, dvrr_stack+358950, dvrr_stack+69188, dvrr_stack+111, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+69179, dvrr_stack+704, dvrr_stack+1966, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+358965, dvrr_stack+569, dvrr_stack+69179, dvrr_stack+873, dvrr_stack+704, dvrr_stack+0);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+358983, dvrr_stack+211315, dvrr_stack+358965, dvrr_stack+69198, dvrr_stack+569, dvrr_stack+358944);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+359013, dvrr_stack+211333, dvrr_stack+358983, dvrr_stack+69207, dvrr_stack+211315, dvrr_stack+47971);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+359058, dvrr_stack+19395, dvrr_stack+359013, dvrr_stack+69225, dvrr_stack+211333, dvrr_stack+358950);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+359121, dvrr_stack+185551, dvrr_stack+359058, dvrr_stack+69040, dvrr_stack+19395, dvrr_stack+32797);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+69198, dvrr_stack+1969, dvrr_stack+1603, NULL, NULL, dvrr_stack+1966);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+11542, dvrr_stack+211363, dvrr_stack+69198, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+69179);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+359205, dvrr_stack+9365, dvrr_stack+11542, dvrr_stack+30, dvrr_stack+211363, dvrr_stack+358965);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+359265, dvrr_stack+67888, dvrr_stack+359205, dvrr_stack+52033, dvrr_stack+9365, dvrr_stack+358983);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+298169, dvrr_stack+614, dvrr_stack+359265, dvrr_stack+52069, dvrr_stack+67888, dvrr_stack+359013);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+359355, dvrr_stack+67948, dvrr_stack+298169, dvrr_stack+52129, dvrr_stack+614, dvrr_stack+359058);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+359523, dvrr_stack+68074, dvrr_stack+359355, dvrr_stack+35106, dvrr_stack+67948, dvrr_stack+359121);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+69216, dvrr_stack+4594, dvrr_stack+9319, NULL, NULL, dvrr_stack+1603);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+68949, dvrr_stack+68242, dvrr_stack+69216, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+69198);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+325832, dvrr_stack+68272, dvrr_stack+68949, dvrr_stack+90679, dvrr_stack+68242, dvrr_stack+11542);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+325932, dvrr_stack+68332, dvrr_stack+325832, dvrr_stack+52219, dvrr_stack+68272, dvrr_stack+359205);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+8770, dvrr_stack+47686, dvrr_stack+325932, dvrr_stack+35232, dvrr_stack+68332, dvrr_stack+359265);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+51734, dvrr_stack+163870, dvrr_stack+8770, dvrr_stack+35332, dvrr_stack+47686, dvrr_stack+298169);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+34632, dvrr_stack+31432, dvrr_stack+51734, dvrr_stack+3205, dvrr_stack+163870, dvrr_stack+359355);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+275116, dvrr_stack+31712, dvrr_stack+34632, dvrr_stack+1637, dvrr_stack+31432, dvrr_stack+359523);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+35232, dvrr_stack+9329, dvrr_stack+19295, NULL, NULL, dvrr_stack+9319);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+35277, dvrr_stack+47836, dvrr_stack+35232, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+69216);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+35367, dvrr_stack+47881, dvrr_stack+35277, dvrr_stack+52279, dvrr_stack+47836, dvrr_stack+68949);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+52014, dvrr_stack+32422, dvrr_stack+35367, dvrr_stack+90793, dvrr_stack+47881, dvrr_stack+325832);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+19440, dvrr_stack+32572, dvrr_stack+52014, dvrr_stack+2318, dvrr_stack+32422, dvrr_stack+325932);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+19755, dvrr_stack+47176, dvrr_stack+19440, dvrr_stack+11317, dvrr_stack+32572, dvrr_stack+8770);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+10792, dvrr_stack+96146, dvrr_stack+19755, dvrr_stack+71678, dvrr_stack+47176, dvrr_stack+51734);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+2701, dvrr_stack+97088, dvrr_stack+10792, dvrr_stack+71993, dvrr_stack+96146, dvrr_stack+34632);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+70159, dvrr_stack+584320, dvrr_stack+2701, dvrr_stack+91643, dvrr_stack+97088, dvrr_stack+275116);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2318, dvrr_stack+19310, dvrr_stack+32123, NULL, NULL, dvrr_stack+19295);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+258052, dvrr_stack+90115, dvrr_stack+2318, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+35232);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+11332, dvrr_stack+90178, dvrr_stack+258052, dvrr_stack+90883, dvrr_stack+90115, dvrr_stack+35277);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+70984, dvrr_stack+8986, dvrr_stack+11332, dvrr_stack+90946, dvrr_stack+90178, dvrr_stack+35367);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+90793, dvrr_stack+584995, dvrr_stack+70984, dvrr_stack+72413, dvrr_stack+8986, dvrr_stack+52014);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+71299, dvrr_stack+585310, dvrr_stack+90793, dvrr_stack+93458, dvrr_stack+584995, dvrr_stack+19440);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+71887, dvrr_stack+585751, dvrr_stack+71299, dvrr_stack+93773, dvrr_stack+585310, dvrr_stack+19755);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+827289, dvrr_stack+586339, dvrr_stack+71887, dvrr_stack+94214, dvrr_stack+585751, dvrr_stack+10792);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+93339, dvrr_stack+587095, dvrr_stack+827289, dvrr_stack+94802, dvrr_stack+586339, dvrr_stack+2701);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+828234, dvrr_stack+588040, dvrr_stack+93339, dvrr_stack+392847, dvrr_stack+587095, dvrr_stack+70159);
 tmp = dvrr_stack + 828234;
 target_ptr = Libderiv->dvrr_classes[10][5];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2381, dvrr_stack+32144, dvrr_stack+48002, NULL, NULL, dvrr_stack+32123);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+91234, dvrr_stack+69907, dvrr_stack+2381, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+2318);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2021, dvrr_stack+69991, dvrr_stack+91234, dvrr_stack+92807, dvrr_stack+69907, dvrr_stack+258052);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+94494, dvrr_stack+892, dvrr_stack+2021, dvrr_stack+92891, dvrr_stack+69991, dvrr_stack+11332);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+94914, dvrr_stack+66805, dvrr_stack+94494, dvrr_stack+93059, dvrr_stack+892, dvrr_stack+70984);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+829620, dvrr_stack+589195, dvrr_stack+94914, dvrr_stack+69255, dvrr_stack+66805, dvrr_stack+90793);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+830404, dvrr_stack+589783, dvrr_stack+829620, dvrr_stack+95558, dvrr_stack+589195, dvrr_stack+71299);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+831412, dvrr_stack+590567, dvrr_stack+830404, dvrr_stack+48723, dvrr_stack+589783, dvrr_stack+71887);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+832672, dvrr_stack+591575, dvrr_stack+831412, dvrr_stack+393792, dvrr_stack+590567, dvrr_stack+827289);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+834212, dvrr_stack+592835, dvrr_stack+832672, dvrr_stack+394800, dvrr_stack+591575, dvrr_stack+93339);
 tmp = dvrr_stack + 834212;
 target_ptr = Libderiv->dvrr_classes[10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+836060,dvrr_stack+834212,dvrr_stack+828234,66);


 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+393792, dvrr_stack+48030, dvrr_stack+67686, NULL, NULL, dvrr_stack+48002);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+393900, dvrr_stack+237876, dvrr_stack+393792, dvrr_stack+32172, dvrr_stack+48030, dvrr_stack+2381);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+394116, dvrr_stack+237984, dvrr_stack+393900, dvrr_stack+117646, dvrr_stack+237876, dvrr_stack+91234);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+69246, dvrr_stack+238200, dvrr_stack+394116, dvrr_stack+117754, dvrr_stack+237984, dvrr_stack+2021);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48619, dvrr_stack+238560, dvrr_stack+69246, dvrr_stack+117970, dvrr_stack+238200, dvrr_stack+94494);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+840218, dvrr_stack+597840, dvrr_stack+48619, dvrr_stack+398895, dvrr_stack+238560, dvrr_stack+94914);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+841226, dvrr_stack+598596, dvrr_stack+840218, dvrr_stack+399435, dvrr_stack+597840, dvrr_stack+829620);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+842522, dvrr_stack+599604, dvrr_stack+841226, dvrr_stack+400191, dvrr_stack+598596, dvrr_stack+830404);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+398895, dvrr_stack+600900, dvrr_stack+842522, dvrr_stack+401199, dvrr_stack+599604, dvrr_stack+831412);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+844142, dvrr_stack+602520, dvrr_stack+398895, dvrr_stack+121202, dvrr_stack+600900, dvrr_stack+832672);
 tmp = dvrr_stack + 844142;
 target_ptr = Libderiv->dvrr_classes[10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+846518,dvrr_stack+844142,dvrr_stack+834212,66);


 /* compute (10 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+852062,dvrr_stack+846518,dvrr_stack+836060,66);


 /* compute (10 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1386,dvrr_stack+860378, dvrr_stack+852062, dvrr_stack+828234);

 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+400875, dvrr_stack+67722, dvrr_stack+20176, NULL, NULL, dvrr_stack+67686);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+401010, dvrr_stack+242524, dvrr_stack+400875, dvrr_stack+48066, dvrr_stack+67722, dvrr_stack+393792);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+401280, dvrr_stack+242659, dvrr_stack+401010, dvrr_stack+66670, dvrr_stack+242524, dvrr_stack+393900);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+401730, dvrr_stack+242929, dvrr_stack+401280, dvrr_stack+118330, dvrr_stack+242659, dvrr_stack+394116);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+117646, dvrr_stack+243379, dvrr_stack+401730, dvrr_stack+32818, dvrr_stack+242929, dvrr_stack+69246);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+864536, dvrr_stack+619515, dvrr_stack+117646, dvrr_stack+414780, dvrr_stack+243379, dvrr_stack+48619);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+865796, dvrr_stack+620460, dvrr_stack+864536, dvrr_stack+415455, dvrr_stack+619515, dvrr_stack+840218);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+867416, dvrr_stack+621720, dvrr_stack+865796, dvrr_stack+416400, dvrr_stack+620460, dvrr_stack+841226);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+414780, dvrr_stack+623340, dvrr_stack+867416, dvrr_stack+417660, dvrr_stack+621720, dvrr_stack+842522);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+869441, dvrr_stack+255412, dvrr_stack+414780, dvrr_stack+131510, dvrr_stack+623340, dvrr_stack+398895);
 tmp = dvrr_stack + 869441;
 target_ptr = Libderiv->dvrr_classes[10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+872411,dvrr_stack+869441,dvrr_stack+844142,66);


 /* compute (10 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+879539,dvrr_stack+872411,dvrr_stack+846518,66);


 /* compute (10 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1848,dvrr_stack+890627, dvrr_stack+879539, dvrr_stack+834212);

 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+417255, dvrr_stack+20221, dvrr_stack+264, NULL, NULL, dvrr_stack+20176);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+417420, dvrr_stack+257887, dvrr_stack+417255, dvrr_stack+67767, dvrr_stack+20221, dvrr_stack+400875);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+417750, dvrr_stack+10462, dvrr_stack+417420, dvrr_stack+4171, dvrr_stack+257887, dvrr_stack+401010);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+418300, dvrr_stack+4647, dvrr_stack+417750, dvrr_stack+9446, dvrr_stack+10462, dvrr_stack+401280);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+896171, dvrr_stack+5571, dvrr_stack+418300, dvrr_stack+435480, dvrr_stack+4647, dvrr_stack+401730);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+897326, dvrr_stack+645165, dvrr_stack+896171, dvrr_stack+436030, dvrr_stack+5571, dvrr_stack+117646);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+898866, dvrr_stack+646320, dvrr_stack+897326, dvrr_stack+436855, dvrr_stack+645165, dvrr_stack+864536);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+435480, dvrr_stack+647860, dvrr_stack+898866, dvrr_stack+438010, dvrr_stack+646320, dvrr_stack+865796);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+900846, dvrr_stack+649840, dvrr_stack+435480, dvrr_stack+439550, dvrr_stack+647860, dvrr_stack+867416);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+903871, dvrr_stack+652315, dvrr_stack+900846, dvrr_stack+144920, dvrr_stack+649840, dvrr_stack+414780);
 tmp = dvrr_stack + 903871;
 target_ptr = Libderiv->dvrr_classes[10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+907501,dvrr_stack+903871,dvrr_stack+869441,66);


 /* compute (10 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+916411,dvrr_stack+907501,dvrr_stack+872411,66);


 /* compute (10 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2376,dvrr_stack+930667, dvrr_stack+916411, dvrr_stack+844142);

 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+437955, dvrr_stack+32263, dvrr_stack+48111, NULL, NULL, dvrr_stack+264);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+438153, dvrr_stack+272872, dvrr_stack+437955, dvrr_stack+20276, dvrr_stack+32263, dvrr_stack+417255);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+438549, dvrr_stack+273070, dvrr_stack+438153, dvrr_stack+18662, dvrr_stack+272872, dvrr_stack+417420);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+439209, dvrr_stack+273466, dvrr_stack+438549, dvrr_stack+18860, dvrr_stack+273070, dvrr_stack+417750);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+937795, dvrr_stack+274126, dvrr_stack+439209, dvrr_stack+462185, dvrr_stack+273466, dvrr_stack+418300);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+939181, dvrr_stack+20857, dvrr_stack+937795, dvrr_stack+462845, dvrr_stack+274126, dvrr_stack+896171);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+941029, dvrr_stack+680585, dvrr_stack+939181, dvrr_stack+463835, dvrr_stack+20857, dvrr_stack+897326);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+462185, dvrr_stack+682433, dvrr_stack+941029, dvrr_stack+465221, dvrr_stack+680585, dvrr_stack+898866);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+943405, dvrr_stack+684809, dvrr_stack+462185, dvrr_stack+467069, dvrr_stack+682433, dvrr_stack+435480);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+947035, dvrr_stack+294071, dvrr_stack+943405, dvrr_stack+469445, dvrr_stack+684809, dvrr_stack+900846);

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+951391,dvrr_stack+947035,dvrr_stack+903871,66);


 /* compute (10 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+962281,dvrr_stack+951391,dvrr_stack+907501,66);


 /* compute (10 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2970,dvrr_stack+980101, dvrr_stack+962281, dvrr_stack+869441);

 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+465155, dvrr_stack+32329, dvrr_stack+325481, NULL, NULL, dvrr_stack+48111);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+465389, dvrr_stack+244054, dvrr_stack+465155, dvrr_stack+48177, dvrr_stack+32329, dvrr_stack+437955);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+465857, dvrr_stack+297701, dvrr_stack+465389, dvrr_stack+161842, dvrr_stack+244054, dvrr_stack+438153);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+466637, dvrr_stack+33852, dvrr_stack+465857, dvrr_stack+162076, dvrr_stack+297701, dvrr_stack+438549);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+467807, dvrr_stack+719129, dvrr_stack+466637, dvrr_stack+162544, dvrr_stack+33852, dvrr_stack+439209);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+989011, dvrr_stack+720299, dvrr_stack+467807, dvrr_stack+498065, dvrr_stack+719129, dvrr_stack+937795);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+991195, dvrr_stack+721937, dvrr_stack+989011, dvrr_stack+499235, dvrr_stack+720299, dvrr_stack+939181);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+994003, dvrr_stack+724121, dvrr_stack+991195, dvrr_stack+500873, dvrr_stack+721937, dvrr_stack+941029);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+498065, dvrr_stack+726929, dvrr_stack+994003, dvrr_stack+503057, dvrr_stack+724121, dvrr_stack+462185);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+997513, dvrr_stack+321191, dvrr_stack+498065, dvrr_stack+182026, dvrr_stack+726929, dvrr_stack+943405);

 /* compute (10 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+1002661,dvrr_stack+997513,dvrr_stack+947035,66);


 /* compute (10 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+1015729,dvrr_stack+1002661,dvrr_stack+951391,66);


 /* compute (10 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,3630,dvrr_stack+1037509, dvrr_stack+1015729, dvrr_stack+903871);

 /* compute (0 0 | 1 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+873, Data->F+21, Data->F+22, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+502355, dvrr_stack+210, dvrr_stack+873, Data->F+20, Data->F+21, NULL);

 /* compute (0 0 | 3 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1975, dvrr_stack+876, dvrr_stack+502355, dvrr_stack+69085, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4604, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+213, dvrr_stack+876, NULL);

 /* compute (0 0 | 5 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+9344, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+882, dvrr_stack+2308, NULL);

 /* compute (0 0 | 6 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19331, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+185536, dvrr_stack+1985, NULL);

 /* compute (0 0 | 7 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+502355, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+2000, dvrr_stack+593, NULL);

 /* compute (0 0 | 8 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+48066, dvrr_stack+19359, dvrr_stack+502355, dvrr_stack+4619, dvrr_stack+1609, NULL);

 /* compute (0 0 | 9 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67767, dvrr_stack+219, dvrr_stack+48066, dvrr_stack+122822, dvrr_stack+19359, NULL);

 /* compute (0 0 | 10 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+502355, dvrr_stack+18607, dvrr_stack+67767, dvrr_stack+133535, dvrr_stack+219, NULL);

 /* compute (0 0 | 11 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48177, dvrr_stack+67822, dvrr_stack+502355, dvrr_stack+147395, dvrr_stack+18607, NULL);

 /* compute (0 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+32172, dvrr_stack+325481, dvrr_stack+48177, dvrr_stack+48111, dvrr_stack+67822, NULL);

 /* compute (1 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+502421, dvrr_stack+69088, dvrr_stack+32172, NULL, NULL, dvrr_stack+325481);

 /* compute (2 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+502694, dvrr_stack+325559, dvrr_stack+502421, dvrr_stack+48255, dvrr_stack+69088, dvrr_stack+465155);

 /* compute (3 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+503240, dvrr_stack+50278, dvrr_stack+502694, dvrr_stack+48346, dvrr_stack+325559, dvrr_stack+465389);

 /* compute (4 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+504150, dvrr_stack+50824, dvrr_stack+503240, dvrr_stack+163324, dvrr_stack+50278, dvrr_stack+465857);

 /* compute (5 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+161842, dvrr_stack+768554, dvrr_stack+504150, dvrr_stack+537050, dvrr_stack+50824, dvrr_stack+466637);

 /* compute (6 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+502421, dvrr_stack+769919, dvrr_stack+161842, dvrr_stack+537960, dvrr_stack+768554, dvrr_stack+467807);

 /* compute (7 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+1048399, dvrr_stack+771830, dvrr_stack+502421, dvrr_stack+539325, dvrr_stack+769919, dvrr_stack+989011);

 /* compute (8 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+537050, dvrr_stack+774378, dvrr_stack+1048399, dvrr_stack+541236, dvrr_stack+771830, dvrr_stack+991195);

 /* compute (9 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+768554, dvrr_stack+777654, dvrr_stack+537050, dvrr_stack+543784, dvrr_stack+774378, dvrr_stack+994003);

 /* compute (10 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+537050, dvrr_stack+353939, dvrr_stack+768554, dvrr_stack+207202, dvrr_stack+777654, dvrr_stack+498065);

 /* compute (10 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+1048399,dvrr_stack+537050,dvrr_stack+997513,66);


 /* compute (10 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+1063843,dvrr_stack+1048399,dvrr_stack+1002661,66);


 /* compute (10 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,4356,dvrr_stack+768554, dvrr_stack+1063843, dvrr_stack+947035);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+543056, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+544379, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+502421, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+1089979, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+1092814, dvrr_stack+79720, dvrr_stack+36382);

 /* compute (5 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1386,dvrr_stack+1096279, dvrr_stack+104584, dvrr_stack+53314);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+161842, dvrr_stack+126218, dvrr_stack+117058);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+1100437, dvrr_stack+137864, dvrr_stack+118654);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+1102789, dvrr_stack+152770, dvrr_stack+122858);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+1105813, dvrr_stack+170686, dvrr_stack+133580);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+1109593, dvrr_stack+193342, dvrr_stack+147450);

 /* compute (6 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1848,dvrr_stack+1114213, dvrr_stack+220488, dvrr_stack+164218);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+1119757, dvrr_stack+248608, dvrr_stack+237120);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+1122025, dvrr_stack+263800, dvrr_stack+239248);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1296,dvrr_stack+1125049, dvrr_stack+282407, dvrr_stack+244288);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+1128937, dvrr_stack+306611, dvrr_stack+258292);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+1133797, dvrr_stack+336119, dvrr_stack+275567);

 /* compute (7 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2376,dvrr_stack+1139737, dvrr_stack+371463, dvrr_stack+298295);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+1146865, dvrr_stack+406275, dvrr_stack+392847);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+1149700, dvrr_stack+424140, dvrr_stack+394800);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+1153480, dvrr_stack+447605, dvrr_stack+121202);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2025,dvrr_stack+1158340, dvrr_stack+479840, dvrr_stack+131510);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+1164415, dvrr_stack+514775, dvrr_stack+144920);

 /* compute (8 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2970,dvrr_stack+1171840, dvrr_stack+557590, dvrr_stack+469445);

 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+1180750, dvrr_stack+609120, dvrr_stack+588040);

 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+1184215, dvrr_stack+631305, dvrr_stack+592835);

 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+1188835, dvrr_stack+662765, dvrr_stack+602520);

 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+1194775, dvrr_stack+696854, dvrr_stack+255412);

 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,3025,dvrr_stack+1202200, dvrr_stack+741329, dvrr_stack+652315);

 /* compute (9 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,3630,dvrr_stack+1211275, dvrr_stack+794619, dvrr_stack+294071);

 /* compute (10 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1386,dvrr_stack+1222165, dvrr_stack+852062, dvrr_stack+828234);

 /* compute (10 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1848,dvrr_stack+1226323, dvrr_stack+879539, dvrr_stack+834212);

 /* compute (10 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2376,dvrr_stack+1231867, dvrr_stack+916411, dvrr_stack+844142);

 /* compute (10 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2970,dvrr_stack+1238995, dvrr_stack+962281, dvrr_stack+869441);

 /* compute (10 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,3630,dvrr_stack+1247905, dvrr_stack+1015729, dvrr_stack+903871);

 /* compute (10 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,4356,dvrr_stack+1258795, dvrr_stack+1063843, dvrr_stack+947035);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+50278, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+14638, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+26140, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+40372, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+58165, dvrr_stack+79720, dvrr_stack+36382);

 /* compute (5 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1386,dvrr_stack+79720, dvrr_stack+104584, dvrr_stack+53314);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+104584, dvrr_stack+126218, dvrr_stack+117058);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+126218, dvrr_stack+137864, dvrr_stack+118654);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+137864, dvrr_stack+152770, dvrr_stack+122858);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+152770, dvrr_stack+170686, dvrr_stack+133580);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+170686, dvrr_stack+193342, dvrr_stack+147450);

 /* compute (6 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1848,dvrr_stack+193342, dvrr_stack+220488, dvrr_stack+164218);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+156550, dvrr_stack+248608, dvrr_stack+237120);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+248608, dvrr_stack+263800, dvrr_stack+239248);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1296,dvrr_stack+263800, dvrr_stack+282407, dvrr_stack+244288);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+282407, dvrr_stack+306611, dvrr_stack+258292);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+306611, dvrr_stack+336119, dvrr_stack+275567);

 /* compute (7 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2376,dvrr_stack+336119, dvrr_stack+371463, dvrr_stack+298295);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+371463, dvrr_stack+406275, dvrr_stack+392847);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+312551, dvrr_stack+424140, dvrr_stack+394800);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+424140, dvrr_stack+447605, dvrr_stack+121202);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2025,dvrr_stack+447605, dvrr_stack+479840, dvrr_stack+131510);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+479840, dvrr_stack+514775, dvrr_stack+144920);

 /* compute (8 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2970,dvrr_stack+514775, dvrr_stack+557590, dvrr_stack+469445);

 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+557590, dvrr_stack+609120, dvrr_stack+588040);

 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+609120, dvrr_stack+631305, dvrr_stack+592835);

 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+523685, dvrr_stack+662765, dvrr_stack+602520);

 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+662765, dvrr_stack+696854, dvrr_stack+255412);

 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,3025,dvrr_stack+696854, dvrr_stack+741329, dvrr_stack+652315);

 /* compute (9 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,3630,dvrr_stack+741329, dvrr_stack+794619, dvrr_stack+294071);

 /* compute (10 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1386,dvrr_stack+794619, dvrr_stack+852062, dvrr_stack+828234);

 /* compute (10 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1848,dvrr_stack+852062, dvrr_stack+879539, dvrr_stack+834212);

 /* compute (10 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2376,dvrr_stack+879539, dvrr_stack+916411, dvrr_stack+844142);

 /* compute (10 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2970,dvrr_stack+916411, dvrr_stack+962281, dvrr_stack+869441);

 /* compute (10 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,3630,dvrr_stack+962281, dvrr_stack+1015729, dvrr_stack+903871);

 /* compute (10 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,4356,dvrr_stack+1015729, dvrr_stack+1063843, dvrr_stack+947035);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1063843, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22243, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+4);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1063846, dvrr_stack+22243, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+1063843);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1063864, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+122822, dvrr_stack+1063864, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+22243);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1063882, dvrr_stack+122822, dvrr_stack+75, dvrr_stack+1063864, dvrr_stack+57, dvrr_stack+1063846);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+24, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+1063942, dvrr_stack+24, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+1063864);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+1064002, dvrr_stack+1063942, dvrr_stack+319, dvrr_stack+24, dvrr_stack+180, dvrr_stack+122822);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+1064102, dvrr_stack+1064002, dvrr_stack+379, dvrr_stack+1063942, dvrr_stack+319, dvrr_stack+1063882);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+48066, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+402405, dvrr_stack+48066, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+24);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1064252, dvrr_stack+402405, dvrr_stack+783, dvrr_stack+48066, dvrr_stack+738, dvrr_stack+1063942);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1064402, dvrr_stack+1064252, dvrr_stack+1192, dvrr_stack+402405, dvrr_stack+783, dvrr_stack+1064002);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+1064627, dvrr_stack+1064402, dvrr_stack+1342, dvrr_stack+1064252, dvrr_stack+1192, dvrr_stack+1064102);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+1064942,dvrr_stack+3730,dvrr_stack+1064627,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+1065887, dvrr_stack+1064942, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+1066202, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 1066202;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+1066790, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 1066790;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+1067231, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 1067231;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+1067987, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 1067987;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+1068932, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 1068932;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+1070087, dvrr_stack+75562, NULL);
 tmp = dvrr_stack + 1070087;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+1071473, dvrr_stack+99670, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+1064252, dvrr_stack+1063843, dvrr_stack+4336, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+1064258, dvrr_stack+1063846, dvrr_stack+90661, dvrr_stack+22243, dvrr_stack+6, dvrr_stack+1064252);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+402405, dvrr_stack+1063882, dvrr_stack+90733, dvrr_stack+122822, dvrr_stack+75, dvrr_stack+1064258);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+1073111, dvrr_stack+1064102, dvrr_stack+9952, dvrr_stack+1064002, dvrr_stack+379, dvrr_stack+402405);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+1073321, dvrr_stack+1064627, dvrr_stack+92492, dvrr_stack+1064402, dvrr_stack+1342, dvrr_stack+1073111);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+28408,dvrr_stack+117058,dvrr_stack+1073321,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+1073741, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+1074161, dvrr_stack+123866, NULL);
 tmp = dvrr_stack + 1074161;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+1074945, dvrr_stack+119438, NULL);
 tmp = dvrr_stack + 1074945;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+1075533, dvrr_stack+134840, NULL);
 tmp = dvrr_stack + 1075533;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+1076541, dvrr_stack+148990, NULL);
 tmp = dvrr_stack + 1076541;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+1077801, dvrr_stack+166066, NULL);
 tmp = dvrr_stack + 1077801;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+1079341, dvrr_stack+187798, NULL);
 tmp = dvrr_stack + 1079341;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+1081189, dvrr_stack+213936, NULL);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+1064288, dvrr_stack+1064252, dvrr_stack+32092, dvrr_stack+1063843, dvrr_stack+4336, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+48066, dvrr_stack+1064258, dvrr_stack+131, dvrr_stack+1063846, dvrr_stack+90661, dvrr_stack+1064288);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+723, dvrr_stack+402405, dvrr_stack+479, dvrr_stack+1063882, dvrr_stack+90733, dvrr_stack+48066);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+1083373, dvrr_stack+1073111, dvrr_stack+96878, dvrr_stack+1064102, dvrr_stack+9952, dvrr_stack+723);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1083653, dvrr_stack+1073321, dvrr_stack+68434, dvrr_stack+1064627, dvrr_stack+92492, dvrr_stack+1083373);

 /* compute (7 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+1084193,dvrr_stack+237120,dvrr_stack+1083653,36);


 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+1085813, dvrr_stack+1084193, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+1086353, dvrr_stack+245584, NULL);
 tmp = dvrr_stack + 1086353;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+1087361, dvrr_stack+240256, NULL);
 tmp = dvrr_stack + 1087361;
 target_ptr = Libderiv->deriv_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+1088117, dvrr_stack+259912, NULL);
 tmp = dvrr_stack + 1088117;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+1028797, dvrr_stack+277547, NULL);
 tmp = dvrr_stack + 1028797;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+1030417, dvrr_stack+300671, NULL);
 tmp = dvrr_stack + 1030417;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+1032397, dvrr_stack+328991, NULL);
 tmp = dvrr_stack + 1032397;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+973171, dvrr_stack+363039, NULL);

 /* compute (4 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+185536, dvrr_stack+1064288, dvrr_stack+69188, dvrr_stack+1064252, dvrr_stack+32092, NULL);

 /* compute (5 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+118591, dvrr_stack+48066, dvrr_stack+69040, dvrr_stack+1064258, dvrr_stack+131, dvrr_stack+185536);

 /* compute (6 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+1089413, dvrr_stack+723, dvrr_stack+35106, dvrr_stack+402405, dvrr_stack+479, dvrr_stack+118591);

 /* compute (7 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+1089581, dvrr_stack+1083373, dvrr_stack+1637, dvrr_stack+1073111, dvrr_stack+96878, dvrr_stack+1089413);

 /* compute (8 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1034773, dvrr_stack+1083653, dvrr_stack+91643, dvrr_stack+1073321, dvrr_stack+68434, dvrr_stack+1089581);

 /* compute (8 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+1035448,dvrr_stack+392847,dvrr_stack+1034773,45);


 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+975979, dvrr_stack+1035448, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+976654, dvrr_stack+402495, NULL);
 tmp = dvrr_stack + 976654;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+977914, dvrr_stack+396060, NULL);
 tmp = dvrr_stack + 977914;
 target_ptr = Libderiv->deriv_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+925321, dvrr_stack+419280, NULL);
 tmp = dvrr_stack + 925321;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+926941, dvrr_stack+441530, NULL);
 tmp = dvrr_stack + 926941;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+886667, dvrr_stack+472415, NULL);
 tmp = dvrr_stack + 886667;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+798777, dvrr_stack+505865, NULL);
 tmp = dvrr_stack + 798777;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+801747, dvrr_stack+547060, NULL);

 /* compute (5 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+9344, dvrr_stack+185536, dvrr_stack+211300, dvrr_stack+1064288, dvrr_stack+69188, NULL);

 /* compute (6 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+1064298, dvrr_stack+118591, dvrr_stack+185551, dvrr_stack+48066, dvrr_stack+69040, dvrr_stack+9344);

 /* compute (7 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+1089413, dvrr_stack+68074, dvrr_stack+723, dvrr_stack+35106, dvrr_stack+1064298);

 /* compute (8 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+978859, dvrr_stack+1089581, dvrr_stack+31712, dvrr_stack+1083373, dvrr_stack+1637, dvrr_stack+319);

 /* compute (9 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+928966, dvrr_stack+1034773, dvrr_stack+584320, dvrr_stack+1083653, dvrr_stack+91643, dvrr_stack+978859);

 /* compute (9 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+857606,dvrr_stack+588040,dvrr_stack+928966,55);


 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+929791, dvrr_stack+857606, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+805257, dvrr_stack+604500, NULL);
 tmp = dvrr_stack + 805257;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+889142, dvrr_stack+594375, NULL);
 tmp = dvrr_stack + 889142;
 target_ptr = Libderiv->deriv_classes[9][5][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+806797, dvrr_stack+625365, NULL);
 tmp = dvrr_stack + 806797;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+808777, dvrr_stack+655340, NULL);
 tmp = dvrr_stack + 808777;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+811252, dvrr_stack+687779, NULL);
 tmp = dvrr_stack + 811252;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+752219, dvrr_stack+730439, NULL);
 tmp = dvrr_stack + 752219;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+705929, dvrr_stack+781749, NULL);

 /* compute (6 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+131, dvrr_stack+9344, dvrr_stack+32797, dvrr_stack+185536, dvrr_stack+211300, NULL);

 /* compute (7 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+979309, dvrr_stack+1064298, dvrr_stack+359121, dvrr_stack+118591, dvrr_stack+185551, dvrr_stack+131);

 /* compute (8 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+979417, dvrr_stack+319, dvrr_stack+359523, dvrr_stack+1089413, dvrr_stack+68074, dvrr_stack+979309);

 /* compute (9 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+814277, dvrr_stack+978859, dvrr_stack+275116, dvrr_stack+1089581, dvrr_stack+31712, dvrr_stack+979417);

 /* compute (10 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+814827, dvrr_stack+928966, dvrr_stack+70159, dvrr_stack+1034773, dvrr_stack+584320, dvrr_stack+814277);

 /* compute (10 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+755849,dvrr_stack+828234,dvrr_stack+814827,66);


 /* compute (10 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+710219, dvrr_stack+755849, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+670190, dvrr_stack+846518, NULL);
 tmp = dvrr_stack + 670190;
 target_ptr = Libderiv->deriv_classes[10][6][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+672038, dvrr_stack+836060, NULL);
 tmp = dvrr_stack + 672038;
 target_ptr = Libderiv->deriv_classes[10][5][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+631305, dvrr_stack+872411, NULL);
 tmp = dvrr_stack + 631305;
 target_ptr = Libderiv->deriv_classes[10][7][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+633681, dvrr_stack+907501, NULL);
 tmp = dvrr_stack + 633681;
 target_ptr = Libderiv->deriv_classes[10][8][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+636651, dvrr_stack+951391, NULL);
 tmp = dvrr_stack + 636651;
 target_ptr = Libderiv->deriv_classes[10][9][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+561055, dvrr_stack+1002661, NULL);
 tmp = dvrr_stack + 561055;
 target_ptr = Libderiv->deriv_classes[10][10][11];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5148,dvrr_stack+565411, dvrr_stack+1048399, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+979687, dvrr_stack+1064942, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+758819, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 758819;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+815817, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 815817;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+673424, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 673424;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+613740, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 613740;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+614685, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 614685;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+570559, dvrr_stack+75562, NULL);
 tmp = dvrr_stack + 570559;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+571945, dvrr_stack+99670, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+4171, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+573583, dvrr_stack+123866, NULL);
 tmp = dvrr_stack + 573583;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+574367, dvrr_stack+119438, NULL);
 tmp = dvrr_stack + 574367;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+487265, dvrr_stack+134840, NULL);
 tmp = dvrr_stack + 487265;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+488273, dvrr_stack+148990, NULL);
 tmp = dvrr_stack + 488273;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+489533, dvrr_stack+166066, NULL);
 tmp = dvrr_stack + 489533;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+453680, dvrr_stack+187798, NULL);
 tmp = dvrr_stack + 453680;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+429000, dvrr_stack+213936, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+491073, dvrr_stack+1084193, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+455528, dvrr_stack+245584, NULL);
 tmp = dvrr_stack + 455528;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+456536, dvrr_stack+240256, NULL);
 tmp = dvrr_stack + 456536;
 target_ptr = Libderiv->deriv_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+406275, dvrr_stack+259912, NULL);
 tmp = dvrr_stack + 406275;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+407571, dvrr_stack+277547, NULL);
 tmp = dvrr_stack + 407571;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+409191, dvrr_stack+300671, NULL);
 tmp = dvrr_stack + 409191;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+374298, dvrr_stack+328991, NULL);
 tmp = dvrr_stack + 374298;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+376674, dvrr_stack+363039, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+411171, dvrr_stack+1035448, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+379482, dvrr_stack+402495, NULL);
 tmp = dvrr_stack + 379482;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+380742, dvrr_stack+396060, NULL);
 tmp = dvrr_stack + 380742;
 target_ptr = Libderiv->deriv_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+381687, dvrr_stack+419280, NULL);
 tmp = dvrr_stack + 381687;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+383307, dvrr_stack+441530, NULL);
 tmp = dvrr_stack + 383307;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+343247, dvrr_stack+472415, NULL);
 tmp = dvrr_stack + 343247;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+220488, dvrr_stack+505865, NULL);
 tmp = dvrr_stack + 220488;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+223458, dvrr_stack+547060, NULL);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+345722, dvrr_stack+857606, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+287267, dvrr_stack+604500, NULL);
 tmp = dvrr_stack + 287267;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+346547, dvrr_stack+594375, NULL);
 tmp = dvrr_stack + 346547;
 target_ptr = Libderiv->deriv_classes[9][5][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+267688, dvrr_stack+625365, NULL);
 tmp = dvrr_stack + 267688;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+226968, dvrr_stack+655340, NULL);
 tmp = dvrr_stack + 226968;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+198886, dvrr_stack+687779, NULL);
 tmp = dvrr_stack + 198886;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+106348, dvrr_stack+730439, NULL);
 tmp = dvrr_stack + 106348;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+1271863, dvrr_stack+781749, NULL);

 /* compute (10 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+288807, dvrr_stack+755849, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+229443, dvrr_stack+846518, NULL);
 tmp = dvrr_stack + 229443;
 target_ptr = Libderiv->deriv_classes[10][6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+251632, dvrr_stack+836060, NULL);
 tmp = dvrr_stack + 251632;
 target_ptr = Libderiv->deriv_classes[10][5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+175306, dvrr_stack+872411, NULL);
 tmp = dvrr_stack + 175306;
 target_ptr = Libderiv->deriv_classes[10][7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1276153, dvrr_stack+907501, NULL);
 tmp = dvrr_stack + 1276153;
 target_ptr = Libderiv->deriv_classes[10][8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1279123, dvrr_stack+951391, NULL);
 tmp = dvrr_stack + 1279123;
 target_ptr = Libderiv->deriv_classes[10][9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+1282753, dvrr_stack+1002661, NULL);
 tmp = dvrr_stack + 1282753;
 target_ptr = Libderiv->deriv_classes[10][10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5148,dvrr_stack+1287109, dvrr_stack+1048399, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+890297, dvrr_stack+1064942, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+1064942, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 1064942;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+12874, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 12874;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+7447, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 7447;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+23872, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 23872;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+37537, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 37537;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+54700, dvrr_stack+75562, NULL);
 tmp = dvrr_stack + 54700;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+75562, dvrr_stack+99670, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+99670, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+28408, dvrr_stack+123866, NULL);
 tmp = dvrr_stack + 28408;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+123866, dvrr_stack+119438, NULL);
 tmp = dvrr_stack + 123866;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+119438, dvrr_stack+134840, NULL);
 tmp = dvrr_stack + 119438;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+134840, dvrr_stack+148990, NULL);
 tmp = dvrr_stack + 134840;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+148990, dvrr_stack+166066, NULL);
 tmp = dvrr_stack + 148990;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+166066, dvrr_stack+187798, NULL);
 tmp = dvrr_stack + 166066;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+187798, dvrr_stack+213936, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+213936, dvrr_stack+1084193, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+1084193, dvrr_stack+245584, NULL);
 tmp = dvrr_stack + 1084193;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+120446, dvrr_stack+240256, NULL);
 tmp = dvrr_stack + 120446;
 target_ptr = Libderiv->deriv_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+240256, dvrr_stack+259912, NULL);
 tmp = dvrr_stack + 240256;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+259912, dvrr_stack+277547, NULL);
 tmp = dvrr_stack + 259912;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+277547, dvrr_stack+300671, NULL);
 tmp = dvrr_stack + 277547;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+300671, dvrr_stack+328991, NULL);
 tmp = dvrr_stack + 300671;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+328991, dvrr_stack+363039, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+363039, dvrr_stack+1035448, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+1035448, dvrr_stack+402495, NULL);
 tmp = dvrr_stack + 1035448;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+402495, dvrr_stack+396060, NULL);
 tmp = dvrr_stack + 402495;
 target_ptr = Libderiv->deriv_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+396060, dvrr_stack+419280, NULL);
 tmp = dvrr_stack + 396060;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+403440, dvrr_stack+441530, NULL);
 tmp = dvrr_stack + 403440;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+363714, dvrr_stack+472415, NULL);
 tmp = dvrr_stack + 363714;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+472415, dvrr_stack+505865, NULL);
 tmp = dvrr_stack + 472415;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+475385, dvrr_stack+547060, NULL);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+478895, dvrr_stack+857606, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+857606, dvrr_stack+604500, NULL);
 tmp = dvrr_stack + 857606;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+604500, dvrr_stack+594375, NULL);
 tmp = dvrr_stack + 604500;
 target_ptr = Libderiv->deriv_classes[9][5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+594375, dvrr_stack+625365, NULL);
 tmp = dvrr_stack + 594375;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+625365, dvrr_stack+655340, NULL);
 tmp = dvrr_stack + 625365;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+655340, dvrr_stack+687779, NULL);
 tmp = dvrr_stack + 655340;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+687779, dvrr_stack+730439, NULL);
 tmp = dvrr_stack + 687779;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+730439, dvrr_stack+781749, NULL);

 /* compute (10 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+734729, dvrr_stack+755849, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+755849, dvrr_stack+846518, NULL);
 tmp = dvrr_stack + 755849;
 target_ptr = Libderiv->deriv_classes[10][6][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+846518, dvrr_stack+836060, NULL);
 tmp = dvrr_stack + 846518;
 target_ptr = Libderiv->deriv_classes[10][5][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+836060, dvrr_stack+872411, NULL);
 tmp = dvrr_stack + 836060;
 target_ptr = Libderiv->deriv_classes[10][7][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+872411, dvrr_stack+907501, NULL);
 tmp = dvrr_stack + 872411;
 target_ptr = Libderiv->deriv_classes[10][8][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+907501, dvrr_stack+951391, NULL);
 tmp = dvrr_stack + 907501;
 target_ptr = Libderiv->deriv_classes[10][9][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+951391, dvrr_stack+1002661, NULL);
 tmp = dvrr_stack + 951391;
 target_ptr = Libderiv->deriv_classes[10][10][9];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5148,dvrr_stack+1002661, dvrr_stack+1048399, NULL);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1048399, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+1048402, dvrr_stack+1048399, dvrr_stack+1063843, Data->F+3, Data->F+4, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1048408, dvrr_stack+161, dvrr_stack+21, NULL, NULL, Data->F+3);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1048417, dvrr_stack+1048408, dvrr_stack+22243, dvrr_stack+161, dvrr_stack+21, dvrr_stack+1048399);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+1048435, dvrr_stack+1048417, dvrr_stack+1063846, dvrr_stack+1048408, dvrr_stack+22243, dvrr_stack+1048402);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1048465, dvrr_stack+707, dvrr_stack+164, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+578, dvrr_stack+1048465, dvrr_stack+1063864, dvrr_stack+707, dvrr_stack+164, dvrr_stack+1048408);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1048483, dvrr_stack+578, dvrr_stack+122822, dvrr_stack+1048465, dvrr_stack+1063864, dvrr_stack+1048417);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+1048543, dvrr_stack+1048483, dvrr_stack+1063882, dvrr_stack+578, dvrr_stack+122822, dvrr_stack+1048435);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+122822, dvrr_stack+121, dvrr_stack+713, NULL, NULL, dvrr_stack+707);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+1048633, dvrr_stack+122822, dvrr_stack+24, dvrr_stack+121, dvrr_stack+713, dvrr_stack+1048465);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+1048693, dvrr_stack+1048633, dvrr_stack+1063942, dvrr_stack+122822, dvrr_stack+24, dvrr_stack+578);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+1048793, dvrr_stack+1048693, dvrr_stack+1064002, dvrr_stack+1048633, dvrr_stack+1063942, dvrr_stack+1048483);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+615840, dvrr_stack+1048793, dvrr_stack+1064102, dvrr_stack+1048693, dvrr_stack+1064002, dvrr_stack+1048543);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+1048943, dvrr_stack+3730, dvrr_stack+615840);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+1049258, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 1049258;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+1049846, dvrr_stack+6859, dvrr_stack+1064627);
 tmp = dvrr_stack + 1049846;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+1050287, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 1050287;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+1051043, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 1051043;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+1051988, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 1051988;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+1053143, dvrr_stack+73924, dvrr_stack+36382);
 tmp = dvrr_stack + 1053143;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,21,1,dvrr_stack+1054529, dvrr_stack+97759, dvrr_stack+53314);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+121, dvrr_stack+1048402, dvrr_stack+1064252, dvrr_stack+1048399, dvrr_stack+1063843, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+1063942, dvrr_stack+1048435, dvrr_stack+1064258, dvrr_stack+1048417, dvrr_stack+1063846, dvrr_stack+121);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+253018, dvrr_stack+1048543, dvrr_stack+402405, dvrr_stack+1048483, dvrr_stack+1063882, dvrr_stack+1063942);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+1056167, dvrr_stack+615840, dvrr_stack+1073111, dvrr_stack+1048793, dvrr_stack+1064102, dvrr_stack+253018);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+1056447, dvrr_stack+117058, dvrr_stack+1056167);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+1056867, dvrr_stack+122858, dvrr_stack+117058);
 tmp = dvrr_stack + 1056867;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+1057651, dvrr_stack+118654, dvrr_stack+1073321);
 tmp = dvrr_stack + 1057651;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+1058239, dvrr_stack+133580, dvrr_stack+118654);
 tmp = dvrr_stack + 1058239;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+1059247, dvrr_stack+147450, dvrr_stack+122858);
 tmp = dvrr_stack + 1059247;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+1060507, dvrr_stack+164218, dvrr_stack+133580);
 tmp = dvrr_stack + 1060507;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+1062047, dvrr_stack+185614, dvrr_stack+147450);
 tmp = dvrr_stack + 1062047;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,28,1,dvrr_stack+1007809, dvrr_stack+211388, dvrr_stack+164218);

 /* compute (4 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+890612, dvrr_stack+121, dvrr_stack+1064288, dvrr_stack+1048402, dvrr_stack+1064252, NULL);

 /* compute (5 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+1063987, dvrr_stack+1063942, dvrr_stack+48066, dvrr_stack+1048435, dvrr_stack+1064258, dvrr_stack+890612);

 /* compute (6 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+1064050, dvrr_stack+253018, dvrr_stack+723, dvrr_stack+1048543, dvrr_stack+402405, dvrr_stack+1063987);

 /* compute (7 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+1048399, dvrr_stack+1056167, dvrr_stack+1083373, dvrr_stack+615840, dvrr_stack+1073111, dvrr_stack+1064050);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,36,1,dvrr_stack+1009993, dvrr_stack+237120, dvrr_stack+1048399);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+1010533, dvrr_stack+244288, dvrr_stack+237120);
 tmp = dvrr_stack + 1010533;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+1011541, dvrr_stack+239248, dvrr_stack+1083653);
 tmp = dvrr_stack + 1011541;
 target_ptr = Libderiv->deriv_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+1012297, dvrr_stack+258292, dvrr_stack+239248);
 tmp = dvrr_stack + 1012297;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+1013593, dvrr_stack+275567, dvrr_stack+244288);
 tmp = dvrr_stack + 1013593;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+955747, dvrr_stack+298295, dvrr_stack+258292);
 tmp = dvrr_stack + 955747;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+957727, dvrr_stack+326183, dvrr_stack+275567);
 tmp = dvrr_stack + 957727;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,36,1,dvrr_stack+911131, dvrr_stack+359763, dvrr_stack+298295);

 /* compute (5 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+1073111, dvrr_stack+890612, dvrr_stack+185536, dvrr_stack+121, dvrr_stack+1064288, NULL);

 /* compute (6 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+1073132, dvrr_stack+1063987, dvrr_stack+118591, dvrr_stack+1063942, dvrr_stack+48066, dvrr_stack+1073111);

 /* compute (7 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+1015213, dvrr_stack+1064050, dvrr_stack+1089413, dvrr_stack+253018, dvrr_stack+723, dvrr_stack+1073132);

 /* compute (8 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+960103, dvrr_stack+1048399, dvrr_stack+1089581, dvrr_stack+1056167, dvrr_stack+1083373, dvrr_stack+1015213);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,45,1,dvrr_stack+960553, dvrr_stack+392847, dvrr_stack+960103);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+913939, dvrr_stack+121202, dvrr_stack+392847);
 tmp = dvrr_stack + 913939;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+961228, dvrr_stack+394800, dvrr_stack+1034773);
 tmp = dvrr_stack + 961228;
 target_ptr = Libderiv->deriv_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+875381, dvrr_stack+131510, dvrr_stack+394800);
 tmp = dvrr_stack + 875381;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+877001, dvrr_stack+144920, dvrr_stack+121202);
 tmp = dvrr_stack + 877001;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+847904, dvrr_stack+469445, dvrr_stack+131510);
 tmp = dvrr_stack + 847904;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+735719, dvrr_stack+182026, dvrr_stack+144920);
 tmp = dvrr_stack + 735719;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,45,1,dvrr_stack+691409, dvrr_stack+207202, dvrr_stack+469445);

 /* compute (6 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+1083373, dvrr_stack+1073111, dvrr_stack+9344, dvrr_stack+890612, dvrr_stack+185536, NULL);

 /* compute (7 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+962173, dvrr_stack+1073132, dvrr_stack+1064298, dvrr_stack+1063987, dvrr_stack+118591, dvrr_stack+1083373);

 /* compute (8 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+1015429, dvrr_stack+1015213, dvrr_stack+319, dvrr_stack+1064050, dvrr_stack+1089413, dvrr_stack+962173);

 /* compute (9 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+915199, dvrr_stack+960103, dvrr_stack+978859, dvrr_stack+1048399, dvrr_stack+1089581, dvrr_stack+1015429);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,55,1,dvrr_stack+838436, dvrr_stack+588040, dvrr_stack+915199);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+850379, dvrr_stack+602520, dvrr_stack+588040);
 tmp = dvrr_stack + 850379;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+738689, dvrr_stack+592835, dvrr_stack+928966);
 tmp = dvrr_stack + 738689;
 target_ptr = Libderiv->deriv_classes[9][5][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+658365, dvrr_stack+255412, dvrr_stack+592835);
 tmp = dvrr_stack + 658365;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+627840, dvrr_stack+652315, dvrr_stack+602520);
 tmp = dvrr_stack + 627840;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+605655, dvrr_stack+294071, dvrr_stack+255412);
 tmp = dvrr_stack + 605655;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+366189, dvrr_stack+321191, dvrr_stack+652315);
 tmp = dvrr_stack + 366189;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,55,1,dvrr_stack+331799, dvrr_stack+353939, dvrr_stack+294071);

 /* compute (7 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 0;
 vrr_build_xxxx(am,Data,dvrr_stack+578, dvrr_stack+1083373, dvrr_stack+131, dvrr_stack+1073111, dvrr_stack+9344, NULL);

 /* compute (8 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+962173, dvrr_stack+979309, dvrr_stack+1073132, dvrr_stack+1064298, dvrr_stack+578);

 /* compute (9 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+1089413, dvrr_stack+1015429, dvrr_stack+979417, dvrr_stack+1015213, dvrr_stack+319, dvrr_stack+66670);

 /* compute (10 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+915749, dvrr_stack+915199, dvrr_stack+814277, dvrr_stack+960103, dvrr_stack+978859, dvrr_stack+1089413);

 /* compute (10 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,66,1,dvrr_stack+630315, dvrr_stack+828234, dvrr_stack+915749);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+694919, dvrr_stack+844142, dvrr_stack+828234);
 tmp = dvrr_stack + 694919;
 target_ptr = Libderiv->deriv_classes[10][6][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+739844, dvrr_stack+834212, dvrr_stack+814827);
 tmp = dvrr_stack + 739844;
 target_ptr = Libderiv->deriv_classes[10][5][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+660345, dvrr_stack+869441, dvrr_stack+834212);
 tmp = dvrr_stack + 660345;
 target_ptr = Libderiv->deriv_classes[10][7][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+303047, dvrr_stack+903871, dvrr_stack+844142);
 tmp = dvrr_stack + 303047;
 target_ptr = Libderiv->deriv_classes[10][8][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+214476, dvrr_stack+947035, dvrr_stack+869441);
 tmp = dvrr_stack + 214476;
 target_ptr = Libderiv->deriv_classes[10][9][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+100090, dvrr_stack+997513, dvrr_stack+903871);
 tmp = dvrr_stack + 100090;
 target_ptr = Libderiv->deriv_classes[10][10][8];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,66,1,dvrr_stack+781622, dvrr_stack+537050, dvrr_stack+947035);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+1089413, dvrr_stack+3730, dvrr_stack+615840);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+839261, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 839261;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+1015213, dvrr_stack+6859, dvrr_stack+1064627);
 tmp = dvrr_stack + 1015213;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+757697, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 757697;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+596355, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 596355;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+859146, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 859146;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+369819, dvrr_stack+73924, dvrr_stack+36382);
 tmp = dvrr_stack + 369819;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,21,1,dvrr_stack+279527, dvrr_stack+97759, dvrr_stack+53314);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+879026, dvrr_stack+117058, dvrr_stack+1056167);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+397680, dvrr_stack+122858, dvrr_stack+117058);
 tmp = dvrr_stack + 397680;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+405465, dvrr_stack+118654, dvrr_stack+1073321);
 tmp = dvrr_stack + 405465;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+281165, dvrr_stack+133580, dvrr_stack+118654);
 tmp = dvrr_stack + 281165;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+261532, dvrr_stack+147450, dvrr_stack+122858);
 tmp = dvrr_stack + 261532;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+245584, dvrr_stack+164218, dvrr_stack+133580);
 tmp = dvrr_stack + 245584;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+218106, dvrr_stack+185614, dvrr_stack+147450);
 tmp = dvrr_stack + 218106;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,28,1,dvrr_stack+189982, dvrr_stack+211388, dvrr_stack+164218);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,36,1,dvrr_stack+597300, dvrr_stack+237120, dvrr_stack+1048399);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+262792, dvrr_stack+244288, dvrr_stack+237120);
 tmp = dvrr_stack + 262792;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1036708, dvrr_stack+239248, dvrr_stack+1083653);
 tmp = dvrr_stack + 1036708;
 target_ptr = Libderiv->deriv_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+247124, dvrr_stack+258292, dvrr_stack+239248);
 tmp = dvrr_stack + 247124;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+167914, dvrr_stack+275567, dvrr_stack+244288);
 tmp = dvrr_stack + 167914;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+150530, dvrr_stack+298295, dvrr_stack+258292);
 tmp = dvrr_stack + 150530;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+77200, dvrr_stack+326183, dvrr_stack+275567);
 tmp = dvrr_stack + 77200;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,36,1,dvrr_stack+109978, dvrr_stack+359763, dvrr_stack+298295);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,45,1,dvrr_stack+241552, dvrr_stack+392847, dvrr_stack+960103);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+136100, dvrr_stack+121202, dvrr_stack+392847);
 tmp = dvrr_stack + 136100;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+192166, dvrr_stack+394800, dvrr_stack+1034773);
 tmp = dvrr_stack + 192166;
 target_ptr = Libderiv->deriv_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+124454, dvrr_stack+131510, dvrr_stack+394800);
 tmp = dvrr_stack + 124454;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+56086, dvrr_stack+144920, dvrr_stack+121202);
 tmp = dvrr_stack + 56086;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+83878, dvrr_stack+469445, dvrr_stack+131510);
 tmp = dvrr_stack + 83878;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+786770, dvrr_stack+182026, dvrr_stack+144920);
 tmp = dvrr_stack + 786770;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,45,1,dvrr_stack+789740, dvrr_stack+207202, dvrr_stack+469445);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,55,1,dvrr_stack+169534, dvrr_stack+588040, dvrr_stack+915199);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+38692, dvrr_stack+602520, dvrr_stack+588040);
 tmp = dvrr_stack + 38692;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+24817, dvrr_stack+592835, dvrr_stack+928966);
 tmp = dvrr_stack + 24817;
 target_ptr = Libderiv->deriv_classes[9][5][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+61630, dvrr_stack+255412, dvrr_stack+592835);
 tmp = dvrr_stack + 61630;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+546143, dvrr_stack+652315, dvrr_stack+602520);
 tmp = dvrr_stack + 546143;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+548618, dvrr_stack+294071, dvrr_stack+255412);
 tmp = dvrr_stack + 548618;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+551643, dvrr_stack+321191, dvrr_stack+652315);
 tmp = dvrr_stack + 551643;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,55,1,dvrr_stack+504689, dvrr_stack+353939, dvrr_stack+294071);

 /* compute (10 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,66,1,dvrr_stack+13315, dvrr_stack+828234, dvrr_stack+915749);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+555273, dvrr_stack+844142, dvrr_stack+828234);
 tmp = dvrr_stack + 555273;
 target_ptr = Libderiv->deriv_classes[10][6][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+140888, dvrr_stack+834212, dvrr_stack+814827);
 tmp = dvrr_stack + 140888;
 target_ptr = Libderiv->deriv_classes[10][5][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+508979, dvrr_stack+869441, dvrr_stack+834212);
 tmp = dvrr_stack + 508979;
 target_ptr = Libderiv->deriv_classes[10][7][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+511355, dvrr_stack+903871, dvrr_stack+844142);
 tmp = dvrr_stack + 511355;
 target_ptr = Libderiv->deriv_classes[10][8][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+440199, dvrr_stack+947035, dvrr_stack+869441);
 tmp = dvrr_stack + 440199;
 target_ptr = Libderiv->deriv_classes[10][9][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+419125, dvrr_stack+997513, dvrr_stack+903871);
 tmp = dvrr_stack + 419125;
 target_ptr = Libderiv->deriv_classes[10][10][7];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,66,1,dvrr_stack+1292257, dvrr_stack+537050, dvrr_stack+947035);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+1063895, dvrr_stack+3730, dvrr_stack+615840);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+306017, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 306017;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+1085201, dvrr_stack+6859, dvrr_stack+1064627);
 tmp = dvrr_stack + 1085201;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+128570, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 128570;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+43207, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 43207;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+793250, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 793250;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+443829, dvrr_stack+73924, dvrr_stack+36382);
 tmp = dvrr_stack + 443829;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,21,1,dvrr_stack+73924, dvrr_stack+97759, dvrr_stack+53314);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+129326, dvrr_stack+117058, dvrr_stack+1056167);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+16402, dvrr_stack+122858, dvrr_stack+117058);
 tmp = dvrr_stack + 16402;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+201911, dvrr_stack+118654, dvrr_stack+1073321);
 tmp = dvrr_stack + 201911;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+445215, dvrr_stack+133580, dvrr_stack+118654);
 tmp = dvrr_stack + 445215;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+446223, dvrr_stack+147450, dvrr_stack+122858);
 tmp = dvrr_stack + 446223;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+91402, dvrr_stack+164218, dvrr_stack+133580);
 tmp = dvrr_stack + 91402;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+97628, dvrr_stack+185614, dvrr_stack+147450);
 tmp = dvrr_stack + 97628;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,28,1,dvrr_stack+185614, dvrr_stack+211388, dvrr_stack+164218);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,36,1,dvrr_stack+1073111, dvrr_stack+237120, dvrr_stack+1048399);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+211381, dvrr_stack+244288, dvrr_stack+237120);
 tmp = dvrr_stack + 211381;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+44152, dvrr_stack+239248, dvrr_stack+1083653);
 tmp = dvrr_stack + 44152;
 target_ptr = Libderiv->deriv_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+212389, dvrr_stack+258292, dvrr_stack+239248);
 tmp = dvrr_stack + 212389;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1297405, dvrr_stack+275567, dvrr_stack+244288);
 tmp = dvrr_stack + 1297405;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1299025, dvrr_stack+298295, dvrr_stack+258292);
 tmp = dvrr_stack + 1299025;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1301005, dvrr_stack+326183, dvrr_stack+275567);
 tmp = dvrr_stack + 1301005;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,36,1,dvrr_stack+326082, dvrr_stack+359763, dvrr_stack+298295);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,45,1,dvrr_stack+1083373, dvrr_stack+392847, dvrr_stack+960103);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+359739, dvrr_stack+121202, dvrr_stack+392847);
 tmp = dvrr_stack + 359739;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+360999, dvrr_stack+394800, dvrr_stack+1034773);
 tmp = dvrr_stack + 360999;
 target_ptr = Libderiv->deriv_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1303381, dvrr_stack+131510, dvrr_stack+394800);
 tmp = dvrr_stack + 1303381;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1305001, dvrr_stack+144920, dvrr_stack+121202);
 tmp = dvrr_stack + 1305001;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1307026, dvrr_stack+469445, dvrr_stack+131510);
 tmp = dvrr_stack + 1307026;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1309501, dvrr_stack+182026, dvrr_stack+144920);
 tmp = dvrr_stack + 1309501;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,45,1,dvrr_stack+182026, dvrr_stack+207202, dvrr_stack+469445);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,55,1,dvrr_stack+207202, dvrr_stack+588040, dvrr_stack+915199);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+208027, dvrr_stack+602520, dvrr_stack+588040);
 tmp = dvrr_stack + 208027;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+209567, dvrr_stack+592835, dvrr_stack+928966);
 tmp = dvrr_stack + 209567;
 target_ptr = Libderiv->deriv_classes[9][5][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1312471, dvrr_stack+255412, dvrr_stack+592835);
 tmp = dvrr_stack + 1312471;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1314451, dvrr_stack+652315, dvrr_stack+602520);
 tmp = dvrr_stack + 1314451;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1316926, dvrr_stack+294071, dvrr_stack+255412);
 tmp = dvrr_stack + 1316926;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1319951, dvrr_stack+321191, dvrr_stack+652315);
 tmp = dvrr_stack + 1319951;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,55,1,dvrr_stack+1323581, dvrr_stack+353939, dvrr_stack+294071);

 /* compute (10 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,66,1,dvrr_stack+353939, dvrr_stack+828234, dvrr_stack+915749);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+354929, dvrr_stack+844142, dvrr_stack+828234);
 tmp = dvrr_stack + 354929;
 target_ptr = Libderiv->deriv_classes[10][6][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+356777, dvrr_stack+834212, dvrr_stack+814827);
 tmp = dvrr_stack + 356777;
 target_ptr = Libderiv->deriv_classes[10][5][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+1327871, dvrr_stack+869441, dvrr_stack+834212);
 tmp = dvrr_stack + 1327871;
 target_ptr = Libderiv->deriv_classes[10][7][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+1330247, dvrr_stack+903871, dvrr_stack+844142);
 tmp = dvrr_stack + 1330247;
 target_ptr = Libderiv->deriv_classes[10][8][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+1333217, dvrr_stack+947035, dvrr_stack+869441);
 tmp = dvrr_stack + 1333217;
 target_ptr = Libderiv->deriv_classes[10][9][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+1336847, dvrr_stack+997513, dvrr_stack+903871);
 tmp = dvrr_stack + 1336847;
 target_ptr = Libderiv->deriv_classes[10][10][6];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,66,1,dvrr_stack+1341203, dvrr_stack+537050, dvrr_stack+947035);

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+537050,dvrr_stack+6439,dvrr_stack+3415,15);


 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+1064627, dvrr_stack+537050, NULL);

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+537995,dvrr_stack+11578,dvrr_stack+6439,15);


 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+539255, dvrr_stack+537995, NULL);

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+539675,dvrr_stack+22252,dvrr_stack+11578,15);


 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+541295, dvrr_stack+539675, NULL);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1346351,dvrr_stack+35557,dvrr_stack+22252,15);


 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+1034773, dvrr_stack+1346351, NULL);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+1348376,dvrr_stack+52324,dvrr_stack+35557,15);


 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+541835, dvrr_stack+1348376, NULL);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+1350851,dvrr_stack+72754,dvrr_stack+52324,15);


 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+915199, dvrr_stack+1350851, NULL);

 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+542660, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+306605, dvrr_stack+0, dvrr_stack+542660, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+121, dvrr_stack+358944, dvrr_stack+306605, dvrr_stack+211297, dvrr_stack+0, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+185536, dvrr_stack+47971, dvrr_stack+121, dvrr_stack+15, dvrr_stack+358944, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+542663, dvrr_stack+358950, dvrr_stack+185536, dvrr_stack+111, dvrr_stack+47971, NULL);

 /* compute (6 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+542684, dvrr_stack+32797, dvrr_stack+542663, dvrr_stack+211300, dvrr_stack+358950, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22243, dvrr_stack+1966, dvrr_stack+4591, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+542712, dvrr_stack+69179, dvrr_stack+22243, dvrr_stack+704, dvrr_stack+1966, dvrr_stack+542660);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+336089, dvrr_stack+358965, dvrr_stack+542712, dvrr_stack+569, dvrr_stack+69179, dvrr_stack+306605);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+48066, dvrr_stack+358983, dvrr_stack+336089, dvrr_stack+211315, dvrr_stack+358965, dvrr_stack+121);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+118591, dvrr_stack+359013, dvrr_stack+48066, dvrr_stack+211333, dvrr_stack+358983, dvrr_stack+185536);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+704, dvrr_stack+359058, dvrr_stack+118591, dvrr_stack+19395, dvrr_stack+359013, dvrr_stack+542663);

 /* compute (7 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+962173, dvrr_stack+359121, dvrr_stack+704, dvrr_stack+185551, dvrr_stack+359058, dvrr_stack+542684);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+185551, dvrr_stack+1603, dvrr_stack+9313, NULL, NULL, dvrr_stack+4591);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+122822, dvrr_stack+69198, dvrr_stack+185551, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+22243);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+788, dvrr_stack+11542, dvrr_stack+122822, dvrr_stack+211363, dvrr_stack+69198, dvrr_stack+542712);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+1073651, dvrr_stack+359205, dvrr_stack+788, dvrr_stack+9365, dvrr_stack+11542, dvrr_stack+336089);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+253018, dvrr_stack+359265, dvrr_stack+1073651, dvrr_stack+67888, dvrr_stack+359205, dvrr_stack+48066);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+25972, dvrr_stack+298169, dvrr_stack+253018, dvrr_stack+614, dvrr_stack+359265, dvrr_stack+118591);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+542730, dvrr_stack+359355, dvrr_stack+25972, dvrr_stack+67948, dvrr_stack+298169, dvrr_stack+704);

 /* compute (8 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+358163, dvrr_stack+359523, dvrr_stack+542730, dvrr_stack+68074, dvrr_stack+359355, dvrr_stack+962173);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+67888, dvrr_stack+9319, dvrr_stack+19285, NULL, NULL, dvrr_stack+9313);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+67918, dvrr_stack+69216, dvrr_stack+67888, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+185551);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+67978, dvrr_stack+68949, dvrr_stack+67918, dvrr_stack+68242, dvrr_stack+69216, dvrr_stack+122822);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+68078, dvrr_stack+325832, dvrr_stack+67978, dvrr_stack+68272, dvrr_stack+68949, dvrr_stack+788);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+615840, dvrr_stack+325932, dvrr_stack+68078, dvrr_stack+68332, dvrr_stack+325832, dvrr_stack+1073651);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+1056167, dvrr_stack+8770, dvrr_stack+615840, dvrr_stack+47686, dvrr_stack+325932, dvrr_stack+253018);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+68228, dvrr_stack+51734, dvrr_stack+1056167, dvrr_stack+163870, dvrr_stack+8770, dvrr_stack+25972);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+960103, dvrr_stack+34632, dvrr_stack+68228, dvrr_stack+31432, dvrr_stack+51734, dvrr_stack+542730);

 /* compute (9 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+210722, dvrr_stack+275116, dvrr_stack+960103, dvrr_stack+31712, dvrr_stack+34632, dvrr_stack+358163);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+185569, dvrr_stack+19295, dvrr_stack+32108, NULL, NULL, dvrr_stack+19285);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+402405, dvrr_stack+35232, dvrr_stack+185569, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+67888);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+31432, dvrr_stack+35277, dvrr_stack+402405, dvrr_stack+47836, dvrr_stack+35232, dvrr_stack+67918);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+63610, dvrr_stack+35367, dvrr_stack+31432, dvrr_stack+47881, dvrr_stack+35277, dvrr_stack+67978);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+31582, dvrr_stack+52014, dvrr_stack+63610, dvrr_stack+32422, dvrr_stack+35367, dvrr_stack+68078);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+358433, dvrr_stack+19440, dvrr_stack+31582, dvrr_stack+32572, dvrr_stack+52014, dvrr_stack+615840);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1048399, dvrr_stack+19755, dvrr_stack+358433, dvrr_stack+47176, dvrr_stack+19440, dvrr_stack+1056167);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+10792, dvrr_stack+1048399, dvrr_stack+96146, dvrr_stack+19755, dvrr_stack+68228);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+361944, dvrr_stack+2701, dvrr_stack+47176, dvrr_stack+97088, dvrr_stack+10792, dvrr_stack+960103);

 /* compute (10 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+95502, dvrr_stack+70159, dvrr_stack+361944, dvrr_stack+584320, dvrr_stack+2701, dvrr_stack+210722);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+584320, dvrr_stack+32123, dvrr_stack+47981, NULL, NULL, dvrr_stack+32108);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+584383, dvrr_stack+2318, dvrr_stack+584320, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+185569);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+584509, dvrr_stack+258052, dvrr_stack+584383, dvrr_stack+90115, dvrr_stack+2318, dvrr_stack+402405);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+32422, dvrr_stack+11332, dvrr_stack+584509, dvrr_stack+90178, dvrr_stack+258052, dvrr_stack+31432);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+90115, dvrr_stack+70984, dvrr_stack+32422, dvrr_stack+8986, dvrr_stack+11332, dvrr_stack+63610);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+163606, dvrr_stack+90793, dvrr_stack+90115, dvrr_stack+584995, dvrr_stack+70984, dvrr_stack+31582);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+96492, dvrr_stack+71299, dvrr_stack+163606, dvrr_stack+585310, dvrr_stack+90793, dvrr_stack+358433);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+584719, dvrr_stack+71887, dvrr_stack+96492, dvrr_stack+585751, dvrr_stack+71299, dvrr_stack+1048399);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+1353821, dvrr_stack+827289, dvrr_stack+584719, dvrr_stack+586339, dvrr_stack+71887, dvrr_stack+47176);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+585664, dvrr_stack+93339, dvrr_stack+1353821, dvrr_stack+587095, dvrr_stack+827289, dvrr_stack+361944);

 /* compute (11 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+1354976, dvrr_stack+828234, dvrr_stack+585664, dvrr_stack+588040, dvrr_stack+93339, dvrr_stack+95502);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+8986, dvrr_stack+48002, dvrr_stack+67658, NULL, NULL, dvrr_stack+47981);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+9070, dvrr_stack+2381, dvrr_stack+8986, dvrr_stack+32144, dvrr_stack+48002, dvrr_stack+584320);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+587050, dvrr_stack+91234, dvrr_stack+9070, dvrr_stack+69907, dvrr_stack+2381, dvrr_stack+584383);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+587330, dvrr_stack+2021, dvrr_stack+587050, dvrr_stack+69991, dvrr_stack+91234, dvrr_stack+584509);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+18662, dvrr_stack+94494, dvrr_stack+587330, dvrr_stack+892, dvrr_stack+2021, dvrr_stack+32422);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+1356614, dvrr_stack+94914, dvrr_stack+18662, dvrr_stack+66805, dvrr_stack+94494, dvrr_stack+90115);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1357398, dvrr_stack+829620, dvrr_stack+1356614, dvrr_stack+589195, dvrr_stack+94914, dvrr_stack+163606);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1358406, dvrr_stack+830404, dvrr_stack+1357398, dvrr_stack+589783, dvrr_stack+829620, dvrr_stack+96492);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1359666, dvrr_stack+831412, dvrr_stack+1358406, dvrr_stack+590567, dvrr_stack+830404, dvrr_stack+584719);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+589195, dvrr_stack+832672, dvrr_stack+1359666, dvrr_stack+591575, dvrr_stack+831412, dvrr_stack+1353821);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1361206, dvrr_stack+834212, dvrr_stack+589195, dvrr_stack+592835, dvrr_stack+832672, dvrr_stack+585664);

 /* compute (11 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+1363390,dvrr_stack+1361206,dvrr_stack+1354976,78);


 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+591043, dvrr_stack+1363390, NULL);

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+592681, dvrr_stack+67686, dvrr_stack+1567, NULL, NULL, dvrr_stack+67658);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+69907, dvrr_stack+393792, dvrr_stack+592681, dvrr_stack+48030, dvrr_stack+67686, dvrr_stack+8986);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+848, dvrr_stack+393900, dvrr_stack+69907, dvrr_stack+237876, dvrr_stack+393792, dvrr_stack+9070);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+394116, dvrr_stack+848, dvrr_stack+237984, dvrr_stack+393900, dvrr_stack+587050);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1368304, dvrr_stack+69246, dvrr_stack+66670, dvrr_stack+238200, dvrr_stack+394116, dvrr_stack+587330);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1369060, dvrr_stack+48619, dvrr_stack+1368304, dvrr_stack+238560, dvrr_stack+69246, dvrr_stack+18662);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+237876, dvrr_stack+840218, dvrr_stack+1369060, dvrr_stack+597840, dvrr_stack+48619, dvrr_stack+1356614);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1370068, dvrr_stack+841226, dvrr_stack+237876, dvrr_stack+598596, dvrr_stack+840218, dvrr_stack+1357398);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1371688, dvrr_stack+842522, dvrr_stack+1370068, dvrr_stack+599604, dvrr_stack+841226, dvrr_stack+1358406);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+597840, dvrr_stack+398895, dvrr_stack+1371688, dvrr_stack+600900, dvrr_stack+842522, dvrr_stack+1359666);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1373668, dvrr_stack+844142, dvrr_stack+597840, dvrr_stack+602520, dvrr_stack+398895, dvrr_stack+589195);

 /* compute (11 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+1376476,dvrr_stack+1373668,dvrr_stack+1361206,78);


 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+600216, dvrr_stack+1376476, NULL);

 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+90556, dvrr_stack+20176, dvrr_stack+9401, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+362769, dvrr_stack+400875, dvrr_stack+90556, dvrr_stack+67722, dvrr_stack+20176, dvrr_stack+592681);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+514325, dvrr_stack+401010, dvrr_stack+362769, dvrr_stack+242524, dvrr_stack+400875, dvrr_stack+69907);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1383028, dvrr_stack+401280, dvrr_stack+514325, dvrr_stack+242659, dvrr_stack+401010, dvrr_stack+848);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1383703, dvrr_stack+401730, dvrr_stack+1383028, dvrr_stack+242929, dvrr_stack+401280, dvrr_stack+66670);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1384648, dvrr_stack+117646, dvrr_stack+1383703, dvrr_stack+243379, dvrr_stack+401730, dvrr_stack+1368304);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242227, dvrr_stack+864536, dvrr_stack+1384648, dvrr_stack+619515, dvrr_stack+117646, dvrr_stack+1369060);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1385908, dvrr_stack+865796, dvrr_stack+242227, dvrr_stack+620460, dvrr_stack+864536, dvrr_stack+237876);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1387933, dvrr_stack+867416, dvrr_stack+1385908, dvrr_stack+621720, dvrr_stack+865796, dvrr_stack+1370068);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+619515, dvrr_stack+414780, dvrr_stack+1387933, dvrr_stack+623340, dvrr_stack+867416, dvrr_stack+1371688);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1390408, dvrr_stack+869441, dvrr_stack+619515, dvrr_stack+255412, dvrr_stack+414780, dvrr_stack+597840);

 /* compute (11 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+1393918,dvrr_stack+1390408,dvrr_stack+1373668,78);


 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+622485, dvrr_stack+1393918, NULL);

 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+587750, dvrr_stack+264, dvrr_stack+147395, NULL, NULL, dvrr_stack+9401);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1208, dvrr_stack+417255, dvrr_stack+587750, dvrr_stack+20221, dvrr_stack+264, dvrr_stack+90556);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8203, dvrr_stack+417420, dvrr_stack+1208, dvrr_stack+257887, dvrr_stack+417255, dvrr_stack+362769);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1402342, dvrr_stack+417750, dvrr_stack+8203, dvrr_stack+10462, dvrr_stack+417420, dvrr_stack+514325);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1403167, dvrr_stack+418300, dvrr_stack+1402342, dvrr_stack+4647, dvrr_stack+417750, dvrr_stack+1383028);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1404322, dvrr_stack+896171, dvrr_stack+1403167, dvrr_stack+5571, dvrr_stack+418300, dvrr_stack+1383703);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1405862, dvrr_stack+897326, dvrr_stack+1404322, dvrr_stack+645165, dvrr_stack+896171, dvrr_stack+1384648);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1407842, dvrr_stack+898866, dvrr_stack+1405862, dvrr_stack+646320, dvrr_stack+897326, dvrr_stack+242227);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1410317, dvrr_stack+435480, dvrr_stack+1407842, dvrr_stack+647860, dvrr_stack+898866, dvrr_stack+1385908);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+645165, dvrr_stack+900846, dvrr_stack+1410317, dvrr_stack+649840, dvrr_stack+435480, dvrr_stack+1387933);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1413342, dvrr_stack+903871, dvrr_stack+645165, dvrr_stack+652315, dvrr_stack+900846, dvrr_stack+619515);

 /* compute (11 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1417632,dvrr_stack+1413342,dvrr_stack+1390408,78);


 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+648795, dvrr_stack+1417632, NULL);

 /* compute (1 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+48111, dvrr_stack+67822, NULL, NULL, dvrr_stack+147395);

 /* compute (2 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5769, dvrr_stack+437955, dvrr_stack+5571, dvrr_stack+32263, dvrr_stack+48111, dvrr_stack+587750);

 /* compute (3 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+4594, dvrr_stack+438153, dvrr_stack+5769, dvrr_stack+272872, dvrr_stack+437955, dvrr_stack+1208);

 /* compute (4 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1428162, dvrr_stack+438549, dvrr_stack+4594, dvrr_stack+273070, dvrr_stack+438153, dvrr_stack+8203);

 /* compute (5 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1429152, dvrr_stack+439209, dvrr_stack+1428162, dvrr_stack+273466, dvrr_stack+438549, dvrr_stack+1402342);

 /* compute (6 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1430538, dvrr_stack+937795, dvrr_stack+1429152, dvrr_stack+274126, dvrr_stack+439209, dvrr_stack+1403167);

 /* compute (7 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1432386, dvrr_stack+939181, dvrr_stack+1430538, dvrr_stack+20857, dvrr_stack+937795, dvrr_stack+1404322);

 /* compute (8 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1434762, dvrr_stack+941029, dvrr_stack+1432386, dvrr_stack+680585, dvrr_stack+939181, dvrr_stack+1405862);

 /* compute (9 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1437732, dvrr_stack+462185, dvrr_stack+1434762, dvrr_stack+682433, dvrr_stack+941029, dvrr_stack+1407842);

 /* compute (10 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1441362, dvrr_stack+943405, dvrr_stack+1437732, dvrr_stack+684809, dvrr_stack+462185, dvrr_stack+1410317);

 /* compute (11 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+680585, dvrr_stack+947035, dvrr_stack+1441362, dvrr_stack+294071, dvrr_stack+943405, dvrr_stack+645165);

 /* compute (11 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+1445718,dvrr_stack+680585,dvrr_stack+1413342,78);


 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+1458588, dvrr_stack+1445718, NULL);

 /* compute (1 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+282173, dvrr_stack+325481, dvrr_stack+48177, NULL, NULL, dvrr_stack+67822);

 /* compute (2 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+685733, dvrr_stack+465155, dvrr_stack+282173, dvrr_stack+32329, dvrr_stack+325481, dvrr_stack+5571);

 /* compute (3 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+686201, dvrr_stack+465389, dvrr_stack+685733, dvrr_stack+244054, dvrr_stack+465155, dvrr_stack+5769);

 /* compute (4 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+465857, dvrr_stack+686201, dvrr_stack+297701, dvrr_stack+465389, dvrr_stack+4594);

 /* compute (5 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+685733, dvrr_stack+466637, dvrr_stack+20857, dvrr_stack+33852, dvrr_stack+465857, dvrr_stack+1428162);

 /* compute (6 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+272872, dvrr_stack+467807, dvrr_stack+685733, dvrr_stack+719129, dvrr_stack+466637, dvrr_stack+1429152);

 /* compute (7 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1462878, dvrr_stack+989011, dvrr_stack+272872, dvrr_stack+720299, dvrr_stack+467807, dvrr_stack+1430538);

 /* compute (8 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+465155, dvrr_stack+991195, dvrr_stack+1462878, dvrr_stack+721937, dvrr_stack+989011, dvrr_stack+1432386);

 /* compute (9 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+719129, dvrr_stack+994003, dvrr_stack+465155, dvrr_stack+724121, dvrr_stack+991195, dvrr_stack+1434762);

 /* compute (10 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1462878, dvrr_stack+498065, dvrr_stack+719129, dvrr_stack+726929, dvrr_stack+994003, dvrr_stack+1437732);

 /* compute (11 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+719129, dvrr_stack+997513, dvrr_stack+1462878, dvrr_stack+321191, dvrr_stack+498065, dvrr_stack+1441362);

 /* compute (11 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+1462878,dvrr_stack+719129,dvrr_stack+680585,78);


 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5148,dvrr_stack+725213, dvrr_stack+1462878, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+498065, dvrr_stack+537050, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+498380, dvrr_stack+537995, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+498800, dvrr_stack+539675, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+499340, dvrr_stack+1346351, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+500015, dvrr_stack+1348376, NULL);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+500840, dvrr_stack+1350851, NULL);

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+321191, dvrr_stack+1363390, NULL);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+322829, dvrr_stack+1376476, NULL);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+465155, dvrr_stack+1393918, NULL);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+989011, dvrr_stack+1417632, NULL);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+992521, dvrr_stack+1445718, NULL);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5148,dvrr_stack+996811, dvrr_stack+1462878, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+501830, dvrr_stack+537050, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+537050, dvrr_stack+537995, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+537470, dvrr_stack+539675, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+539675, dvrr_stack+1346351, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+1346351, dvrr_stack+1348376, NULL);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+1347176, dvrr_stack+1350851, NULL);

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+1348166, dvrr_stack+1363390, NULL);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+1363390, dvrr_stack+1376476, NULL);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+1376476, dvrr_stack+1393918, NULL);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+1393918, dvrr_stack+1417632, NULL);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+1417632, dvrr_stack+1445718, NULL);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5148,dvrr_stack+1445718, dvrr_stack+1462878, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+1462878, dvrr_stack+6439, dvrr_stack+1064402);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+1463193, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+1463613, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+1464153, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+1464828, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+1465653, dvrr_stack+72754, dvrr_stack+35557);

 /* compute (7 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 0;
 vrr_build_xxxx(am,Data,dvrr_stack+48030, dvrr_stack+131, dvrr_stack+542684, dvrr_stack+9344, dvrr_stack+32797, NULL);

 /* compute (8 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+1466643, dvrr_stack+979309, dvrr_stack+962173, dvrr_stack+1064298, dvrr_stack+359121, dvrr_stack+48030);

 /* compute (9 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+979417, dvrr_stack+358163, dvrr_stack+319, dvrr_stack+359523, dvrr_stack+1466643);

 /* compute (10 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+1466643, dvrr_stack+814277, dvrr_stack+210722, dvrr_stack+978859, dvrr_stack+275116, dvrr_stack+10462);

 /* compute (11 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1467303, dvrr_stack+814827, dvrr_stack+95502, dvrr_stack+928966, dvrr_stack+70159, dvrr_stack+1466643);

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,78,1,dvrr_stack+1468473, dvrr_stack+1361206, dvrr_stack+1467303);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,78,1,dvrr_stack+1470111, dvrr_stack+1373668, dvrr_stack+1354976);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,78,1,dvrr_stack+1472295, dvrr_stack+1390408, dvrr_stack+1361206);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,78,1,dvrr_stack+1475103, dvrr_stack+1413342, dvrr_stack+1373668);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,78,1,dvrr_stack+1450866, dvrr_stack+680585, dvrr_stack+1390408);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,78,1,dvrr_stack+1421922, dvrr_stack+719129, dvrr_stack+1413342);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+1466643, dvrr_stack+6439, dvrr_stack+1064402);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+928966, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+978859, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+814277, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+814952, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+1455156, dvrr_stack+72754, dvrr_stack+35557);

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,78,1,dvrr_stack+1456146, dvrr_stack+1361206, dvrr_stack+1467303);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,78,1,dvrr_stack+1397428, dvrr_stack+1373668, dvrr_stack+1354976);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,78,1,dvrr_stack+1379284, dvrr_stack+1390408, dvrr_stack+1361206);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,78,1,dvrr_stack+1349804, dvrr_stack+1413342, dvrr_stack+1373668);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,78,1,dvrr_stack+1478613, dvrr_stack+680585, dvrr_stack+1390408);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,78,1,dvrr_stack+1482903, dvrr_stack+719129, dvrr_stack+1413342);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+1466958, dvrr_stack+6439, dvrr_stack+1064402);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+1488051, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+1457784, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+1427070, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+1399612, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+1400437, dvrr_stack+72754, dvrr_stack+35557);

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,78,1,dvrr_stack+1365574, dvrr_stack+1361206, dvrr_stack+1467303);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,78,1,dvrr_stack+272872, dvrr_stack+1373668, dvrr_stack+1354976);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,78,1,dvrr_stack+1488471, dvrr_stack+1390408, dvrr_stack+1361206);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,78,1,dvrr_stack+1491279, dvrr_stack+1413342, dvrr_stack+1373668);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,78,1,dvrr_stack+1494789, dvrr_stack+680585, dvrr_stack+1390408);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,78,1,dvrr_stack+1499079, dvrr_stack+719129, dvrr_stack+1413342);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+719129, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+719444, dvrr_stack+237120, dvrr_stack+3730);
 tmp = dvrr_stack + 719444;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+720032, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+720452, dvrr_stack+239248, dvrr_stack+6859);
 tmp = dvrr_stack + 720452;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+721236, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+721776, dvrr_stack+244288, dvrr_stack+12118);
 tmp = dvrr_stack + 721776;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+722784, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+723459, dvrr_stack+258292, dvrr_stack+22927);
 tmp = dvrr_stack + 723459;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+1467273, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+685733, dvrr_stack+275567, dvrr_stack+36382);
 tmp = dvrr_stack + 685733;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+1367212, dvrr_stack+53314, dvrr_stack+49618);

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1504227, dvrr_stack+298295, dvrr_stack+53314);
 tmp = dvrr_stack + 1504227;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+243847, dvrr_stack+117058, dvrr_stack+3415);
 tmp = dvrr_stack + 243847;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1506075, dvrr_stack+392847, dvrr_stack+117058);
 tmp = dvrr_stack + 1506075;
 target_ptr = Libderiv->deriv_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1401427, dvrr_stack+118654, dvrr_stack+6439);
 tmp = dvrr_stack + 1401427;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+538010, dvrr_stack+394800, dvrr_stack+118654);
 tmp = dvrr_stack + 538010;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1382092, dvrr_stack+122858, dvrr_stack+11578);
 tmp = dvrr_stack + 1382092;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+467963, dvrr_stack+121202, dvrr_stack+122858);
 tmp = dvrr_stack + 467963;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+540350, dvrr_stack+133580, dvrr_stack+22252);
 tmp = dvrr_stack + 540350;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1506831, dvrr_stack+131510, dvrr_stack+133580);
 tmp = dvrr_stack + 1506831;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+20857, dvrr_stack+147450, dvrr_stack+35557);
 tmp = dvrr_stack + 20857;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1508451, dvrr_stack+144920, dvrr_stack+147450);
 tmp = dvrr_stack + 1508451;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1510431, dvrr_stack+164218, dvrr_stack+52324);
 tmp = dvrr_stack + 1510431;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1511817, dvrr_stack+469445, dvrr_stack+164218);
 tmp = dvrr_stack + 1511817;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+72643, dvrr_stack+588040, dvrr_stack+237120);
 tmp = dvrr_stack + 72643;
 target_ptr = Libderiv->deriv_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1514193, dvrr_stack+592835, dvrr_stack+239248);
 tmp = dvrr_stack + 1514193;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1515453, dvrr_stack+602520, dvrr_stack+244288);
 tmp = dvrr_stack + 1515453;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1517073, dvrr_stack+255412, dvrr_stack+258292);
 tmp = dvrr_stack + 1517073;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1519098, dvrr_stack+652315, dvrr_stack+275567);
 tmp = dvrr_stack + 1519098;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1521573, dvrr_stack+294071, dvrr_stack+298295);
 tmp = dvrr_stack + 1521573;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1524543, dvrr_stack+828234, dvrr_stack+392847);
 tmp = dvrr_stack + 1524543;
 target_ptr = Libderiv->deriv_classes[9][5][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1525698, dvrr_stack+834212, dvrr_stack+394800);
 tmp = dvrr_stack + 1525698;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1527238, dvrr_stack+844142, dvrr_stack+121202);
 tmp = dvrr_stack + 1527238;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1529218, dvrr_stack+869441, dvrr_stack+131510);
 tmp = dvrr_stack + 1529218;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1531693, dvrr_stack+903871, dvrr_stack+144920);
 tmp = dvrr_stack + 1531693;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1534718, dvrr_stack+947035, dvrr_stack+469445);
 tmp = dvrr_stack + 1534718;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+1538348, dvrr_stack+1354976, dvrr_stack+588040);
 tmp = dvrr_stack + 1538348;
 target_ptr = Libderiv->deriv_classes[10][5][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+1539734, dvrr_stack+1361206, dvrr_stack+592835);
 tmp = dvrr_stack + 1539734;
 target_ptr = Libderiv->deriv_classes[10][6][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+1541582, dvrr_stack+1373668, dvrr_stack+602520);
 tmp = dvrr_stack + 1541582;
 target_ptr = Libderiv->deriv_classes[10][7][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+1543958, dvrr_stack+1390408, dvrr_stack+255412);
 tmp = dvrr_stack + 1543958;
 target_ptr = Libderiv->deriv_classes[10][8][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+1546928, dvrr_stack+1413342, dvrr_stack+652315);
 tmp = dvrr_stack + 1546928;
 target_ptr = Libderiv->deriv_classes[10][9][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+1550558, dvrr_stack+680585, dvrr_stack+294071);
 tmp = dvrr_stack + 1550558;
 target_ptr = Libderiv->deriv_classes[10][10][2];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+724719, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+724722, dvrr_stack+542660, dvrr_stack+724719, Data->F+10, Data->F+11, NULL);

 /* compute (3 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+652305, dvrr_stack+306605, dvrr_stack+724722, dvrr_stack+0, dvrr_stack+542660, NULL);

 /* compute (4 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+890612, dvrr_stack+121, dvrr_stack+652305, dvrr_stack+358944, dvrr_stack+306605, NULL);

 /* compute (5 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+0, dvrr_stack+185536, dvrr_stack+890612, dvrr_stack+47971, dvrr_stack+121, NULL);

 /* compute (6 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+21, dvrr_stack+542663, dvrr_stack+0, dvrr_stack+358950, dvrr_stack+185536, NULL);

 /* compute (7 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 0;
 vrr_build_xxxx(am,Data,dvrr_stack+48030, dvrr_stack+542684, dvrr_stack+21, dvrr_stack+32797, dvrr_stack+542663, NULL);

 /* compute (1 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+185536, dvrr_stack+4591, dvrr_stack+9310, NULL, NULL, Data->F+12);

 /* compute (2 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+542660, dvrr_stack+22243, dvrr_stack+185536, dvrr_stack+1966, dvrr_stack+4591, dvrr_stack+724719);

 /* compute (3 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+542678, dvrr_stack+542712, dvrr_stack+542660, dvrr_stack+69179, dvrr_stack+22243, dvrr_stack+724722);

 /* compute (4 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+1037464, dvrr_stack+336089, dvrr_stack+542678, dvrr_stack+358965, dvrr_stack+542712, dvrr_stack+652305);

 /* compute (5 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+724719, dvrr_stack+48066, dvrr_stack+1037464, dvrr_stack+358983, dvrr_stack+336089, dvrr_stack+890612);

 /* compute (6 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+724782, dvrr_stack+118591, dvrr_stack+724719, dvrr_stack+359013, dvrr_stack+48066, dvrr_stack+0);

 /* compute (7 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+724866, dvrr_stack+704, dvrr_stack+724782, dvrr_stack+359058, dvrr_stack+118591, dvrr_stack+21);

 /* compute (8 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+962173, dvrr_stack+724866, dvrr_stack+359121, dvrr_stack+704, dvrr_stack+48030);

 /* compute (1 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+48030, dvrr_stack+9313, dvrr_stack+8980, NULL, NULL, dvrr_stack+9310);

 /* compute (2 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+70123, dvrr_stack+185551, dvrr_stack+48030, dvrr_stack+1603, dvrr_stack+9313, dvrr_stack+185536);

 /* compute (3 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+275056, dvrr_stack+122822, dvrr_stack+70123, dvrr_stack+69198, dvrr_stack+185551, dvrr_stack+542660);

 /* compute (4 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+1603, dvrr_stack+788, dvrr_stack+275056, dvrr_stack+11542, dvrr_stack+122822, dvrr_stack+542678);

 /* compute (5 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+1693, dvrr_stack+1073651, dvrr_stack+1603, dvrr_stack+359205, dvrr_stack+788, dvrr_stack+1037464);

 /* compute (6 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+1819, dvrr_stack+253018, dvrr_stack+1693, dvrr_stack+359265, dvrr_stack+1073651, dvrr_stack+724719);

 /* compute (7 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+724974, dvrr_stack+25972, dvrr_stack+1819, dvrr_stack+298169, dvrr_stack+253018, dvrr_stack+724782);

 /* compute (8 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+1468098, dvrr_stack+542730, dvrr_stack+724974, dvrr_stack+359355, dvrr_stack+25972, dvrr_stack+724866);

 /* compute (9 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+358163, dvrr_stack+1468098, dvrr_stack+359523, dvrr_stack+542730, dvrr_stack+0);

 /* compute (1 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+336089, dvrr_stack+19285, dvrr_stack+32098, NULL, NULL, dvrr_stack+8980);

 /* compute (2 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+0, dvrr_stack+67888, dvrr_stack+336089, dvrr_stack+9319, dvrr_stack+19285, dvrr_stack+48030);

 /* compute (3 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+67722, dvrr_stack+67918, dvrr_stack+0, dvrr_stack+69216, dvrr_stack+67888, dvrr_stack+70123);

 /* compute (4 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+60, dvrr_stack+67978, dvrr_stack+67722, dvrr_stack+68949, dvrr_stack+67918, dvrr_stack+275056);

 /* compute (5 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+502145, dvrr_stack+68078, dvrr_stack+60, dvrr_stack+325832, dvrr_stack+67978, dvrr_stack+1603);

 /* compute (6 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+68949, dvrr_stack+615840, dvrr_stack+502145, dvrr_stack+325932, dvrr_stack+68078, dvrr_stack+1693);

 /* compute (7 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+542660, dvrr_stack+1056167, dvrr_stack+68949, dvrr_stack+8770, dvrr_stack+615840, dvrr_stack+1819);

 /* compute (8 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+68228, dvrr_stack+542660, dvrr_stack+51734, dvrr_stack+1056167, dvrr_stack+724974);

 /* compute (9 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+325013, dvrr_stack+960103, dvrr_stack+319, dvrr_stack+34632, dvrr_stack+68228, dvrr_stack+1468098);

 /* compute (10 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+67888, dvrr_stack+210722, dvrr_stack+325013, dvrr_stack+275116, dvrr_stack+960103, dvrr_stack+10462);

 /* compute (1 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+1037464, dvrr_stack+32108, dvrr_stack+32407, NULL, NULL, dvrr_stack+32098);

 /* compute (2 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+1073651, dvrr_stack+185569, dvrr_stack+1037464, dvrr_stack+19295, dvrr_stack+32108, dvrr_stack+336089);

 /* compute (3 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+10462, dvrr_stack+402405, dvrr_stack+1073651, dvrr_stack+35232, dvrr_stack+185569, dvrr_stack+0);

 /* compute (4 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+960103, dvrr_stack+31432, dvrr_stack+10462, dvrr_stack+35277, dvrr_stack+402405, dvrr_stack+67722);

 /* compute (5 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+210722, dvrr_stack+63610, dvrr_stack+960103, dvrr_stack+35367, dvrr_stack+31432, dvrr_stack+60);

 /* compute (6 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+275056, dvrr_stack+31582, dvrr_stack+210722, dvrr_stack+52014, dvrr_stack+63610, dvrr_stack+502145);

 /* compute (7 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1001959, dvrr_stack+358433, dvrr_stack+275056, dvrr_stack+19440, dvrr_stack+31582, dvrr_stack+68949);

 /* compute (8 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+1048399, dvrr_stack+1001959, dvrr_stack+19755, dvrr_stack+358433, dvrr_stack+542660);

 /* compute (9 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+358163, dvrr_stack+47176, dvrr_stack+31432, dvrr_stack+10792, dvrr_stack+1048399, dvrr_stack+319);

 /* compute (10 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+361944, dvrr_stack+358163, dvrr_stack+2701, dvrr_stack+47176, dvrr_stack+325013);

 /* compute (11 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1554914, dvrr_stack+95502, dvrr_stack+33852, dvrr_stack+70159, dvrr_stack+361944, dvrr_stack+67888);

 /* compute (1 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+118591, dvrr_stack+47981, dvrr_stack+67637, NULL, NULL, dvrr_stack+32407);

 /* compute (2 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+253018, dvrr_stack+584320, dvrr_stack+118591, dvrr_stack+32123, dvrr_stack+47981, dvrr_stack+1037464);

 /* compute (3 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+502145, dvrr_stack+584383, dvrr_stack+253018, dvrr_stack+2318, dvrr_stack+584320, dvrr_stack+1073651);

 /* compute (4 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+32107, dvrr_stack+584509, dvrr_stack+502145, dvrr_stack+258052, dvrr_stack+584383, dvrr_stack+10462);

 /* compute (5 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+10462, dvrr_stack+32422, dvrr_stack+32107, dvrr_stack+11332, dvrr_stack+584509, dvrr_stack+960103);

 /* compute (6 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+10903, dvrr_stack+90115, dvrr_stack+10462, dvrr_stack+70984, dvrr_stack+32422, dvrr_stack+210722);

 /* compute (7 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+163606, dvrr_stack+10903, dvrr_stack+90793, dvrr_stack+90115, dvrr_stack+275056);

 /* compute (8 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+67888, dvrr_stack+96492, dvrr_stack+32422, dvrr_stack+71299, dvrr_stack+163606, dvrr_stack+1001959);

 /* compute (9 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+70123, dvrr_stack+584719, dvrr_stack+67888, dvrr_stack+71887, dvrr_stack+96492, dvrr_stack+31432);

 /* compute (10 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+95502, dvrr_stack+1353821, dvrr_stack+70123, dvrr_stack+827289, dvrr_stack+584719, dvrr_stack+358163);

 /* compute (11 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+1556084, dvrr_stack+585664, dvrr_stack+95502, dvrr_stack+93339, dvrr_stack+1353821, dvrr_stack+33852);

 /* compute (12 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+1557722, dvrr_stack+1354976, dvrr_stack+1556084, dvrr_stack+828234, dvrr_stack+585664, dvrr_stack+1554914);

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,21,dvrr_stack+33852, dvrr_stack+1557722, dvrr_stack+828234);

 /* compute (1 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1554914, dvrr_stack+67658, dvrr_stack+69879, NULL, NULL, dvrr_stack+67637);

 /* compute (2 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+25972, dvrr_stack+8986, dvrr_stack+1554914, dvrr_stack+48002, dvrr_stack+67658, dvrr_stack+118591);

 /* compute (3 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1056167, dvrr_stack+9070, dvrr_stack+25972, dvrr_stack+2381, dvrr_stack+8986, dvrr_stack+253018);

 /* compute (4 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+1554998, dvrr_stack+587050, dvrr_stack+1056167, dvrr_stack+91234, dvrr_stack+9070, dvrr_stack+502145);

 /* compute (5 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+1555418, dvrr_stack+587330, dvrr_stack+1554998, dvrr_stack+2021, dvrr_stack+587050, dvrr_stack+32107);

 /* compute (6 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+358163, dvrr_stack+18662, dvrr_stack+1555418, dvrr_stack+94494, dvrr_stack+587330, dvrr_stack+10462);

 /* compute (7 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+584320, dvrr_stack+1356614, dvrr_stack+358163, dvrr_stack+94914, dvrr_stack+18662, dvrr_stack+10903);

 /* compute (8 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+1357398, dvrr_stack+584320, dvrr_stack+829620, dvrr_stack+1356614, dvrr_stack+32422);

 /* compute (9 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+1358406, dvrr_stack+18662, dvrr_stack+830404, dvrr_stack+1357398, dvrr_stack+67888);

 /* compute (10 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+585328, dvrr_stack+1359666, dvrr_stack+31432, dvrr_stack+831412, dvrr_stack+1358406, dvrr_stack+70123);

 /* compute (11 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+70123, dvrr_stack+589195, dvrr_stack+585328, dvrr_stack+832672, dvrr_stack+1359666, dvrr_stack+95502);

 /* compute (12 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1356614, dvrr_stack+1361206, dvrr_stack+70123, dvrr_stack+834212, dvrr_stack+589195, dvrr_stack+1556084);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,28,dvrr_stack+829620, dvrr_stack+1356614, dvrr_stack+834212);

 /* compute (1 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+962173, dvrr_stack+1567, dvrr_stack+68913, NULL, NULL, dvrr_stack+69879);

 /* compute (2 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+589195, dvrr_stack+592681, dvrr_stack+962173, dvrr_stack+67686, dvrr_stack+1567, dvrr_stack+1554914);

 /* compute (3 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+589411, dvrr_stack+69907, dvrr_stack+589195, dvrr_stack+393792, dvrr_stack+592681, dvrr_stack+25972);

 /* compute (4 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+589771, dvrr_stack+848, dvrr_stack+589411, dvrr_stack+393900, dvrr_stack+69907, dvrr_stack+1056167);

 /* compute (5 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+67888, dvrr_stack+66670, dvrr_stack+589771, dvrr_stack+394116, dvrr_stack+848, dvrr_stack+1554998);

 /* compute (6 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+393792, dvrr_stack+1368304, dvrr_stack+67888, dvrr_stack+69246, dvrr_stack+66670, dvrr_stack+1555418);

 /* compute (7 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1554914, dvrr_stack+1369060, dvrr_stack+393792, dvrr_stack+48619, dvrr_stack+1368304, dvrr_stack+358163);

 /* compute (8 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1359162, dvrr_stack+237876, dvrr_stack+1554914, dvrr_stack+840218, dvrr_stack+1369060, dvrr_stack+584320);

 /* compute (9 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+831804, dvrr_stack+1370068, dvrr_stack+1359162, dvrr_stack+841226, dvrr_stack+237876, dvrr_stack+18662);

 /* compute (10 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+839849, dvrr_stack+1371688, dvrr_stack+831804, dvrr_stack+842522, dvrr_stack+1370068, dvrr_stack+31432);

 /* compute (11 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1368202, dvrr_stack+597840, dvrr_stack+839849, dvrr_stack+398895, dvrr_stack+1371688, dvrr_stack+585328);

 /* compute (12 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+584320, dvrr_stack+1373668, dvrr_stack+1368202, dvrr_stack+844142, dvrr_stack+597840, dvrr_stack+70123);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,36,dvrr_stack+68949, dvrr_stack+584320, dvrr_stack+844142);

 /* compute (1 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+597840, dvrr_stack+9401, dvrr_stack+133535, NULL, NULL, dvrr_stack+68913);

 /* compute (2 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+597975, dvrr_stack+90556, dvrr_stack+597840, dvrr_stack+20176, dvrr_stack+9401, dvrr_stack+962173);

 /* compute (3 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+960103, dvrr_stack+362769, dvrr_stack+597975, dvrr_stack+400875, dvrr_stack+90556, dvrr_stack+589195);

 /* compute (4 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+598245, dvrr_stack+514325, dvrr_stack+960103, dvrr_stack+401010, dvrr_stack+362769, dvrr_stack+589411);

 /* compute (5 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+827289, dvrr_stack+1383028, dvrr_stack+598245, dvrr_stack+401280, dvrr_stack+514325, dvrr_stack+589771);

 /* compute (6 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+589195, dvrr_stack+1383703, dvrr_stack+827289, dvrr_stack+401730, dvrr_stack+1383028, dvrr_stack+67888);

 /* compute (7 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+1384648, dvrr_stack+589195, dvrr_stack+117646, dvrr_stack+1383703, dvrr_stack+393792);

 /* compute (8 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1371010, dvrr_stack+242227, dvrr_stack+31432, dvrr_stack+864536, dvrr_stack+1384648, dvrr_stack+1554914);

 /* compute (9 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1554914, dvrr_stack+1385908, dvrr_stack+1371010, dvrr_stack+865796, dvrr_stack+242227, dvrr_stack+1359162);

 /* compute (10 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1382848, dvrr_stack+1387933, dvrr_stack+1554914, dvrr_stack+867416, dvrr_stack+1385908, dvrr_stack+831804);

 /* compute (11 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+864536, dvrr_stack+619515, dvrr_stack+1382848, dvrr_stack+414780, dvrr_stack+1387933, dvrr_stack+839849);

 /* compute (12 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+839849, dvrr_stack+1390408, dvrr_stack+864536, dvrr_stack+869441, dvrr_stack+619515, dvrr_stack+1368202);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,45,dvrr_stack+1385818, dvrr_stack+839849, dvrr_stack+869441);

 /* compute (1 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1368202, dvrr_stack+147395, dvrr_stack+18607, NULL, NULL, dvrr_stack+133535);

 /* compute (2 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1368367, dvrr_stack+587750, dvrr_stack+1368202, dvrr_stack+264, dvrr_stack+147395, dvrr_stack+597840);

 /* compute (3 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1368697, dvrr_stack+1208, dvrr_stack+1368367, dvrr_stack+417255, dvrr_stack+587750, dvrr_stack+597975);

 /* compute (4 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1369247, dvrr_stack+8203, dvrr_stack+1368697, dvrr_stack+417420, dvrr_stack+1208, dvrr_stack+960103);

 /* compute (5 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+619515, dvrr_stack+1402342, dvrr_stack+1369247, dvrr_stack+417750, dvrr_stack+8203, dvrr_stack+598245);

 /* compute (6 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8203, dvrr_stack+1403167, dvrr_stack+619515, dvrr_stack+418300, dvrr_stack+1402342, dvrr_stack+827289);

 /* compute (7 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+597840, dvrr_stack+1404322, dvrr_stack+8203, dvrr_stack+896171, dvrr_stack+1403167, dvrr_stack+589195);

 /* compute (8 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+414780, dvrr_stack+1405862, dvrr_stack+597840, dvrr_stack+897326, dvrr_stack+1404322, dvrr_stack+31432);

 /* compute (9 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1402015, dvrr_stack+1407842, dvrr_stack+414780, dvrr_stack+898866, dvrr_stack+1405862, dvrr_stack+1371010);

 /* compute (10 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+896171, dvrr_stack+1410317, dvrr_stack+1402015, dvrr_stack+435480, dvrr_stack+1407842, dvrr_stack+1554914);

 /* compute (11 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1405040, dvrr_stack+645165, dvrr_stack+896171, dvrr_stack+900846, dvrr_stack+1410317, dvrr_stack+1382848);

 /* compute (12 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1559633, dvrr_stack+1413342, dvrr_stack+1405040, dvrr_stack+903871, dvrr_stack+645165, dvrr_stack+864536);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,55,dvrr_stack+864536, dvrr_stack+1559633, dvrr_stack+903871);

 /* compute (1 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+843944, dvrr_stack+67822, dvrr_stack+502355, NULL, NULL, dvrr_stack+18607);

 /* compute (2 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+599820, dvrr_stack+5571, dvrr_stack+843944, dvrr_stack+48111, dvrr_stack+67822, dvrr_stack+1368202);

 /* compute (3 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+5769, dvrr_stack+599820, dvrr_stack+437955, dvrr_stack+5571, dvrr_stack+1368367);

 /* compute (4 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19267, dvrr_stack+4594, dvrr_stack+18607, dvrr_stack+438153, dvrr_stack+5769, dvrr_stack+1368697);

 /* compute (5 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+645165, dvrr_stack+1428162, dvrr_stack+19267, dvrr_stack+438549, dvrr_stack+4594, dvrr_stack+1369247);

 /* compute (6 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+589195, dvrr_stack+1429152, dvrr_stack+645165, dvrr_stack+439209, dvrr_stack+1428162, dvrr_stack+619515);

 /* compute (7 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+619515, dvrr_stack+1430538, dvrr_stack+589195, dvrr_stack+937795, dvrr_stack+1429152, dvrr_stack+8203);

 /* compute (8 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1382848, dvrr_stack+1432386, dvrr_stack+619515, dvrr_stack+939181, dvrr_stack+1430538, dvrr_stack+597840);

 /* compute (9 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+645165, dvrr_stack+1434762, dvrr_stack+1382848, dvrr_stack+941029, dvrr_stack+1432386, dvrr_stack+414780);

 /* compute (10 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+937795, dvrr_stack+1437732, dvrr_stack+645165, dvrr_stack+462185, dvrr_stack+1434762, dvrr_stack+1402015);

 /* compute (11 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1368202, dvrr_stack+1441362, dvrr_stack+937795, dvrr_stack+943405, dvrr_stack+1437732, dvrr_stack+896171);

 /* compute (12 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+896171, dvrr_stack+680585, dvrr_stack+1368202, dvrr_stack+947035, dvrr_stack+1441362, dvrr_stack+1405040);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,66,dvrr_stack+1368202, dvrr_stack+896171, dvrr_stack+947035);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+1373350, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+902177, dvrr_stack+237120, dvrr_stack+3730);
 tmp = dvrr_stack + 902177;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+902765, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+937795, dvrr_stack+239248, dvrr_stack+6859);
 tmp = dvrr_stack + 937795;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+903185, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+393792, dvrr_stack+244288, dvrr_stack+12118);
 tmp = dvrr_stack + 393792;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+938579, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+939254, dvrr_stack+258292, dvrr_stack+22927);
 tmp = dvrr_stack + 939254;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+940514, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+941339, dvrr_stack+275567, dvrr_stack+36382);
 tmp = dvrr_stack + 941339;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+942879, dvrr_stack+53314, dvrr_stack+49618);

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+589195, dvrr_stack+298295, dvrr_stack+53314);
 tmp = dvrr_stack + 589195;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+943869, dvrr_stack+117058, dvrr_stack+3415);
 tmp = dvrr_stack + 943869;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+944310, dvrr_stack+392847, dvrr_stack+117058);
 tmp = dvrr_stack + 944310;
 target_ptr = Libderiv->deriv_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+945066, dvrr_stack+118654, dvrr_stack+6439);
 tmp = dvrr_stack + 945066;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+117646, dvrr_stack+394800, dvrr_stack+118654);
 tmp = dvrr_stack + 117646;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+945654, dvrr_stack+122858, dvrr_stack+11578);
 tmp = dvrr_stack + 945654;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1402015, dvrr_stack+121202, dvrr_stack+122858);
 tmp = dvrr_stack + 1402015;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+827289, dvrr_stack+133580, dvrr_stack+22252);
 tmp = dvrr_stack + 827289;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+242227, dvrr_stack+131510, dvrr_stack+133580);
 tmp = dvrr_stack + 242227;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1403311, dvrr_stack+147450, dvrr_stack+35557);
 tmp = dvrr_stack + 1403311;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1404466, dvrr_stack+144920, dvrr_stack+147450);
 tmp = dvrr_stack + 1404466;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+1406446, dvrr_stack+164218, dvrr_stack+52324);
 tmp = dvrr_stack + 1406446;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+597840, dvrr_stack+469445, dvrr_stack+164218);
 tmp = dvrr_stack + 597840;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1407832, dvrr_stack+588040, dvrr_stack+237120);
 tmp = dvrr_stack + 1407832;
 target_ptr = Libderiv->deriv_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1408777, dvrr_stack+592835, dvrr_stack+239248);
 tmp = dvrr_stack + 1408777;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1410037, dvrr_stack+602520, dvrr_stack+244288);
 tmp = dvrr_stack + 1410037;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+462185, dvrr_stack+255412, dvrr_stack+258292);
 tmp = dvrr_stack + 462185;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+645165, dvrr_stack+652315, dvrr_stack+275567);
 tmp = dvrr_stack + 645165;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+1382848, dvrr_stack+294071, dvrr_stack+298295);
 tmp = dvrr_stack + 1382848;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+647640, dvrr_stack+828234, dvrr_stack+392847);
 tmp = dvrr_stack + 647640;
 target_ptr = Libderiv->deriv_classes[9][5][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1411657, dvrr_stack+834212, dvrr_stack+394800);
 tmp = dvrr_stack + 1411657;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+414780, dvrr_stack+844142, dvrr_stack+121202);
 tmp = dvrr_stack + 414780;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+619515, dvrr_stack+869441, dvrr_stack+131510);
 tmp = dvrr_stack + 619515;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+435480, dvrr_stack+903871, dvrr_stack+144920);
 tmp = dvrr_stack + 435480;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+1427745, dvrr_stack+947035, dvrr_stack+469445);
 tmp = dvrr_stack + 1427745;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+416760, dvrr_stack+1354976, dvrr_stack+588040);
 tmp = dvrr_stack + 416760;
 target_ptr = Libderiv->deriv_classes[10][5][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+8203, dvrr_stack+1361206, dvrr_stack+592835);
 tmp = dvrr_stack + 8203;
 target_ptr = Libderiv->deriv_classes[10][6][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+1554914, dvrr_stack+1373668, dvrr_stack+602520);
 tmp = dvrr_stack + 1554914;
 target_ptr = Libderiv->deriv_classes[10][7][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+1431375, dvrr_stack+1390408, dvrr_stack+255412);
 tmp = dvrr_stack + 1431375;
 target_ptr = Libderiv->deriv_classes[10][8][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+1434345, dvrr_stack+1413342, dvrr_stack+652315);
 tmp = dvrr_stack + 1434345;
 target_ptr = Libderiv->deriv_classes[10][9][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+1437975, dvrr_stack+680585, dvrr_stack+294071);
 tmp = dvrr_stack + 1437975;
 target_ptr = Libderiv->deriv_classes[10][10][1];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,21,dvrr_stack+18607, dvrr_stack+1557722, dvrr_stack+828234);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,28,dvrr_stack+831804, dvrr_stack+1356614, dvrr_stack+834212);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,36,dvrr_stack+1442331, dvrr_stack+584320, dvrr_stack+844142);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,45,dvrr_stack+398464, dvrr_stack+839849, dvrr_stack+869441);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,55,dvrr_stack+92942, dvrr_stack+1559633, dvrr_stack+903871);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,66,dvrr_stack+1564638, dvrr_stack+896171, dvrr_stack+947035);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+946410, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+464210, dvrr_stack+237120, dvrr_stack+3730);
 tmp = dvrr_stack + 464210;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+3730, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+418146, dvrr_stack+239248, dvrr_stack+6859);
 tmp = dvrr_stack + 418146;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+6859, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+10051, dvrr_stack+244288, dvrr_stack+12118);
 tmp = dvrr_stack + 10051;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+12118, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+438505, dvrr_stack+258292, dvrr_stack+22927);
 tmp = dvrr_stack + 438505;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+22927, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+31432, dvrr_stack+275567, dvrr_stack+36382);
 tmp = dvrr_stack + 31432;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+36382, dvrr_stack+53314, dvrr_stack+49618);

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+4591, dvrr_stack+298295, dvrr_stack+53314);
 tmp = dvrr_stack + 4591;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+53314, dvrr_stack+117058, dvrr_stack+3415);
 tmp = dvrr_stack + 53314;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+53755, dvrr_stack+392847, dvrr_stack+117058);
 tmp = dvrr_stack + 53755;
 target_ptr = Libderiv->deriv_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+117058, dvrr_stack+118654, dvrr_stack+6439);
 tmp = dvrr_stack + 117058;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+1359162, dvrr_stack+394800, dvrr_stack+118654);
 tmp = dvrr_stack + 1359162;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+118654, dvrr_stack+122858, dvrr_stack+11578);
 tmp = dvrr_stack + 118654;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+237876, dvrr_stack+121202, dvrr_stack+122858);
 tmp = dvrr_stack + 237876;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+11059, dvrr_stack+133580, dvrr_stack+22252);
 tmp = dvrr_stack + 11059;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+66670, dvrr_stack+131510, dvrr_stack+133580);
 tmp = dvrr_stack + 66670;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+133535, dvrr_stack+147450, dvrr_stack+35557);
 tmp = dvrr_stack + 133535;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+47176, dvrr_stack+144920, dvrr_stack+147450);
 tmp = dvrr_stack + 47176;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+147395, dvrr_stack+164218, dvrr_stack+52324);
 tmp = dvrr_stack + 147395;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+0, dvrr_stack+469445, dvrr_stack+164218);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+1360170, dvrr_stack+588040, dvrr_stack+237120);
 tmp = dvrr_stack + 1360170;
 target_ptr = Libderiv->deriv_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+358163, dvrr_stack+592835, dvrr_stack+239248);
 tmp = dvrr_stack + 358163;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+163606, dvrr_stack+602520, dvrr_stack+244288);
 tmp = dvrr_stack + 163606;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1569786, dvrr_stack+255412, dvrr_stack+258292);
 tmp = dvrr_stack + 1569786;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1571811, dvrr_stack+652315, dvrr_stack+275567);
 tmp = dvrr_stack + 1571811;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1574286, dvrr_stack+294071, dvrr_stack+298295);
 tmp = dvrr_stack + 1574286;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+244288, dvrr_stack+828234, dvrr_stack+392847);
 tmp = dvrr_stack + 244288;
 target_ptr = Libderiv->deriv_classes[9][5][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+275056, dvrr_stack+834212, dvrr_stack+394800);
 tmp = dvrr_stack + 275056;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+297701, dvrr_stack+844142, dvrr_stack+121202);
 tmp = dvrr_stack + 297701;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+121202, dvrr_stack+869441, dvrr_stack+131510);
 tmp = dvrr_stack + 121202;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1577256, dvrr_stack+903871, dvrr_stack+144920);
 tmp = dvrr_stack + 1577256;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1580281, dvrr_stack+947035, dvrr_stack+469445);
 tmp = dvrr_stack + 1580281;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+144920, dvrr_stack+1354976, dvrr_stack+588040);
 tmp = dvrr_stack + 144920;
 target_ptr = Libderiv->deriv_classes[10][5][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+131510, dvrr_stack+1361206, dvrr_stack+592835);
 tmp = dvrr_stack + 131510;
 target_ptr = Libderiv->deriv_classes[10][6][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+1353314, dvrr_stack+1373668, dvrr_stack+602520);
 tmp = dvrr_stack + 1353314;
 target_ptr = Libderiv->deriv_classes[10][7][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+469259, dvrr_stack+1390408, dvrr_stack+255412);
 tmp = dvrr_stack + 469259;
 target_ptr = Libderiv->deriv_classes[10][8][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+255412, dvrr_stack+1413342, dvrr_stack+652315);
 tmp = dvrr_stack + 255412;
 target_ptr = Libderiv->deriv_classes[10][9][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+1413197, dvrr_stack+680585, dvrr_stack+294071);
 tmp = dvrr_stack + 1413197;
 target_ptr = Libderiv->deriv_classes[10][10][0];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,21,dvrr_stack+294071, dvrr_stack+1557722, dvrr_stack+828234);

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,28,dvrr_stack+680585, dvrr_stack+1356614, dvrr_stack+834212);

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,36,dvrr_stack+682769, dvrr_stack+584320, dvrr_stack+844142);

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,45,dvrr_stack+584320, dvrr_stack+839849, dvrr_stack+869441);

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,55,dvrr_stack+839849, dvrr_stack+1559633, dvrr_stack+903871);

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,66,dvrr_stack+1557290, dvrr_stack+896171, dvrr_stack+947035);

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+896171, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 896171;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+896612, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 896612;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+237120, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 237120;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+392847, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 392847;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+897200, dvrr_stack+86650, NULL);
 tmp = dvrr_stack + 897200;
 target_ptr = Libderiv->deriv2_classes[5][9][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+828234, dvrr_stack+112900, NULL);
 tmp = dvrr_stack + 828234;
 target_ptr = Libderiv->deriv2_classes[5][10][143];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+898355, dvrr_stack+129746, NULL);
 tmp = dvrr_stack + 898355;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+898943, dvrr_stack+142568, NULL);
 tmp = dvrr_stack + 898943;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+899727, dvrr_stack+158818, NULL);
 tmp = dvrr_stack + 899727;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+394800, dvrr_stack+178246, NULL);
 tmp = dvrr_stack + 394800;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+844139, dvrr_stack+202582, NULL);
 tmp = dvrr_stack + 844139;
 target_ptr = Libderiv->deriv2_classes[6][9][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+295709, dvrr_stack+231576, NULL);
 tmp = dvrr_stack + 295709;
 target_ptr = Libderiv->deriv2_classes[6][10][143];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+900735, dvrr_stack+253144, NULL);
 tmp = dvrr_stack + 900735;
 target_ptr = Libderiv->deriv2_classes[7][5][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+587830, dvrr_stack+269848, NULL);
 tmp = dvrr_stack + 587830;
 target_ptr = Libderiv->deriv2_classes[7][6][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+1373665, dvrr_stack+290183, NULL);
 tmp = dvrr_stack + 1373665;
 target_ptr = Libderiv->deriv2_classes[7][7][143];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+903725, dvrr_stack+316331, NULL);
 tmp = dvrr_stack + 903725;
 target_ptr = Libderiv->deriv2_classes[7][8][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+905345, dvrr_stack+347999, NULL);
 tmp = dvrr_stack + 905345;
 target_ptr = Libderiv->deriv2_classes[7][9][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+946725, dvrr_stack+385719, NULL);
 tmp = dvrr_stack + 946725;
 target_ptr = Libderiv->deriv2_classes[7][10][143];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+146306, dvrr_stack+411945, NULL);
 tmp = dvrr_stack + 146306;
 target_ptr = Libderiv->deriv2_classes[8][5][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+1374961, dvrr_stack+431700, NULL);
 tmp = dvrr_stack + 1374961;
 target_ptr = Libderiv->deriv2_classes[8][6][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+949101, dvrr_stack+457325, NULL);
 tmp = dvrr_stack + 949101;
 target_ptr = Libderiv->deriv2_classes[8][7][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+868826, dvrr_stack+491990, NULL);
 tmp = dvrr_stack + 868826;
 target_ptr = Libderiv->deriv2_classes[8][8][143];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+652305, dvrr_stack+529625, NULL);
 tmp = dvrr_stack + 652305;
 target_ptr = Libderiv->deriv2_classes[8][9][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+1389328, dvrr_stack+575410, NULL);
 tmp = dvrr_stack + 1389328;
 target_ptr = Libderiv->deriv2_classes[8][10][143];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+870851, dvrr_stack+616050, NULL);
 tmp = dvrr_stack + 870851;
 target_ptr = Libderiv->deriv2_classes[9][5][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+1562438, dvrr_stack+640545, NULL);
 tmp = dvrr_stack + 1562438;
 target_ptr = Libderiv->deriv2_classes[9][6][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+833988, dvrr_stack+674645, NULL);
 tmp = dvrr_stack + 833988;
 target_ptr = Libderiv->deriv2_classes[9][7][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+1355690, dvrr_stack+711704, NULL);
 tmp = dvrr_stack + 1355690;
 target_ptr = Libderiv->deriv2_classes[9][8][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+1583911, dvrr_stack+759479, NULL);
 tmp = dvrr_stack + 1583911;
 target_ptr = Libderiv->deriv2_classes[9][9][143];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+1586936, dvrr_stack+816399, NULL);
 tmp = dvrr_stack + 1586936;
 target_ptr = Libderiv->deriv2_classes[9][10][143];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+1361115, dvrr_stack+860378, NULL);
 tmp = dvrr_stack + 1361115;
 target_ptr = Libderiv->deriv2_classes[10][5][143];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+602400, dvrr_stack+890627, NULL);
 tmp = dvrr_stack + 602400;
 target_ptr = Libderiv->deriv2_classes[10][6][143];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+1590566, dvrr_stack+930667, NULL);
 tmp = dvrr_stack + 1590566;
 target_ptr = Libderiv->deriv2_classes[10][7][143];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+1592942, dvrr_stack+980101, NULL);
 tmp = dvrr_stack + 1592942;
 target_ptr = Libderiv->deriv2_classes[10][8][143];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+1595912, dvrr_stack+1037509, NULL);
 tmp = dvrr_stack + 1595912;
 target_ptr = Libderiv->deriv2_classes[10][9][143];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+1599542, dvrr_stack+768554, NULL);
 tmp = dvrr_stack + 1599542;
 target_ptr = Libderiv->deriv2_classes[10][10][143];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+901491, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 901491;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+845679, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 845679;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+259042, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 259042;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+239172, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 239172;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+592681, dvrr_stack+86650, NULL);
 tmp = dvrr_stack + 592681;
 target_ptr = Libderiv->deriv2_classes[5][9][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1386,dvrr_stack+1392298, dvrr_stack+112900, NULL);
 tmp = dvrr_stack + 1392298;
 target_ptr = Libderiv->deriv2_classes[5][10][131];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+950721, dvrr_stack+129746, NULL);
 tmp = dvrr_stack + 950721;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+32972, dvrr_stack+142568, NULL);
 tmp = dvrr_stack + 32972;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+90115, dvrr_stack+158818, NULL);
 tmp = dvrr_stack + 90115;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+2376, dvrr_stack+178246, NULL);
 tmp = dvrr_stack + 2376;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+51601, dvrr_stack+202582, NULL);
 tmp = dvrr_stack + 51601;
 target_ptr = Libderiv->deriv2_classes[6][9][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1848,dvrr_stack+1603898, dvrr_stack+231576, NULL);
 tmp = dvrr_stack + 1603898;
 target_ptr = Libderiv->deriv2_classes[6][10][131];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+1362501, dvrr_stack+253144, NULL);
 tmp = dvrr_stack + 1362501;
 target_ptr = Libderiv->deriv2_classes[7][5][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+361944, dvrr_stack+269848, NULL);
 tmp = dvrr_stack + 361944;
 target_ptr = Libderiv->deriv2_classes[7][6][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1296,dvrr_stack+1605746, dvrr_stack+290183, NULL);
 tmp = dvrr_stack + 1605746;
 target_ptr = Libderiv->deriv2_classes[7][7][131];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1607042, dvrr_stack+316331, NULL);
 tmp = dvrr_stack + 1607042;
 target_ptr = Libderiv->deriv2_classes[7][8][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1608662, dvrr_stack+347999, NULL);
 tmp = dvrr_stack + 1608662;
 target_ptr = Libderiv->deriv2_classes[7][9][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2376,dvrr_stack+1610642, dvrr_stack+385719, NULL);
 tmp = dvrr_stack + 1610642;
 target_ptr = Libderiv->deriv2_classes[7][10][131];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+276596, dvrr_stack+411945, NULL);
 tmp = dvrr_stack + 276596;
 target_ptr = Libderiv->deriv2_classes[8][5][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1613018, dvrr_stack+431700, NULL);
 tmp = dvrr_stack + 1613018;
 target_ptr = Libderiv->deriv2_classes[8][6][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1614278, dvrr_stack+457325, NULL);
 tmp = dvrr_stack + 1614278;
 target_ptr = Libderiv->deriv2_classes[8][7][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2025,dvrr_stack+1615898, dvrr_stack+491990, NULL);
 tmp = dvrr_stack + 1615898;
 target_ptr = Libderiv->deriv2_classes[8][8][131];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1617923, dvrr_stack+529625, NULL);
 tmp = dvrr_stack + 1617923;
 target_ptr = Libderiv->deriv2_classes[8][9][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1620398, dvrr_stack+575410, NULL);
 tmp = dvrr_stack + 1620398;
 target_ptr = Libderiv->deriv2_classes[8][10][131];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+1623368, dvrr_stack+616050, NULL);
 tmp = dvrr_stack + 1623368;
 target_ptr = Libderiv->deriv2_classes[9][5][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+1624523, dvrr_stack+640545, NULL);
 tmp = dvrr_stack + 1624523;
 target_ptr = Libderiv->deriv2_classes[9][6][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1626063, dvrr_stack+674645, NULL);
 tmp = dvrr_stack + 1626063;
 target_ptr = Libderiv->deriv2_classes[9][7][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1628043, dvrr_stack+711704, NULL);
 tmp = dvrr_stack + 1628043;
 target_ptr = Libderiv->deriv2_classes[9][8][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,3025,dvrr_stack+1630518, dvrr_stack+759479, NULL);
 tmp = dvrr_stack + 1630518;
 target_ptr = Libderiv->deriv2_classes[9][9][131];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1633543, dvrr_stack+816399, NULL);
 tmp = dvrr_stack + 1633543;
 target_ptr = Libderiv->deriv2_classes[9][10][131];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1386,dvrr_stack+1637173, dvrr_stack+860378, NULL);
 tmp = dvrr_stack + 1637173;
 target_ptr = Libderiv->deriv2_classes[10][5][131];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1848,dvrr_stack+1638559, dvrr_stack+890627, NULL);
 tmp = dvrr_stack + 1638559;
 target_ptr = Libderiv->deriv2_classes[10][6][131];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2376,dvrr_stack+1640407, dvrr_stack+930667, NULL);
 tmp = dvrr_stack + 1640407;
 target_ptr = Libderiv->deriv2_classes[10][7][131];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1642783, dvrr_stack+980101, NULL);
 tmp = dvrr_stack + 1642783;
 target_ptr = Libderiv->deriv2_classes[10][8][131];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1645753, dvrr_stack+1037509, NULL);
 tmp = dvrr_stack + 1645753;
 target_ptr = Libderiv->deriv2_classes[10][9][131];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,4356,dvrr_stack+1649383, dvrr_stack+768554, NULL);
 tmp = dvrr_stack + 1649383;
 target_ptr = Libderiv->deriv2_classes[10][10][131];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+621990, dvrr_stack+543056, NULL);
 tmp = dvrr_stack + 621990;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+20245, dvrr_stack+544379, NULL);
 tmp = dvrr_stack + 20245;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+35490, dvrr_stack+502421, NULL);
 tmp = dvrr_stack + 35490;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+325013, dvrr_stack+1089979, NULL);
 tmp = dvrr_stack + 325013;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+1653739, dvrr_stack+1092814, NULL);
 tmp = dvrr_stack + 1653739;
 target_ptr = Libderiv->deriv2_classes[5][9][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+1654894, dvrr_stack+1096279, NULL);
 tmp = dvrr_stack + 1654894;
 target_ptr = Libderiv->deriv2_classes[5][10][130];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+1563978, dvrr_stack+161842, NULL);
 tmp = dvrr_stack + 1563978;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+165226, dvrr_stack+1100437, NULL);
 tmp = dvrr_stack + 165226;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+49156, dvrr_stack+1102789, NULL);
 tmp = dvrr_stack + 49156;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1656280, dvrr_stack+1105813, NULL);
 tmp = dvrr_stack + 1656280;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+1657540, dvrr_stack+1109593, NULL);
 tmp = dvrr_stack + 1657540;
 target_ptr = Libderiv->deriv2_classes[6][9][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+1659080, dvrr_stack+1114213, NULL);
 tmp = dvrr_stack + 1659080;
 target_ptr = Libderiv->deriv2_classes[6][10][130];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+71757, dvrr_stack+1119757, NULL);
 tmp = dvrr_stack + 71757;
 target_ptr = Libderiv->deriv2_classes[7][5][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+1660928, dvrr_stack+1122025, NULL);
 tmp = dvrr_stack + 1660928;
 target_ptr = Libderiv->deriv2_classes[7][6][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+1661936, dvrr_stack+1125049, NULL);
 tmp = dvrr_stack + 1661936;
 target_ptr = Libderiv->deriv2_classes[7][7][130];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1663232, dvrr_stack+1128937, NULL);
 tmp = dvrr_stack + 1663232;
 target_ptr = Libderiv->deriv2_classes[7][8][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1664852, dvrr_stack+1133797, NULL);
 tmp = dvrr_stack + 1664852;
 target_ptr = Libderiv->deriv2_classes[7][9][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+1666832, dvrr_stack+1139737, NULL);
 tmp = dvrr_stack + 1666832;
 target_ptr = Libderiv->deriv2_classes[7][10][130];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+1358165, dvrr_stack+1146865, NULL);
 tmp = dvrr_stack + 1358165;
 target_ptr = Libderiv->deriv2_classes[8][5][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1669208, dvrr_stack+1149700, NULL);
 tmp = dvrr_stack + 1669208;
 target_ptr = Libderiv->deriv2_classes[8][6][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1670468, dvrr_stack+1153480, NULL);
 tmp = dvrr_stack + 1670468;
 target_ptr = Libderiv->deriv2_classes[8][7][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+1672088, dvrr_stack+1158340, NULL);
 tmp = dvrr_stack + 1672088;
 target_ptr = Libderiv->deriv2_classes[8][8][130];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1674113, dvrr_stack+1164415, NULL);
 tmp = dvrr_stack + 1674113;
 target_ptr = Libderiv->deriv2_classes[8][9][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1676588, dvrr_stack+1171840, NULL);
 tmp = dvrr_stack + 1676588;
 target_ptr = Libderiv->deriv2_classes[8][10][130];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+1679558, dvrr_stack+1180750, NULL);
 tmp = dvrr_stack + 1679558;
 target_ptr = Libderiv->deriv2_classes[9][5][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+1680713, dvrr_stack+1184215, NULL);
 tmp = dvrr_stack + 1680713;
 target_ptr = Libderiv->deriv2_classes[9][6][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1682253, dvrr_stack+1188835, NULL);
 tmp = dvrr_stack + 1682253;
 target_ptr = Libderiv->deriv2_classes[9][7][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1684233, dvrr_stack+1194775, NULL);
 tmp = dvrr_stack + 1684233;
 target_ptr = Libderiv->deriv2_classes[9][8][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+1686708, dvrr_stack+1202200, NULL);
 tmp = dvrr_stack + 1686708;
 target_ptr = Libderiv->deriv2_classes[9][9][130];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1689733, dvrr_stack+1211275, NULL);
 tmp = dvrr_stack + 1689733;
 target_ptr = Libderiv->deriv2_classes[9][10][130];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+1693363, dvrr_stack+1222165, NULL);
 tmp = dvrr_stack + 1693363;
 target_ptr = Libderiv->deriv2_classes[10][5][130];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+1694749, dvrr_stack+1226323, NULL);
 tmp = dvrr_stack + 1694749;
 target_ptr = Libderiv->deriv2_classes[10][6][130];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+1696597, dvrr_stack+1231867, NULL);
 tmp = dvrr_stack + 1696597;
 target_ptr = Libderiv->deriv2_classes[10][7][130];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1698973, dvrr_stack+1238995, NULL);
 tmp = dvrr_stack + 1698973;
 target_ptr = Libderiv->deriv2_classes[10][8][130];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1701943, dvrr_stack+1247905, NULL);
 tmp = dvrr_stack + 1701943;
 target_ptr = Libderiv->deriv2_classes[10][9][130];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+1705573, dvrr_stack+1258795, NULL);
 tmp = dvrr_stack + 1705573;
 target_ptr = Libderiv->deriv2_classes[10][10][130];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+960103, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 960103;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+68290, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 68290;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+22012, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 22012;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+44908, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 44908;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+45853, dvrr_stack+86650, NULL);
 tmp = dvrr_stack + 45853;
 target_ptr = Libderiv->deriv2_classes[5][9][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1386,dvrr_stack+63610, dvrr_stack+112900, NULL);
 tmp = dvrr_stack + 63610;
 target_ptr = Libderiv->deriv2_classes[5][10][119];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+1001959, dvrr_stack+129746, NULL);
 tmp = dvrr_stack + 1001959;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+129746, dvrr_stack+142568, NULL);
 tmp = dvrr_stack + 129746;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+64996, dvrr_stack+158818, NULL);
 tmp = dvrr_stack + 64996;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+158818, dvrr_stack+178246, NULL);
 tmp = dvrr_stack + 158818;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+160078, dvrr_stack+202582, NULL);
 tmp = dvrr_stack + 160078;
 target_ptr = Libderiv->deriv2_classes[6][9][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1848,dvrr_stack+29192, dvrr_stack+231576, NULL);
 tmp = dvrr_stack + 29192;
 target_ptr = Libderiv->deriv2_classes[6][10][119];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+130530, dvrr_stack+253144, NULL);
 tmp = dvrr_stack + 130530;
 target_ptr = Libderiv->deriv2_classes[7][5][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+253018, dvrr_stack+269848, NULL);
 tmp = dvrr_stack + 253018;
 target_ptr = Libderiv->deriv2_classes[7][6][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1296,dvrr_stack+254026, dvrr_stack+290183, NULL);
 tmp = dvrr_stack + 254026;
 target_ptr = Libderiv->deriv2_classes[7][7][119];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+289797, dvrr_stack+316331, NULL);
 tmp = dvrr_stack + 289797;
 target_ptr = Libderiv->deriv2_classes[7][8][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+316331, dvrr_stack+347999, NULL);
 tmp = dvrr_stack + 316331;
 target_ptr = Libderiv->deriv2_classes[7][9][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2376,dvrr_stack+318311, dvrr_stack+385719, NULL);
 tmp = dvrr_stack + 318311;
 target_ptr = Libderiv->deriv2_classes[7][10][119];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+299681, dvrr_stack+411945, NULL);
 tmp = dvrr_stack + 299681;
 target_ptr = Libderiv->deriv2_classes[8][5][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+411846, dvrr_stack+431700, NULL);
 tmp = dvrr_stack + 411846;
 target_ptr = Libderiv->deriv2_classes[8][6][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+431184, dvrr_stack+457325, NULL);
 tmp = dvrr_stack + 431184;
 target_ptr = Libderiv->deriv2_classes[8][7][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2025,dvrr_stack+457292, dvrr_stack+491990, NULL);
 tmp = dvrr_stack + 457292;
 target_ptr = Libderiv->deriv2_classes[8][8][119];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+491613, dvrr_stack+529625, NULL);
 tmp = dvrr_stack + 491613;
 target_ptr = Libderiv->deriv2_classes[8][9][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2970,dvrr_stack+529625, dvrr_stack+575410, NULL);
 tmp = dvrr_stack + 529625;
 target_ptr = Libderiv->deriv2_classes[8][10][119];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+532595, dvrr_stack+616050, NULL);
 tmp = dvrr_stack + 532595;
 target_ptr = Libderiv->deriv2_classes[9][5][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+533750, dvrr_stack+640545, NULL);
 tmp = dvrr_stack + 533750;
 target_ptr = Libderiv->deriv2_classes[9][6][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+615840, dvrr_stack+674645, NULL);
 tmp = dvrr_stack + 615840;
 target_ptr = Libderiv->deriv2_classes[9][7][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+674180, dvrr_stack+711704, NULL);
 tmp = dvrr_stack + 674180;
 target_ptr = Libderiv->deriv2_classes[9][8][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,3025,dvrr_stack+711209, dvrr_stack+759479, NULL);
 tmp = dvrr_stack + 711209;
 target_ptr = Libderiv->deriv2_classes[9][9][119];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,3630,dvrr_stack+759407, dvrr_stack+816399, NULL);
 tmp = dvrr_stack + 759407;
 target_ptr = Libderiv->deriv2_classes[9][10][119];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1386,dvrr_stack+535290, dvrr_stack+860378, NULL);
 tmp = dvrr_stack + 535290;
 target_ptr = Libderiv->deriv2_classes[10][5][119];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1848,dvrr_stack+860301, dvrr_stack+890627, NULL);
 tmp = dvrr_stack + 860301;
 target_ptr = Libderiv->deriv2_classes[10][6][119];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2376,dvrr_stack+890612, dvrr_stack+930667, NULL);
 tmp = dvrr_stack + 890612;
 target_ptr = Libderiv->deriv2_classes[10][7][119];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2970,dvrr_stack+892988, dvrr_stack+980101, NULL);
 tmp = dvrr_stack + 892988;
 target_ptr = Libderiv->deriv2_classes[10][8][119];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,3630,dvrr_stack+980002, dvrr_stack+1037509, NULL);
 tmp = dvrr_stack + 980002;
 target_ptr = Libderiv->deriv2_classes[10][9][119];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,4356,dvrr_stack+1037464, dvrr_stack+768554, NULL);
 tmp = dvrr_stack + 1037464;
 target_ptr = Libderiv->deriv2_classes[10][10][119];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+320687, dvrr_stack+543056, NULL);
 tmp = dvrr_stack + 320687;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+210722, dvrr_stack+544379, NULL);
 tmp = dvrr_stack + 210722;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+1041820, dvrr_stack+502421, NULL);
 tmp = dvrr_stack + 1041820;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+502145, dvrr_stack+1089979, NULL);
 tmp = dvrr_stack + 502145;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+503090, dvrr_stack+1092814, NULL);
 tmp = dvrr_stack + 503090;
 target_ptr = Libderiv->deriv2_classes[5][9][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+1042576, dvrr_stack+1096279, NULL);
 tmp = dvrr_stack + 1042576;
 target_ptr = Libderiv->deriv2_classes[5][10][118];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+1043962, dvrr_stack+161842, NULL);
 tmp = dvrr_stack + 1043962;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+161618, dvrr_stack+1100437, NULL);
 tmp = dvrr_stack + 161618;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+162402, dvrr_stack+1102789, NULL);
 tmp = dvrr_stack + 162402;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+1044550, dvrr_stack+1105813, NULL);
 tmp = dvrr_stack + 1044550;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+1045810, dvrr_stack+1109593, NULL);
 tmp = dvrr_stack + 1045810;
 target_ptr = Libderiv->deriv2_classes[6][9][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+542660, dvrr_stack+1114213, NULL);
 tmp = dvrr_stack + 542660;
 target_ptr = Libderiv->deriv2_classes[6][10][118];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+1047350, dvrr_stack+1119757, NULL);
 tmp = dvrr_stack + 1047350;
 target_ptr = Libderiv->deriv2_classes[7][5][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+544508, dvrr_stack+1122025, NULL);
 tmp = dvrr_stack + 544508;
 target_ptr = Libderiv->deriv2_classes[7][6][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+617820, dvrr_stack+1125049, NULL);
 tmp = dvrr_stack + 617820;
 target_ptr = Libderiv->deriv2_classes[7][7][118];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+1089728, dvrr_stack+1128937, NULL);
 tmp = dvrr_stack + 1089728;
 target_ptr = Libderiv->deriv2_classes[7][8][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+1091348, dvrr_stack+1133797, NULL);
 tmp = dvrr_stack + 1091348;
 target_ptr = Libderiv->deriv2_classes[7][9][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+1093328, dvrr_stack+1139737, NULL);
 tmp = dvrr_stack + 1093328;
 target_ptr = Libderiv->deriv2_classes[7][10][118];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+1095704, dvrr_stack+1146865, NULL);
 tmp = dvrr_stack + 1095704;
 target_ptr = Libderiv->deriv2_classes[8][5][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+1096649, dvrr_stack+1149700, NULL);
 tmp = dvrr_stack + 1096649;
 target_ptr = Libderiv->deriv2_classes[8][6][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+1097909, dvrr_stack+1153480, NULL);
 tmp = dvrr_stack + 1097909;
 target_ptr = Libderiv->deriv2_classes[8][7][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+1099529, dvrr_stack+1158340, NULL);
 tmp = dvrr_stack + 1099529;
 target_ptr = Libderiv->deriv2_classes[8][8][118];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+1101554, dvrr_stack+1164415, NULL);
 tmp = dvrr_stack + 1101554;
 target_ptr = Libderiv->deriv2_classes[8][9][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+1104029, dvrr_stack+1171840, NULL);
 tmp = dvrr_stack + 1104029;
 target_ptr = Libderiv->deriv2_classes[8][10][118];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+1106999, dvrr_stack+1180750, NULL);
 tmp = dvrr_stack + 1106999;
 target_ptr = Libderiv->deriv2_classes[9][5][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+1108154, dvrr_stack+1184215, NULL);
 tmp = dvrr_stack + 1108154;
 target_ptr = Libderiv->deriv2_classes[9][6][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+1109694, dvrr_stack+1188835, NULL);
 tmp = dvrr_stack + 1109694;
 target_ptr = Libderiv->deriv2_classes[9][7][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+1111674, dvrr_stack+1194775, NULL);
 tmp = dvrr_stack + 1111674;
 target_ptr = Libderiv->deriv2_classes[9][8][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+1114149, dvrr_stack+1202200, NULL);
 tmp = dvrr_stack + 1114149;
 target_ptr = Libderiv->deriv2_classes[9][9][118];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+1117174, dvrr_stack+1211275, NULL);
 tmp = dvrr_stack + 1117174;
 target_ptr = Libderiv->deriv2_classes[9][10][118];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+1120804, dvrr_stack+1222165, NULL);
 tmp = dvrr_stack + 1120804;
 target_ptr = Libderiv->deriv2_classes[10][5][118];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+1122190, dvrr_stack+1226323, NULL);
 tmp = dvrr_stack + 1122190;
 target_ptr = Libderiv->deriv2_classes[10][6][118];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+1124038, dvrr_stack+1231867, NULL);
 tmp = dvrr_stack + 1124038;
 target_ptr = Libderiv->deriv2_classes[10][7][118];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+1126414, dvrr_stack+1238995, NULL);
 tmp = dvrr_stack + 1126414;
 target_ptr = Libderiv->deriv2_classes[10][8][118];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+1129384, dvrr_stack+1247905, NULL);
 tmp = dvrr_stack + 1129384;
 target_ptr = Libderiv->deriv2_classes[10][9][118];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+1133014, dvrr_stack+1258795, NULL);
 tmp = dvrr_stack + 1133014;
 target_ptr = Libderiv->deriv2_classes[10][10][118];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+514325, dvrr_stack+50278, NULL);
 tmp = dvrr_stack + 514325;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+1048106, dvrr_stack+14638, NULL);
 tmp = dvrr_stack + 1048106;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+50164, dvrr_stack+26140, NULL);
 tmp = dvrr_stack + 50164;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+25972, dvrr_stack+40372, NULL);
 tmp = dvrr_stack + 25972;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+26917, dvrr_stack+58165, NULL);
 tmp = dvrr_stack + 26917;
 target_ptr = Libderiv->deriv2_classes[5][9][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+1137370, dvrr_stack+79720, NULL);
 tmp = dvrr_stack + 1137370;
 target_ptr = Libderiv->deriv2_classes[5][10][117];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+50920, dvrr_stack+104584, NULL);
 tmp = dvrr_stack + 50920;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+1138756, dvrr_stack+126218, NULL);
 tmp = dvrr_stack + 1138756;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+1139540, dvrr_stack+137864, NULL);
 tmp = dvrr_stack + 1139540;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+1140548, dvrr_stack+152770, NULL);
 tmp = dvrr_stack + 1140548;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+1141808, dvrr_stack+170686, NULL);
 tmp = dvrr_stack + 1141808;
 target_ptr = Libderiv->deriv2_classes[6][9][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+1143348, dvrr_stack+193342, NULL);
 tmp = dvrr_stack + 1143348;
 target_ptr = Libderiv->deriv2_classes[6][10][117];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+1145196, dvrr_stack+156550, NULL);
 tmp = dvrr_stack + 1145196;
 target_ptr = Libderiv->deriv2_classes[7][5][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+1145952, dvrr_stack+248608, NULL);
 tmp = dvrr_stack + 1145952;
 target_ptr = Libderiv->deriv2_classes[7][6][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+1146960, dvrr_stack+263800, NULL);
 tmp = dvrr_stack + 1146960;
 target_ptr = Libderiv->deriv2_classes[7][7][117];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+263800, dvrr_stack+282407, NULL);
 tmp = dvrr_stack + 263800;
 target_ptr = Libderiv->deriv2_classes[7][8][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+265420, dvrr_stack+306611, NULL);
 tmp = dvrr_stack + 265420;
 target_ptr = Libderiv->deriv2_classes[7][9][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+306605, dvrr_stack+336119, NULL);
 tmp = dvrr_stack + 306605;
 target_ptr = Libderiv->deriv2_classes[7][10][117];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+336089, dvrr_stack+371463, NULL);
 tmp = dvrr_stack + 336089;
 target_ptr = Libderiv->deriv2_classes[8][5][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+337034, dvrr_stack+312551, NULL);
 tmp = dvrr_stack + 337034;
 target_ptr = Libderiv->deriv2_classes[8][6][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+338294, dvrr_stack+424140, NULL);
 tmp = dvrr_stack + 338294;
 target_ptr = Libderiv->deriv2_classes[8][7][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+339914, dvrr_stack+447605, NULL);
 tmp = dvrr_stack + 339914;
 target_ptr = Libderiv->deriv2_classes[8][8][117];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+308981, dvrr_stack+479840, NULL);
 tmp = dvrr_stack + 308981;
 target_ptr = Libderiv->deriv2_classes[8][9][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+311456, dvrr_stack+514775, NULL);
 tmp = dvrr_stack + 311456;
 target_ptr = Libderiv->deriv2_classes[8][10][117];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+514766, dvrr_stack+557590, NULL);
 tmp = dvrr_stack + 514766;
 target_ptr = Libderiv->deriv2_classes[9][5][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+515921, dvrr_stack+609120, NULL);
 tmp = dvrr_stack + 515921;
 target_ptr = Libderiv->deriv2_classes[9][6][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+517461, dvrr_stack+523685, NULL);
 tmp = dvrr_stack + 517461;
 target_ptr = Libderiv->deriv2_classes[9][7][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+519441, dvrr_stack+662765, NULL);
 tmp = dvrr_stack + 519441;
 target_ptr = Libderiv->deriv2_classes[9][8][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+521916, dvrr_stack+696854, NULL);
 tmp = dvrr_stack + 521916;
 target_ptr = Libderiv->deriv2_classes[9][9][117];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+524941, dvrr_stack+741329, NULL);
 tmp = dvrr_stack + 524941;
 target_ptr = Libderiv->deriv2_classes[9][10][117];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+314426, dvrr_stack+794619, NULL);
 tmp = dvrr_stack + 314426;
 target_ptr = Libderiv->deriv2_classes[10][5][117];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+282173, dvrr_stack+852062, NULL);
 tmp = dvrr_stack + 282173;
 target_ptr = Libderiv->deriv2_classes[10][6][117];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+284021, dvrr_stack+879539, NULL);
 tmp = dvrr_stack + 284021;
 target_ptr = Libderiv->deriv2_classes[10][7][117];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+1148256, dvrr_stack+916411, NULL);
 tmp = dvrr_stack + 1148256;
 target_ptr = Libderiv->deriv2_classes[10][8][117];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+916189, dvrr_stack+962281, NULL);
 tmp = dvrr_stack + 916189;
 target_ptr = Libderiv->deriv2_classes[10][9][117];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+962173, dvrr_stack+1015729, NULL);
 tmp = dvrr_stack + 962173;
 target_ptr = Libderiv->deriv2_classes[10][10][117];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+528571, dvrr_stack+1066202, dvrr_stack+1065887);
 tmp = dvrr_stack + 528571;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+529012, dvrr_stack+1067231, dvrr_stack+1066790);
 tmp = dvrr_stack + 529012;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+966529, dvrr_stack+1067987, dvrr_stack+1066202);
 tmp = dvrr_stack + 966529;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+967285, dvrr_stack+1068932, dvrr_stack+1067231);
 tmp = dvrr_stack + 967285;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+968230, dvrr_stack+1070087, dvrr_stack+1067987);
 tmp = dvrr_stack + 968230;
 target_ptr = Libderiv->deriv2_classes[5][9][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+969385, dvrr_stack+1071473, dvrr_stack+1068932);
 tmp = dvrr_stack + 969385;
 target_ptr = Libderiv->deriv2_classes[5][10][107];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+970771, dvrr_stack+1074161, dvrr_stack+1073741);
 tmp = dvrr_stack + 970771;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+971359, dvrr_stack+1075533, dvrr_stack+1074945);
 tmp = dvrr_stack + 971359;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+972143, dvrr_stack+1076541, dvrr_stack+1074161);
 tmp = dvrr_stack + 972143;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+341939, dvrr_stack+1077801, dvrr_stack+1075533);
 tmp = dvrr_stack + 341939;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+919819, dvrr_stack+1079341, dvrr_stack+1076541);
 tmp = dvrr_stack + 919819;
 target_ptr = Libderiv->deriv2_classes[6][9][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+921359, dvrr_stack+1081189, dvrr_stack+1077801);
 tmp = dvrr_stack + 921359;
 target_ptr = Libderiv->deriv2_classes[6][10][107];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+286397, dvrr_stack+1086353, dvrr_stack+1085813);
 tmp = dvrr_stack + 286397;
 target_ptr = Libderiv->deriv2_classes[7][5][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+923207, dvrr_stack+1088117, dvrr_stack+1087361);
 tmp = dvrr_stack + 923207;
 target_ptr = Libderiv->deriv2_classes[7][6][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+1151226, dvrr_stack+1028797, dvrr_stack+1086353);
 tmp = dvrr_stack + 1151226;
 target_ptr = Libderiv->deriv2_classes[7][7][107];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+1152522, dvrr_stack+1030417, dvrr_stack+1088117);
 tmp = dvrr_stack + 1152522;
 target_ptr = Libderiv->deriv2_classes[7][8][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+1154142, dvrr_stack+1032397, dvrr_stack+1028797);
 tmp = dvrr_stack + 1154142;
 target_ptr = Libderiv->deriv2_classes[7][9][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+1156122, dvrr_stack+973171, dvrr_stack+1030417);
 tmp = dvrr_stack + 1156122;
 target_ptr = Libderiv->deriv2_classes[7][10][107];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+924215, dvrr_stack+976654, dvrr_stack+975979);
 tmp = dvrr_stack + 924215;
 target_ptr = Libderiv->deriv2_classes[8][5][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+1158498, dvrr_stack+925321, dvrr_stack+977914);
 tmp = dvrr_stack + 1158498;
 target_ptr = Libderiv->deriv2_classes[8][6][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+1159758, dvrr_stack+926941, dvrr_stack+976654);
 tmp = dvrr_stack + 1159758;
 target_ptr = Libderiv->deriv2_classes[8][7][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+1161378, dvrr_stack+886667, dvrr_stack+925321);
 tmp = dvrr_stack + 1161378;
 target_ptr = Libderiv->deriv2_classes[8][8][107];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+1163403, dvrr_stack+798777, dvrr_stack+926941);
 tmp = dvrr_stack + 1163403;
 target_ptr = Libderiv->deriv2_classes[8][9][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+1165878, dvrr_stack+801747, dvrr_stack+886667);
 tmp = dvrr_stack + 1165878;
 target_ptr = Libderiv->deriv2_classes[8][10][107];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+1168848, dvrr_stack+805257, dvrr_stack+929791);
 tmp = dvrr_stack + 1168848;
 target_ptr = Libderiv->deriv2_classes[9][5][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+1170003, dvrr_stack+806797, dvrr_stack+889142);
 tmp = dvrr_stack + 1170003;
 target_ptr = Libderiv->deriv2_classes[9][6][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+1171543, dvrr_stack+808777, dvrr_stack+805257);
 tmp = dvrr_stack + 1171543;
 target_ptr = Libderiv->deriv2_classes[9][7][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+1173523, dvrr_stack+811252, dvrr_stack+806797);
 tmp = dvrr_stack + 1173523;
 target_ptr = Libderiv->deriv2_classes[9][8][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+1175998, dvrr_stack+752219, dvrr_stack+808777);
 tmp = dvrr_stack + 1175998;
 target_ptr = Libderiv->deriv2_classes[9][9][107];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+1179023, dvrr_stack+705929, dvrr_stack+811252);
 tmp = dvrr_stack + 1179023;
 target_ptr = Libderiv->deriv2_classes[9][10][107];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+1182653, dvrr_stack+670190, dvrr_stack+710219);
 tmp = dvrr_stack + 1182653;
 target_ptr = Libderiv->deriv2_classes[10][5][107];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+1184039, dvrr_stack+631305, dvrr_stack+672038);
 tmp = dvrr_stack + 1184039;
 target_ptr = Libderiv->deriv2_classes[10][6][107];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+1185887, dvrr_stack+633681, dvrr_stack+670190);
 tmp = dvrr_stack + 1185887;
 target_ptr = Libderiv->deriv2_classes[10][7][107];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+1188263, dvrr_stack+636651, dvrr_stack+631305);
 tmp = dvrr_stack + 1188263;
 target_ptr = Libderiv->deriv2_classes[10][8][107];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+1191233, dvrr_stack+561055, dvrr_stack+633681);
 tmp = dvrr_stack + 1191233;
 target_ptr = Libderiv->deriv2_classes[10][9][107];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+1194863, dvrr_stack+565411, dvrr_stack+636651);
 tmp = dvrr_stack + 1194863;
 target_ptr = Libderiv->deriv2_classes[10][10][107];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+593836, dvrr_stack+758819, dvrr_stack+979687);
 tmp = dvrr_stack + 593836;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+545516, dvrr_stack+673424, dvrr_stack+815817);
 tmp = dvrr_stack + 545516;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+1199219, dvrr_stack+613740, dvrr_stack+758819);
 tmp = dvrr_stack + 1199219;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+1199975, dvrr_stack+614685, dvrr_stack+673424);
 tmp = dvrr_stack + 1199975;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+1200920, dvrr_stack+570559, dvrr_stack+613740);
 tmp = dvrr_stack + 1200920;
 target_ptr = Libderiv->deriv2_classes[5][9][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+1202075, dvrr_stack+571945, dvrr_stack+614685);
 tmp = dvrr_stack + 1202075;
 target_ptr = Libderiv->deriv2_classes[5][10][106];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+66004, dvrr_stack+573583, dvrr_stack+4171);
 tmp = dvrr_stack + 66004;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+1203461, dvrr_stack+487265, dvrr_stack+574367);
 tmp = dvrr_stack + 1203461;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+1204245, dvrr_stack+488273, dvrr_stack+573583);
 tmp = dvrr_stack + 1204245;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+1205253, dvrr_stack+489533, dvrr_stack+487265);
 tmp = dvrr_stack + 1205253;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+1206513, dvrr_stack+453680, dvrr_stack+488273);
 tmp = dvrr_stack + 1206513;
 target_ptr = Libderiv->deriv2_classes[6][9][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+1208053, dvrr_stack+429000, dvrr_stack+489533);
 tmp = dvrr_stack + 1208053;
 target_ptr = Libderiv->deriv2_classes[6][10][106];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+1209901, dvrr_stack+455528, dvrr_stack+491073);
 tmp = dvrr_stack + 1209901;
 target_ptr = Libderiv->deriv2_classes[7][5][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+1210657, dvrr_stack+406275, dvrr_stack+456536);
 tmp = dvrr_stack + 1210657;
 target_ptr = Libderiv->deriv2_classes[7][6][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+1211665, dvrr_stack+407571, dvrr_stack+455528);
 tmp = dvrr_stack + 1211665;
 target_ptr = Libderiv->deriv2_classes[7][7][106];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+1212961, dvrr_stack+409191, dvrr_stack+406275);
 tmp = dvrr_stack + 1212961;
 target_ptr = Libderiv->deriv2_classes[7][8][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+1214581, dvrr_stack+374298, dvrr_stack+407571);
 tmp = dvrr_stack + 1214581;
 target_ptr = Libderiv->deriv2_classes[7][9][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+1216561, dvrr_stack+376674, dvrr_stack+409191);
 tmp = dvrr_stack + 1216561;
 target_ptr = Libderiv->deriv2_classes[7][10][106];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+1218937, dvrr_stack+379482, dvrr_stack+411171);
 tmp = dvrr_stack + 1218937;
 target_ptr = Libderiv->deriv2_classes[8][5][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+1219882, dvrr_stack+381687, dvrr_stack+380742);
 tmp = dvrr_stack + 1219882;
 target_ptr = Libderiv->deriv2_classes[8][6][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+1221142, dvrr_stack+383307, dvrr_stack+379482);
 tmp = dvrr_stack + 1221142;
 target_ptr = Libderiv->deriv2_classes[8][7][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+1222762, dvrr_stack+343247, dvrr_stack+381687);
 tmp = dvrr_stack + 1222762;
 target_ptr = Libderiv->deriv2_classes[8][8][106];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+1224787, dvrr_stack+220488, dvrr_stack+383307);
 tmp = dvrr_stack + 1224787;
 target_ptr = Libderiv->deriv2_classes[8][9][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+1227262, dvrr_stack+223458, dvrr_stack+343247);
 tmp = dvrr_stack + 1227262;
 target_ptr = Libderiv->deriv2_classes[8][10][106];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+1230232, dvrr_stack+287267, dvrr_stack+345722);
 tmp = dvrr_stack + 1230232;
 target_ptr = Libderiv->deriv2_classes[9][5][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+1231387, dvrr_stack+267688, dvrr_stack+346547);
 tmp = dvrr_stack + 1231387;
 target_ptr = Libderiv->deriv2_classes[9][6][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+1232927, dvrr_stack+226968, dvrr_stack+287267);
 tmp = dvrr_stack + 1232927;
 target_ptr = Libderiv->deriv2_classes[9][7][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+1234907, dvrr_stack+198886, dvrr_stack+267688);
 tmp = dvrr_stack + 1234907;
 target_ptr = Libderiv->deriv2_classes[9][8][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+1237382, dvrr_stack+106348, dvrr_stack+226968);
 tmp = dvrr_stack + 1237382;
 target_ptr = Libderiv->deriv2_classes[9][9][106];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+1240407, dvrr_stack+1271863, dvrr_stack+198886);
 tmp = dvrr_stack + 1240407;
 target_ptr = Libderiv->deriv2_classes[9][10][106];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+1244037, dvrr_stack+229443, dvrr_stack+288807);
 tmp = dvrr_stack + 1244037;
 target_ptr = Libderiv->deriv2_classes[10][5][106];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+1245423, dvrr_stack+175306, dvrr_stack+251632);
 tmp = dvrr_stack + 1245423;
 target_ptr = Libderiv->deriv2_classes[10][6][106];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+1247271, dvrr_stack+1276153, dvrr_stack+229443);
 tmp = dvrr_stack + 1247271;
 target_ptr = Libderiv->deriv2_classes[10][7][106];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+1249647, dvrr_stack+1279123, dvrr_stack+175306);
 tmp = dvrr_stack + 1249647;
 target_ptr = Libderiv->deriv2_classes[10][8][106];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+1252617, dvrr_stack+1282753, dvrr_stack+1276153);
 tmp = dvrr_stack + 1252617;
 target_ptr = Libderiv->deriv2_classes[10][9][106];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+1256247, dvrr_stack+1287109, dvrr_stack+1279123);
 tmp = dvrr_stack + 1256247;
 target_ptr = Libderiv->deriv2_classes[10][10][106];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+504245, dvrr_stack+1064942, dvrr_stack+890297);
 tmp = dvrr_stack + 504245;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+1260603, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 1260603;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+1261191, dvrr_stack+23872, dvrr_stack+1064942);
 tmp = dvrr_stack + 1261191;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+1261947, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 1261947;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+1262892, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 1262892;
 target_ptr = Libderiv->deriv2_classes[5][9][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+1264047, dvrr_stack+75562, dvrr_stack+37537);
 tmp = dvrr_stack + 1264047;
 target_ptr = Libderiv->deriv2_classes[5][10][105];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+1265433, dvrr_stack+28408, dvrr_stack+99670);
 tmp = dvrr_stack + 1265433;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+1266021, dvrr_stack+119438, dvrr_stack+123866);
 tmp = dvrr_stack + 1266021;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+1266805, dvrr_stack+134840, dvrr_stack+28408);
 tmp = dvrr_stack + 1266805;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+1267813, dvrr_stack+148990, dvrr_stack+119438);
 tmp = dvrr_stack + 1267813;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+1269073, dvrr_stack+166066, dvrr_stack+134840);
 tmp = dvrr_stack + 1269073;
 target_ptr = Libderiv->deriv2_classes[6][9][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+1015654, dvrr_stack+187798, dvrr_stack+148990);
 tmp = dvrr_stack + 1015654;
 target_ptr = Libderiv->deriv2_classes[6][10][105];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+1270613, dvrr_stack+1084193, dvrr_stack+213936);
 tmp = dvrr_stack + 1270613;
 target_ptr = Libderiv->deriv2_classes[7][5][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+1017502, dvrr_stack+240256, dvrr_stack+120446);
 tmp = dvrr_stack + 1017502;
 target_ptr = Libderiv->deriv2_classes[7][6][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+1018510, dvrr_stack+259912, dvrr_stack+1084193);
 tmp = dvrr_stack + 1018510;
 target_ptr = Libderiv->deriv2_classes[7][7][105];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+1019806, dvrr_stack+277547, dvrr_stack+240256);
 tmp = dvrr_stack + 1019806;
 target_ptr = Libderiv->deriv2_classes[7][8][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+1021426, dvrr_stack+300671, dvrr_stack+259912);
 tmp = dvrr_stack + 1021426;
 target_ptr = Libderiv->deriv2_classes[7][9][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+1023406, dvrr_stack+328991, dvrr_stack+277547);
 tmp = dvrr_stack + 1023406;
 target_ptr = Libderiv->deriv2_classes[7][10][105];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+1025782, dvrr_stack+1035448, dvrr_stack+363039);
 tmp = dvrr_stack + 1025782;
 target_ptr = Libderiv->deriv2_classes[8][5][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+1026727, dvrr_stack+396060, dvrr_stack+402495);
 tmp = dvrr_stack + 1026727;
 target_ptr = Libderiv->deriv2_classes[8][6][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+879446, dvrr_stack+403440, dvrr_stack+1035448);
 tmp = dvrr_stack + 879446;
 target_ptr = Libderiv->deriv2_classes[8][7][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+881066, dvrr_stack+363714, dvrr_stack+396060);
 tmp = dvrr_stack + 881066;
 target_ptr = Libderiv->deriv2_classes[8][8][105];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+883091, dvrr_stack+472415, dvrr_stack+403440);
 tmp = dvrr_stack + 883091;
 target_ptr = Libderiv->deriv2_classes[8][9][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+851919, dvrr_stack+475385, dvrr_stack+363714);
 tmp = dvrr_stack + 851919;
 target_ptr = Libderiv->deriv2_classes[8][10][105];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+854889, dvrr_stack+857606, dvrr_stack+478895);
 tmp = dvrr_stack + 854889;
 target_ptr = Libderiv->deriv2_classes[9][5][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+856044, dvrr_stack+594375, dvrr_stack+604500);
 tmp = dvrr_stack + 856044;
 target_ptr = Libderiv->deriv2_classes[9][6][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+741230, dvrr_stack+625365, dvrr_stack+857606);
 tmp = dvrr_stack + 741230;
 target_ptr = Libderiv->deriv2_classes[9][7][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+743210, dvrr_stack+655340, dvrr_stack+594375);
 tmp = dvrr_stack + 743210;
 target_ptr = Libderiv->deriv2_classes[9][8][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+745685, dvrr_stack+687779, dvrr_stack+625365);
 tmp = dvrr_stack + 745685;
 target_ptr = Libderiv->deriv2_classes[9][9][105];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+696767, dvrr_stack+730439, dvrr_stack+655340);
 tmp = dvrr_stack + 696767;
 target_ptr = Libderiv->deriv2_classes[9][10][105];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+748710, dvrr_stack+755849, dvrr_stack+734729);
 tmp = dvrr_stack + 748710;
 target_ptr = Libderiv->deriv2_classes[10][5][105];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+750096, dvrr_stack+836060, dvrr_stack+846518);
 tmp = dvrr_stack + 750096;
 target_ptr = Libderiv->deriv2_classes[10][6][105];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+700397, dvrr_stack+872411, dvrr_stack+755849);
 tmp = dvrr_stack + 700397;
 target_ptr = Libderiv->deriv2_classes[10][7][105];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+702773, dvrr_stack+907501, dvrr_stack+836060);
 tmp = dvrr_stack + 702773;
 target_ptr = Libderiv->deriv2_classes[10][8][105];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+662721, dvrr_stack+951391, dvrr_stack+872411);
 tmp = dvrr_stack + 662721;
 target_ptr = Libderiv->deriv2_classes[10][9][105];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+608680, dvrr_stack+1002661, dvrr_stack+907501);
 tmp = dvrr_stack + 608680;
 target_ptr = Libderiv->deriv2_classes[10][10][105];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+724719, dvrr_stack+1049258, dvrr_stack+1048943);
 tmp = dvrr_stack + 724719;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+1027987, dvrr_stack+1050287, dvrr_stack+1049846);
 tmp = dvrr_stack + 1027987;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+885566, dvrr_stack+1051043, dvrr_stack+1049258);
 tmp = dvrr_stack + 885566;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+666351, dvrr_stack+1051988, dvrr_stack+1050287);
 tmp = dvrr_stack + 666351;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+667296, dvrr_stack+1053143, dvrr_stack+1051043);
 tmp = dvrr_stack + 667296;
 target_ptr = Libderiv->deriv2_classes[5][9][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+668451, dvrr_stack+1054529, dvrr_stack+1051988);
 tmp = dvrr_stack + 668451;
 target_ptr = Libderiv->deriv2_classes[5][10][104];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+613036, dvrr_stack+1056867, dvrr_stack+1056447);
 tmp = dvrr_stack + 613036;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+862149, dvrr_stack+1058239, dvrr_stack+1057651);
 tmp = dvrr_stack + 862149;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+862933, dvrr_stack+1059247, dvrr_stack+1056867);
 tmp = dvrr_stack + 862933;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+479720, dvrr_stack+1060507, dvrr_stack+1058239);
 tmp = dvrr_stack + 479720;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+480980, dvrr_stack+1062047, dvrr_stack+1059247);
 tmp = dvrr_stack + 480980;
 target_ptr = Libderiv->deriv2_classes[6][9][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+482520, dvrr_stack+1007809, dvrr_stack+1060507);
 tmp = dvrr_stack + 482520;
 target_ptr = Libderiv->deriv2_classes[6][10][104];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+484368, dvrr_stack+1010533, dvrr_stack+1009993);
 tmp = dvrr_stack + 484368;
 target_ptr = Libderiv->deriv2_classes[7][5][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+485124, dvrr_stack+1012297, dvrr_stack+1011541);
 tmp = dvrr_stack + 485124;
 target_ptr = Libderiv->deriv2_classes[7][6][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+371205, dvrr_stack+1013593, dvrr_stack+1010533);
 tmp = dvrr_stack + 371205;
 target_ptr = Libderiv->deriv2_classes[7][7][104];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+372501, dvrr_stack+955747, dvrr_stack+1012297);
 tmp = dvrr_stack + 372501;
 target_ptr = Libderiv->deriv2_classes[7][8][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+248420, dvrr_stack+957727, dvrr_stack+1013593);
 tmp = dvrr_stack + 248420;
 target_ptr = Libderiv->deriv2_classes[7][9][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+193111, dvrr_stack+911131, dvrr_stack+955747);
 tmp = dvrr_stack + 193111;
 target_ptr = Libderiv->deriv2_classes[7][10][104];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+486132, dvrr_stack+913939, dvrr_stack+960553);
 tmp = dvrr_stack + 486132;
 target_ptr = Libderiv->deriv2_classes[8][5][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+195487, dvrr_stack+875381, dvrr_stack+961228);
 tmp = dvrr_stack + 195487;
 target_ptr = Libderiv->deriv2_classes[8][6][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+196747, dvrr_stack+877001, dvrr_stack+913939);
 tmp = dvrr_stack + 196747;
 target_ptr = Libderiv->deriv2_classes[8][7][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+170359, dvrr_stack+847904, dvrr_stack+875381);
 tmp = dvrr_stack + 170359;
 target_ptr = Libderiv->deriv2_classes[8][8][104];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+172384, dvrr_stack+735719, dvrr_stack+877001);
 tmp = dvrr_stack + 172384;
 target_ptr = Libderiv->deriv2_classes[8][9][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+152510, dvrr_stack+691409, dvrr_stack+847904);
 tmp = dvrr_stack + 152510;
 target_ptr = Libderiv->deriv2_classes[8][10][104];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+250400, dvrr_stack+850379, dvrr_stack+838436);
 tmp = dvrr_stack + 250400;
 target_ptr = Libderiv->deriv2_classes[9][5][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+155480, dvrr_stack+658365, dvrr_stack+738689);
 tmp = dvrr_stack + 155480;
 target_ptr = Libderiv->deriv2_classes[9][6][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+137360, dvrr_stack+627840, dvrr_stack+850379);
 tmp = dvrr_stack + 137360;
 target_ptr = Libderiv->deriv2_classes[9][7][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+126074, dvrr_stack+605655, dvrr_stack+658365);
 tmp = dvrr_stack + 126074;
 target_ptr = Libderiv->deriv2_classes[9][8][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+79576, dvrr_stack+366189, dvrr_stack+627840);
 tmp = dvrr_stack + 79576;
 target_ptr = Libderiv->deriv2_classes[9][9][104];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+983632, dvrr_stack+331799, dvrr_stack+605655);
 tmp = dvrr_stack + 983632;
 target_ptr = Libderiv->deriv2_classes[9][10][104];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+157020, dvrr_stack+694919, dvrr_stack+630315);
 tmp = dvrr_stack + 157020;
 target_ptr = Libderiv->deriv2_classes[10][5][104];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+104446, dvrr_stack+660345, dvrr_stack+739844);
 tmp = dvrr_stack + 104446;
 target_ptr = Libderiv->deriv2_classes[10][6][104];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+58111, dvrr_stack+303047, dvrr_stack+694919);
 tmp = dvrr_stack + 58111;
 target_ptr = Libderiv->deriv2_classes[10][7][104];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+40232, dvrr_stack+214476, dvrr_stack+660345);
 tmp = dvrr_stack + 40232;
 target_ptr = Libderiv->deriv2_classes[10][8][104];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+930616, dvrr_stack+100090, dvrr_stack+303047);
 tmp = dvrr_stack + 930616;
 target_ptr = Libderiv->deriv2_classes[10][9][104];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+816258, dvrr_stack+781622, dvrr_stack+214476);
 tmp = dvrr_stack + 816258;
 target_ptr = Libderiv->deriv2_classes[10][10][104];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+654780, dvrr_stack+1066202, dvrr_stack+1065887);
 tmp = dvrr_stack + 654780;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+863941, dvrr_stack+1067231, dvrr_stack+1066790);
 tmp = dvrr_stack + 863941;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+139340, dvrr_stack+1067987, dvrr_stack+1066202);
 tmp = dvrr_stack + 139340;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+82601, dvrr_stack+1068932, dvrr_stack+1067231);
 tmp = dvrr_stack + 82601;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+14305, dvrr_stack+1070087, dvrr_stack+1067987);
 tmp = dvrr_stack + 14305;
 target_ptr = Libderiv->deriv2_classes[5][9][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+987262, dvrr_stack+1071473, dvrr_stack+1068932);
 tmp = dvrr_stack + 987262;
 target_ptr = Libderiv->deriv2_classes[5][10][95];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+140096, dvrr_stack+1074161, dvrr_stack+1073741);
 tmp = dvrr_stack + 140096;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+60487, dvrr_stack+1075533, dvrr_stack+1074945);
 tmp = dvrr_stack + 60487;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+934246, dvrr_stack+1076541, dvrr_stack+1074161);
 tmp = dvrr_stack + 934246;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+935254, dvrr_stack+1077801, dvrr_stack+1075533);
 tmp = dvrr_stack + 935254;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+820614, dvrr_stack+1079341, dvrr_stack+1076541);
 tmp = dvrr_stack + 820614;
 target_ptr = Libderiv->deriv2_classes[6][9][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+822154, dvrr_stack+1081189, dvrr_stack+1077801);
 tmp = dvrr_stack + 822154;
 target_ptr = Libderiv->deriv2_classes[6][10][95];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+15460, dvrr_stack+1086353, dvrr_stack+1085813);
 tmp = dvrr_stack + 15460;
 target_ptr = Libderiv->deriv2_classes[7][5][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+936514, dvrr_stack+1088117, dvrr_stack+1087361);
 tmp = dvrr_stack + 936514;
 target_ptr = Libderiv->deriv2_classes[7][6][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+824002, dvrr_stack+1028797, dvrr_stack+1086353);
 tmp = dvrr_stack + 824002;
 target_ptr = Libderiv->deriv2_classes[7][7][95];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+825298, dvrr_stack+1030417, dvrr_stack+1088117);
 tmp = dvrr_stack + 825298;
 target_ptr = Libderiv->deriv2_classes[7][8][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+763037, dvrr_stack+1032397, dvrr_stack+1028797);
 tmp = dvrr_stack + 763037;
 target_ptr = Libderiv->deriv2_classes[7][9][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+765017, dvrr_stack+973171, dvrr_stack+1030417);
 tmp = dvrr_stack + 765017;
 target_ptr = Libderiv->deriv2_classes[7][10][95];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+767393, dvrr_stack+976654, dvrr_stack+975979);
 tmp = dvrr_stack + 767393;
 target_ptr = Libderiv->deriv2_classes[8][5][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+768338, dvrr_stack+925321, dvrr_stack+977914);
 tmp = dvrr_stack + 768338;
 target_ptr = Libderiv->deriv2_classes[8][6][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+769598, dvrr_stack+926941, dvrr_stack+976654);
 tmp = dvrr_stack + 769598;
 target_ptr = Libderiv->deriv2_classes[8][7][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+771218, dvrr_stack+886667, dvrr_stack+925321);
 tmp = dvrr_stack + 771218;
 target_ptr = Libderiv->deriv2_classes[8][8][95];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+773243, dvrr_stack+798777, dvrr_stack+926941);
 tmp = dvrr_stack + 773243;
 target_ptr = Libderiv->deriv2_classes[8][9][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+775718, dvrr_stack+801747, dvrr_stack+886667);
 tmp = dvrr_stack + 775718;
 target_ptr = Libderiv->deriv2_classes[8][10][95];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+778688, dvrr_stack+805257, dvrr_stack+929791);
 tmp = dvrr_stack + 778688;
 target_ptr = Libderiv->deriv2_classes[9][5][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+779843, dvrr_stack+806797, dvrr_stack+889142);
 tmp = dvrr_stack + 779843;
 target_ptr = Libderiv->deriv2_classes[9][6][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+714234, dvrr_stack+808777, dvrr_stack+805257);
 tmp = dvrr_stack + 714234;
 target_ptr = Libderiv->deriv2_classes[9][7][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+716214, dvrr_stack+811252, dvrr_stack+806797);
 tmp = dvrr_stack + 716214;
 target_ptr = Libderiv->deriv2_classes[9][8][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+676655, dvrr_stack+752219, dvrr_stack+808777);
 tmp = dvrr_stack + 676655;
 target_ptr = Libderiv->deriv2_classes[9][9][95];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+640281, dvrr_stack+705929, dvrr_stack+811252);
 tmp = dvrr_stack + 640281;
 target_ptr = Libderiv->deriv2_classes[9][10][95];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+574955, dvrr_stack+670190, dvrr_stack+710219);
 tmp = dvrr_stack + 574955;
 target_ptr = Libderiv->deriv2_classes[10][5][95];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+576341, dvrr_stack+631305, dvrr_stack+672038);
 tmp = dvrr_stack + 576341;
 target_ptr = Libderiv->deriv2_classes[10][6][95];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+578189, dvrr_stack+633681, dvrr_stack+670190);
 tmp = dvrr_stack + 578189;
 target_ptr = Libderiv->deriv2_classes[10][7][95];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+580565, dvrr_stack+636651, dvrr_stack+631305);
 tmp = dvrr_stack + 580565;
 target_ptr = Libderiv->deriv2_classes[10][8][95];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+494088, dvrr_stack+561055, dvrr_stack+633681);
 tmp = dvrr_stack + 494088;
 target_ptr = Libderiv->deriv2_classes[10][9][95];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+385332, dvrr_stack+565411, dvrr_stack+636651);
 tmp = dvrr_stack + 385332;
 target_ptr = Libderiv->deriv2_classes[10][10][95];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+315812, dvrr_stack+758819, dvrr_stack+979687);
 tmp = dvrr_stack + 315812;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+679680, dvrr_stack+673424, dvrr_stack+815817);
 tmp = dvrr_stack + 679680;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+643911, dvrr_stack+613740, dvrr_stack+758819);
 tmp = dvrr_stack + 643911;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+459317, dvrr_stack+614685, dvrr_stack+673424);
 tmp = dvrr_stack + 459317;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+460262, dvrr_stack+570559, dvrr_stack+613740);
 tmp = dvrr_stack + 460262;
 target_ptr = Libderiv->deriv2_classes[5][9][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+432804, dvrr_stack+571945, dvrr_stack+614685);
 tmp = dvrr_stack + 432804;
 target_ptr = Libderiv->deriv2_classes[5][10][94];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+583535, dvrr_stack+573583, dvrr_stack+4171);
 tmp = dvrr_stack + 583535;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+434190, dvrr_stack+487265, dvrr_stack+574367);
 tmp = dvrr_stack + 434190;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+413106, dvrr_stack+488273, dvrr_stack+573583);
 tmp = dvrr_stack + 413106;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+389688, dvrr_stack+489533, dvrr_stack+487265);
 tmp = dvrr_stack + 389688;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+390948, dvrr_stack+453680, dvrr_stack+488273);
 tmp = dvrr_stack + 390948;
 target_ptr = Libderiv->deriv2_classes[6][9][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+347702, dvrr_stack+429000, dvrr_stack+489533);
 tmp = dvrr_stack + 347702;
 target_ptr = Libderiv->deriv2_classes[6][10][94];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+461417, dvrr_stack+455528, dvrr_stack+491073);
 tmp = dvrr_stack + 461417;
 target_ptr = Libderiv->deriv2_classes[7][5][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+349550, dvrr_stack+406275, dvrr_stack+456536);
 tmp = dvrr_stack + 349550;
 target_ptr = Libderiv->deriv2_classes[7][6][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+350558, dvrr_stack+407571, dvrr_stack+455528);
 tmp = dvrr_stack + 350558;
 target_ptr = Libderiv->deriv2_classes[7][7][94];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+351854, dvrr_stack+409191, dvrr_stack+406275);
 tmp = dvrr_stack + 351854;
 target_ptr = Libderiv->deriv2_classes[7][8][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+291417, dvrr_stack+374298, dvrr_stack+407571);
 tmp = dvrr_stack + 291417;
 target_ptr = Libderiv->deriv2_classes[7][9][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+269668, dvrr_stack+376674, dvrr_stack+409191);
 tmp = dvrr_stack + 269668;
 target_ptr = Libderiv->deriv2_classes[7][10][94];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+231291, dvrr_stack+379482, dvrr_stack+411171);
 tmp = dvrr_stack + 231291;
 target_ptr = Libderiv->deriv2_classes[8][5][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+232236, dvrr_stack+381687, dvrr_stack+380742);
 tmp = dvrr_stack + 232236;
 target_ptr = Libderiv->deriv2_classes[8][6][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+233496, dvrr_stack+383307, dvrr_stack+379482);
 tmp = dvrr_stack + 233496;
 target_ptr = Libderiv->deriv2_classes[8][7][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+202499, dvrr_stack+343247, dvrr_stack+381687);
 tmp = dvrr_stack + 202499;
 target_ptr = Libderiv->deriv2_classes[8][8][94];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+204524, dvrr_stack+220488, dvrr_stack+383307);
 tmp = dvrr_stack + 204524;
 target_ptr = Libderiv->deriv2_classes[8][9][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+177682, dvrr_stack+223458, dvrr_stack+343247);
 tmp = dvrr_stack + 177682;
 target_ptr = Libderiv->deriv2_classes[8][10][94];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+235116, dvrr_stack+287267, dvrr_stack+345722);
 tmp = dvrr_stack + 235116;
 target_ptr = Libderiv->deriv2_classes[9][5][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+142274, dvrr_stack+267688, dvrr_stack+346547);
 tmp = dvrr_stack + 142274;
 target_ptr = Libderiv->deriv2_classes[9][6][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+112786, dvrr_stack+226968, dvrr_stack+287267);
 tmp = dvrr_stack + 112786;
 target_ptr = Libderiv->deriv2_classes[9][7][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+86353, dvrr_stack+198886, dvrr_stack+267688);
 tmp = dvrr_stack + 86353;
 target_ptr = Libderiv->deriv2_classes[9][8][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+794405, dvrr_stack+106348, dvrr_stack+226968);
 tmp = dvrr_stack + 794405;
 target_ptr = Libderiv->deriv2_classes[9][9][94];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+557121, dvrr_stack+1271863, dvrr_stack+198886);
 tmp = dvrr_stack + 557121;
 target_ptr = Libderiv->deriv2_classes[9][10][94];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+114766, dvrr_stack+229443, dvrr_stack+288807);
 tmp = dvrr_stack + 114766;
 target_ptr = Libderiv->deriv2_classes[10][5][94];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+447483, dvrr_stack+175306, dvrr_stack+251632);
 tmp = dvrr_stack + 447483;
 target_ptr = Libderiv->deriv2_classes[10][6][94];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+449331, dvrr_stack+1276153, dvrr_stack+229443);
 tmp = dvrr_stack + 449331;
 target_ptr = Libderiv->deriv2_classes[10][7][94];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+423481, dvrr_stack+1279123, dvrr_stack+175306);
 tmp = dvrr_stack + 423481;
 target_ptr = Libderiv->deriv2_classes[10][8][94];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+1709929, dvrr_stack+1282753, dvrr_stack+1276153);
 tmp = dvrr_stack + 1709929;
 target_ptr = Libderiv->deriv2_classes[10][9][94];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+1713559, dvrr_stack+1287109, dvrr_stack+1279123);
 tmp = dvrr_stack + 1713559;
 target_ptr = Libderiv->deriv2_classes[10][10][94];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+1445139, dvrr_stack+1064942, dvrr_stack+890297);
 tmp = dvrr_stack + 1445139;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+414114, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 414114;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+272044, dvrr_stack+23872, dvrr_stack+1064942);
 tmp = dvrr_stack + 272044;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+180652, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 180652;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+88828, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 88828;
 target_ptr = Libderiv->deriv2_classes[5][9][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+17186, dvrr_stack+75562, dvrr_stack+37537);
 tmp = dvrr_stack + 17186;
 target_ptr = Libderiv->deriv2_classes[5][10][93];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+293397, dvrr_stack+28408, dvrr_stack+99670);
 tmp = dvrr_stack + 293397;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+236271, dvrr_stack+119438, dvrr_stack+123866);
 tmp = dvrr_stack + 236271;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+143814, dvrr_stack+134840, dvrr_stack+28408);
 tmp = dvrr_stack + 143814;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+797430, dvrr_stack+148990, dvrr_stack+119438);
 tmp = dvrr_stack + 797430;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+451707, dvrr_stack+166066, dvrr_stack+134840);
 tmp = dvrr_stack + 451707;
 target_ptr = Libderiv->deriv2_classes[6][9][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+426451, dvrr_stack+187798, dvrr_stack+148990);
 tmp = dvrr_stack + 426451;
 target_ptr = Libderiv->deriv2_classes[6][10][93];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+116152, dvrr_stack+1084193, dvrr_stack+213936);
 tmp = dvrr_stack + 116152;
 target_ptr = Libderiv->deriv2_classes[7][5][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1717915, dvrr_stack+240256, dvrr_stack+120446);
 tmp = dvrr_stack + 1717915;
 target_ptr = Libderiv->deriv2_classes[7][6][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1718923, dvrr_stack+259912, dvrr_stack+1084193);
 tmp = dvrr_stack + 1718923;
 target_ptr = Libderiv->deriv2_classes[7][7][93];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1720219, dvrr_stack+277547, dvrr_stack+240256);
 tmp = dvrr_stack + 1720219;
 target_ptr = Libderiv->deriv2_classes[7][8][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1721839, dvrr_stack+300671, dvrr_stack+259912);
 tmp = dvrr_stack + 1721839;
 target_ptr = Libderiv->deriv2_classes[7][9][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+1723819, dvrr_stack+328991, dvrr_stack+277547);
 tmp = dvrr_stack + 1723819;
 target_ptr = Libderiv->deriv2_classes[7][10][93];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1726195, dvrr_stack+1035448, dvrr_stack+363039);
 tmp = dvrr_stack + 1726195;
 target_ptr = Libderiv->deriv2_classes[8][5][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1727140, dvrr_stack+396060, dvrr_stack+402495);
 tmp = dvrr_stack + 1727140;
 target_ptr = Libderiv->deriv2_classes[8][6][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1728400, dvrr_stack+403440, dvrr_stack+1035448);
 tmp = dvrr_stack + 1728400;
 target_ptr = Libderiv->deriv2_classes[8][7][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1730020, dvrr_stack+363714, dvrr_stack+396060);
 tmp = dvrr_stack + 1730020;
 target_ptr = Libderiv->deriv2_classes[8][8][93];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1732045, dvrr_stack+472415, dvrr_stack+403440);
 tmp = dvrr_stack + 1732045;
 target_ptr = Libderiv->deriv2_classes[8][9][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+1734520, dvrr_stack+475385, dvrr_stack+363714);
 tmp = dvrr_stack + 1734520;
 target_ptr = Libderiv->deriv2_classes[8][10][93];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1737490, dvrr_stack+857606, dvrr_stack+478895);
 tmp = dvrr_stack + 1737490;
 target_ptr = Libderiv->deriv2_classes[9][5][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1738645, dvrr_stack+594375, dvrr_stack+604500);
 tmp = dvrr_stack + 1738645;
 target_ptr = Libderiv->deriv2_classes[9][6][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1740185, dvrr_stack+625365, dvrr_stack+857606);
 tmp = dvrr_stack + 1740185;
 target_ptr = Libderiv->deriv2_classes[9][7][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1742165, dvrr_stack+655340, dvrr_stack+594375);
 tmp = dvrr_stack + 1742165;
 target_ptr = Libderiv->deriv2_classes[9][8][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1744640, dvrr_stack+687779, dvrr_stack+625365);
 tmp = dvrr_stack + 1744640;
 target_ptr = Libderiv->deriv2_classes[9][9][93];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1747665, dvrr_stack+730439, dvrr_stack+655340);
 tmp = dvrr_stack + 1747665;
 target_ptr = Libderiv->deriv2_classes[9][10][93];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+1751295, dvrr_stack+755849, dvrr_stack+734729);
 tmp = dvrr_stack + 1751295;
 target_ptr = Libderiv->deriv2_classes[10][5][93];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+1752681, dvrr_stack+836060, dvrr_stack+846518);
 tmp = dvrr_stack + 1752681;
 target_ptr = Libderiv->deriv2_classes[10][6][93];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+1754529, dvrr_stack+872411, dvrr_stack+755849);
 tmp = dvrr_stack + 1754529;
 target_ptr = Libderiv->deriv2_classes[10][7][93];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+1756905, dvrr_stack+907501, dvrr_stack+836060);
 tmp = dvrr_stack + 1756905;
 target_ptr = Libderiv->deriv2_classes[10][8][93];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+1759875, dvrr_stack+951391, dvrr_stack+872411);
 tmp = dvrr_stack + 1759875;
 target_ptr = Libderiv->deriv2_classes[10][9][93];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+1763505, dvrr_stack+1002661, dvrr_stack+907501);
 tmp = dvrr_stack + 1763505;
 target_ptr = Libderiv->deriv2_classes[10][10][93];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+687273, dvrr_stack+1049258, dvrr_stack+1048943);
 tmp = dvrr_stack + 687273;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+428299, dvrr_stack+1050287, dvrr_stack+1049846);
 tmp = dvrr_stack + 428299;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+1767861, dvrr_stack+1051043, dvrr_stack+1049258);
 tmp = dvrr_stack + 1767861;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+1768617, dvrr_stack+1051988, dvrr_stack+1050287);
 tmp = dvrr_stack + 1768617;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+1769562, dvrr_stack+1053143, dvrr_stack+1051043);
 tmp = dvrr_stack + 1769562;
 target_ptr = Libderiv->deriv2_classes[5][9][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+1770717, dvrr_stack+1054529, dvrr_stack+1051988);
 tmp = dvrr_stack + 1770717;
 target_ptr = Libderiv->deriv2_classes[5][10][92];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+1772103, dvrr_stack+1056867, dvrr_stack+1056447);
 tmp = dvrr_stack + 1772103;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+1772691, dvrr_stack+1058239, dvrr_stack+1057651);
 tmp = dvrr_stack + 1772691;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+1773475, dvrr_stack+1059247, dvrr_stack+1056867);
 tmp = dvrr_stack + 1773475;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1774483, dvrr_stack+1060507, dvrr_stack+1058239);
 tmp = dvrr_stack + 1774483;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1775743, dvrr_stack+1062047, dvrr_stack+1059247);
 tmp = dvrr_stack + 1775743;
 target_ptr = Libderiv->deriv2_classes[6][9][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+1777283, dvrr_stack+1007809, dvrr_stack+1060507);
 tmp = dvrr_stack + 1777283;
 target_ptr = Libderiv->deriv2_classes[6][10][92];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1779131, dvrr_stack+1010533, dvrr_stack+1009993);
 tmp = dvrr_stack + 1779131;
 target_ptr = Libderiv->deriv2_classes[7][5][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1779887, dvrr_stack+1012297, dvrr_stack+1011541);
 tmp = dvrr_stack + 1779887;
 target_ptr = Libderiv->deriv2_classes[7][6][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1780895, dvrr_stack+1013593, dvrr_stack+1010533);
 tmp = dvrr_stack + 1780895;
 target_ptr = Libderiv->deriv2_classes[7][7][92];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1782191, dvrr_stack+955747, dvrr_stack+1012297);
 tmp = dvrr_stack + 1782191;
 target_ptr = Libderiv->deriv2_classes[7][8][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1783811, dvrr_stack+957727, dvrr_stack+1013593);
 tmp = dvrr_stack + 1783811;
 target_ptr = Libderiv->deriv2_classes[7][9][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+1785791, dvrr_stack+911131, dvrr_stack+955747);
 tmp = dvrr_stack + 1785791;
 target_ptr = Libderiv->deriv2_classes[7][10][92];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1788167, dvrr_stack+913939, dvrr_stack+960553);
 tmp = dvrr_stack + 1788167;
 target_ptr = Libderiv->deriv2_classes[8][5][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1789112, dvrr_stack+875381, dvrr_stack+961228);
 tmp = dvrr_stack + 1789112;
 target_ptr = Libderiv->deriv2_classes[8][6][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1790372, dvrr_stack+877001, dvrr_stack+913939);
 tmp = dvrr_stack + 1790372;
 target_ptr = Libderiv->deriv2_classes[8][7][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1791992, dvrr_stack+847904, dvrr_stack+875381);
 tmp = dvrr_stack + 1791992;
 target_ptr = Libderiv->deriv2_classes[8][8][92];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1794017, dvrr_stack+735719, dvrr_stack+877001);
 tmp = dvrr_stack + 1794017;
 target_ptr = Libderiv->deriv2_classes[8][9][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+1796492, dvrr_stack+691409, dvrr_stack+847904);
 tmp = dvrr_stack + 1796492;
 target_ptr = Libderiv->deriv2_classes[8][10][92];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1799462, dvrr_stack+850379, dvrr_stack+838436);
 tmp = dvrr_stack + 1799462;
 target_ptr = Libderiv->deriv2_classes[9][5][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1800617, dvrr_stack+658365, dvrr_stack+738689);
 tmp = dvrr_stack + 1800617;
 target_ptr = Libderiv->deriv2_classes[9][6][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1802157, dvrr_stack+627840, dvrr_stack+850379);
 tmp = dvrr_stack + 1802157;
 target_ptr = Libderiv->deriv2_classes[9][7][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1804137, dvrr_stack+605655, dvrr_stack+658365);
 tmp = dvrr_stack + 1804137;
 target_ptr = Libderiv->deriv2_classes[9][8][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1806612, dvrr_stack+366189, dvrr_stack+627840);
 tmp = dvrr_stack + 1806612;
 target_ptr = Libderiv->deriv2_classes[9][9][92];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1809637, dvrr_stack+331799, dvrr_stack+605655);
 tmp = dvrr_stack + 1809637;
 target_ptr = Libderiv->deriv2_classes[9][10][92];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+1813267, dvrr_stack+694919, dvrr_stack+630315);
 tmp = dvrr_stack + 1813267;
 target_ptr = Libderiv->deriv2_classes[10][5][92];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+1814653, dvrr_stack+660345, dvrr_stack+739844);
 tmp = dvrr_stack + 1814653;
 target_ptr = Libderiv->deriv2_classes[10][6][92];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+1816501, dvrr_stack+303047, dvrr_stack+694919);
 tmp = dvrr_stack + 1816501;
 target_ptr = Libderiv->deriv2_classes[10][7][92];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+1818877, dvrr_stack+214476, dvrr_stack+660345);
 tmp = dvrr_stack + 1818877;
 target_ptr = Libderiv->deriv2_classes[10][8][92];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+1821847, dvrr_stack+100090, dvrr_stack+303047);
 tmp = dvrr_stack + 1821847;
 target_ptr = Libderiv->deriv2_classes[10][9][92];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+1825477, dvrr_stack+781622, dvrr_stack+214476);
 tmp = dvrr_stack + 1825477;
 target_ptr = Libderiv->deriv2_classes[10][10][92];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+1271369, dvrr_stack+839261, dvrr_stack+1089413);
 tmp = dvrr_stack + 1271369;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+1829833, dvrr_stack+757697, dvrr_stack+1015213);
 tmp = dvrr_stack + 1829833;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+1830421, dvrr_stack+596355, dvrr_stack+839261);
 tmp = dvrr_stack + 1830421;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+1831177, dvrr_stack+859146, dvrr_stack+757697);
 tmp = dvrr_stack + 1831177;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+1832122, dvrr_stack+369819, dvrr_stack+596355);
 tmp = dvrr_stack + 1832122;
 target_ptr = Libderiv->deriv2_classes[5][9][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+1833277, dvrr_stack+279527, dvrr_stack+859146);
 tmp = dvrr_stack + 1833277;
 target_ptr = Libderiv->deriv2_classes[5][10][91];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+1834663, dvrr_stack+397680, dvrr_stack+879026);
 tmp = dvrr_stack + 1834663;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+1835251, dvrr_stack+281165, dvrr_stack+405465);
 tmp = dvrr_stack + 1835251;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+1836035, dvrr_stack+261532, dvrr_stack+397680);
 tmp = dvrr_stack + 1836035;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1837043, dvrr_stack+245584, dvrr_stack+281165);
 tmp = dvrr_stack + 1837043;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1838303, dvrr_stack+218106, dvrr_stack+261532);
 tmp = dvrr_stack + 1838303;
 target_ptr = Libderiv->deriv2_classes[6][9][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+1839843, dvrr_stack+189982, dvrr_stack+245584);
 tmp = dvrr_stack + 1839843;
 target_ptr = Libderiv->deriv2_classes[6][10][91];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1841691, dvrr_stack+262792, dvrr_stack+597300);
 tmp = dvrr_stack + 1841691;
 target_ptr = Libderiv->deriv2_classes[7][5][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1842447, dvrr_stack+247124, dvrr_stack+1036708);
 tmp = dvrr_stack + 1842447;
 target_ptr = Libderiv->deriv2_classes[7][6][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1843455, dvrr_stack+167914, dvrr_stack+262792);
 tmp = dvrr_stack + 1843455;
 target_ptr = Libderiv->deriv2_classes[7][7][91];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1844751, dvrr_stack+150530, dvrr_stack+247124);
 tmp = dvrr_stack + 1844751;
 target_ptr = Libderiv->deriv2_classes[7][8][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1846371, dvrr_stack+77200, dvrr_stack+167914);
 tmp = dvrr_stack + 1846371;
 target_ptr = Libderiv->deriv2_classes[7][9][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+1848351, dvrr_stack+109978, dvrr_stack+150530);
 tmp = dvrr_stack + 1848351;
 target_ptr = Libderiv->deriv2_classes[7][10][91];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1850727, dvrr_stack+136100, dvrr_stack+241552);
 tmp = dvrr_stack + 1850727;
 target_ptr = Libderiv->deriv2_classes[8][5][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1851672, dvrr_stack+124454, dvrr_stack+192166);
 tmp = dvrr_stack + 1851672;
 target_ptr = Libderiv->deriv2_classes[8][6][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1852932, dvrr_stack+56086, dvrr_stack+136100);
 tmp = dvrr_stack + 1852932;
 target_ptr = Libderiv->deriv2_classes[8][7][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1854552, dvrr_stack+83878, dvrr_stack+124454);
 tmp = dvrr_stack + 1854552;
 target_ptr = Libderiv->deriv2_classes[8][8][91];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1856577, dvrr_stack+786770, dvrr_stack+56086);
 tmp = dvrr_stack + 1856577;
 target_ptr = Libderiv->deriv2_classes[8][9][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+1859052, dvrr_stack+789740, dvrr_stack+83878);
 tmp = dvrr_stack + 1859052;
 target_ptr = Libderiv->deriv2_classes[8][10][91];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1862022, dvrr_stack+38692, dvrr_stack+169534);
 tmp = dvrr_stack + 1862022;
 target_ptr = Libderiv->deriv2_classes[9][5][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1863177, dvrr_stack+61630, dvrr_stack+24817);
 tmp = dvrr_stack + 1863177;
 target_ptr = Libderiv->deriv2_classes[9][6][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1864717, dvrr_stack+546143, dvrr_stack+38692);
 tmp = dvrr_stack + 1864717;
 target_ptr = Libderiv->deriv2_classes[9][7][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1866697, dvrr_stack+548618, dvrr_stack+61630);
 tmp = dvrr_stack + 1866697;
 target_ptr = Libderiv->deriv2_classes[9][8][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1869172, dvrr_stack+551643, dvrr_stack+546143);
 tmp = dvrr_stack + 1869172;
 target_ptr = Libderiv->deriv2_classes[9][9][91];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1872197, dvrr_stack+504689, dvrr_stack+548618);
 tmp = dvrr_stack + 1872197;
 target_ptr = Libderiv->deriv2_classes[9][10][91];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+1875827, dvrr_stack+555273, dvrr_stack+13315);
 tmp = dvrr_stack + 1875827;
 target_ptr = Libderiv->deriv2_classes[10][5][91];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+1877213, dvrr_stack+508979, dvrr_stack+140888);
 tmp = dvrr_stack + 1877213;
 target_ptr = Libderiv->deriv2_classes[10][6][91];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+1879061, dvrr_stack+511355, dvrr_stack+555273);
 tmp = dvrr_stack + 1879061;
 target_ptr = Libderiv->deriv2_classes[10][7][91];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+1881437, dvrr_stack+440199, dvrr_stack+508979);
 tmp = dvrr_stack + 1881437;
 target_ptr = Libderiv->deriv2_classes[10][8][91];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+1884407, dvrr_stack+419125, dvrr_stack+511355);
 tmp = dvrr_stack + 1884407;
 target_ptr = Libderiv->deriv2_classes[10][9][91];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+1888037, dvrr_stack+1292257, dvrr_stack+440199);
 tmp = dvrr_stack + 1888037;
 target_ptr = Libderiv->deriv2_classes[10][10][91];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+1892393, dvrr_stack+1066202, dvrr_stack+1065887);
 tmp = dvrr_stack + 1892393;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+1065530, dvrr_stack+1067231, dvrr_stack+1066790);
 tmp = dvrr_stack + 1065530;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1892834, dvrr_stack+1067987, dvrr_stack+1066202);
 tmp = dvrr_stack + 1892834;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+1893590, dvrr_stack+1068932, dvrr_stack+1067231);
 tmp = dvrr_stack + 1893590;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1894535, dvrr_stack+1070087, dvrr_stack+1067987);
 tmp = dvrr_stack + 1894535;
 target_ptr = Libderiv->deriv2_classes[5][9][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1895690, dvrr_stack+1071473, dvrr_stack+1068932);
 tmp = dvrr_stack + 1895690;
 target_ptr = Libderiv->deriv2_classes[5][10][83];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+1071473, dvrr_stack+1074161, dvrr_stack+1073741);
 tmp = dvrr_stack + 1071473;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+1072061, dvrr_stack+1075533, dvrr_stack+1074945);
 tmp = dvrr_stack + 1072061;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1897076, dvrr_stack+1076541, dvrr_stack+1074161);
 tmp = dvrr_stack + 1897076;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1898084, dvrr_stack+1077801, dvrr_stack+1075533);
 tmp = dvrr_stack + 1898084;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1899344, dvrr_stack+1079341, dvrr_stack+1076541);
 tmp = dvrr_stack + 1899344;
 target_ptr = Libderiv->deriv2_classes[6][9][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1900884, dvrr_stack+1081189, dvrr_stack+1077801);
 tmp = dvrr_stack + 1900884;
 target_ptr = Libderiv->deriv2_classes[6][10][83];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+1081189, dvrr_stack+1086353, dvrr_stack+1085813);
 tmp = dvrr_stack + 1081189;
 target_ptr = Libderiv->deriv2_classes[7][5][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+1081945, dvrr_stack+1088117, dvrr_stack+1087361);
 tmp = dvrr_stack + 1081945;
 target_ptr = Libderiv->deriv2_classes[7][6][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1902732, dvrr_stack+1028797, dvrr_stack+1086353);
 tmp = dvrr_stack + 1902732;
 target_ptr = Libderiv->deriv2_classes[7][7][83];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1904028, dvrr_stack+1030417, dvrr_stack+1088117);
 tmp = dvrr_stack + 1904028;
 target_ptr = Libderiv->deriv2_classes[7][8][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1905648, dvrr_stack+1032397, dvrr_stack+1028797);
 tmp = dvrr_stack + 1905648;
 target_ptr = Libderiv->deriv2_classes[7][9][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1907628, dvrr_stack+973171, dvrr_stack+1030417);
 tmp = dvrr_stack + 1907628;
 target_ptr = Libderiv->deriv2_classes[7][10][83];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+973151, dvrr_stack+976654, dvrr_stack+975979);
 tmp = dvrr_stack + 973151;
 target_ptr = Libderiv->deriv2_classes[8][5][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+974096, dvrr_stack+925321, dvrr_stack+977914);
 tmp = dvrr_stack + 974096;
 target_ptr = Libderiv->deriv2_classes[8][6][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1910004, dvrr_stack+926941, dvrr_stack+976654);
 tmp = dvrr_stack + 1910004;
 target_ptr = Libderiv->deriv2_classes[8][7][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1911624, dvrr_stack+886667, dvrr_stack+925321);
 tmp = dvrr_stack + 1911624;
 target_ptr = Libderiv->deriv2_classes[8][8][83];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1913649, dvrr_stack+798777, dvrr_stack+926941);
 tmp = dvrr_stack + 1913649;
 target_ptr = Libderiv->deriv2_classes[8][9][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1916124, dvrr_stack+801747, dvrr_stack+886667);
 tmp = dvrr_stack + 1916124;
 target_ptr = Libderiv->deriv2_classes[8][10][83];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+801747, dvrr_stack+805257, dvrr_stack+929791);
 tmp = dvrr_stack + 801747;
 target_ptr = Libderiv->deriv2_classes[9][5][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+802902, dvrr_stack+806797, dvrr_stack+889142);
 tmp = dvrr_stack + 802902;
 target_ptr = Libderiv->deriv2_classes[9][6][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1919094, dvrr_stack+808777, dvrr_stack+805257);
 tmp = dvrr_stack + 1919094;
 target_ptr = Libderiv->deriv2_classes[9][7][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1921074, dvrr_stack+811252, dvrr_stack+806797);
 tmp = dvrr_stack + 1921074;
 target_ptr = Libderiv->deriv2_classes[9][8][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1923549, dvrr_stack+752219, dvrr_stack+808777);
 tmp = dvrr_stack + 1923549;
 target_ptr = Libderiv->deriv2_classes[9][9][83];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1926574, dvrr_stack+705929, dvrr_stack+811252);
 tmp = dvrr_stack + 1926574;
 target_ptr = Libderiv->deriv2_classes[9][10][83];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+705743, dvrr_stack+670190, dvrr_stack+710219);
 tmp = dvrr_stack + 705743;
 target_ptr = Libderiv->deriv2_classes[10][5][83];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+707129, dvrr_stack+631305, dvrr_stack+672038);
 tmp = dvrr_stack + 707129;
 target_ptr = Libderiv->deriv2_classes[10][6][83];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+1930204, dvrr_stack+633681, dvrr_stack+670190);
 tmp = dvrr_stack + 1930204;
 target_ptr = Libderiv->deriv2_classes[10][7][83];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+1932580, dvrr_stack+636651, dvrr_stack+631305);
 tmp = dvrr_stack + 1932580;
 target_ptr = Libderiv->deriv2_classes[10][8][83];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+1935550, dvrr_stack+561055, dvrr_stack+633681);
 tmp = dvrr_stack + 1935550;
 target_ptr = Libderiv->deriv2_classes[10][9][83];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+1939180, dvrr_stack+565411, dvrr_stack+636651);
 tmp = dvrr_stack + 1939180;
 target_ptr = Libderiv->deriv2_classes[10][10][83];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+565411, dvrr_stack+758819, dvrr_stack+979687);
 tmp = dvrr_stack + 565411;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+565852, dvrr_stack+673424, dvrr_stack+815817);
 tmp = dvrr_stack + 565852;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+566440, dvrr_stack+613740, dvrr_stack+758819);
 tmp = dvrr_stack + 566440;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+567196, dvrr_stack+614685, dvrr_stack+673424);
 tmp = dvrr_stack + 567196;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+568141, dvrr_stack+570559, dvrr_stack+613740);
 tmp = dvrr_stack + 568141;
 target_ptr = Libderiv->deriv2_classes[5][9][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+708977, dvrr_stack+571945, dvrr_stack+614685);
 tmp = dvrr_stack + 708977;
 target_ptr = Libderiv->deriv2_classes[5][10][82];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+571945, dvrr_stack+573583, dvrr_stack+4171);
 tmp = dvrr_stack + 571945;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+572533, dvrr_stack+487265, dvrr_stack+574367);
 tmp = dvrr_stack + 572533;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+569296, dvrr_stack+488273, dvrr_stack+573583);
 tmp = dvrr_stack + 569296;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+975356, dvrr_stack+489533, dvrr_stack+487265);
 tmp = dvrr_stack + 975356;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1943536, dvrr_stack+453680, dvrr_stack+488273);
 tmp = dvrr_stack + 1943536;
 target_ptr = Libderiv->deriv2_classes[6][9][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1945076, dvrr_stack+429000, dvrr_stack+489533);
 tmp = dvrr_stack + 1945076;
 target_ptr = Libderiv->deriv2_classes[6][10][82];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+804442, dvrr_stack+455528, dvrr_stack+491073);
 tmp = dvrr_stack + 804442;
 target_ptr = Libderiv->deriv2_classes[7][5][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+929386, dvrr_stack+406275, dvrr_stack+456536);
 tmp = dvrr_stack + 929386;
 target_ptr = Libderiv->deriv2_classes[7][6][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+428887, dvrr_stack+407571, dvrr_stack+455528);
 tmp = dvrr_stack + 428887;
 target_ptr = Libderiv->deriv2_classes[7][7][82];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1946924, dvrr_stack+409191, dvrr_stack+406275);
 tmp = dvrr_stack + 1946924;
 target_ptr = Libderiv->deriv2_classes[7][8][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1948544, dvrr_stack+374298, dvrr_stack+407571);
 tmp = dvrr_stack + 1948544;
 target_ptr = Libderiv->deriv2_classes[7][9][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1950524, dvrr_stack+376674, dvrr_stack+409191);
 tmp = dvrr_stack + 1950524;
 target_ptr = Libderiv->deriv2_classes[7][10][82];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+376674, dvrr_stack+379482, dvrr_stack+411171);
 tmp = dvrr_stack + 376674;
 target_ptr = Libderiv->deriv2_classes[8][5][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+377619, dvrr_stack+381687, dvrr_stack+380742);
 tmp = dvrr_stack + 377619;
 target_ptr = Libderiv->deriv2_classes[8][6][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1952900, dvrr_stack+383307, dvrr_stack+379482);
 tmp = dvrr_stack + 1952900;
 target_ptr = Libderiv->deriv2_classes[8][7][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1954520, dvrr_stack+343247, dvrr_stack+381687);
 tmp = dvrr_stack + 1954520;
 target_ptr = Libderiv->deriv2_classes[8][8][82];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1956545, dvrr_stack+220488, dvrr_stack+383307);
 tmp = dvrr_stack + 1956545;
 target_ptr = Libderiv->deriv2_classes[8][9][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1959020, dvrr_stack+223458, dvrr_stack+343247);
 tmp = dvrr_stack + 1959020;
 target_ptr = Libderiv->deriv2_classes[8][10][82];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+223458, dvrr_stack+287267, dvrr_stack+345722);
 tmp = dvrr_stack + 223458;
 target_ptr = Libderiv->deriv2_classes[9][5][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+224613, dvrr_stack+267688, dvrr_stack+346547);
 tmp = dvrr_stack + 224613;
 target_ptr = Libderiv->deriv2_classes[9][6][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1961990, dvrr_stack+226968, dvrr_stack+287267);
 tmp = dvrr_stack + 1961990;
 target_ptr = Libderiv->deriv2_classes[9][7][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1963970, dvrr_stack+198886, dvrr_stack+267688);
 tmp = dvrr_stack + 1963970;
 target_ptr = Libderiv->deriv2_classes[9][8][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1966445, dvrr_stack+106348, dvrr_stack+226968);
 tmp = dvrr_stack + 1966445;
 target_ptr = Libderiv->deriv2_classes[9][9][82];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1969470, dvrr_stack+1271863, dvrr_stack+198886);
 tmp = dvrr_stack + 1969470;
 target_ptr = Libderiv->deriv2_classes[9][10][82];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+1271810, dvrr_stack+229443, dvrr_stack+288807);
 tmp = dvrr_stack + 1271810;
 target_ptr = Libderiv->deriv2_classes[10][5][82];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+1273196, dvrr_stack+175306, dvrr_stack+251632);
 tmp = dvrr_stack + 1273196;
 target_ptr = Libderiv->deriv2_classes[10][6][82];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+1973100, dvrr_stack+1276153, dvrr_stack+229443);
 tmp = dvrr_stack + 1973100;
 target_ptr = Libderiv->deriv2_classes[10][7][82];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+1975476, dvrr_stack+1279123, dvrr_stack+175306);
 tmp = dvrr_stack + 1975476;
 target_ptr = Libderiv->deriv2_classes[10][8][82];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+1978446, dvrr_stack+1282753, dvrr_stack+1276153);
 tmp = dvrr_stack + 1978446;
 target_ptr = Libderiv->deriv2_classes[10][9][82];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+1982076, dvrr_stack+1287109, dvrr_stack+1279123);
 tmp = dvrr_stack + 1982076;
 target_ptr = Libderiv->deriv2_classes[10][10][82];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+4150, dvrr_stack+1064942, dvrr_stack+890297);
 tmp = dvrr_stack + 4150;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+1287109, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 1287109;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1287697, dvrr_stack+23872, dvrr_stack+1064942);
 tmp = dvrr_stack + 1287697;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+1288453, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 1288453;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1289398, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 1289398;
 target_ptr = Libderiv->deriv2_classes[5][9][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1290553, dvrr_stack+75562, dvrr_stack+37537);
 tmp = dvrr_stack + 1290553;
 target_ptr = Libderiv->deriv2_classes[5][10][81];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+75562, dvrr_stack+28408, dvrr_stack+99670);
 tmp = dvrr_stack + 75562;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+76150, dvrr_stack+119438, dvrr_stack+123866);
 tmp = dvrr_stack + 76150;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1275044, dvrr_stack+134840, dvrr_stack+28408);
 tmp = dvrr_stack + 1275044;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1986432, dvrr_stack+148990, dvrr_stack+119438);
 tmp = dvrr_stack + 1986432;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1987692, dvrr_stack+166066, dvrr_stack+134840);
 tmp = dvrr_stack + 1987692;
 target_ptr = Libderiv->deriv2_classes[6][9][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1989232, dvrr_stack+187798, dvrr_stack+148990);
 tmp = dvrr_stack + 1989232;
 target_ptr = Libderiv->deriv2_classes[6][10][81];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+187798, dvrr_stack+1084193, dvrr_stack+213936);
 tmp = dvrr_stack + 187798;
 target_ptr = Libderiv->deriv2_classes[7][5][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+188554, dvrr_stack+240256, dvrr_stack+120446);
 tmp = dvrr_stack + 188554;
 target_ptr = Libderiv->deriv2_classes[7][6][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1991080, dvrr_stack+259912, dvrr_stack+1084193);
 tmp = dvrr_stack + 1991080;
 target_ptr = Libderiv->deriv2_classes[7][7][81];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1992376, dvrr_stack+277547, dvrr_stack+240256);
 tmp = dvrr_stack + 1992376;
 target_ptr = Libderiv->deriv2_classes[7][8][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1993996, dvrr_stack+300671, dvrr_stack+259912);
 tmp = dvrr_stack + 1993996;
 target_ptr = Libderiv->deriv2_classes[7][9][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1995976, dvrr_stack+328991, dvrr_stack+277547);
 tmp = dvrr_stack + 1995976;
 target_ptr = Libderiv->deriv2_classes[7][10][81];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+288807, dvrr_stack+1035448, dvrr_stack+363039);
 tmp = dvrr_stack + 288807;
 target_ptr = Libderiv->deriv2_classes[8][5][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+328890, dvrr_stack+396060, dvrr_stack+402495);
 tmp = dvrr_stack + 328890;
 target_ptr = Libderiv->deriv2_classes[8][6][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+330150, dvrr_stack+403440, dvrr_stack+1035448);
 tmp = dvrr_stack + 330150;
 target_ptr = Libderiv->deriv2_classes[8][7][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1998352, dvrr_stack+363714, dvrr_stack+396060);
 tmp = dvrr_stack + 1998352;
 target_ptr = Libderiv->deriv2_classes[8][8][81];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+2000377, dvrr_stack+472415, dvrr_stack+403440);
 tmp = dvrr_stack + 2000377;
 target_ptr = Libderiv->deriv2_classes[8][9][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+2002852, dvrr_stack+475385, dvrr_stack+363714);
 tmp = dvrr_stack + 2002852;
 target_ptr = Libderiv->deriv2_classes[8][10][81];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+475385, dvrr_stack+857606, dvrr_stack+478895);
 tmp = dvrr_stack + 475385;
 target_ptr = Libderiv->deriv2_classes[9][5][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+476540, dvrr_stack+594375, dvrr_stack+604500);
 tmp = dvrr_stack + 476540;
 target_ptr = Libderiv->deriv2_classes[9][6][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+2005822, dvrr_stack+625365, dvrr_stack+857606);
 tmp = dvrr_stack + 2005822;
 target_ptr = Libderiv->deriv2_classes[9][7][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+2007802, dvrr_stack+655340, dvrr_stack+594375);
 tmp = dvrr_stack + 2007802;
 target_ptr = Libderiv->deriv2_classes[9][8][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+2010277, dvrr_stack+687779, dvrr_stack+625365);
 tmp = dvrr_stack + 2010277;
 target_ptr = Libderiv->deriv2_classes[9][9][81];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+2013302, dvrr_stack+730439, dvrr_stack+655340);
 tmp = dvrr_stack + 2013302;
 target_ptr = Libderiv->deriv2_classes[9][10][81];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+478080, dvrr_stack+755849, dvrr_stack+734729);
 tmp = dvrr_stack + 478080;
 target_ptr = Libderiv->deriv2_classes[10][5][81];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+730361, dvrr_stack+836060, dvrr_stack+846518);
 tmp = dvrr_stack + 730361;
 target_ptr = Libderiv->deriv2_classes[10][6][81];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+732209, dvrr_stack+872411, dvrr_stack+755849);
 tmp = dvrr_stack + 732209;
 target_ptr = Libderiv->deriv2_classes[10][7][81];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+2016932, dvrr_stack+907501, dvrr_stack+836060);
 tmp = dvrr_stack + 2016932;
 target_ptr = Libderiv->deriv2_classes[10][8][81];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+2019902, dvrr_stack+951391, dvrr_stack+872411);
 tmp = dvrr_stack + 2019902;
 target_ptr = Libderiv->deriv2_classes[10][9][81];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+2023532, dvrr_stack+1002661, dvrr_stack+907501);
 tmp = dvrr_stack + 2023532;
 target_ptr = Libderiv->deriv2_classes[10][10][81];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+345722, dvrr_stack+1049258, dvrr_stack+1048943);
 tmp = dvrr_stack + 345722;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+226153, dvrr_stack+1050287, dvrr_stack+1049846);
 tmp = dvrr_stack + 226153;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1002547, dvrr_stack+1051043, dvrr_stack+1049258);
 tmp = dvrr_stack + 1002547;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+1003303, dvrr_stack+1051988, dvrr_stack+1050287);
 tmp = dvrr_stack + 1003303;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1004248, dvrr_stack+1053143, dvrr_stack+1051043);
 tmp = dvrr_stack + 1004248;
 target_ptr = Libderiv->deriv2_classes[5][9][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1005403, dvrr_stack+1054529, dvrr_stack+1051988);
 tmp = dvrr_stack + 1005403;
 target_ptr = Libderiv->deriv2_classes[5][10][80];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+1054529, dvrr_stack+1056867, dvrr_stack+1056447);
 tmp = dvrr_stack + 1054529;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+1055117, dvrr_stack+1058239, dvrr_stack+1057651);
 tmp = dvrr_stack + 1055117;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1006789, dvrr_stack+1059247, dvrr_stack+1056867);
 tmp = dvrr_stack + 1006789;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+2027888, dvrr_stack+1060507, dvrr_stack+1058239);
 tmp = dvrr_stack + 2027888;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+2029148, dvrr_stack+1062047, dvrr_stack+1059247);
 tmp = dvrr_stack + 2029148;
 target_ptr = Libderiv->deriv2_classes[6][9][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+2030688, dvrr_stack+1007809, dvrr_stack+1060507);
 tmp = dvrr_stack + 2030688;
 target_ptr = Libderiv->deriv2_classes[6][10][80];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+1055901, dvrr_stack+1010533, dvrr_stack+1009993);
 tmp = dvrr_stack + 1055901;
 target_ptr = Libderiv->deriv2_classes[7][5][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+1007797, dvrr_stack+1012297, dvrr_stack+1011541);
 tmp = dvrr_stack + 1007797;
 target_ptr = Libderiv->deriv2_classes[7][6][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1008805, dvrr_stack+1013593, dvrr_stack+1010533);
 tmp = dvrr_stack + 1008805;
 target_ptr = Libderiv->deriv2_classes[7][7][80];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+2032536, dvrr_stack+955747, dvrr_stack+1012297);
 tmp = dvrr_stack + 2032536;
 target_ptr = Libderiv->deriv2_classes[7][8][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+2034156, dvrr_stack+957727, dvrr_stack+1013593);
 tmp = dvrr_stack + 2034156;
 target_ptr = Libderiv->deriv2_classes[7][9][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+2036136, dvrr_stack+911131, dvrr_stack+955747);
 tmp = dvrr_stack + 2036136;
 target_ptr = Libderiv->deriv2_classes[7][10][80];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+911131, dvrr_stack+913939, dvrr_stack+960553);
 tmp = dvrr_stack + 911131;
 target_ptr = Libderiv->deriv2_classes[8][5][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+912076, dvrr_stack+875381, dvrr_stack+961228);
 tmp = dvrr_stack + 912076;
 target_ptr = Libderiv->deriv2_classes[8][6][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+2038512, dvrr_stack+877001, dvrr_stack+913939);
 tmp = dvrr_stack + 2038512;
 target_ptr = Libderiv->deriv2_classes[8][7][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+2040132, dvrr_stack+847904, dvrr_stack+875381);
 tmp = dvrr_stack + 2040132;
 target_ptr = Libderiv->deriv2_classes[8][8][80];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+2042157, dvrr_stack+735719, dvrr_stack+877001);
 tmp = dvrr_stack + 2042157;
 target_ptr = Libderiv->deriv2_classes[8][9][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+2044632, dvrr_stack+691409, dvrr_stack+847904);
 tmp = dvrr_stack + 2044632;
 target_ptr = Libderiv->deriv2_classes[8][10][80];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+691409, dvrr_stack+850379, dvrr_stack+838436);
 tmp = dvrr_stack + 691409;
 target_ptr = Libderiv->deriv2_classes[9][5][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+692564, dvrr_stack+658365, dvrr_stack+738689);
 tmp = dvrr_stack + 692564;
 target_ptr = Libderiv->deriv2_classes[9][6][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+2047602, dvrr_stack+627840, dvrr_stack+850379);
 tmp = dvrr_stack + 2047602;
 target_ptr = Libderiv->deriv2_classes[9][7][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+2049582, dvrr_stack+605655, dvrr_stack+658365);
 tmp = dvrr_stack + 2049582;
 target_ptr = Libderiv->deriv2_classes[9][8][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+2052057, dvrr_stack+366189, dvrr_stack+627840);
 tmp = dvrr_stack + 2052057;
 target_ptr = Libderiv->deriv2_classes[9][9][80];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+2055082, dvrr_stack+331799, dvrr_stack+605655);
 tmp = dvrr_stack + 2055082;
 target_ptr = Libderiv->deriv2_classes[9][10][80];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+331770, dvrr_stack+694919, dvrr_stack+630315);
 tmp = dvrr_stack + 331770;
 target_ptr = Libderiv->deriv2_classes[10][5][80];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+333156, dvrr_stack+660345, dvrr_stack+739844);
 tmp = dvrr_stack + 333156;
 target_ptr = Libderiv->deriv2_classes[10][6][80];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+2058712, dvrr_stack+303047, dvrr_stack+694919);
 tmp = dvrr_stack + 2058712;
 target_ptr = Libderiv->deriv2_classes[10][7][80];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+2061088, dvrr_stack+214476, dvrr_stack+660345);
 tmp = dvrr_stack + 2061088;
 target_ptr = Libderiv->deriv2_classes[10][8][80];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+2064058, dvrr_stack+100090, dvrr_stack+303047);
 tmp = dvrr_stack + 2064058;
 target_ptr = Libderiv->deriv2_classes[10][9][80];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+2067688, dvrr_stack+781622, dvrr_stack+214476);
 tmp = dvrr_stack + 2067688;
 target_ptr = Libderiv->deriv2_classes[10][10][80];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+630315, dvrr_stack+839261, dvrr_stack+1089413);
 tmp = dvrr_stack + 630315;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+838436, dvrr_stack+757697, dvrr_stack+1015213);
 tmp = dvrr_stack + 838436;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+694104, dvrr_stack+596355, dvrr_stack+839261);
 tmp = dvrr_stack + 694104;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+2072044, dvrr_stack+859146, dvrr_stack+757697);
 tmp = dvrr_stack + 2072044;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+781383, dvrr_stack+369819, dvrr_stack+596355);
 tmp = dvrr_stack + 781383;
 target_ptr = Libderiv->deriv2_classes[5][9][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+782538, dvrr_stack+279527, dvrr_stack+859146);
 tmp = dvrr_stack + 782538;
 target_ptr = Libderiv->deriv2_classes[5][10][79];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+279527, dvrr_stack+397680, dvrr_stack+879026);
 tmp = dvrr_stack + 279527;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+280115, dvrr_stack+281165, dvrr_stack+405465);
 tmp = dvrr_stack + 280115;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+734585, dvrr_stack+261532, dvrr_stack+397680);
 tmp = dvrr_stack + 734585;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+783924, dvrr_stack+245584, dvrr_stack+281165);
 tmp = dvrr_stack + 783924;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+785184, dvrr_stack+218106, dvrr_stack+261532);
 tmp = dvrr_stack + 785184;
 target_ptr = Libderiv->deriv2_classes[6][9][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+2072989, dvrr_stack+189982, dvrr_stack+245584);
 tmp = dvrr_stack + 2072989;
 target_ptr = Libderiv->deriv2_classes[6][10][79];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+189562, dvrr_stack+262792, dvrr_stack+597300);
 tmp = dvrr_stack + 189562;
 target_ptr = Libderiv->deriv2_classes[7][5][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+190318, dvrr_stack+247124, dvrr_stack+1036708);
 tmp = dvrr_stack + 190318;
 target_ptr = Libderiv->deriv2_classes[7][6][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+2074837, dvrr_stack+167914, dvrr_stack+262792);
 tmp = dvrr_stack + 2074837;
 target_ptr = Libderiv->deriv2_classes[7][7][79];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+2076133, dvrr_stack+150530, dvrr_stack+247124);
 tmp = dvrr_stack + 2076133;
 target_ptr = Libderiv->deriv2_classes[7][8][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+2077753, dvrr_stack+77200, dvrr_stack+167914);
 tmp = dvrr_stack + 2077753;
 target_ptr = Libderiv->deriv2_classes[7][9][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+2079733, dvrr_stack+109978, dvrr_stack+150530);
 tmp = dvrr_stack + 2079733;
 target_ptr = Libderiv->deriv2_classes[7][10][79];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+109978, dvrr_stack+136100, dvrr_stack+241552);
 tmp = dvrr_stack + 109978;
 target_ptr = Libderiv->deriv2_classes[8][5][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+110923, dvrr_stack+124454, dvrr_stack+192166);
 tmp = dvrr_stack + 110923;
 target_ptr = Libderiv->deriv2_classes[8][6][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+2082109, dvrr_stack+56086, dvrr_stack+136100);
 tmp = dvrr_stack + 2082109;
 target_ptr = Libderiv->deriv2_classes[8][7][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+2083729, dvrr_stack+83878, dvrr_stack+124454);
 tmp = dvrr_stack + 2083729;
 target_ptr = Libderiv->deriv2_classes[8][8][79];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+2085754, dvrr_stack+786770, dvrr_stack+56086);
 tmp = dvrr_stack + 2085754;
 target_ptr = Libderiv->deriv2_classes[8][9][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+2088229, dvrr_stack+789740, dvrr_stack+83878);
 tmp = dvrr_stack + 2088229;
 target_ptr = Libderiv->deriv2_classes[8][10][79];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+789740, dvrr_stack+38692, dvrr_stack+169534);
 tmp = dvrr_stack + 789740;
 target_ptr = Libderiv->deriv2_classes[9][5][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+790895, dvrr_stack+61630, dvrr_stack+24817);
 tmp = dvrr_stack + 790895;
 target_ptr = Libderiv->deriv2_classes[9][6][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+2091199, dvrr_stack+546143, dvrr_stack+38692);
 tmp = dvrr_stack + 2091199;
 target_ptr = Libderiv->deriv2_classes[9][7][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+2093179, dvrr_stack+548618, dvrr_stack+61630);
 tmp = dvrr_stack + 2093179;
 target_ptr = Libderiv->deriv2_classes[9][8][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+2095654, dvrr_stack+551643, dvrr_stack+546143);
 tmp = dvrr_stack + 2095654;
 target_ptr = Libderiv->deriv2_classes[9][9][79];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+2098679, dvrr_stack+504689, dvrr_stack+548618);
 tmp = dvrr_stack + 2098679;
 target_ptr = Libderiv->deriv2_classes[9][10][79];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+504686, dvrr_stack+555273, dvrr_stack+13315);
 tmp = dvrr_stack + 504686;
 target_ptr = Libderiv->deriv2_classes[10][5][79];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+506072, dvrr_stack+508979, dvrr_stack+140888);
 tmp = dvrr_stack + 506072;
 target_ptr = Libderiv->deriv2_classes[10][6][79];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+2102309, dvrr_stack+511355, dvrr_stack+555273);
 tmp = dvrr_stack + 2102309;
 target_ptr = Libderiv->deriv2_classes[10][7][79];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+2104685, dvrr_stack+440199, dvrr_stack+508979);
 tmp = dvrr_stack + 2104685;
 target_ptr = Libderiv->deriv2_classes[10][8][79];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+2107655, dvrr_stack+419125, dvrr_stack+511355);
 tmp = dvrr_stack + 2107655;
 target_ptr = Libderiv->deriv2_classes[10][9][79];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+2111285, dvrr_stack+1292257, dvrr_stack+440199);
 tmp = dvrr_stack + 2111285;
 target_ptr = Libderiv->deriv2_classes[10][10][79];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+13315, dvrr_stack+306017, dvrr_stack+1063895);
 tmp = dvrr_stack + 13315;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+1063895, dvrr_stack+128570, dvrr_stack+1085201);
 tmp = dvrr_stack + 1063895;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+169534, dvrr_stack+43207, dvrr_stack+306017);
 tmp = dvrr_stack + 169534;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+1291939, dvrr_stack+793250, dvrr_stack+128570);
 tmp = dvrr_stack + 1291939;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1292884, dvrr_stack+443829, dvrr_stack+43207);
 tmp = dvrr_stack + 1292884;
 target_ptr = Libderiv->deriv2_classes[5][9][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1294039, dvrr_stack+73924, dvrr_stack+793250);
 tmp = dvrr_stack + 1294039;
 target_ptr = Libderiv->deriv2_classes[5][10][78];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+792435, dvrr_stack+16402, dvrr_stack+129326);
 tmp = dvrr_stack + 792435;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+191326, dvrr_stack+445215, dvrr_stack+201911);
 tmp = dvrr_stack + 191326;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1295425, dvrr_stack+446223, dvrr_stack+16402);
 tmp = dvrr_stack + 1295425;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+73588, dvrr_stack+91402, dvrr_stack+445215);
 tmp = dvrr_stack + 73588;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+2115641, dvrr_stack+97628, dvrr_stack+446223);
 tmp = dvrr_stack + 2115641;
 target_ptr = Libderiv->deriv2_classes[6][9][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+2117181, dvrr_stack+185614, dvrr_stack+91402);
 tmp = dvrr_stack + 2117181;
 target_ptr = Libderiv->deriv2_classes[6][10][78];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+1296433, dvrr_stack+211381, dvrr_stack+1073111);
 tmp = dvrr_stack + 1296433;
 target_ptr = Libderiv->deriv2_classes[7][5][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+1072845, dvrr_stack+212389, dvrr_stack+44152);
 tmp = dvrr_stack + 1072845;
 target_ptr = Libderiv->deriv2_classes[7][6][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+185536, dvrr_stack+1297405, dvrr_stack+211381);
 tmp = dvrr_stack + 185536;
 target_ptr = Libderiv->deriv2_classes[7][7][78];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+2119029, dvrr_stack+1299025, dvrr_stack+212389);
 tmp = dvrr_stack + 2119029;
 target_ptr = Libderiv->deriv2_classes[7][8][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+2120649, dvrr_stack+1301005, dvrr_stack+1297405);
 tmp = dvrr_stack + 2120649;
 target_ptr = Libderiv->deriv2_classes[7][9][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+2122629, dvrr_stack+326082, dvrr_stack+1299025);
 tmp = dvrr_stack + 2122629;
 target_ptr = Libderiv->deriv2_classes[7][10][78];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+507920, dvrr_stack+359739, dvrr_stack+1083373);
 tmp = dvrr_stack + 507920;
 target_ptr = Libderiv->deriv2_classes[8][5][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+325958, dvrr_stack+1303381, dvrr_stack+360999);
 tmp = dvrr_stack + 325958;
 target_ptr = Libderiv->deriv2_classes[8][6][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+327218, dvrr_stack+1305001, dvrr_stack+359739);
 tmp = dvrr_stack + 327218;
 target_ptr = Libderiv->deriv2_classes[8][7][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+2125005, dvrr_stack+1307026, dvrr_stack+1303381);
 tmp = dvrr_stack + 2125005;
 target_ptr = Libderiv->deriv2_classes[8][8][78];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+2127030, dvrr_stack+1309501, dvrr_stack+1305001);
 tmp = dvrr_stack + 2127030;
 target_ptr = Libderiv->deriv2_classes[8][9][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+2129505, dvrr_stack+182026, dvrr_stack+1307026);
 tmp = dvrr_stack + 2129505;
 target_ptr = Libderiv->deriv2_classes[8][10][78];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+1082953, dvrr_stack+208027, dvrr_stack+207202);
 tmp = dvrr_stack + 1082953;
 target_ptr = Libderiv->deriv2_classes[9][5][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+181597, dvrr_stack+1312471, dvrr_stack+209567);
 tmp = dvrr_stack + 181597;
 target_ptr = Libderiv->deriv2_classes[9][6][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+183137, dvrr_stack+1314451, dvrr_stack+208027);
 tmp = dvrr_stack + 183137;
 target_ptr = Libderiv->deriv2_classes[9][7][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+2132475, dvrr_stack+1316926, dvrr_stack+1312471);
 tmp = dvrr_stack + 2132475;
 target_ptr = Libderiv->deriv2_classes[9][8][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+2134950, dvrr_stack+1319951, dvrr_stack+1314451);
 tmp = dvrr_stack + 2134950;
 target_ptr = Libderiv->deriv2_classes[9][9][78];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+2137975, dvrr_stack+1323581, dvrr_stack+1316926);
 tmp = dvrr_stack + 2137975;
 target_ptr = Libderiv->deriv2_classes[9][10][78];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+1323581, dvrr_stack+354929, dvrr_stack+353939);
 tmp = dvrr_stack + 1323581;
 target_ptr = Libderiv->deriv2_classes[10][5][78];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+1324967, dvrr_stack+1327871, dvrr_stack+356777);
 tmp = dvrr_stack + 1324967;
 target_ptr = Libderiv->deriv2_classes[10][6][78];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+2141605, dvrr_stack+1330247, dvrr_stack+354929);
 tmp = dvrr_stack + 2141605;
 target_ptr = Libderiv->deriv2_classes[10][7][78];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+2143981, dvrr_stack+1333217, dvrr_stack+1327871);
 tmp = dvrr_stack + 2143981;
 target_ptr = Libderiv->deriv2_classes[10][8][78];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+2146951, dvrr_stack+1336847, dvrr_stack+1330247);
 tmp = dvrr_stack + 2146951;
 target_ptr = Libderiv->deriv2_classes[10][9][78];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+2150581, dvrr_stack+1341203, dvrr_stack+1333217);
 tmp = dvrr_stack + 2150581;
 target_ptr = Libderiv->deriv2_classes[10][10][78];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1341203, dvrr_stack+1074945, dvrr_stack+1064627);
 tmp = dvrr_stack + 1341203;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1341644, dvrr_stack+1074161, dvrr_stack+539255);
 tmp = dvrr_stack + 1341644;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1342232, dvrr_stack+1075533, dvrr_stack+541295);
 tmp = dvrr_stack + 1342232;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1342988, dvrr_stack+1076541, dvrr_stack+1034773);
 tmp = dvrr_stack + 1342988;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1343933, dvrr_stack+1077801, dvrr_stack+541835);
 tmp = dvrr_stack + 1343933;
 target_ptr = Libderiv->deriv2_classes[5][9][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,66,dvrr_stack+353474, dvrr_stack+1079341, dvrr_stack+915199);
 tmp = dvrr_stack + 353474;
 target_ptr = Libderiv->deriv2_classes[5][10][35];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1345088, dvrr_stack+1087361, dvrr_stack+1066790);
 tmp = dvrr_stack + 1345088;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1326815, dvrr_stack+1086353, dvrr_stack+1066202);
 tmp = dvrr_stack + 1326815;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+206999, dvrr_stack+1088117, dvrr_stack+1067231);
 tmp = dvrr_stack + 206999;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2154937, dvrr_stack+1028797, dvrr_stack+1067987);
 tmp = dvrr_stack + 2154937;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2156197, dvrr_stack+1030417, dvrr_stack+1068932);
 tmp = dvrr_stack + 2156197;
 target_ptr = Libderiv->deriv2_classes[6][9][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2157737, dvrr_stack+1032397, dvrr_stack+1070087);
 tmp = dvrr_stack + 2157737;
 target_ptr = Libderiv->deriv2_classes[6][10][35];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,21,dvrr_stack+362952, dvrr_stack+977914, dvrr_stack+1074945);
 tmp = dvrr_stack + 362952;
 target_ptr = Libderiv->deriv2_classes[7][5][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,28,dvrr_stack+335004, dvrr_stack+976654, dvrr_stack+1074161);
 tmp = dvrr_stack + 335004;
 target_ptr = Libderiv->deriv2_classes[7][6][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2159585, dvrr_stack+925321, dvrr_stack+1075533);
 tmp = dvrr_stack + 2159585;
 target_ptr = Libderiv->deriv2_classes[7][7][35];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2160881, dvrr_stack+926941, dvrr_stack+1076541);
 tmp = dvrr_stack + 2160881;
 target_ptr = Libderiv->deriv2_classes[7][8][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2162501, dvrr_stack+886667, dvrr_stack+1077801);
 tmp = dvrr_stack + 2162501;
 target_ptr = Libderiv->deriv2_classes[7][9][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2164481, dvrr_stack+798777, dvrr_stack+1079341);
 tmp = dvrr_stack + 2164481;
 target_ptr = Libderiv->deriv2_classes[7][10][35];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,21,dvrr_stack+186832, dvrr_stack+889142, dvrr_stack+1087361);
 tmp = dvrr_stack + 186832;
 target_ptr = Libderiv->deriv2_classes[8][5][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2166857, dvrr_stack+805257, dvrr_stack+1086353);
 tmp = dvrr_stack + 2166857;
 target_ptr = Libderiv->deriv2_classes[8][6][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2168117, dvrr_stack+806797, dvrr_stack+1088117);
 tmp = dvrr_stack + 2168117;
 target_ptr = Libderiv->deriv2_classes[8][7][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2169737, dvrr_stack+808777, dvrr_stack+1028797);
 tmp = dvrr_stack + 2169737;
 target_ptr = Libderiv->deriv2_classes[8][8][35];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2171762, dvrr_stack+811252, dvrr_stack+1030417);
 tmp = dvrr_stack + 2171762;
 target_ptr = Libderiv->deriv2_classes[8][9][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2174237, dvrr_stack+752219, dvrr_stack+1032397);
 tmp = dvrr_stack + 2174237;
 target_ptr = Libderiv->deriv2_classes[8][10][35];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2177207, dvrr_stack+672038, dvrr_stack+977914);
 tmp = dvrr_stack + 2177207;
 target_ptr = Libderiv->deriv2_classes[9][5][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2178362, dvrr_stack+670190, dvrr_stack+976654);
 tmp = dvrr_stack + 2178362;
 target_ptr = Libderiv->deriv2_classes[9][6][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2179902, dvrr_stack+631305, dvrr_stack+925321);
 tmp = dvrr_stack + 2179902;
 target_ptr = Libderiv->deriv2_classes[9][7][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2181882, dvrr_stack+633681, dvrr_stack+926941);
 tmp = dvrr_stack + 2181882;
 target_ptr = Libderiv->deriv2_classes[9][8][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2184357, dvrr_stack+636651, dvrr_stack+886667);
 tmp = dvrr_stack + 2184357;
 target_ptr = Libderiv->deriv2_classes[9][9][35];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2187382, dvrr_stack+561055, dvrr_stack+798777);
 tmp = dvrr_stack + 2187382;
 target_ptr = Libderiv->deriv2_classes[9][10][35];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2191012, dvrr_stack+591043, dvrr_stack+889142);
 tmp = dvrr_stack + 2191012;
 target_ptr = Libderiv->deriv2_classes[10][5][35];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2192398, dvrr_stack+600216, dvrr_stack+805257);
 tmp = dvrr_stack + 2192398;
 target_ptr = Libderiv->deriv2_classes[10][6][35];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2194246, dvrr_stack+622485, dvrr_stack+806797);
 tmp = dvrr_stack + 2194246;
 target_ptr = Libderiv->deriv2_classes[10][7][35];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2196622, dvrr_stack+648795, dvrr_stack+808777);
 tmp = dvrr_stack + 2196622;
 target_ptr = Libderiv->deriv2_classes[10][8][35];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2199592, dvrr_stack+1458588, dvrr_stack+811252);
 tmp = dvrr_stack + 2199592;
 target_ptr = Libderiv->deriv2_classes[10][9][35];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2203222, dvrr_stack+725213, dvrr_stack+752219);
 tmp = dvrr_stack + 2203222;
 target_ptr = Libderiv->deriv2_classes[10][10][35];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1345676, dvrr_stack+574367, dvrr_stack+498065);
 tmp = dvrr_stack + 1345676;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+241552, dvrr_stack+573583, dvrr_stack+498380);
 tmp = dvrr_stack + 241552;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+710363, dvrr_stack+487265, dvrr_stack+498800);
 tmp = dvrr_stack + 710363;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+430183, dvrr_stack+488273, dvrr_stack+499340);
 tmp = dvrr_stack + 430183;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+2207578, dvrr_stack+489533, dvrr_stack+500015);
 tmp = dvrr_stack + 2207578;
 target_ptr = Libderiv->deriv2_classes[5][9][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+2208733, dvrr_stack+453680, dvrr_stack+500840);
 tmp = dvrr_stack + 2208733;
 target_ptr = Libderiv->deriv2_classes[5][10][34];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+112183, dvrr_stack+456536, dvrr_stack+815817);
 tmp = dvrr_stack + 112183;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+2210119, dvrr_stack+455528, dvrr_stack+758819);
 tmp = dvrr_stack + 2210119;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+2210903, dvrr_stack+406275, dvrr_stack+673424);
 tmp = dvrr_stack + 2210903;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2211911, dvrr_stack+407571, dvrr_stack+613740);
 tmp = dvrr_stack + 2211911;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2213171, dvrr_stack+409191, dvrr_stack+614685);
 tmp = dvrr_stack + 2213171;
 target_ptr = Libderiv->deriv2_classes[6][9][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2214711, dvrr_stack+374298, dvrr_stack+570559);
 tmp = dvrr_stack + 2214711;
 target_ptr = Libderiv->deriv2_classes[6][10][34];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+213685, dvrr_stack+380742, dvrr_stack+574367);
 tmp = dvrr_stack + 213685;
 target_ptr = Libderiv->deriv2_classes[7][5][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2216559, dvrr_stack+379482, dvrr_stack+573583);
 tmp = dvrr_stack + 2216559;
 target_ptr = Libderiv->deriv2_classes[7][6][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2217567, dvrr_stack+381687, dvrr_stack+487265);
 tmp = dvrr_stack + 2217567;
 target_ptr = Libderiv->deriv2_classes[7][7][34];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2218863, dvrr_stack+383307, dvrr_stack+488273);
 tmp = dvrr_stack + 2218863;
 target_ptr = Libderiv->deriv2_classes[7][8][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2220483, dvrr_stack+343247, dvrr_stack+489533);
 tmp = dvrr_stack + 2220483;
 target_ptr = Libderiv->deriv2_classes[7][9][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2222463, dvrr_stack+220488, dvrr_stack+453680);
 tmp = dvrr_stack + 2222463;
 target_ptr = Libderiv->deriv2_classes[7][10][34];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+2224839, dvrr_stack+346547, dvrr_stack+456536);
 tmp = dvrr_stack + 2224839;
 target_ptr = Libderiv->deriv2_classes[8][5][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2225784, dvrr_stack+287267, dvrr_stack+455528);
 tmp = dvrr_stack + 2225784;
 target_ptr = Libderiv->deriv2_classes[8][6][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2227044, dvrr_stack+267688, dvrr_stack+406275);
 tmp = dvrr_stack + 2227044;
 target_ptr = Libderiv->deriv2_classes[8][7][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2228664, dvrr_stack+226968, dvrr_stack+407571);
 tmp = dvrr_stack + 2228664;
 target_ptr = Libderiv->deriv2_classes[8][8][34];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2230689, dvrr_stack+198886, dvrr_stack+409191);
 tmp = dvrr_stack + 2230689;
 target_ptr = Libderiv->deriv2_classes[8][9][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2233164, dvrr_stack+106348, dvrr_stack+374298);
 tmp = dvrr_stack + 2233164;
 target_ptr = Libderiv->deriv2_classes[8][10][34];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2236134, dvrr_stack+251632, dvrr_stack+380742);
 tmp = dvrr_stack + 2236134;
 target_ptr = Libderiv->deriv2_classes[9][5][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2237289, dvrr_stack+229443, dvrr_stack+379482);
 tmp = dvrr_stack + 2237289;
 target_ptr = Libderiv->deriv2_classes[9][6][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2238829, dvrr_stack+175306, dvrr_stack+381687);
 tmp = dvrr_stack + 2238829;
 target_ptr = Libderiv->deriv2_classes[9][7][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2240809, dvrr_stack+1276153, dvrr_stack+383307);
 tmp = dvrr_stack + 2240809;
 target_ptr = Libderiv->deriv2_classes[9][8][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2243284, dvrr_stack+1279123, dvrr_stack+343247);
 tmp = dvrr_stack + 2243284;
 target_ptr = Libderiv->deriv2_classes[9][9][34];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2246309, dvrr_stack+1282753, dvrr_stack+220488);
 tmp = dvrr_stack + 2246309;
 target_ptr = Libderiv->deriv2_classes[9][10][34];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2249939, dvrr_stack+321191, dvrr_stack+346547);
 tmp = dvrr_stack + 2249939;
 target_ptr = Libderiv->deriv2_classes[10][5][34];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2251325, dvrr_stack+322829, dvrr_stack+287267);
 tmp = dvrr_stack + 2251325;
 target_ptr = Libderiv->deriv2_classes[10][6][34];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2253173, dvrr_stack+465155, dvrr_stack+267688);
 tmp = dvrr_stack + 2253173;
 target_ptr = Libderiv->deriv2_classes[10][7][34];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2255549, dvrr_stack+989011, dvrr_stack+226968);
 tmp = dvrr_stack + 2255549;
 target_ptr = Libderiv->deriv2_classes[10][8][34];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2258519, dvrr_stack+992521, dvrr_stack+198886);
 tmp = dvrr_stack + 2258519;
 target_ptr = Libderiv->deriv2_classes[10][9][34];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2262149, dvrr_stack+996811, dvrr_stack+106348);
 tmp = dvrr_stack + 2262149;
 target_ptr = Libderiv->deriv2_classes[10][10][34];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+13756, dvrr_stack+123866, dvrr_stack+501830);
 tmp = dvrr_stack + 13756;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+913336, dvrr_stack+28408, dvrr_stack+537050);
 tmp = dvrr_stack + 913336;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+2266505, dvrr_stack+119438, dvrr_stack+537470);
 tmp = dvrr_stack + 2266505;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+2267261, dvrr_stack+134840, dvrr_stack+539675);
 tmp = dvrr_stack + 2267261;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+2268206, dvrr_stack+148990, dvrr_stack+1346351);
 tmp = dvrr_stack + 2268206;
 target_ptr = Libderiv->deriv2_classes[5][9][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+2269361, dvrr_stack+166066, dvrr_stack+1347176);
 tmp = dvrr_stack + 2269361;
 target_ptr = Libderiv->deriv2_classes[5][10][33];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+411171, dvrr_stack+120446, dvrr_stack+12874);
 tmp = dvrr_stack + 411171;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+2270747, dvrr_stack+1084193, dvrr_stack+1064942);
 tmp = dvrr_stack + 2270747;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+2271531, dvrr_stack+240256, dvrr_stack+7447);
 tmp = dvrr_stack + 2271531;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2272539, dvrr_stack+259912, dvrr_stack+23872);
 tmp = dvrr_stack + 2272539;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2273799, dvrr_stack+277547, dvrr_stack+37537);
 tmp = dvrr_stack + 2273799;
 target_ptr = Libderiv->deriv2_classes[6][9][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2275339, dvrr_stack+300671, dvrr_stack+54700);
 tmp = dvrr_stack + 2275339;
 target_ptr = Libderiv->deriv2_classes[6][10][33];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+2277187, dvrr_stack+402495, dvrr_stack+123866);
 tmp = dvrr_stack + 2277187;
 target_ptr = Libderiv->deriv2_classes[7][5][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2277943, dvrr_stack+1035448, dvrr_stack+28408);
 tmp = dvrr_stack + 2277943;
 target_ptr = Libderiv->deriv2_classes[7][6][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2278951, dvrr_stack+396060, dvrr_stack+119438);
 tmp = dvrr_stack + 2278951;
 target_ptr = Libderiv->deriv2_classes[7][7][33];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2280247, dvrr_stack+403440, dvrr_stack+134840);
 tmp = dvrr_stack + 2280247;
 target_ptr = Libderiv->deriv2_classes[7][8][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2281867, dvrr_stack+363714, dvrr_stack+148990);
 tmp = dvrr_stack + 2281867;
 target_ptr = Libderiv->deriv2_classes[7][9][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2283847, dvrr_stack+472415, dvrr_stack+166066);
 tmp = dvrr_stack + 2283847;
 target_ptr = Libderiv->deriv2_classes[7][10][33];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+2286223, dvrr_stack+604500, dvrr_stack+120446);
 tmp = dvrr_stack + 2286223;
 target_ptr = Libderiv->deriv2_classes[8][5][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2287168, dvrr_stack+857606, dvrr_stack+1084193);
 tmp = dvrr_stack + 2287168;
 target_ptr = Libderiv->deriv2_classes[8][6][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2288428, dvrr_stack+594375, dvrr_stack+240256);
 tmp = dvrr_stack + 2288428;
 target_ptr = Libderiv->deriv2_classes[8][7][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2290048, dvrr_stack+625365, dvrr_stack+259912);
 tmp = dvrr_stack + 2290048;
 target_ptr = Libderiv->deriv2_classes[8][8][33];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2292073, dvrr_stack+655340, dvrr_stack+277547);
 tmp = dvrr_stack + 2292073;
 target_ptr = Libderiv->deriv2_classes[8][9][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2294548, dvrr_stack+687779, dvrr_stack+300671);
 tmp = dvrr_stack + 2294548;
 target_ptr = Libderiv->deriv2_classes[8][10][33];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2297518, dvrr_stack+846518, dvrr_stack+402495);
 tmp = dvrr_stack + 2297518;
 target_ptr = Libderiv->deriv2_classes[9][5][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2298673, dvrr_stack+755849, dvrr_stack+1035448);
 tmp = dvrr_stack + 2298673;
 target_ptr = Libderiv->deriv2_classes[9][6][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2300213, dvrr_stack+836060, dvrr_stack+396060);
 tmp = dvrr_stack + 2300213;
 target_ptr = Libderiv->deriv2_classes[9][7][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2302193, dvrr_stack+872411, dvrr_stack+403440);
 tmp = dvrr_stack + 2302193;
 target_ptr = Libderiv->deriv2_classes[9][8][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2304668, dvrr_stack+907501, dvrr_stack+363714);
 tmp = dvrr_stack + 2304668;
 target_ptr = Libderiv->deriv2_classes[9][9][33];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2307693, dvrr_stack+951391, dvrr_stack+472415);
 tmp = dvrr_stack + 2307693;
 target_ptr = Libderiv->deriv2_classes[9][10][33];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2311323, dvrr_stack+1348166, dvrr_stack+604500);
 tmp = dvrr_stack + 2311323;
 target_ptr = Libderiv->deriv2_classes[10][5][33];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2312709, dvrr_stack+1363390, dvrr_stack+857606);
 tmp = dvrr_stack + 2312709;
 target_ptr = Libderiv->deriv2_classes[10][6][33];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2314557, dvrr_stack+1376476, dvrr_stack+594375);
 tmp = dvrr_stack + 2314557;
 target_ptr = Libderiv->deriv2_classes[10][7][33];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2316933, dvrr_stack+1393918, dvrr_stack+625365);
 tmp = dvrr_stack + 2316933;
 target_ptr = Libderiv->deriv2_classes[10][8][33];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2319903, dvrr_stack+1417632, dvrr_stack+655340);
 tmp = dvrr_stack + 2319903;
 target_ptr = Libderiv->deriv2_classes[10][9][33];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2323533, dvrr_stack+1445718, dvrr_stack+687779);
 tmp = dvrr_stack + 2323533;
 target_ptr = Libderiv->deriv2_classes[10][10][33];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+597300, dvrr_stack+1057651, dvrr_stack+1462878);
 tmp = dvrr_stack + 597300;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+378879, dvrr_stack+1056867, dvrr_stack+1463193);
 tmp = dvrr_stack + 378879;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+2327889, dvrr_stack+1058239, dvrr_stack+1463613);
 tmp = dvrr_stack + 2327889;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+2328645, dvrr_stack+1059247, dvrr_stack+1464153);
 tmp = dvrr_stack + 2328645;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+2329590, dvrr_stack+1060507, dvrr_stack+1464828);
 tmp = dvrr_stack + 2329590;
 target_ptr = Libderiv->deriv2_classes[5][9][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+2330745, dvrr_stack+1062047, dvrr_stack+1465653);
 tmp = dvrr_stack + 2330745;
 target_ptr = Libderiv->deriv2_classes[5][10][32];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+960544, dvrr_stack+1011541, dvrr_stack+1049846);
 tmp = dvrr_stack + 960544;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+2332131, dvrr_stack+1010533, dvrr_stack+1049258);
 tmp = dvrr_stack + 2332131;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+2332915, dvrr_stack+1012297, dvrr_stack+1050287);
 tmp = dvrr_stack + 2332915;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2333923, dvrr_stack+1013593, dvrr_stack+1051043);
 tmp = dvrr_stack + 2333923;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2335183, dvrr_stack+955747, dvrr_stack+1051988);
 tmp = dvrr_stack + 2335183;
 target_ptr = Libderiv->deriv2_classes[6][9][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2336723, dvrr_stack+957727, dvrr_stack+1053143);
 tmp = dvrr_stack + 2336723;
 target_ptr = Libderiv->deriv2_classes[6][10][32];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+2338571, dvrr_stack+961228, dvrr_stack+1057651);
 tmp = dvrr_stack + 2338571;
 target_ptr = Libderiv->deriv2_classes[7][5][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2339327, dvrr_stack+913939, dvrr_stack+1056867);
 tmp = dvrr_stack + 2339327;
 target_ptr = Libderiv->deriv2_classes[7][6][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2340335, dvrr_stack+875381, dvrr_stack+1058239);
 tmp = dvrr_stack + 2340335;
 target_ptr = Libderiv->deriv2_classes[7][7][32];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2341631, dvrr_stack+877001, dvrr_stack+1059247);
 tmp = dvrr_stack + 2341631;
 target_ptr = Libderiv->deriv2_classes[7][8][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2343251, dvrr_stack+847904, dvrr_stack+1060507);
 tmp = dvrr_stack + 2343251;
 target_ptr = Libderiv->deriv2_classes[7][9][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2345231, dvrr_stack+735719, dvrr_stack+1062047);
 tmp = dvrr_stack + 2345231;
 target_ptr = Libderiv->deriv2_classes[7][10][32];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+2347607, dvrr_stack+738689, dvrr_stack+1011541);
 tmp = dvrr_stack + 2347607;
 target_ptr = Libderiv->deriv2_classes[8][5][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2348552, dvrr_stack+850379, dvrr_stack+1010533);
 tmp = dvrr_stack + 2348552;
 target_ptr = Libderiv->deriv2_classes[8][6][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2349812, dvrr_stack+658365, dvrr_stack+1012297);
 tmp = dvrr_stack + 2349812;
 target_ptr = Libderiv->deriv2_classes[8][7][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2351432, dvrr_stack+627840, dvrr_stack+1013593);
 tmp = dvrr_stack + 2351432;
 target_ptr = Libderiv->deriv2_classes[8][8][32];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2353457, dvrr_stack+605655, dvrr_stack+955747);
 tmp = dvrr_stack + 2353457;
 target_ptr = Libderiv->deriv2_classes[8][9][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2355932, dvrr_stack+366189, dvrr_stack+957727);
 tmp = dvrr_stack + 2355932;
 target_ptr = Libderiv->deriv2_classes[8][10][32];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2358902, dvrr_stack+739844, dvrr_stack+961228);
 tmp = dvrr_stack + 2358902;
 target_ptr = Libderiv->deriv2_classes[9][5][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2360057, dvrr_stack+694919, dvrr_stack+913939);
 tmp = dvrr_stack + 2360057;
 target_ptr = Libderiv->deriv2_classes[9][6][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2361597, dvrr_stack+660345, dvrr_stack+875381);
 tmp = dvrr_stack + 2361597;
 target_ptr = Libderiv->deriv2_classes[9][7][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2363577, dvrr_stack+303047, dvrr_stack+877001);
 tmp = dvrr_stack + 2363577;
 target_ptr = Libderiv->deriv2_classes[9][8][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2366052, dvrr_stack+214476, dvrr_stack+847904);
 tmp = dvrr_stack + 2366052;
 target_ptr = Libderiv->deriv2_classes[9][9][32];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2369077, dvrr_stack+100090, dvrr_stack+735719);
 tmp = dvrr_stack + 2369077;
 target_ptr = Libderiv->deriv2_classes[9][10][32];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2372707, dvrr_stack+1468473, dvrr_stack+738689);
 tmp = dvrr_stack + 2372707;
 target_ptr = Libderiv->deriv2_classes[10][5][32];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2374093, dvrr_stack+1470111, dvrr_stack+850379);
 tmp = dvrr_stack + 2374093;
 target_ptr = Libderiv->deriv2_classes[10][6][32];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2375941, dvrr_stack+1472295, dvrr_stack+658365);
 tmp = dvrr_stack + 2375941;
 target_ptr = Libderiv->deriv2_classes[10][7][32];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2378317, dvrr_stack+1475103, dvrr_stack+627840);
 tmp = dvrr_stack + 2378317;
 target_ptr = Libderiv->deriv2_classes[10][8][32];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2381287, dvrr_stack+1450866, dvrr_stack+605655);
 tmp = dvrr_stack + 2381287;
 target_ptr = Libderiv->deriv2_classes[10][9][32];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2384917, dvrr_stack+1421922, dvrr_stack+366189);
 tmp = dvrr_stack + 2384917;
 target_ptr = Libderiv->deriv2_classes[10][10][32];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+630756, dvrr_stack+405465, dvrr_stack+1466643);
 tmp = dvrr_stack + 630756;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+979399, dvrr_stack+397680, dvrr_stack+928966);
 tmp = dvrr_stack + 979399;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+2389273, dvrr_stack+281165, dvrr_stack+978859);
 tmp = dvrr_stack + 2389273;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+2390029, dvrr_stack+261532, dvrr_stack+814277);
 tmp = dvrr_stack + 2390029;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+2390974, dvrr_stack+245584, dvrr_stack+814952);
 tmp = dvrr_stack + 2390974;
 target_ptr = Libderiv->deriv2_classes[5][9][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+2392129, dvrr_stack+218106, dvrr_stack+1455156);
 tmp = dvrr_stack + 2392129;
 target_ptr = Libderiv->deriv2_classes[5][10][31];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1085642, dvrr_stack+1036708, dvrr_stack+1015213);
 tmp = dvrr_stack + 1085642;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+2393515, dvrr_stack+262792, dvrr_stack+839261);
 tmp = dvrr_stack + 2393515;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+2394299, dvrr_stack+247124, dvrr_stack+757697);
 tmp = dvrr_stack + 2394299;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2395307, dvrr_stack+167914, dvrr_stack+596355);
 tmp = dvrr_stack + 2395307;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2396567, dvrr_stack+150530, dvrr_stack+859146);
 tmp = dvrr_stack + 2396567;
 target_ptr = Libderiv->deriv2_classes[6][9][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2398107, dvrr_stack+77200, dvrr_stack+369819);
 tmp = dvrr_stack + 2398107;
 target_ptr = Libderiv->deriv2_classes[6][10][31];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+2399955, dvrr_stack+192166, dvrr_stack+405465);
 tmp = dvrr_stack + 2399955;
 target_ptr = Libderiv->deriv2_classes[7][5][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2400711, dvrr_stack+136100, dvrr_stack+397680);
 tmp = dvrr_stack + 2400711;
 target_ptr = Libderiv->deriv2_classes[7][6][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2401719, dvrr_stack+124454, dvrr_stack+281165);
 tmp = dvrr_stack + 2401719;
 target_ptr = Libderiv->deriv2_classes[7][7][31];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2403015, dvrr_stack+56086, dvrr_stack+261532);
 tmp = dvrr_stack + 2403015;
 target_ptr = Libderiv->deriv2_classes[7][8][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2404635, dvrr_stack+83878, dvrr_stack+245584);
 tmp = dvrr_stack + 2404635;
 target_ptr = Libderiv->deriv2_classes[7][9][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2406615, dvrr_stack+786770, dvrr_stack+218106);
 tmp = dvrr_stack + 2406615;
 target_ptr = Libderiv->deriv2_classes[7][10][31];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+2408991, dvrr_stack+24817, dvrr_stack+1036708);
 tmp = dvrr_stack + 2408991;
 target_ptr = Libderiv->deriv2_classes[8][5][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2409936, dvrr_stack+38692, dvrr_stack+262792);
 tmp = dvrr_stack + 2409936;
 target_ptr = Libderiv->deriv2_classes[8][6][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2411196, dvrr_stack+61630, dvrr_stack+247124);
 tmp = dvrr_stack + 2411196;
 target_ptr = Libderiv->deriv2_classes[8][7][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2412816, dvrr_stack+546143, dvrr_stack+167914);
 tmp = dvrr_stack + 2412816;
 target_ptr = Libderiv->deriv2_classes[8][8][31];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2414841, dvrr_stack+548618, dvrr_stack+150530);
 tmp = dvrr_stack + 2414841;
 target_ptr = Libderiv->deriv2_classes[8][9][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2417316, dvrr_stack+551643, dvrr_stack+77200);
 tmp = dvrr_stack + 2417316;
 target_ptr = Libderiv->deriv2_classes[8][10][31];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2420286, dvrr_stack+140888, dvrr_stack+192166);
 tmp = dvrr_stack + 2420286;
 target_ptr = Libderiv->deriv2_classes[9][5][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2421441, dvrr_stack+555273, dvrr_stack+136100);
 tmp = dvrr_stack + 2421441;
 target_ptr = Libderiv->deriv2_classes[9][6][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2422981, dvrr_stack+508979, dvrr_stack+124454);
 tmp = dvrr_stack + 2422981;
 target_ptr = Libderiv->deriv2_classes[9][7][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2424961, dvrr_stack+511355, dvrr_stack+56086);
 tmp = dvrr_stack + 2424961;
 target_ptr = Libderiv->deriv2_classes[9][8][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2427436, dvrr_stack+440199, dvrr_stack+83878);
 tmp = dvrr_stack + 2427436;
 target_ptr = Libderiv->deriv2_classes[9][9][31];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2430461, dvrr_stack+419125, dvrr_stack+786770);
 tmp = dvrr_stack + 2430461;
 target_ptr = Libderiv->deriv2_classes[9][10][31];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2434091, dvrr_stack+1456146, dvrr_stack+24817);
 tmp = dvrr_stack + 2434091;
 target_ptr = Libderiv->deriv2_classes[10][5][31];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2435477, dvrr_stack+1397428, dvrr_stack+38692);
 tmp = dvrr_stack + 2435477;
 target_ptr = Libderiv->deriv2_classes[10][6][31];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2437325, dvrr_stack+1379284, dvrr_stack+61630);
 tmp = dvrr_stack + 2437325;
 target_ptr = Libderiv->deriv2_classes[10][7][31];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2439701, dvrr_stack+1349804, dvrr_stack+546143);
 tmp = dvrr_stack + 2439701;
 target_ptr = Libderiv->deriv2_classes[10][8][31];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2442671, dvrr_stack+1478613, dvrr_stack+548618);
 tmp = dvrr_stack + 2442671;
 target_ptr = Libderiv->deriv2_classes[10][9][31];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2446301, dvrr_stack+1482903, dvrr_stack+551643);
 tmp = dvrr_stack + 2446301;
 target_ptr = Libderiv->deriv2_classes[10][10][31];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+491073, dvrr_stack+201911, dvrr_stack+1466958);
 tmp = dvrr_stack + 491073;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+74848, dvrr_stack+16402, dvrr_stack+1488051);
 tmp = dvrr_stack + 74848;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+2450657, dvrr_stack+445215, dvrr_stack+1457784);
 tmp = dvrr_stack + 2450657;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+2451413, dvrr_stack+446223, dvrr_stack+1427070);
 tmp = dvrr_stack + 2451413;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+2452358, dvrr_stack+91402, dvrr_stack+1399612);
 tmp = dvrr_stack + 2452358;
 target_ptr = Libderiv->deriv2_classes[5][9][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+2453513, dvrr_stack+97628, dvrr_stack+1400437);
 tmp = dvrr_stack + 2453513;
 target_ptr = Libderiv->deriv2_classes[5][10][30];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+99476, dvrr_stack+44152, dvrr_stack+1085201);
 tmp = dvrr_stack + 99476;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+2454899, dvrr_stack+211381, dvrr_stack+306017);
 tmp = dvrr_stack + 2454899;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+2455683, dvrr_stack+212389, dvrr_stack+128570);
 tmp = dvrr_stack + 2455683;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2456691, dvrr_stack+1297405, dvrr_stack+43207);
 tmp = dvrr_stack + 2456691;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2457951, dvrr_stack+1299025, dvrr_stack+793250);
 tmp = dvrr_stack + 2457951;
 target_ptr = Libderiv->deriv2_classes[6][9][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2459491, dvrr_stack+1301005, dvrr_stack+443829);
 tmp = dvrr_stack + 2459491;
 target_ptr = Libderiv->deriv2_classes[6][10][30];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+2461339, dvrr_stack+360999, dvrr_stack+201911);
 tmp = dvrr_stack + 2461339;
 target_ptr = Libderiv->deriv2_classes[7][5][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2462095, dvrr_stack+359739, dvrr_stack+16402);
 tmp = dvrr_stack + 2462095;
 target_ptr = Libderiv->deriv2_classes[7][6][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2463103, dvrr_stack+1303381, dvrr_stack+445215);
 tmp = dvrr_stack + 2463103;
 target_ptr = Libderiv->deriv2_classes[7][7][30];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2464399, dvrr_stack+1305001, dvrr_stack+446223);
 tmp = dvrr_stack + 2464399;
 target_ptr = Libderiv->deriv2_classes[7][8][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2466019, dvrr_stack+1307026, dvrr_stack+91402);
 tmp = dvrr_stack + 2466019;
 target_ptr = Libderiv->deriv2_classes[7][9][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2467999, dvrr_stack+1309501, dvrr_stack+97628);
 tmp = dvrr_stack + 2467999;
 target_ptr = Libderiv->deriv2_classes[7][10][30];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+2470375, dvrr_stack+209567, dvrr_stack+44152);
 tmp = dvrr_stack + 2470375;
 target_ptr = Libderiv->deriv2_classes[8][5][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2471320, dvrr_stack+208027, dvrr_stack+211381);
 tmp = dvrr_stack + 2471320;
 target_ptr = Libderiv->deriv2_classes[8][6][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2472580, dvrr_stack+1312471, dvrr_stack+212389);
 tmp = dvrr_stack + 2472580;
 target_ptr = Libderiv->deriv2_classes[8][7][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2474200, dvrr_stack+1314451, dvrr_stack+1297405);
 tmp = dvrr_stack + 2474200;
 target_ptr = Libderiv->deriv2_classes[8][8][30];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2476225, dvrr_stack+1316926, dvrr_stack+1299025);
 tmp = dvrr_stack + 2476225;
 target_ptr = Libderiv->deriv2_classes[8][9][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2478700, dvrr_stack+1319951, dvrr_stack+1301005);
 tmp = dvrr_stack + 2478700;
 target_ptr = Libderiv->deriv2_classes[8][10][30];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2481670, dvrr_stack+356777, dvrr_stack+360999);
 tmp = dvrr_stack + 2481670;
 target_ptr = Libderiv->deriv2_classes[9][5][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2482825, dvrr_stack+354929, dvrr_stack+359739);
 tmp = dvrr_stack + 2482825;
 target_ptr = Libderiv->deriv2_classes[9][6][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2484365, dvrr_stack+1327871, dvrr_stack+1303381);
 tmp = dvrr_stack + 2484365;
 target_ptr = Libderiv->deriv2_classes[9][7][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2486345, dvrr_stack+1330247, dvrr_stack+1305001);
 tmp = dvrr_stack + 2486345;
 target_ptr = Libderiv->deriv2_classes[9][8][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2488820, dvrr_stack+1333217, dvrr_stack+1307026);
 tmp = dvrr_stack + 2488820;
 target_ptr = Libderiv->deriv2_classes[9][9][30];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2491845, dvrr_stack+1336847, dvrr_stack+1309501);
 tmp = dvrr_stack + 2491845;
 target_ptr = Libderiv->deriv2_classes[9][10][30];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2495475, dvrr_stack+1365574, dvrr_stack+209567);
 tmp = dvrr_stack + 2495475;
 target_ptr = Libderiv->deriv2_classes[10][5][30];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2496861, dvrr_stack+272872, dvrr_stack+208027);
 tmp = dvrr_stack + 2496861;
 target_ptr = Libderiv->deriv2_classes[10][6][30];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2498709, dvrr_stack+1488471, dvrr_stack+1312471);
 tmp = dvrr_stack + 2498709;
 target_ptr = Libderiv->deriv2_classes[10][7][30];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2501085, dvrr_stack+1491279, dvrr_stack+1314451);
 tmp = dvrr_stack + 2501085;
 target_ptr = Libderiv->deriv2_classes[10][8][30];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2504055, dvrr_stack+1494789, dvrr_stack+1316926);
 tmp = dvrr_stack + 2504055;
 target_ptr = Libderiv->deriv2_classes[10][9][30];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2507685, dvrr_stack+1499079, dvrr_stack+1319951);
 tmp = dvrr_stack + 2507685;
 target_ptr = Libderiv->deriv2_classes[10][10][30];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1048694, dvrr_stack+719444, dvrr_stack+719129);
 tmp = dvrr_stack + 1048694;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+2512041, dvrr_stack+720452, dvrr_stack+720032);
 tmp = dvrr_stack + 2512041;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+2512629, dvrr_stack+721776, dvrr_stack+721236);
 tmp = dvrr_stack + 2512629;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+2513385, dvrr_stack+723459, dvrr_stack+722784);
 tmp = dvrr_stack + 2513385;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+2514330, dvrr_stack+685733, dvrr_stack+1467273);
 tmp = dvrr_stack + 2514330;
 target_ptr = Libderiv->deriv2_classes[5][9][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+2515485, dvrr_stack+1504227, dvrr_stack+1367212);
 tmp = dvrr_stack + 2515485;
 target_ptr = Libderiv->deriv2_classes[5][10][26];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+2516871, dvrr_stack+1506075, dvrr_stack+243847);
 tmp = dvrr_stack + 2516871;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+2517459, dvrr_stack+538010, dvrr_stack+1401427);
 tmp = dvrr_stack + 2517459;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+2518243, dvrr_stack+467963, dvrr_stack+1382092);
 tmp = dvrr_stack + 2518243;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+2519251, dvrr_stack+1506831, dvrr_stack+540350);
 tmp = dvrr_stack + 2519251;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+2520511, dvrr_stack+1508451, dvrr_stack+20857);
 tmp = dvrr_stack + 2520511;
 target_ptr = Libderiv->deriv2_classes[6][9][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+2522051, dvrr_stack+1511817, dvrr_stack+1510431);
 tmp = dvrr_stack + 2522051;
 target_ptr = Libderiv->deriv2_classes[6][10][26];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+2523899, dvrr_stack+72643, dvrr_stack+719444);
 tmp = dvrr_stack + 2523899;
 target_ptr = Libderiv->deriv2_classes[7][5][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2524655, dvrr_stack+1514193, dvrr_stack+720452);
 tmp = dvrr_stack + 2524655;
 target_ptr = Libderiv->deriv2_classes[7][6][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+2525663, dvrr_stack+1515453, dvrr_stack+721776);
 tmp = dvrr_stack + 2525663;
 target_ptr = Libderiv->deriv2_classes[7][7][26];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+2526959, dvrr_stack+1517073, dvrr_stack+723459);
 tmp = dvrr_stack + 2526959;
 target_ptr = Libderiv->deriv2_classes[7][8][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+2528579, dvrr_stack+1519098, dvrr_stack+685733);
 tmp = dvrr_stack + 2528579;
 target_ptr = Libderiv->deriv2_classes[7][9][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+2530559, dvrr_stack+1521573, dvrr_stack+1504227);
 tmp = dvrr_stack + 2530559;
 target_ptr = Libderiv->deriv2_classes[7][10][26];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+2532935, dvrr_stack+1524543, dvrr_stack+1506075);
 tmp = dvrr_stack + 2532935;
 target_ptr = Libderiv->deriv2_classes[8][5][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+2533880, dvrr_stack+1525698, dvrr_stack+538010);
 tmp = dvrr_stack + 2533880;
 target_ptr = Libderiv->deriv2_classes[8][6][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+2535140, dvrr_stack+1527238, dvrr_stack+467963);
 tmp = dvrr_stack + 2535140;
 target_ptr = Libderiv->deriv2_classes[8][7][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+2536760, dvrr_stack+1529218, dvrr_stack+1506831);
 tmp = dvrr_stack + 2536760;
 target_ptr = Libderiv->deriv2_classes[8][8][26];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+2538785, dvrr_stack+1531693, dvrr_stack+1508451);
 tmp = dvrr_stack + 2538785;
 target_ptr = Libderiv->deriv2_classes[8][9][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+2541260, dvrr_stack+1534718, dvrr_stack+1511817);
 tmp = dvrr_stack + 2541260;
 target_ptr = Libderiv->deriv2_classes[8][10][26];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+2544230, dvrr_stack+1538348, dvrr_stack+72643);
 tmp = dvrr_stack + 2544230;
 target_ptr = Libderiv->deriv2_classes[9][5][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+2545385, dvrr_stack+1539734, dvrr_stack+1514193);
 tmp = dvrr_stack + 2545385;
 target_ptr = Libderiv->deriv2_classes[9][6][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+2546925, dvrr_stack+1541582, dvrr_stack+1515453);
 tmp = dvrr_stack + 2546925;
 target_ptr = Libderiv->deriv2_classes[9][7][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+2548905, dvrr_stack+1543958, dvrr_stack+1517073);
 tmp = dvrr_stack + 2548905;
 target_ptr = Libderiv->deriv2_classes[9][8][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+2551380, dvrr_stack+1546928, dvrr_stack+1519098);
 tmp = dvrr_stack + 2551380;
 target_ptr = Libderiv->deriv2_classes[9][9][26];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+2554405, dvrr_stack+1550558, dvrr_stack+1521573);
 tmp = dvrr_stack + 2554405;
 target_ptr = Libderiv->deriv2_classes[9][10][26];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+2558035, dvrr_stack+33852, dvrr_stack+1524543);
 tmp = dvrr_stack + 2558035;
 target_ptr = Libderiv->deriv2_classes[10][5][26];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+2559421, dvrr_stack+829620, dvrr_stack+1525698);
 tmp = dvrr_stack + 2559421;
 target_ptr = Libderiv->deriv2_classes[10][6][26];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+2561269, dvrr_stack+68949, dvrr_stack+1527238);
 tmp = dvrr_stack + 2561269;
 target_ptr = Libderiv->deriv2_classes[10][7][26];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+2563645, dvrr_stack+1385818, dvrr_stack+1529218);
 tmp = dvrr_stack + 2563645;
 target_ptr = Libderiv->deriv2_classes[10][8][26];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+2566615, dvrr_stack+864536, dvrr_stack+1531693);
 tmp = dvrr_stack + 2566615;
 target_ptr = Libderiv->deriv2_classes[10][9][26];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+2570245, dvrr_stack+1368202, dvrr_stack+1534718);
 tmp = dvrr_stack + 2570245;
 target_ptr = Libderiv->deriv2_classes[10][10][26];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+401974, dvrr_stack+1074945, dvrr_stack+1064627);
 tmp = dvrr_stack + 401974;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+2574601, dvrr_stack+1074161, dvrr_stack+539255);
 tmp = dvrr_stack + 2574601;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+2575189, dvrr_stack+1075533, dvrr_stack+541295);
 tmp = dvrr_stack + 2575189;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+2575945, dvrr_stack+1076541, dvrr_stack+1034773);
 tmp = dvrr_stack + 2575945;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,55,dvrr_stack+2576890, dvrr_stack+1077801, dvrr_stack+541835);
 tmp = dvrr_stack + 2576890;
 target_ptr = Libderiv->deriv2_classes[5][9][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,66,dvrr_stack+2578045, dvrr_stack+1079341, dvrr_stack+915199);
 tmp = dvrr_stack + 2578045;
 target_ptr = Libderiv->deriv2_classes[5][10][23];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+2579431, dvrr_stack+1087361, dvrr_stack+1066790);
 tmp = dvrr_stack + 2579431;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+2580019, dvrr_stack+1086353, dvrr_stack+1066202);
 tmp = dvrr_stack + 2580019;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+2580803, dvrr_stack+1088117, dvrr_stack+1067231);
 tmp = dvrr_stack + 2580803;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+2581811, dvrr_stack+1028797, dvrr_stack+1067987);
 tmp = dvrr_stack + 2581811;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,55,dvrr_stack+2583071, dvrr_stack+1030417, dvrr_stack+1068932);
 tmp = dvrr_stack + 2583071;
 target_ptr = Libderiv->deriv2_classes[6][9][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,66,dvrr_stack+2584611, dvrr_stack+1032397, dvrr_stack+1070087);
 tmp = dvrr_stack + 2584611;
 target_ptr = Libderiv->deriv2_classes[6][10][23];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,21,dvrr_stack+2586459, dvrr_stack+977914, dvrr_stack+1074945);
 tmp = dvrr_stack + 2586459;
 target_ptr = Libderiv->deriv2_classes[7][5][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,28,dvrr_stack+2587215, dvrr_stack+976654, dvrr_stack+1074161);
 tmp = dvrr_stack + 2587215;
 target_ptr = Libderiv->deriv2_classes[7][6][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,36,dvrr_stack+2588223, dvrr_stack+925321, dvrr_stack+1075533);
 tmp = dvrr_stack + 2588223;
 target_ptr = Libderiv->deriv2_classes[7][7][23];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,45,dvrr_stack+2589519, dvrr_stack+926941, dvrr_stack+1076541);
 tmp = dvrr_stack + 2589519;
 target_ptr = Libderiv->deriv2_classes[7][8][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,55,dvrr_stack+2591139, dvrr_stack+886667, dvrr_stack+1077801);
 tmp = dvrr_stack + 2591139;
 target_ptr = Libderiv->deriv2_classes[7][9][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,66,dvrr_stack+2593119, dvrr_stack+798777, dvrr_stack+1079341);
 tmp = dvrr_stack + 2593119;
 target_ptr = Libderiv->deriv2_classes[7][10][23];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,21,dvrr_stack+2595495, dvrr_stack+889142, dvrr_stack+1087361);
 tmp = dvrr_stack + 2595495;
 target_ptr = Libderiv->deriv2_classes[8][5][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,28,dvrr_stack+2596440, dvrr_stack+805257, dvrr_stack+1086353);
 tmp = dvrr_stack + 2596440;
 target_ptr = Libderiv->deriv2_classes[8][6][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,36,dvrr_stack+2597700, dvrr_stack+806797, dvrr_stack+1088117);
 tmp = dvrr_stack + 2597700;
 target_ptr = Libderiv->deriv2_classes[8][7][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,45,dvrr_stack+2599320, dvrr_stack+808777, dvrr_stack+1028797);
 tmp = dvrr_stack + 2599320;
 target_ptr = Libderiv->deriv2_classes[8][8][23];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,55,dvrr_stack+2601345, dvrr_stack+811252, dvrr_stack+1030417);
 tmp = dvrr_stack + 2601345;
 target_ptr = Libderiv->deriv2_classes[8][9][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,66,dvrr_stack+2603820, dvrr_stack+752219, dvrr_stack+1032397);
 tmp = dvrr_stack + 2603820;
 target_ptr = Libderiv->deriv2_classes[8][10][23];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,21,dvrr_stack+2606790, dvrr_stack+672038, dvrr_stack+977914);
 tmp = dvrr_stack + 2606790;
 target_ptr = Libderiv->deriv2_classes[9][5][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,28,dvrr_stack+2607945, dvrr_stack+670190, dvrr_stack+976654);
 tmp = dvrr_stack + 2607945;
 target_ptr = Libderiv->deriv2_classes[9][6][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,36,dvrr_stack+2609485, dvrr_stack+631305, dvrr_stack+925321);
 tmp = dvrr_stack + 2609485;
 target_ptr = Libderiv->deriv2_classes[9][7][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,45,dvrr_stack+2611465, dvrr_stack+633681, dvrr_stack+926941);
 tmp = dvrr_stack + 2611465;
 target_ptr = Libderiv->deriv2_classes[9][8][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,55,dvrr_stack+2613940, dvrr_stack+636651, dvrr_stack+886667);
 tmp = dvrr_stack + 2613940;
 target_ptr = Libderiv->deriv2_classes[9][9][23];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,66,dvrr_stack+2616965, dvrr_stack+561055, dvrr_stack+798777);
 tmp = dvrr_stack + 2616965;
 target_ptr = Libderiv->deriv2_classes[9][10][23];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_n(Data,21,dvrr_stack+2620595, dvrr_stack+591043, dvrr_stack+889142);
 tmp = dvrr_stack + 2620595;
 target_ptr = Libderiv->deriv2_classes[10][5][23];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_n(Data,28,dvrr_stack+2621981, dvrr_stack+600216, dvrr_stack+805257);
 tmp = dvrr_stack + 2621981;
 target_ptr = Libderiv->deriv2_classes[10][6][23];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_n(Data,36,dvrr_stack+2623829, dvrr_stack+622485, dvrr_stack+806797);
 tmp = dvrr_stack + 2623829;
 target_ptr = Libderiv->deriv2_classes[10][7][23];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_n(Data,45,dvrr_stack+2626205, dvrr_stack+648795, dvrr_stack+808777);
 tmp = dvrr_stack + 2626205;
 target_ptr = Libderiv->deriv2_classes[10][8][23];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_n(Data,55,dvrr_stack+2629175, dvrr_stack+1458588, dvrr_stack+811252);
 tmp = dvrr_stack + 2629175;
 target_ptr = Libderiv->deriv2_classes[10][9][23];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_n(Data,66,dvrr_stack+2632805, dvrr_stack+725213, dvrr_stack+752219);
 tmp = dvrr_stack + 2632805;
 target_ptr = Libderiv->deriv2_classes[10][10][23];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2637161, dvrr_stack+574367, dvrr_stack+498065);
 tmp = dvrr_stack + 2637161;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2637602, dvrr_stack+573583, dvrr_stack+498380);
 tmp = dvrr_stack + 2637602;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2638190, dvrr_stack+487265, dvrr_stack+498800);
 tmp = dvrr_stack + 2638190;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2638946, dvrr_stack+488273, dvrr_stack+499340);
 tmp = dvrr_stack + 2638946;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2639891, dvrr_stack+489533, dvrr_stack+500015);
 tmp = dvrr_stack + 2639891;
 target_ptr = Libderiv->deriv2_classes[5][9][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2641046, dvrr_stack+453680, dvrr_stack+500840);
 tmp = dvrr_stack + 2641046;
 target_ptr = Libderiv->deriv2_classes[5][10][22];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2642432, dvrr_stack+456536, dvrr_stack+815817);
 tmp = dvrr_stack + 2642432;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2643020, dvrr_stack+455528, dvrr_stack+758819);
 tmp = dvrr_stack + 2643020;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2643804, dvrr_stack+406275, dvrr_stack+673424);
 tmp = dvrr_stack + 2643804;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2644812, dvrr_stack+407571, dvrr_stack+613740);
 tmp = dvrr_stack + 2644812;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2646072, dvrr_stack+409191, dvrr_stack+614685);
 tmp = dvrr_stack + 2646072;
 target_ptr = Libderiv->deriv2_classes[6][9][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2647612, dvrr_stack+374298, dvrr_stack+570559);
 tmp = dvrr_stack + 2647612;
 target_ptr = Libderiv->deriv2_classes[6][10][22];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2649460, dvrr_stack+380742, dvrr_stack+574367);
 tmp = dvrr_stack + 2649460;
 target_ptr = Libderiv->deriv2_classes[7][5][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2650216, dvrr_stack+379482, dvrr_stack+573583);
 tmp = dvrr_stack + 2650216;
 target_ptr = Libderiv->deriv2_classes[7][6][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2651224, dvrr_stack+381687, dvrr_stack+487265);
 tmp = dvrr_stack + 2651224;
 target_ptr = Libderiv->deriv2_classes[7][7][22];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2652520, dvrr_stack+383307, dvrr_stack+488273);
 tmp = dvrr_stack + 2652520;
 target_ptr = Libderiv->deriv2_classes[7][8][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2654140, dvrr_stack+343247, dvrr_stack+489533);
 tmp = dvrr_stack + 2654140;
 target_ptr = Libderiv->deriv2_classes[7][9][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2656120, dvrr_stack+220488, dvrr_stack+453680);
 tmp = dvrr_stack + 2656120;
 target_ptr = Libderiv->deriv2_classes[7][10][22];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2658496, dvrr_stack+346547, dvrr_stack+456536);
 tmp = dvrr_stack + 2658496;
 target_ptr = Libderiv->deriv2_classes[8][5][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2659441, dvrr_stack+287267, dvrr_stack+455528);
 tmp = dvrr_stack + 2659441;
 target_ptr = Libderiv->deriv2_classes[8][6][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2660701, dvrr_stack+267688, dvrr_stack+406275);
 tmp = dvrr_stack + 2660701;
 target_ptr = Libderiv->deriv2_classes[8][7][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2662321, dvrr_stack+226968, dvrr_stack+407571);
 tmp = dvrr_stack + 2662321;
 target_ptr = Libderiv->deriv2_classes[8][8][22];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2664346, dvrr_stack+198886, dvrr_stack+409191);
 tmp = dvrr_stack + 2664346;
 target_ptr = Libderiv->deriv2_classes[8][9][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2666821, dvrr_stack+106348, dvrr_stack+374298);
 tmp = dvrr_stack + 2666821;
 target_ptr = Libderiv->deriv2_classes[8][10][22];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2669791, dvrr_stack+251632, dvrr_stack+380742);
 tmp = dvrr_stack + 2669791;
 target_ptr = Libderiv->deriv2_classes[9][5][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2670946, dvrr_stack+229443, dvrr_stack+379482);
 tmp = dvrr_stack + 2670946;
 target_ptr = Libderiv->deriv2_classes[9][6][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2672486, dvrr_stack+175306, dvrr_stack+381687);
 tmp = dvrr_stack + 2672486;
 target_ptr = Libderiv->deriv2_classes[9][7][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2674466, dvrr_stack+1276153, dvrr_stack+383307);
 tmp = dvrr_stack + 2674466;
 target_ptr = Libderiv->deriv2_classes[9][8][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2676941, dvrr_stack+1279123, dvrr_stack+343247);
 tmp = dvrr_stack + 2676941;
 target_ptr = Libderiv->deriv2_classes[9][9][22];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2679966, dvrr_stack+1282753, dvrr_stack+220488);
 tmp = dvrr_stack + 2679966;
 target_ptr = Libderiv->deriv2_classes[9][10][22];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+2683596, dvrr_stack+321191, dvrr_stack+346547);
 tmp = dvrr_stack + 2683596;
 target_ptr = Libderiv->deriv2_classes[10][5][22];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+2684982, dvrr_stack+322829, dvrr_stack+287267);
 tmp = dvrr_stack + 2684982;
 target_ptr = Libderiv->deriv2_classes[10][6][22];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+2686830, dvrr_stack+465155, dvrr_stack+267688);
 tmp = dvrr_stack + 2686830;
 target_ptr = Libderiv->deriv2_classes[10][7][22];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+2689206, dvrr_stack+989011, dvrr_stack+226968);
 tmp = dvrr_stack + 2689206;
 target_ptr = Libderiv->deriv2_classes[10][8][22];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+2692176, dvrr_stack+992521, dvrr_stack+198886);
 tmp = dvrr_stack + 2692176;
 target_ptr = Libderiv->deriv2_classes[10][9][22];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+2695806, dvrr_stack+996811, dvrr_stack+106348);
 tmp = dvrr_stack + 2695806;
 target_ptr = Libderiv->deriv2_classes[10][10][22];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2700162, dvrr_stack+123866, dvrr_stack+501830);
 tmp = dvrr_stack + 2700162;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2700603, dvrr_stack+28408, dvrr_stack+537050);
 tmp = dvrr_stack + 2700603;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2701191, dvrr_stack+119438, dvrr_stack+537470);
 tmp = dvrr_stack + 2701191;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2701947, dvrr_stack+134840, dvrr_stack+539675);
 tmp = dvrr_stack + 2701947;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2702892, dvrr_stack+148990, dvrr_stack+1346351);
 tmp = dvrr_stack + 2702892;
 target_ptr = Libderiv->deriv2_classes[5][9][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2704047, dvrr_stack+166066, dvrr_stack+1347176);
 tmp = dvrr_stack + 2704047;
 target_ptr = Libderiv->deriv2_classes[5][10][21];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2705433, dvrr_stack+120446, dvrr_stack+12874);
 tmp = dvrr_stack + 2705433;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2706021, dvrr_stack+1084193, dvrr_stack+1064942);
 tmp = dvrr_stack + 2706021;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2706805, dvrr_stack+240256, dvrr_stack+7447);
 tmp = dvrr_stack + 2706805;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2707813, dvrr_stack+259912, dvrr_stack+23872);
 tmp = dvrr_stack + 2707813;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2709073, dvrr_stack+277547, dvrr_stack+37537);
 tmp = dvrr_stack + 2709073;
 target_ptr = Libderiv->deriv2_classes[6][9][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2710613, dvrr_stack+300671, dvrr_stack+54700);
 tmp = dvrr_stack + 2710613;
 target_ptr = Libderiv->deriv2_classes[6][10][21];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2712461, dvrr_stack+402495, dvrr_stack+123866);
 tmp = dvrr_stack + 2712461;
 target_ptr = Libderiv->deriv2_classes[7][5][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2713217, dvrr_stack+1035448, dvrr_stack+28408);
 tmp = dvrr_stack + 2713217;
 target_ptr = Libderiv->deriv2_classes[7][6][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2714225, dvrr_stack+396060, dvrr_stack+119438);
 tmp = dvrr_stack + 2714225;
 target_ptr = Libderiv->deriv2_classes[7][7][21];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2715521, dvrr_stack+403440, dvrr_stack+134840);
 tmp = dvrr_stack + 2715521;
 target_ptr = Libderiv->deriv2_classes[7][8][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2717141, dvrr_stack+363714, dvrr_stack+148990);
 tmp = dvrr_stack + 2717141;
 target_ptr = Libderiv->deriv2_classes[7][9][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2719121, dvrr_stack+472415, dvrr_stack+166066);
 tmp = dvrr_stack + 2719121;
 target_ptr = Libderiv->deriv2_classes[7][10][21];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2721497, dvrr_stack+604500, dvrr_stack+120446);
 tmp = dvrr_stack + 2721497;
 target_ptr = Libderiv->deriv2_classes[8][5][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2722442, dvrr_stack+857606, dvrr_stack+1084193);
 tmp = dvrr_stack + 2722442;
 target_ptr = Libderiv->deriv2_classes[8][6][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2723702, dvrr_stack+594375, dvrr_stack+240256);
 tmp = dvrr_stack + 2723702;
 target_ptr = Libderiv->deriv2_classes[8][7][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2725322, dvrr_stack+625365, dvrr_stack+259912);
 tmp = dvrr_stack + 2725322;
 target_ptr = Libderiv->deriv2_classes[8][8][21];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2727347, dvrr_stack+655340, dvrr_stack+277547);
 tmp = dvrr_stack + 2727347;
 target_ptr = Libderiv->deriv2_classes[8][9][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2729822, dvrr_stack+687779, dvrr_stack+300671);
 tmp = dvrr_stack + 2729822;
 target_ptr = Libderiv->deriv2_classes[8][10][21];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2732792, dvrr_stack+846518, dvrr_stack+402495);
 tmp = dvrr_stack + 2732792;
 target_ptr = Libderiv->deriv2_classes[9][5][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2733947, dvrr_stack+755849, dvrr_stack+1035448);
 tmp = dvrr_stack + 2733947;
 target_ptr = Libderiv->deriv2_classes[9][6][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2735487, dvrr_stack+836060, dvrr_stack+396060);
 tmp = dvrr_stack + 2735487;
 target_ptr = Libderiv->deriv2_classes[9][7][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2737467, dvrr_stack+872411, dvrr_stack+403440);
 tmp = dvrr_stack + 2737467;
 target_ptr = Libderiv->deriv2_classes[9][8][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2739942, dvrr_stack+907501, dvrr_stack+363714);
 tmp = dvrr_stack + 2739942;
 target_ptr = Libderiv->deriv2_classes[9][9][21];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2742967, dvrr_stack+951391, dvrr_stack+472415);
 tmp = dvrr_stack + 2742967;
 target_ptr = Libderiv->deriv2_classes[9][10][21];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+2746597, dvrr_stack+1348166, dvrr_stack+604500);
 tmp = dvrr_stack + 2746597;
 target_ptr = Libderiv->deriv2_classes[10][5][21];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+2747983, dvrr_stack+1363390, dvrr_stack+857606);
 tmp = dvrr_stack + 2747983;
 target_ptr = Libderiv->deriv2_classes[10][6][21];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+2749831, dvrr_stack+1376476, dvrr_stack+594375);
 tmp = dvrr_stack + 2749831;
 target_ptr = Libderiv->deriv2_classes[10][7][21];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+2752207, dvrr_stack+1393918, dvrr_stack+625365);
 tmp = dvrr_stack + 2752207;
 target_ptr = Libderiv->deriv2_classes[10][8][21];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+2755177, dvrr_stack+1417632, dvrr_stack+655340);
 tmp = dvrr_stack + 2755177;
 target_ptr = Libderiv->deriv2_classes[10][9][21];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+2758807, dvrr_stack+1445718, dvrr_stack+687779);
 tmp = dvrr_stack + 2758807;
 target_ptr = Libderiv->deriv2_classes[10][10][21];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2763163, dvrr_stack+1057651, dvrr_stack+1462878);
 tmp = dvrr_stack + 2763163;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2763604, dvrr_stack+1056867, dvrr_stack+1463193);
 tmp = dvrr_stack + 2763604;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2764192, dvrr_stack+1058239, dvrr_stack+1463613);
 tmp = dvrr_stack + 2764192;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2764948, dvrr_stack+1059247, dvrr_stack+1464153);
 tmp = dvrr_stack + 2764948;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2765893, dvrr_stack+1060507, dvrr_stack+1464828);
 tmp = dvrr_stack + 2765893;
 target_ptr = Libderiv->deriv2_classes[5][9][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2767048, dvrr_stack+1062047, dvrr_stack+1465653);
 tmp = dvrr_stack + 2767048;
 target_ptr = Libderiv->deriv2_classes[5][10][20];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2768434, dvrr_stack+1011541, dvrr_stack+1049846);
 tmp = dvrr_stack + 2768434;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2769022, dvrr_stack+1010533, dvrr_stack+1049258);
 tmp = dvrr_stack + 2769022;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2769806, dvrr_stack+1012297, dvrr_stack+1050287);
 tmp = dvrr_stack + 2769806;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2770814, dvrr_stack+1013593, dvrr_stack+1051043);
 tmp = dvrr_stack + 2770814;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2772074, dvrr_stack+955747, dvrr_stack+1051988);
 tmp = dvrr_stack + 2772074;
 target_ptr = Libderiv->deriv2_classes[6][9][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2773614, dvrr_stack+957727, dvrr_stack+1053143);
 tmp = dvrr_stack + 2773614;
 target_ptr = Libderiv->deriv2_classes[6][10][20];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2775462, dvrr_stack+961228, dvrr_stack+1057651);
 tmp = dvrr_stack + 2775462;
 target_ptr = Libderiv->deriv2_classes[7][5][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2776218, dvrr_stack+913939, dvrr_stack+1056867);
 tmp = dvrr_stack + 2776218;
 target_ptr = Libderiv->deriv2_classes[7][6][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2777226, dvrr_stack+875381, dvrr_stack+1058239);
 tmp = dvrr_stack + 2777226;
 target_ptr = Libderiv->deriv2_classes[7][7][20];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2778522, dvrr_stack+877001, dvrr_stack+1059247);
 tmp = dvrr_stack + 2778522;
 target_ptr = Libderiv->deriv2_classes[7][8][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2780142, dvrr_stack+847904, dvrr_stack+1060507);
 tmp = dvrr_stack + 2780142;
 target_ptr = Libderiv->deriv2_classes[7][9][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2782122, dvrr_stack+735719, dvrr_stack+1062047);
 tmp = dvrr_stack + 2782122;
 target_ptr = Libderiv->deriv2_classes[7][10][20];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2784498, dvrr_stack+738689, dvrr_stack+1011541);
 tmp = dvrr_stack + 2784498;
 target_ptr = Libderiv->deriv2_classes[8][5][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2785443, dvrr_stack+850379, dvrr_stack+1010533);
 tmp = dvrr_stack + 2785443;
 target_ptr = Libderiv->deriv2_classes[8][6][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2786703, dvrr_stack+658365, dvrr_stack+1012297);
 tmp = dvrr_stack + 2786703;
 target_ptr = Libderiv->deriv2_classes[8][7][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2788323, dvrr_stack+627840, dvrr_stack+1013593);
 tmp = dvrr_stack + 2788323;
 target_ptr = Libderiv->deriv2_classes[8][8][20];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2790348, dvrr_stack+605655, dvrr_stack+955747);
 tmp = dvrr_stack + 2790348;
 target_ptr = Libderiv->deriv2_classes[8][9][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2792823, dvrr_stack+366189, dvrr_stack+957727);
 tmp = dvrr_stack + 2792823;
 target_ptr = Libderiv->deriv2_classes[8][10][20];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2795793, dvrr_stack+739844, dvrr_stack+961228);
 tmp = dvrr_stack + 2795793;
 target_ptr = Libderiv->deriv2_classes[9][5][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2796948, dvrr_stack+694919, dvrr_stack+913939);
 tmp = dvrr_stack + 2796948;
 target_ptr = Libderiv->deriv2_classes[9][6][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2798488, dvrr_stack+660345, dvrr_stack+875381);
 tmp = dvrr_stack + 2798488;
 target_ptr = Libderiv->deriv2_classes[9][7][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2800468, dvrr_stack+303047, dvrr_stack+877001);
 tmp = dvrr_stack + 2800468;
 target_ptr = Libderiv->deriv2_classes[9][8][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2802943, dvrr_stack+214476, dvrr_stack+847904);
 tmp = dvrr_stack + 2802943;
 target_ptr = Libderiv->deriv2_classes[9][9][20];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2805968, dvrr_stack+100090, dvrr_stack+735719);
 tmp = dvrr_stack + 2805968;
 target_ptr = Libderiv->deriv2_classes[9][10][20];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+2809598, dvrr_stack+1468473, dvrr_stack+738689);
 tmp = dvrr_stack + 2809598;
 target_ptr = Libderiv->deriv2_classes[10][5][20];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+2810984, dvrr_stack+1470111, dvrr_stack+850379);
 tmp = dvrr_stack + 2810984;
 target_ptr = Libderiv->deriv2_classes[10][6][20];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+2812832, dvrr_stack+1472295, dvrr_stack+658365);
 tmp = dvrr_stack + 2812832;
 target_ptr = Libderiv->deriv2_classes[10][7][20];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+2815208, dvrr_stack+1475103, dvrr_stack+627840);
 tmp = dvrr_stack + 2815208;
 target_ptr = Libderiv->deriv2_classes[10][8][20];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+2818178, dvrr_stack+1450866, dvrr_stack+605655);
 tmp = dvrr_stack + 2818178;
 target_ptr = Libderiv->deriv2_classes[10][9][20];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+2821808, dvrr_stack+1421922, dvrr_stack+366189);
 tmp = dvrr_stack + 2821808;
 target_ptr = Libderiv->deriv2_classes[10][10][20];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2826164, dvrr_stack+405465, dvrr_stack+1466643);
 tmp = dvrr_stack + 2826164;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2826605, dvrr_stack+397680, dvrr_stack+928966);
 tmp = dvrr_stack + 2826605;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2827193, dvrr_stack+281165, dvrr_stack+978859);
 tmp = dvrr_stack + 2827193;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2827949, dvrr_stack+261532, dvrr_stack+814277);
 tmp = dvrr_stack + 2827949;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2828894, dvrr_stack+245584, dvrr_stack+814952);
 tmp = dvrr_stack + 2828894;
 target_ptr = Libderiv->deriv2_classes[5][9][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2830049, dvrr_stack+218106, dvrr_stack+1455156);
 tmp = dvrr_stack + 2830049;
 target_ptr = Libderiv->deriv2_classes[5][10][19];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2831435, dvrr_stack+1036708, dvrr_stack+1015213);
 tmp = dvrr_stack + 2831435;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2832023, dvrr_stack+262792, dvrr_stack+839261);
 tmp = dvrr_stack + 2832023;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2832807, dvrr_stack+247124, dvrr_stack+757697);
 tmp = dvrr_stack + 2832807;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2833815, dvrr_stack+167914, dvrr_stack+596355);
 tmp = dvrr_stack + 2833815;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2835075, dvrr_stack+150530, dvrr_stack+859146);
 tmp = dvrr_stack + 2835075;
 target_ptr = Libderiv->deriv2_classes[6][9][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2836615, dvrr_stack+77200, dvrr_stack+369819);
 tmp = dvrr_stack + 2836615;
 target_ptr = Libderiv->deriv2_classes[6][10][19];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2838463, dvrr_stack+192166, dvrr_stack+405465);
 tmp = dvrr_stack + 2838463;
 target_ptr = Libderiv->deriv2_classes[7][5][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2839219, dvrr_stack+136100, dvrr_stack+397680);
 tmp = dvrr_stack + 2839219;
 target_ptr = Libderiv->deriv2_classes[7][6][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2840227, dvrr_stack+124454, dvrr_stack+281165);
 tmp = dvrr_stack + 2840227;
 target_ptr = Libderiv->deriv2_classes[7][7][19];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2841523, dvrr_stack+56086, dvrr_stack+261532);
 tmp = dvrr_stack + 2841523;
 target_ptr = Libderiv->deriv2_classes[7][8][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2843143, dvrr_stack+83878, dvrr_stack+245584);
 tmp = dvrr_stack + 2843143;
 target_ptr = Libderiv->deriv2_classes[7][9][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2845123, dvrr_stack+786770, dvrr_stack+218106);
 tmp = dvrr_stack + 2845123;
 target_ptr = Libderiv->deriv2_classes[7][10][19];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2847499, dvrr_stack+24817, dvrr_stack+1036708);
 tmp = dvrr_stack + 2847499;
 target_ptr = Libderiv->deriv2_classes[8][5][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2848444, dvrr_stack+38692, dvrr_stack+262792);
 tmp = dvrr_stack + 2848444;
 target_ptr = Libderiv->deriv2_classes[8][6][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2849704, dvrr_stack+61630, dvrr_stack+247124);
 tmp = dvrr_stack + 2849704;
 target_ptr = Libderiv->deriv2_classes[8][7][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2851324, dvrr_stack+546143, dvrr_stack+167914);
 tmp = dvrr_stack + 2851324;
 target_ptr = Libderiv->deriv2_classes[8][8][19];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2853349, dvrr_stack+548618, dvrr_stack+150530);
 tmp = dvrr_stack + 2853349;
 target_ptr = Libderiv->deriv2_classes[8][9][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2855824, dvrr_stack+551643, dvrr_stack+77200);
 tmp = dvrr_stack + 2855824;
 target_ptr = Libderiv->deriv2_classes[8][10][19];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2858794, dvrr_stack+140888, dvrr_stack+192166);
 tmp = dvrr_stack + 2858794;
 target_ptr = Libderiv->deriv2_classes[9][5][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2859949, dvrr_stack+555273, dvrr_stack+136100);
 tmp = dvrr_stack + 2859949;
 target_ptr = Libderiv->deriv2_classes[9][6][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2861489, dvrr_stack+508979, dvrr_stack+124454);
 tmp = dvrr_stack + 2861489;
 target_ptr = Libderiv->deriv2_classes[9][7][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2863469, dvrr_stack+511355, dvrr_stack+56086);
 tmp = dvrr_stack + 2863469;
 target_ptr = Libderiv->deriv2_classes[9][8][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2865944, dvrr_stack+440199, dvrr_stack+83878);
 tmp = dvrr_stack + 2865944;
 target_ptr = Libderiv->deriv2_classes[9][9][19];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2868969, dvrr_stack+419125, dvrr_stack+786770);
 tmp = dvrr_stack + 2868969;
 target_ptr = Libderiv->deriv2_classes[9][10][19];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+2872599, dvrr_stack+1456146, dvrr_stack+24817);
 tmp = dvrr_stack + 2872599;
 target_ptr = Libderiv->deriv2_classes[10][5][19];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+2873985, dvrr_stack+1397428, dvrr_stack+38692);
 tmp = dvrr_stack + 2873985;
 target_ptr = Libderiv->deriv2_classes[10][6][19];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+2875833, dvrr_stack+1379284, dvrr_stack+61630);
 tmp = dvrr_stack + 2875833;
 target_ptr = Libderiv->deriv2_classes[10][7][19];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+2878209, dvrr_stack+1349804, dvrr_stack+546143);
 tmp = dvrr_stack + 2878209;
 target_ptr = Libderiv->deriv2_classes[10][8][19];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+2881179, dvrr_stack+1478613, dvrr_stack+548618);
 tmp = dvrr_stack + 2881179;
 target_ptr = Libderiv->deriv2_classes[10][9][19];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+2884809, dvrr_stack+1482903, dvrr_stack+551643);
 tmp = dvrr_stack + 2884809;
 target_ptr = Libderiv->deriv2_classes[10][10][19];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2889165, dvrr_stack+201911, dvrr_stack+1466958);
 tmp = dvrr_stack + 2889165;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2889606, dvrr_stack+16402, dvrr_stack+1488051);
 tmp = dvrr_stack + 2889606;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2890194, dvrr_stack+445215, dvrr_stack+1457784);
 tmp = dvrr_stack + 2890194;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2890950, dvrr_stack+446223, dvrr_stack+1427070);
 tmp = dvrr_stack + 2890950;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2891895, dvrr_stack+91402, dvrr_stack+1399612);
 tmp = dvrr_stack + 2891895;
 target_ptr = Libderiv->deriv2_classes[5][9][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2893050, dvrr_stack+97628, dvrr_stack+1400437);
 tmp = dvrr_stack + 2893050;
 target_ptr = Libderiv->deriv2_classes[5][10][18];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2894436, dvrr_stack+44152, dvrr_stack+1085201);
 tmp = dvrr_stack + 2894436;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2895024, dvrr_stack+211381, dvrr_stack+306017);
 tmp = dvrr_stack + 2895024;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2895808, dvrr_stack+212389, dvrr_stack+128570);
 tmp = dvrr_stack + 2895808;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2896816, dvrr_stack+1297405, dvrr_stack+43207);
 tmp = dvrr_stack + 2896816;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2898076, dvrr_stack+1299025, dvrr_stack+793250);
 tmp = dvrr_stack + 2898076;
 target_ptr = Libderiv->deriv2_classes[6][9][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2899616, dvrr_stack+1301005, dvrr_stack+443829);
 tmp = dvrr_stack + 2899616;
 target_ptr = Libderiv->deriv2_classes[6][10][18];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2901464, dvrr_stack+360999, dvrr_stack+201911);
 tmp = dvrr_stack + 2901464;
 target_ptr = Libderiv->deriv2_classes[7][5][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2902220, dvrr_stack+359739, dvrr_stack+16402);
 tmp = dvrr_stack + 2902220;
 target_ptr = Libderiv->deriv2_classes[7][6][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2903228, dvrr_stack+1303381, dvrr_stack+445215);
 tmp = dvrr_stack + 2903228;
 target_ptr = Libderiv->deriv2_classes[7][7][18];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2904524, dvrr_stack+1305001, dvrr_stack+446223);
 tmp = dvrr_stack + 2904524;
 target_ptr = Libderiv->deriv2_classes[7][8][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2906144, dvrr_stack+1307026, dvrr_stack+91402);
 tmp = dvrr_stack + 2906144;
 target_ptr = Libderiv->deriv2_classes[7][9][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2908124, dvrr_stack+1309501, dvrr_stack+97628);
 tmp = dvrr_stack + 2908124;
 target_ptr = Libderiv->deriv2_classes[7][10][18];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2910500, dvrr_stack+209567, dvrr_stack+44152);
 tmp = dvrr_stack + 2910500;
 target_ptr = Libderiv->deriv2_classes[8][5][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2911445, dvrr_stack+208027, dvrr_stack+211381);
 tmp = dvrr_stack + 2911445;
 target_ptr = Libderiv->deriv2_classes[8][6][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2912705, dvrr_stack+1312471, dvrr_stack+212389);
 tmp = dvrr_stack + 2912705;
 target_ptr = Libderiv->deriv2_classes[8][7][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2914325, dvrr_stack+1314451, dvrr_stack+1297405);
 tmp = dvrr_stack + 2914325;
 target_ptr = Libderiv->deriv2_classes[8][8][18];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2916350, dvrr_stack+1316926, dvrr_stack+1299025);
 tmp = dvrr_stack + 2916350;
 target_ptr = Libderiv->deriv2_classes[8][9][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2918825, dvrr_stack+1319951, dvrr_stack+1301005);
 tmp = dvrr_stack + 2918825;
 target_ptr = Libderiv->deriv2_classes[8][10][18];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2921795, dvrr_stack+356777, dvrr_stack+360999);
 tmp = dvrr_stack + 2921795;
 target_ptr = Libderiv->deriv2_classes[9][5][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2922950, dvrr_stack+354929, dvrr_stack+359739);
 tmp = dvrr_stack + 2922950;
 target_ptr = Libderiv->deriv2_classes[9][6][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2924490, dvrr_stack+1327871, dvrr_stack+1303381);
 tmp = dvrr_stack + 2924490;
 target_ptr = Libderiv->deriv2_classes[9][7][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2926470, dvrr_stack+1330247, dvrr_stack+1305001);
 tmp = dvrr_stack + 2926470;
 target_ptr = Libderiv->deriv2_classes[9][8][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2928945, dvrr_stack+1333217, dvrr_stack+1307026);
 tmp = dvrr_stack + 2928945;
 target_ptr = Libderiv->deriv2_classes[9][9][18];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2931970, dvrr_stack+1336847, dvrr_stack+1309501);
 tmp = dvrr_stack + 2931970;
 target_ptr = Libderiv->deriv2_classes[9][10][18];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+2935600, dvrr_stack+1365574, dvrr_stack+209567);
 tmp = dvrr_stack + 2935600;
 target_ptr = Libderiv->deriv2_classes[10][5][18];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+2936986, dvrr_stack+272872, dvrr_stack+208027);
 tmp = dvrr_stack + 2936986;
 target_ptr = Libderiv->deriv2_classes[10][6][18];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+2938834, dvrr_stack+1488471, dvrr_stack+1312471);
 tmp = dvrr_stack + 2938834;
 target_ptr = Libderiv->deriv2_classes[10][7][18];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+2941210, dvrr_stack+1491279, dvrr_stack+1314451);
 tmp = dvrr_stack + 2941210;
 target_ptr = Libderiv->deriv2_classes[10][8][18];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+2944180, dvrr_stack+1494789, dvrr_stack+1316926);
 tmp = dvrr_stack + 2944180;
 target_ptr = Libderiv->deriv2_classes[10][9][18];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+2947810, dvrr_stack+1499079, dvrr_stack+1319951);
 tmp = dvrr_stack + 2947810;
 target_ptr = Libderiv->deriv2_classes[10][10][18];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2952166, dvrr_stack+719444, dvrr_stack+719129);
 tmp = dvrr_stack + 2952166;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2952607, dvrr_stack+720452, dvrr_stack+720032);
 tmp = dvrr_stack + 2952607;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2953195, dvrr_stack+721776, dvrr_stack+721236);
 tmp = dvrr_stack + 2953195;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2953951, dvrr_stack+723459, dvrr_stack+722784);
 tmp = dvrr_stack + 2953951;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2954896, dvrr_stack+685733, dvrr_stack+1467273);
 tmp = dvrr_stack + 2954896;
 target_ptr = Libderiv->deriv2_classes[5][9][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2956051, dvrr_stack+1504227, dvrr_stack+1367212);
 tmp = dvrr_stack + 2956051;
 target_ptr = Libderiv->deriv2_classes[5][10][14];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2957437, dvrr_stack+1506075, dvrr_stack+243847);
 tmp = dvrr_stack + 2957437;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2958025, dvrr_stack+538010, dvrr_stack+1401427);
 tmp = dvrr_stack + 2958025;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2958809, dvrr_stack+467963, dvrr_stack+1382092);
 tmp = dvrr_stack + 2958809;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2959817, dvrr_stack+1506831, dvrr_stack+540350);
 tmp = dvrr_stack + 2959817;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2961077, dvrr_stack+1508451, dvrr_stack+20857);
 tmp = dvrr_stack + 2961077;
 target_ptr = Libderiv->deriv2_classes[6][9][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2962617, dvrr_stack+1511817, dvrr_stack+1510431);
 tmp = dvrr_stack + 2962617;
 target_ptr = Libderiv->deriv2_classes[6][10][14];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2964465, dvrr_stack+72643, dvrr_stack+719444);
 tmp = dvrr_stack + 2964465;
 target_ptr = Libderiv->deriv2_classes[7][5][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2965221, dvrr_stack+1514193, dvrr_stack+720452);
 tmp = dvrr_stack + 2965221;
 target_ptr = Libderiv->deriv2_classes[7][6][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2966229, dvrr_stack+1515453, dvrr_stack+721776);
 tmp = dvrr_stack + 2966229;
 target_ptr = Libderiv->deriv2_classes[7][7][14];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2967525, dvrr_stack+1517073, dvrr_stack+723459);
 tmp = dvrr_stack + 2967525;
 target_ptr = Libderiv->deriv2_classes[7][8][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2969145, dvrr_stack+1519098, dvrr_stack+685733);
 tmp = dvrr_stack + 2969145;
 target_ptr = Libderiv->deriv2_classes[7][9][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2971125, dvrr_stack+1521573, dvrr_stack+1504227);
 tmp = dvrr_stack + 2971125;
 target_ptr = Libderiv->deriv2_classes[7][10][14];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2973501, dvrr_stack+1524543, dvrr_stack+1506075);
 tmp = dvrr_stack + 2973501;
 target_ptr = Libderiv->deriv2_classes[8][5][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2974446, dvrr_stack+1525698, dvrr_stack+538010);
 tmp = dvrr_stack + 2974446;
 target_ptr = Libderiv->deriv2_classes[8][6][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2975706, dvrr_stack+1527238, dvrr_stack+467963);
 tmp = dvrr_stack + 2975706;
 target_ptr = Libderiv->deriv2_classes[8][7][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2977326, dvrr_stack+1529218, dvrr_stack+1506831);
 tmp = dvrr_stack + 2977326;
 target_ptr = Libderiv->deriv2_classes[8][8][14];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2979351, dvrr_stack+1531693, dvrr_stack+1508451);
 tmp = dvrr_stack + 2979351;
 target_ptr = Libderiv->deriv2_classes[8][9][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2981826, dvrr_stack+1534718, dvrr_stack+1511817);
 tmp = dvrr_stack + 2981826;
 target_ptr = Libderiv->deriv2_classes[8][10][14];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2984796, dvrr_stack+1538348, dvrr_stack+72643);
 tmp = dvrr_stack + 2984796;
 target_ptr = Libderiv->deriv2_classes[9][5][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2985951, dvrr_stack+1539734, dvrr_stack+1514193);
 tmp = dvrr_stack + 2985951;
 target_ptr = Libderiv->deriv2_classes[9][6][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2987491, dvrr_stack+1541582, dvrr_stack+1515453);
 tmp = dvrr_stack + 2987491;
 target_ptr = Libderiv->deriv2_classes[9][7][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2989471, dvrr_stack+1543958, dvrr_stack+1517073);
 tmp = dvrr_stack + 2989471;
 target_ptr = Libderiv->deriv2_classes[9][8][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2991946, dvrr_stack+1546928, dvrr_stack+1519098);
 tmp = dvrr_stack + 2991946;
 target_ptr = Libderiv->deriv2_classes[9][9][14];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2994971, dvrr_stack+1550558, dvrr_stack+1521573);
 tmp = dvrr_stack + 2994971;
 target_ptr = Libderiv->deriv2_classes[9][10][14];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+2998601, dvrr_stack+33852, dvrr_stack+1524543);
 tmp = dvrr_stack + 2998601;
 target_ptr = Libderiv->deriv2_classes[10][5][14];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+2999987, dvrr_stack+829620, dvrr_stack+1525698);
 tmp = dvrr_stack + 2999987;
 target_ptr = Libderiv->deriv2_classes[10][6][14];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+3001835, dvrr_stack+68949, dvrr_stack+1527238);
 tmp = dvrr_stack + 3001835;
 target_ptr = Libderiv->deriv2_classes[10][7][14];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+3004211, dvrr_stack+1385818, dvrr_stack+1529218);
 tmp = dvrr_stack + 3004211;
 target_ptr = Libderiv->deriv2_classes[10][8][14];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+3007181, dvrr_stack+864536, dvrr_stack+1531693);
 tmp = dvrr_stack + 3007181;
 target_ptr = Libderiv->deriv2_classes[10][9][14];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+3010811, dvrr_stack+1368202, dvrr_stack+1534718);
 tmp = dvrr_stack + 3010811;
 target_ptr = Libderiv->deriv2_classes[10][10][14];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+3015167, dvrr_stack+902177, dvrr_stack+1373350);
 tmp = dvrr_stack + 3015167;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+3015608, dvrr_stack+937795, dvrr_stack+902765);
 tmp = dvrr_stack + 3015608;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+3016196, dvrr_stack+393792, dvrr_stack+903185);
 tmp = dvrr_stack + 3016196;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+3016952, dvrr_stack+939254, dvrr_stack+938579);
 tmp = dvrr_stack + 3016952;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+3017897, dvrr_stack+941339, dvrr_stack+940514);
 tmp = dvrr_stack + 3017897;
 target_ptr = Libderiv->deriv2_classes[5][9][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+3019052, dvrr_stack+589195, dvrr_stack+942879);
 tmp = dvrr_stack + 3019052;
 target_ptr = Libderiv->deriv2_classes[5][10][13];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+3020438, dvrr_stack+944310, dvrr_stack+943869);
 tmp = dvrr_stack + 3020438;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+3021026, dvrr_stack+117646, dvrr_stack+945066);
 tmp = dvrr_stack + 3021026;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+3021810, dvrr_stack+1402015, dvrr_stack+945654);
 tmp = dvrr_stack + 3021810;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+3022818, dvrr_stack+242227, dvrr_stack+827289);
 tmp = dvrr_stack + 3022818;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+3024078, dvrr_stack+1404466, dvrr_stack+1403311);
 tmp = dvrr_stack + 3024078;
 target_ptr = Libderiv->deriv2_classes[6][9][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+3025618, dvrr_stack+597840, dvrr_stack+1406446);
 tmp = dvrr_stack + 3025618;
 target_ptr = Libderiv->deriv2_classes[6][10][13];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+3027466, dvrr_stack+1407832, dvrr_stack+902177);
 tmp = dvrr_stack + 3027466;
 target_ptr = Libderiv->deriv2_classes[7][5][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+3028222, dvrr_stack+1408777, dvrr_stack+937795);
 tmp = dvrr_stack + 3028222;
 target_ptr = Libderiv->deriv2_classes[7][6][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+3029230, dvrr_stack+1410037, dvrr_stack+393792);
 tmp = dvrr_stack + 3029230;
 target_ptr = Libderiv->deriv2_classes[7][7][13];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+3030526, dvrr_stack+462185, dvrr_stack+939254);
 tmp = dvrr_stack + 3030526;
 target_ptr = Libderiv->deriv2_classes[7][8][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+3032146, dvrr_stack+645165, dvrr_stack+941339);
 tmp = dvrr_stack + 3032146;
 target_ptr = Libderiv->deriv2_classes[7][9][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+3034126, dvrr_stack+1382848, dvrr_stack+589195);
 tmp = dvrr_stack + 3034126;
 target_ptr = Libderiv->deriv2_classes[7][10][13];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+3036502, dvrr_stack+647640, dvrr_stack+944310);
 tmp = dvrr_stack + 3036502;
 target_ptr = Libderiv->deriv2_classes[8][5][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+3037447, dvrr_stack+1411657, dvrr_stack+117646);
 tmp = dvrr_stack + 3037447;
 target_ptr = Libderiv->deriv2_classes[8][6][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+3038707, dvrr_stack+414780, dvrr_stack+1402015);
 tmp = dvrr_stack + 3038707;
 target_ptr = Libderiv->deriv2_classes[8][7][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+3040327, dvrr_stack+619515, dvrr_stack+242227);
 tmp = dvrr_stack + 3040327;
 target_ptr = Libderiv->deriv2_classes[8][8][13];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+3042352, dvrr_stack+435480, dvrr_stack+1404466);
 tmp = dvrr_stack + 3042352;
 target_ptr = Libderiv->deriv2_classes[8][9][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+3044827, dvrr_stack+1427745, dvrr_stack+597840);
 tmp = dvrr_stack + 3044827;
 target_ptr = Libderiv->deriv2_classes[8][10][13];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+3047797, dvrr_stack+416760, dvrr_stack+1407832);
 tmp = dvrr_stack + 3047797;
 target_ptr = Libderiv->deriv2_classes[9][5][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+3048952, dvrr_stack+8203, dvrr_stack+1408777);
 tmp = dvrr_stack + 3048952;
 target_ptr = Libderiv->deriv2_classes[9][6][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+3050492, dvrr_stack+1554914, dvrr_stack+1410037);
 tmp = dvrr_stack + 3050492;
 target_ptr = Libderiv->deriv2_classes[9][7][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+3052472, dvrr_stack+1431375, dvrr_stack+462185);
 tmp = dvrr_stack + 3052472;
 target_ptr = Libderiv->deriv2_classes[9][8][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+3054947, dvrr_stack+1434345, dvrr_stack+645165);
 tmp = dvrr_stack + 3054947;
 target_ptr = Libderiv->deriv2_classes[9][9][13];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+3057972, dvrr_stack+1437975, dvrr_stack+1382848);
 tmp = dvrr_stack + 3057972;
 target_ptr = Libderiv->deriv2_classes[9][10][13];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+3061602, dvrr_stack+18607, dvrr_stack+647640);
 tmp = dvrr_stack + 3061602;
 target_ptr = Libderiv->deriv2_classes[10][5][13];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+3062988, dvrr_stack+831804, dvrr_stack+1411657);
 tmp = dvrr_stack + 3062988;
 target_ptr = Libderiv->deriv2_classes[10][6][13];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+3064836, dvrr_stack+1442331, dvrr_stack+414780);
 tmp = dvrr_stack + 3064836;
 target_ptr = Libderiv->deriv2_classes[10][7][13];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+3067212, dvrr_stack+398464, dvrr_stack+619515);
 tmp = dvrr_stack + 3067212;
 target_ptr = Libderiv->deriv2_classes[10][8][13];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+3070182, dvrr_stack+92942, dvrr_stack+435480);
 tmp = dvrr_stack + 3070182;
 target_ptr = Libderiv->deriv2_classes[10][9][13];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+3073812, dvrr_stack+1564638, dvrr_stack+1427745);
 tmp = dvrr_stack + 3073812;
 target_ptr = Libderiv->deriv2_classes[10][10][13];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+3078168, dvrr_stack+1074945, dvrr_stack+1064627);
 tmp = dvrr_stack + 3078168;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+3078609, dvrr_stack+1074161, dvrr_stack+539255);
 tmp = dvrr_stack + 3078609;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+3079197, dvrr_stack+1075533, dvrr_stack+541295);
 tmp = dvrr_stack + 3079197;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+3079953, dvrr_stack+1076541, dvrr_stack+1034773);
 tmp = dvrr_stack + 3079953;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,55,dvrr_stack+3080898, dvrr_stack+1077801, dvrr_stack+541835);
 tmp = dvrr_stack + 3080898;
 target_ptr = Libderiv->deriv2_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,66,dvrr_stack+3082053, dvrr_stack+1079341, dvrr_stack+915199);
 tmp = dvrr_stack + 3082053;
 target_ptr = Libderiv->deriv2_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+915199, dvrr_stack+1087361, dvrr_stack+1066790);
 tmp = dvrr_stack + 915199;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+541295, dvrr_stack+1086353, dvrr_stack+1066202);
 tmp = dvrr_stack + 541295;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+1066118, dvrr_stack+1088117, dvrr_stack+1067231);
 tmp = dvrr_stack + 1066118;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+3083439, dvrr_stack+1028797, dvrr_stack+1067987);
 tmp = dvrr_stack + 3083439;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,55,dvrr_stack+1067126, dvrr_stack+1030417, dvrr_stack+1068932);
 tmp = dvrr_stack + 1067126;
 target_ptr = Libderiv->deriv2_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,66,dvrr_stack+3084699, dvrr_stack+1032397, dvrr_stack+1070087);
 tmp = dvrr_stack + 3084699;
 target_ptr = Libderiv->deriv2_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,21,dvrr_stack+1068666, dvrr_stack+977914, dvrr_stack+1074945);
 tmp = dvrr_stack + 1068666;
 target_ptr = Libderiv->deriv2_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,28,dvrr_stack+1069422, dvrr_stack+976654, dvrr_stack+1074161);
 tmp = dvrr_stack + 1069422;
 target_ptr = Libderiv->deriv2_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,36,dvrr_stack+1073853, dvrr_stack+925321, dvrr_stack+1075533);
 tmp = dvrr_stack + 1073853;
 target_ptr = Libderiv->deriv2_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,45,dvrr_stack+3086547, dvrr_stack+926941, dvrr_stack+1076541);
 tmp = dvrr_stack + 3086547;
 target_ptr = Libderiv->deriv2_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,55,dvrr_stack+1075149, dvrr_stack+886667, dvrr_stack+1077801);
 tmp = dvrr_stack + 1075149;
 target_ptr = Libderiv->deriv2_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,66,dvrr_stack+3088167, dvrr_stack+798777, dvrr_stack+1079341);
 tmp = dvrr_stack + 3088167;
 target_ptr = Libderiv->deriv2_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,21,dvrr_stack+1077129, dvrr_stack+889142, dvrr_stack+1087361);
 tmp = dvrr_stack + 1077129;
 target_ptr = Libderiv->deriv2_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,28,dvrr_stack+1078074, dvrr_stack+805257, dvrr_stack+1086353);
 tmp = dvrr_stack + 1078074;
 target_ptr = Libderiv->deriv2_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,36,dvrr_stack+1079334, dvrr_stack+806797, dvrr_stack+1088117);
 tmp = dvrr_stack + 1079334;
 target_ptr = Libderiv->deriv2_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,45,dvrr_stack+1086230, dvrr_stack+808777, dvrr_stack+1028797);
 tmp = dvrr_stack + 1086230;
 target_ptr = Libderiv->deriv2_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,55,dvrr_stack+3090543, dvrr_stack+811252, dvrr_stack+1030417);
 tmp = dvrr_stack + 3090543;
 target_ptr = Libderiv->deriv2_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,66,dvrr_stack+1028575, dvrr_stack+752219, dvrr_stack+1032397);
 tmp = dvrr_stack + 1028575;
 target_ptr = Libderiv->deriv2_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,21,dvrr_stack+1031545, dvrr_stack+672038, dvrr_stack+977914);
 tmp = dvrr_stack + 1031545;
 target_ptr = Libderiv->deriv2_classes[9][5][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,28,dvrr_stack+1032700, dvrr_stack+670190, dvrr_stack+976654);
 tmp = dvrr_stack + 1032700;
 target_ptr = Libderiv->deriv2_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,36,dvrr_stack+976616, dvrr_stack+631305, dvrr_stack+925321);
 tmp = dvrr_stack + 976616;
 target_ptr = Libderiv->deriv2_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,45,dvrr_stack+631197, dvrr_stack+633681, dvrr_stack+926941);
 tmp = dvrr_stack + 631197;
 target_ptr = Libderiv->deriv2_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,55,dvrr_stack+925160, dvrr_stack+636651, dvrr_stack+886667);
 tmp = dvrr_stack + 925160;
 target_ptr = Libderiv->deriv2_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,66,dvrr_stack+633672, dvrr_stack+561055, dvrr_stack+798777);
 tmp = dvrr_stack + 633672;
 target_ptr = Libderiv->deriv2_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_n(Data,21,dvrr_stack+637302, dvrr_stack+591043, dvrr_stack+889142);
 tmp = dvrr_stack + 637302;
 target_ptr = Libderiv->deriv2_classes[10][5][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_n(Data,28,dvrr_stack+886322, dvrr_stack+600216, dvrr_stack+805257);
 tmp = dvrr_stack + 886322;
 target_ptr = Libderiv->deriv2_classes[10][6][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_n(Data,36,dvrr_stack+888170, dvrr_stack+622485, dvrr_stack+806797);
 tmp = dvrr_stack + 888170;
 target_ptr = Libderiv->deriv2_classes[10][7][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_n(Data,45,dvrr_stack+805198, dvrr_stack+648795, dvrr_stack+808777);
 tmp = dvrr_stack + 805198;
 target_ptr = Libderiv->deriv2_classes[10][8][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_n(Data,55,dvrr_stack+560751, dvrr_stack+1458588, dvrr_stack+811252);
 tmp = dvrr_stack + 560751;
 target_ptr = Libderiv->deriv2_classes[10][9][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_n(Data,66,dvrr_stack+808168, dvrr_stack+725213, dvrr_stack+752219);
 tmp = dvrr_stack + 808168;
 target_ptr = Libderiv->deriv2_classes[10][10][11];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+648795, dvrr_stack+574367, dvrr_stack+498065);
 tmp = dvrr_stack + 648795;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+649236, dvrr_stack+573583, dvrr_stack+498380);
 tmp = dvrr_stack + 649236;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+649824, dvrr_stack+487265, dvrr_stack+498800);
 tmp = dvrr_stack + 649824;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+650580, dvrr_stack+488273, dvrr_stack+499340);
 tmp = dvrr_stack + 650580;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+600216, dvrr_stack+489533, dvrr_stack+500015);
 tmp = dvrr_stack + 600216;
 target_ptr = Libderiv->deriv2_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+591043, dvrr_stack+453680, dvrr_stack+500840);
 tmp = dvrr_stack + 591043;
 target_ptr = Libderiv->deriv2_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+651525, dvrr_stack+456536, dvrr_stack+815817);
 tmp = dvrr_stack + 651525;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+601371, dvrr_stack+455528, dvrr_stack+758819);
 tmp = dvrr_stack + 601371;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+638688, dvrr_stack+406275, dvrr_stack+673424);
 tmp = dvrr_stack + 638688;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+812524, dvrr_stack+407571, dvrr_stack+613740);
 tmp = dvrr_stack + 812524;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+622431, dvrr_stack+409191, dvrr_stack+614685);
 tmp = dvrr_stack + 622431;
 target_ptr = Libderiv->deriv2_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+725160, dvrr_stack+374298, dvrr_stack+570559);
 tmp = dvrr_stack + 725160;
 target_ptr = Libderiv->deriv2_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+570304, dvrr_stack+380742, dvrr_stack+574367);
 tmp = dvrr_stack + 570304;
 target_ptr = Libderiv->deriv2_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+623971, dvrr_stack+379482, dvrr_stack+573583);
 tmp = dvrr_stack + 623971;
 target_ptr = Libderiv->deriv2_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+573317, dvrr_stack+381687, dvrr_stack+487265);
 tmp = dvrr_stack + 573317;
 target_ptr = Libderiv->deriv2_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+727008, dvrr_stack+383307, dvrr_stack+488273);
 tmp = dvrr_stack + 727008;
 target_ptr = Libderiv->deriv2_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1458324, dvrr_stack+343247, dvrr_stack+489533);
 tmp = dvrr_stack + 1458324;
 target_ptr = Libderiv->deriv2_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1460304, dvrr_stack+220488, dvrr_stack+453680);
 tmp = dvrr_stack + 1460304;
 target_ptr = Libderiv->deriv2_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+728628, dvrr_stack+346547, dvrr_stack+456536);
 tmp = dvrr_stack + 728628;
 target_ptr = Libderiv->deriv2_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+751944, dvrr_stack+287267, dvrr_stack+455528);
 tmp = dvrr_stack + 751944;
 target_ptr = Libderiv->deriv2_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+753204, dvrr_stack+267688, dvrr_stack+406275);
 tmp = dvrr_stack + 753204;
 target_ptr = Libderiv->deriv2_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+669837, dvrr_stack+226968, dvrr_stack+407571);
 tmp = dvrr_stack + 669837;
 target_ptr = Libderiv->deriv2_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+487077, dvrr_stack+198886, dvrr_stack+409191);
 tmp = dvrr_stack + 487077;
 target_ptr = Libderiv->deriv2_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+406053, dvrr_stack+106348, dvrr_stack+374298);
 tmp = dvrr_stack + 406053;
 target_ptr = Libderiv->deriv2_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+1034240, dvrr_stack+251632, dvrr_stack+380742);
 tmp = dvrr_stack + 1034240;
 target_ptr = Libderiv->deriv2_classes[9][5][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+671862, dvrr_stack+229443, dvrr_stack+379482);
 tmp = dvrr_stack + 671862;
 target_ptr = Libderiv->deriv2_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+379467, dvrr_stack+175306, dvrr_stack+381687);
 tmp = dvrr_stack + 379467;
 target_ptr = Libderiv->deriv2_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+374121, dvrr_stack+1276153, dvrr_stack+383307);
 tmp = dvrr_stack + 374121;
 target_ptr = Libderiv->deriv2_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+381447, dvrr_stack+1279123, dvrr_stack+343247);
 tmp = dvrr_stack + 381447;
 target_ptr = Libderiv->deriv2_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1276052, dvrr_stack+1282753, dvrr_stack+220488);
 tmp = dvrr_stack + 1276052;
 target_ptr = Libderiv->deriv2_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+229443, dvrr_stack+321191, dvrr_stack+346547);
 tmp = dvrr_stack + 229443;
 target_ptr = Libderiv->deriv2_classes[10][5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+343199, dvrr_stack+322829, dvrr_stack+287267);
 tmp = dvrr_stack + 343199;
 target_ptr = Libderiv->deriv2_classes[10][6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+321128, dvrr_stack+465155, dvrr_stack+267688);
 tmp = dvrr_stack + 321128;
 target_ptr = Libderiv->deriv2_classes[10][7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+464798, dvrr_stack+989011, dvrr_stack+226968);
 tmp = dvrr_stack + 464798;
 target_ptr = Libderiv->deriv2_classes[10][8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1279682, dvrr_stack+992521, dvrr_stack+198886);
 tmp = dvrr_stack + 1279682;
 target_ptr = Libderiv->deriv2_classes[10][9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+988648, dvrr_stack+996811, dvrr_stack+106348);
 tmp = dvrr_stack + 988648;
 target_ptr = Libderiv->deriv2_classes[10][10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+230829, dvrr_stack+123866, dvrr_stack+501830);
 tmp = dvrr_stack + 230829;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+346163, dvrr_stack+28408, dvrr_stack+537050);
 tmp = dvrr_stack + 346163;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+346751, dvrr_stack+119438, dvrr_stack+537470);
 tmp = dvrr_stack + 346751;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+226741, dvrr_stack+134840, dvrr_stack+539675);
 tmp = dvrr_stack + 226741;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+227686, dvrr_stack+148990, dvrr_stack+1346351);
 tmp = dvrr_stack + 227686;
 target_ptr = Libderiv->deriv2_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+267400, dvrr_stack+166066, dvrr_stack+1347176);
 tmp = dvrr_stack + 267400;
 target_ptr = Libderiv->deriv2_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+1346117, dvrr_stack+120446, dvrr_stack+12874);
 tmp = dvrr_stack + 1346117;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+1346705, dvrr_stack+1084193, dvrr_stack+1064942);
 tmp = dvrr_stack + 1346705;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+1064483, dvrr_stack+240256, dvrr_stack+7447);
 tmp = dvrr_stack + 1064483;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+536676, dvrr_stack+259912, dvrr_stack+23872);
 tmp = dvrr_stack + 536676;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+287153, dvrr_stack+277547, dvrr_stack+37537);
 tmp = dvrr_stack + 287153;
 target_ptr = Libderiv->deriv2_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+1283312, dvrr_stack+300671, dvrr_stack+54700);
 tmp = dvrr_stack + 1283312;
 target_ptr = Libderiv->deriv2_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+384472, dvrr_stack+402495, dvrr_stack+123866);
 tmp = dvrr_stack + 384472;
 target_ptr = Libderiv->deriv2_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+323504, dvrr_stack+1035448, dvrr_stack+28408);
 tmp = dvrr_stack + 323504;
 target_ptr = Libderiv->deriv2_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+54511, dvrr_stack+396060, dvrr_stack+119438);
 tmp = dvrr_stack + 54511;
 target_ptr = Libderiv->deriv2_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+1285160, dvrr_stack+403440, dvrr_stack+134840);
 tmp = dvrr_stack + 1285160;
 target_ptr = Libderiv->deriv2_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+613624, dvrr_stack+363714, dvrr_stack+148990);
 tmp = dvrr_stack + 613624;
 target_ptr = Libderiv->deriv2_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+219954, dvrr_stack+472415, dvrr_stack+166066);
 tmp = dvrr_stack + 219954;
 target_ptr = Libderiv->deriv2_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+119410, dvrr_stack+604500, dvrr_stack+120446);
 tmp = dvrr_stack + 119410;
 target_ptr = Libderiv->deriv2_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+37372, dvrr_stack+857606, dvrr_stack+1084193);
 tmp = dvrr_stack + 37372;
 target_ptr = Libderiv->deriv2_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+148781, dvrr_stack+594375, dvrr_stack+240256);
 tmp = dvrr_stack + 148781;
 target_ptr = Libderiv->deriv2_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+409023, dvrr_stack+625365, dvrr_stack+259912);
 tmp = dvrr_stack + 409023;
 target_ptr = Libderiv->deriv2_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+198367, dvrr_stack+655340, dvrr_stack+277547);
 tmp = dvrr_stack + 198367;
 target_ptr = Libderiv->deriv2_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+106294, dvrr_stack+687779, dvrr_stack+300671);
 tmp = dvrr_stack + 106294;
 target_ptr = Libderiv->deriv2_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+259798, dvrr_stack+846518, dvrr_stack+402495);
 tmp = dvrr_stack + 259798;
 target_ptr = Libderiv->deriv2_classes[9][5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+846267, dvrr_stack+755849, dvrr_stack+1035448);
 tmp = dvrr_stack + 846267;
 target_ptr = Libderiv->deriv2_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+277541, dvrr_stack+836060, dvrr_stack+396060);
 tmp = dvrr_stack + 277541;
 target_ptr = Libderiv->deriv2_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+754824, dvrr_stack+872411, dvrr_stack+403440);
 tmp = dvrr_stack + 754824;
 target_ptr = Libderiv->deriv2_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+872006, dvrr_stack+907501, dvrr_stack+363714);
 tmp = dvrr_stack + 872006;
 target_ptr = Libderiv->deriv2_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+907325, dvrr_stack+951391, dvrr_stack+472415);
 tmp = dvrr_stack + 907325;
 target_ptr = Libderiv->deriv2_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+396060, dvrr_stack+1348166, dvrr_stack+604500);
 tmp = dvrr_stack + 396060;
 target_ptr = Libderiv->deriv2_classes[10][5][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+1347489, dvrr_stack+1363390, dvrr_stack+857606);
 tmp = dvrr_stack + 1347489;
 target_ptr = Libderiv->deriv2_classes[10][6][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+951309, dvrr_stack+1376476, dvrr_stack+594375);
 tmp = dvrr_stack + 951309;
 target_ptr = Libderiv->deriv2_classes[10][7][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+1376221, dvrr_stack+1393918, dvrr_stack+625365);
 tmp = dvrr_stack + 1376221;
 target_ptr = Libderiv->deriv2_classes[10][8][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1393684, dvrr_stack+1417632, dvrr_stack+655340);
 tmp = dvrr_stack + 1393684;
 target_ptr = Libderiv->deriv2_classes[10][9][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+1417553, dvrr_stack+1445718, dvrr_stack+687779);
 tmp = dvrr_stack + 1417553;
 target_ptr = Libderiv->deriv2_classes[10][10][9];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+542079, dvrr_stack+1057651, dvrr_stack+1462878);
 tmp = dvrr_stack + 542079;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+228841, dvrr_stack+1056867, dvrr_stack+1463193);
 tmp = dvrr_stack + 228841;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+571060, dvrr_stack+1058239, dvrr_stack+1463613);
 tmp = dvrr_stack + 571060;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1084108, dvrr_stack+1059247, dvrr_stack+1464153);
 tmp = dvrr_stack + 1084108;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+953685, dvrr_stack+1060507, dvrr_stack+1464828);
 tmp = dvrr_stack + 953685;
 target_ptr = Libderiv->deriv2_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+624979, dvrr_stack+1062047, dvrr_stack+1465653);
 tmp = dvrr_stack + 624979;
 target_ptr = Libderiv->deriv2_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+268786, dvrr_stack+1011541, dvrr_stack+1049846);
 tmp = dvrr_stack + 268786;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+120355, dvrr_stack+1010533, dvrr_stack+1049258);
 tmp = dvrr_stack + 120355;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+23752, dvrr_stack+1012297, dvrr_stack+1050287);
 tmp = dvrr_stack + 23752;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+626365, dvrr_stack+1013593, dvrr_stack+1051043);
 tmp = dvrr_stack + 626365;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+835968, dvrr_stack+955747, dvrr_stack+1051988);
 tmp = dvrr_stack + 835968;
 target_ptr = Libderiv->deriv2_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+1363257, dvrr_stack+957727, dvrr_stack+1053143);
 tmp = dvrr_stack + 1363257;
 target_ptr = Libderiv->deriv2_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+123677, dvrr_stack+961228, dvrr_stack+1057651);
 tmp = dvrr_stack + 123677;
 target_ptr = Libderiv->deriv2_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+134690, dvrr_stack+913939, dvrr_stack+1056867);
 tmp = dvrr_stack + 134690;
 target_ptr = Libderiv->deriv2_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+1056657, dvrr_stack+875381, dvrr_stack+1058239);
 tmp = dvrr_stack + 1056657;
 target_ptr = Libderiv->deriv2_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+594277, dvrr_stack+877001, dvrr_stack+1059247);
 tmp = dvrr_stack + 594277;
 target_ptr = Libderiv->deriv2_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1057953, dvrr_stack+847904, dvrr_stack+1060507);
 tmp = dvrr_stack + 1057953;
 target_ptr = Libderiv->deriv2_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1049135, dvrr_stack+735719, dvrr_stack+1062047);
 tmp = dvrr_stack + 1049135;
 target_ptr = Libderiv->deriv2_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+1059933, dvrr_stack+738689, dvrr_stack+1011541);
 tmp = dvrr_stack + 1059933;
 target_ptr = Libderiv->deriv2_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+1060878, dvrr_stack+850379, dvrr_stack+1010533);
 tmp = dvrr_stack + 1060878;
 target_ptr = Libderiv->deriv2_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+1062138, dvrr_stack+658365, dvrr_stack+1012297);
 tmp = dvrr_stack + 1062138;
 target_ptr = Libderiv->deriv2_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1010101, dvrr_stack+627840, dvrr_stack+1013593);
 tmp = dvrr_stack + 1010101;
 target_ptr = Libderiv->deriv2_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1012126, dvrr_stack+605655, dvrr_stack+955747);
 tmp = dvrr_stack + 1012126;
 target_ptr = Libderiv->deriv2_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1051511, dvrr_stack+366189, dvrr_stack+957727);
 tmp = dvrr_stack + 1051511;
 target_ptr = Libderiv->deriv2_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+954840, dvrr_stack+739844, dvrr_stack+961228);
 tmp = dvrr_stack + 954840;
 target_ptr = Libderiv->deriv2_classes[9][5][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+955995, dvrr_stack+694919, dvrr_stack+913939);
 tmp = dvrr_stack + 955995;
 target_ptr = Libderiv->deriv2_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+957535, dvrr_stack+660345, dvrr_stack+875381);
 tmp = dvrr_stack + 957535;
 target_ptr = Libderiv->deriv2_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+363708, dvrr_stack+303047, dvrr_stack+877001);
 tmp = dvrr_stack + 363708;
 target_ptr = Libderiv->deriv2_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+875031, dvrr_stack+214476, dvrr_stack+847904);
 tmp = dvrr_stack + 875031;
 target_ptr = Libderiv->deriv2_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1462680, dvrr_stack+100090, dvrr_stack+735719);
 tmp = dvrr_stack + 1462680;
 target_ptr = Libderiv->deriv2_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+739844, dvrr_stack+1468473, dvrr_stack+738689);
 tmp = dvrr_stack + 739844;
 target_ptr = Libderiv->deriv2_classes[10][5][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+660345, dvrr_stack+1470111, dvrr_stack+850379);
 tmp = dvrr_stack + 660345;
 target_ptr = Libderiv->deriv2_classes[10][6][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+847807, dvrr_stack+1472295, dvrr_stack+658365);
 tmp = dvrr_stack + 847807;
 target_ptr = Libderiv->deriv2_classes[10][7][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+1468098, dvrr_stack+1475103, dvrr_stack+627840);
 tmp = dvrr_stack + 1468098;
 target_ptr = Libderiv->deriv2_classes[10][8][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1471068, dvrr_stack+1450866, dvrr_stack+605655);
 tmp = dvrr_stack + 1471068;
 target_ptr = Libderiv->deriv2_classes[10][9][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+655221, dvrr_stack+1421922, dvrr_stack+366189);
 tmp = dvrr_stack + 655221;
 target_ptr = Libderiv->deriv2_classes[10][10][8];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+662193, dvrr_stack+405465, dvrr_stack+1466643);
 tmp = dvrr_stack + 662193;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+959515, dvrr_stack+397680, dvrr_stack+928966);
 tmp = dvrr_stack + 959515;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+694860, dvrr_stack+281165, dvrr_stack+978859);
 tmp = dvrr_stack + 694860;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+695616, dvrr_stack+261532, dvrr_stack+814277);
 tmp = dvrr_stack + 695616;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+913924, dvrr_stack+245584, dvrr_stack+814952);
 tmp = dvrr_stack + 913924;
 target_ptr = Libderiv->deriv2_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+813784, dvrr_stack+218106, dvrr_stack+1455156);
 tmp = dvrr_stack + 813784;
 target_ptr = Libderiv->deriv2_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+815170, dvrr_stack+1036708, dvrr_stack+1015213);
 tmp = dvrr_stack + 815170;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+850183, dvrr_stack+262792, dvrr_stack+839261);
 tmp = dvrr_stack + 850183;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+1421909, dvrr_stack+247124, dvrr_stack+757697);
 tmp = dvrr_stack + 1421909;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1422917, dvrr_stack+167914, dvrr_stack+596355);
 tmp = dvrr_stack + 1422917;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1424177, dvrr_stack+150530, dvrr_stack+859146);
 tmp = dvrr_stack + 1424177;
 target_ptr = Libderiv->deriv2_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+627625, dvrr_stack+77200, dvrr_stack+369819);
 tmp = dvrr_stack + 627625;
 target_ptr = Libderiv->deriv2_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+839024, dvrr_stack+192166, dvrr_stack+405465);
 tmp = dvrr_stack + 839024;
 target_ptr = Libderiv->deriv2_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+1425717, dvrr_stack+136100, dvrr_stack+397680);
 tmp = dvrr_stack + 1425717;
 target_ptr = Libderiv->deriv2_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+878056, dvrr_stack+124454, dvrr_stack+281165);
 tmp = dvrr_stack + 878056;
 target_ptr = Libderiv->deriv2_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+166010, dvrr_stack+56086, dvrr_stack+261532);
 tmp = dvrr_stack + 166010;
 target_ptr = Libderiv->deriv2_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+366183, dvrr_stack+83878, dvrr_stack+245584);
 tmp = dvrr_stack + 366183;
 target_ptr = Libderiv->deriv2_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+368163, dvrr_stack+786770, dvrr_stack+218106);
 tmp = dvrr_stack + 368163;
 target_ptr = Libderiv->deriv2_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+397446, dvrr_stack+24817, dvrr_stack+1036708);
 tmp = dvrr_stack + 397446;
 target_ptr = Libderiv->deriv2_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+280899, dvrr_stack+38692, dvrr_stack+262792);
 tmp = dvrr_stack + 280899;
 target_ptr = Libderiv->deriv2_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+260953, dvrr_stack+61630, dvrr_stack+247124);
 tmp = dvrr_stack + 260953;
 target_ptr = Libderiv->deriv2_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+245443, dvrr_stack+546143, dvrr_stack+167914);
 tmp = dvrr_stack + 245443;
 target_ptr = Libderiv->deriv2_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1474698, dvrr_stack+548618, dvrr_stack+150530);
 tmp = dvrr_stack + 1474698;
 target_ptr = Libderiv->deriv2_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1445580, dvrr_stack+551643, dvrr_stack+77200);
 tmp = dvrr_stack + 1445580;
 target_ptr = Libderiv->deriv2_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+76934, dvrr_stack+140888, dvrr_stack+192166);
 tmp = dvrr_stack + 76934;
 target_ptr = Libderiv->deriv2_classes[9][5][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+150401, dvrr_stack+555273, dvrr_stack+136100);
 tmp = dvrr_stack + 150401;
 target_ptr = Libderiv->deriv2_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+1448550, dvrr_stack+508979, dvrr_stack+124454);
 tmp = dvrr_stack + 1448550;
 target_ptr = Libderiv->deriv2_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+508865, dvrr_stack+511355, dvrr_stack+56086);
 tmp = dvrr_stack + 508865;
 target_ptr = Libderiv->deriv2_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1450530, dvrr_stack+440199, dvrr_stack+83878);
 tmp = dvrr_stack + 1450530;
 target_ptr = Libderiv->deriv2_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+439765, dvrr_stack+419125, dvrr_stack+786770);
 tmp = dvrr_stack + 439765;
 target_ptr = Libderiv->deriv2_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+555273, dvrr_stack+1456146, dvrr_stack+24817);
 tmp = dvrr_stack + 555273;
 target_ptr = Libderiv->deriv2_classes[10][5][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+55807, dvrr_stack+1397428, dvrr_stack+38692);
 tmp = dvrr_stack + 55807;
 target_ptr = Libderiv->deriv2_classes[10][6][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+418930, dvrr_stack+1379284, dvrr_stack+61630);
 tmp = dvrr_stack + 418930;
 target_ptr = Libderiv->deriv2_classes[10][7][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+511340, dvrr_stack+1349804, dvrr_stack+546143);
 tmp = dvrr_stack + 511340;
 target_ptr = Libderiv->deriv2_classes[10][8][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1349337, dvrr_stack+1478613, dvrr_stack+548618);
 tmp = dvrr_stack + 1349337;
 target_ptr = Libderiv->deriv2_classes[10][9][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+546104, dvrr_stack+1482903, dvrr_stack+551643);
 tmp = dvrr_stack + 546104;
 target_ptr = Libderiv->deriv2_classes[10][10][7];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+556659, dvrr_stack+201911, dvrr_stack+1466958);
 tmp = dvrr_stack + 556659;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+192110, dvrr_stack+16402, dvrr_stack+1488051);
 tmp = dvrr_stack + 192110;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+78089, dvrr_stack+445215, dvrr_stack+1457784);
 tmp = dvrr_stack + 78089;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+850967, dvrr_stack+446223, dvrr_stack+1427070);
 tmp = dvrr_stack + 850967;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+262573, dvrr_stack+91402, dvrr_stack+1399612);
 tmp = dvrr_stack + 262573;
 target_ptr = Libderiv->deriv2_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+124433, dvrr_stack+97628, dvrr_stack+1400437);
 tmp = dvrr_stack + 124433;
 target_ptr = Libderiv->deriv2_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+78845, dvrr_stack+44152, dvrr_stack+1085201);
 tmp = dvrr_stack + 78845;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+247468, dvrr_stack+211381, dvrr_stack+306017);
 tmp = dvrr_stack + 247468;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+38632, dvrr_stack+212389, dvrr_stack+128570);
 tmp = dvrr_stack + 38632;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1379191, dvrr_stack+1297405, dvrr_stack+43207);
 tmp = dvrr_stack + 1379191;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1380451, dvrr_stack+1299025, dvrr_stack+793250);
 tmp = dvrr_stack + 1380451;
 target_ptr = Libderiv->deriv2_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+421306, dvrr_stack+1301005, dvrr_stack+443829);
 tmp = dvrr_stack + 421306;
 target_ptr = Libderiv->deriv2_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+793023, dvrr_stack+360999, dvrr_stack+201911);
 tmp = dvrr_stack + 793023;
 target_ptr = Libderiv->deriv2_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+24760, dvrr_stack+359739, dvrr_stack+16402);
 tmp = dvrr_stack + 24760;
 target_ptr = Libderiv->deriv2_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+443395, dvrr_stack+1303381, dvrr_stack+445215);
 tmp = dvrr_stack + 443395;
 target_ptr = Libderiv->deriv2_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+135698, dvrr_stack+1305001, dvrr_stack+446223);
 tmp = dvrr_stack + 135698;
 target_ptr = Libderiv->deriv2_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+444691, dvrr_stack+1307026, dvrr_stack+91402);
 tmp = dvrr_stack + 444691;
 target_ptr = Libderiv->deriv2_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+550460, dvrr_stack+1309501, dvrr_stack+97628);
 tmp = dvrr_stack + 550460;
 target_ptr = Libderiv->deriv2_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+1426725, dvrr_stack+209567, dvrr_stack+44152);
 tmp = dvrr_stack + 1426725;
 target_ptr = Libderiv->deriv2_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+240117, dvrr_stack+208027, dvrr_stack+211381);
 tmp = dvrr_stack + 240117;
 target_ptr = Libderiv->deriv2_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+167630, dvrr_stack+1312471, dvrr_stack+212389);
 tmp = dvrr_stack + 167630;
 target_ptr = Libderiv->deriv2_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+211310, dvrr_stack+1314451, dvrr_stack+1297405);
 tmp = dvrr_stack + 211310;
 target_ptr = Libderiv->deriv2_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1477173, dvrr_stack+1316926, dvrr_stack+1299025);
 tmp = dvrr_stack + 1477173;
 target_ptr = Libderiv->deriv2_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1297189, dvrr_stack+1319951, dvrr_stack+1301005);
 tmp = dvrr_stack + 1297189;
 target_ptr = Libderiv->deriv2_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+1300159, dvrr_stack+356777, dvrr_stack+360999);
 tmp = dvrr_stack + 1300159;
 target_ptr = Libderiv->deriv2_classes[9][5][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1301314, dvrr_stack+354929, dvrr_stack+359739);
 tmp = dvrr_stack + 1301314;
 target_ptr = Libderiv->deriv2_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+359423, dvrr_stack+1327871, dvrr_stack+1303381);
 tmp = dvrr_stack + 359423;
 target_ptr = Libderiv->deriv2_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1327599, dvrr_stack+1330247, dvrr_stack+1305001);
 tmp = dvrr_stack + 1327599;
 target_ptr = Libderiv->deriv2_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1330074, dvrr_stack+1333217, dvrr_stack+1307026);
 tmp = dvrr_stack + 1330074;
 target_ptr = Libderiv->deriv2_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1333099, dvrr_stack+1336847, dvrr_stack+1309501);
 tmp = dvrr_stack + 1333099;
 target_ptr = Libderiv->deriv2_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+1336729, dvrr_stack+1365574, dvrr_stack+209567);
 tmp = dvrr_stack + 1336729;
 target_ptr = Libderiv->deriv2_classes[10][5][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+1338115, dvrr_stack+272872, dvrr_stack+208027);
 tmp = dvrr_stack + 1338115;
 target_ptr = Libderiv->deriv2_classes[10][6][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+1302854, dvrr_stack+1488471, dvrr_stack+1312471);
 tmp = dvrr_stack + 1302854;
 target_ptr = Libderiv->deriv2_classes[10][7][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+1305230, dvrr_stack+1491279, dvrr_stack+1314451);
 tmp = dvrr_stack + 1305230;
 target_ptr = Libderiv->deriv2_classes[10][8][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1308200, dvrr_stack+1494789, dvrr_stack+1316926);
 tmp = dvrr_stack + 1308200;
 target_ptr = Libderiv->deriv2_classes[10][9][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+1311830, dvrr_stack+1499079, dvrr_stack+1319951);
 tmp = dvrr_stack + 1311830;
 target_ptr = Libderiv->deriv2_classes[10][10][6];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+1339963, dvrr_stack+719444, dvrr_stack+719129);
 tmp = dvrr_stack + 1339963;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+1340404, dvrr_stack+720452, dvrr_stack+720032);
 tmp = dvrr_stack + 1340404;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+1316186, dvrr_stack+721776, dvrr_stack+721236);
 tmp = dvrr_stack + 1316186;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1316942, dvrr_stack+723459, dvrr_stack+722784);
 tmp = dvrr_stack + 1316942;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+1317887, dvrr_stack+685733, dvrr_stack+1467273);
 tmp = dvrr_stack + 1317887;
 target_ptr = Libderiv->deriv2_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+1319042, dvrr_stack+1504227, dvrr_stack+1367212);
 tmp = dvrr_stack + 1319042;
 target_ptr = Libderiv->deriv2_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+722784, dvrr_stack+1506075, dvrr_stack+243847);
 tmp = dvrr_stack + 722784;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+1320428, dvrr_stack+538010, dvrr_stack+1401427);
 tmp = dvrr_stack + 1320428;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+1321212, dvrr_stack+467963, dvrr_stack+1382092);
 tmp = dvrr_stack + 1321212;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1322220, dvrr_stack+1506831, dvrr_stack+540350);
 tmp = dvrr_stack + 1322220;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1365105, dvrr_stack+1508451, dvrr_stack+20857);
 tmp = dvrr_stack + 1365105;
 target_ptr = Libderiv->deriv2_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+552836, dvrr_stack+1511817, dvrr_stack+1510431);
 tmp = dvrr_stack + 552836;
 target_ptr = Libderiv->deriv2_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+1510431, dvrr_stack+72643, dvrr_stack+719444);
 tmp = dvrr_stack + 1510431;
 target_ptr = Libderiv->deriv2_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+20833, dvrr_stack+1514193, dvrr_stack+720452);
 tmp = dvrr_stack + 20833;
 target_ptr = Libderiv->deriv2_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+1366645, dvrr_stack+1515453, dvrr_stack+721776);
 tmp = dvrr_stack + 1366645;
 target_ptr = Libderiv->deriv2_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+91123, dvrr_stack+1517073, dvrr_stack+723459);
 tmp = dvrr_stack + 91123;
 target_ptr = Libderiv->deriv2_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1479648, dvrr_stack+1519098, dvrr_stack+685733);
 tmp = dvrr_stack + 1479648;
 target_ptr = Libderiv->deriv2_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1481628, dvrr_stack+1521573, dvrr_stack+1504227);
 tmp = dvrr_stack + 1481628;
 target_ptr = Libderiv->deriv2_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+723372, dvrr_stack+1524543, dvrr_stack+1506075);
 tmp = dvrr_stack + 723372;
 target_ptr = Libderiv->deriv2_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+685577, dvrr_stack+1525698, dvrr_stack+538010);
 tmp = dvrr_stack + 685577;
 target_ptr = Libderiv->deriv2_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+537936, dvrr_stack+1527238, dvrr_stack+467963);
 tmp = dvrr_stack + 537936;
 target_ptr = Libderiv->deriv2_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1484004, dvrr_stack+1529218, dvrr_stack+1506831);
 tmp = dvrr_stack + 1484004;
 target_ptr = Libderiv->deriv2_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1486029, dvrr_stack+1531693, dvrr_stack+1508451);
 tmp = dvrr_stack + 1486029;
 target_ptr = Libderiv->deriv2_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1488504, dvrr_stack+1534718, dvrr_stack+1511817);
 tmp = dvrr_stack + 1488504;
 target_ptr = Libderiv->deriv2_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+1511187, dvrr_stack+1538348, dvrr_stack+72643);
 tmp = dvrr_stack + 1511187;
 target_ptr = Libderiv->deriv2_classes[9][5][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1512342, dvrr_stack+1539734, dvrr_stack+1514193);
 tmp = dvrr_stack + 1512342;
 target_ptr = Libderiv->deriv2_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+1538348, dvrr_stack+1541582, dvrr_stack+1515453);
 tmp = dvrr_stack + 1538348;
 target_ptr = Libderiv->deriv2_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1540328, dvrr_stack+1543958, dvrr_stack+1517073);
 tmp = dvrr_stack + 1540328;
 target_ptr = Libderiv->deriv2_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1542803, dvrr_stack+1546928, dvrr_stack+1519098);
 tmp = dvrr_stack + 1542803;
 target_ptr = Libderiv->deriv2_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1545828, dvrr_stack+1550558, dvrr_stack+1521573);
 tmp = dvrr_stack + 1545828;
 target_ptr = Libderiv->deriv2_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+1549458, dvrr_stack+33852, dvrr_stack+1524543);
 tmp = dvrr_stack + 1549458;
 target_ptr = Libderiv->deriv2_classes[10][5][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+1550844, dvrr_stack+829620, dvrr_stack+1525698);
 tmp = dvrr_stack + 1550844;
 target_ptr = Libderiv->deriv2_classes[10][6][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+1513882, dvrr_stack+68949, dvrr_stack+1527238);
 tmp = dvrr_stack + 1513882;
 target_ptr = Libderiv->deriv2_classes[10][7][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+1516258, dvrr_stack+1385818, dvrr_stack+1529218);
 tmp = dvrr_stack + 1516258;
 target_ptr = Libderiv->deriv2_classes[10][8][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1519228, dvrr_stack+864536, dvrr_stack+1531693);
 tmp = dvrr_stack + 1519228;
 target_ptr = Libderiv->deriv2_classes[10][9][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+1522858, dvrr_stack+1368202, dvrr_stack+1534718);
 tmp = dvrr_stack + 1522858;
 target_ptr = Libderiv->deriv2_classes[10][10][2];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+243847, dvrr_stack+902177, dvrr_stack+1373350);
 tmp = dvrr_stack + 243847;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+1385818, dvrr_stack+937795, dvrr_stack+902765);
 tmp = dvrr_stack + 1385818;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+1386406, dvrr_stack+393792, dvrr_stack+903185);
 tmp = dvrr_stack + 1386406;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+902765, dvrr_stack+939254, dvrr_stack+938579);
 tmp = dvrr_stack + 902765;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+1387162, dvrr_stack+941339, dvrr_stack+940514);
 tmp = dvrr_stack + 1387162;
 target_ptr = Libderiv->deriv2_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+829620, dvrr_stack+589195, dvrr_stack+942879);
 tmp = dvrr_stack + 829620;
 target_ptr = Libderiv->deriv2_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+942879, dvrr_stack+944310, dvrr_stack+943869);
 tmp = dvrr_stack + 942879;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+943467, dvrr_stack+117646, dvrr_stack+945066);
 tmp = dvrr_stack + 943467;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+1388317, dvrr_stack+1402015, dvrr_stack+945654);
 tmp = dvrr_stack + 1388317;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+945066, dvrr_stack+242227, dvrr_stack+827289);
 tmp = dvrr_stack + 945066;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1552692, dvrr_stack+1404466, dvrr_stack+1403311);
 tmp = dvrr_stack + 1552692;
 target_ptr = Libderiv->deriv2_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+1527214, dvrr_stack+597840, dvrr_stack+1406446);
 tmp = dvrr_stack + 1527214;
 target_ptr = Libderiv->deriv2_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+1406446, dvrr_stack+1407832, dvrr_stack+902177);
 tmp = dvrr_stack + 1406446;
 target_ptr = Libderiv->deriv2_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+1403311, dvrr_stack+1408777, dvrr_stack+937795);
 tmp = dvrr_stack + 1403311;
 target_ptr = Libderiv->deriv2_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+1529062, dvrr_stack+1410037, dvrr_stack+393792);
 tmp = dvrr_stack + 1529062;
 target_ptr = Libderiv->deriv2_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+1530358, dvrr_stack+462185, dvrr_stack+939254);
 tmp = dvrr_stack + 1530358;
 target_ptr = Libderiv->deriv2_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1531978, dvrr_stack+645165, dvrr_stack+941339);
 tmp = dvrr_stack + 1531978;
 target_ptr = Libderiv->deriv2_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1533958, dvrr_stack+1382848, dvrr_stack+589195);
 tmp = dvrr_stack + 1533958;
 target_ptr = Libderiv->deriv2_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+393792, dvrr_stack+647640, dvrr_stack+944310);
 tmp = dvrr_stack + 393792;
 target_ptr = Libderiv->deriv2_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+1536334, dvrr_stack+1411657, dvrr_stack+117646);
 tmp = dvrr_stack + 1536334;
 target_ptr = Libderiv->deriv2_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+539556, dvrr_stack+414780, dvrr_stack+1402015);
 tmp = dvrr_stack + 539556;
 target_ptr = Libderiv->deriv2_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+588838, dvrr_stack+619515, dvrr_stack+242227);
 tmp = dvrr_stack + 588838;
 target_ptr = Libderiv->deriv2_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1367941, dvrr_stack+435480, dvrr_stack+1404466);
 tmp = dvrr_stack + 1367941;
 target_ptr = Libderiv->deriv2_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1370416, dvrr_stack+1427745, dvrr_stack+597840);
 tmp = dvrr_stack + 1370416;
 target_ptr = Libderiv->deriv2_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+1404319, dvrr_stack+416760, dvrr_stack+1407832);
 tmp = dvrr_stack + 1404319;
 target_ptr = Libderiv->deriv2_classes[9][5][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1407202, dvrr_stack+8203, dvrr_stack+1408777);
 tmp = dvrr_stack + 1407202;
 target_ptr = Libderiv->deriv2_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+597741, dvrr_stack+1554914, dvrr_stack+1410037);
 tmp = dvrr_stack + 597741;
 target_ptr = Libderiv->deriv2_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1408742, dvrr_stack+1431375, dvrr_stack+462185);
 tmp = dvrr_stack + 1408742;
 target_ptr = Libderiv->deriv2_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1554232, dvrr_stack+1434345, dvrr_stack+645165);
 tmp = dvrr_stack + 1554232;
 target_ptr = Libderiv->deriv2_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1431375, dvrr_stack+1437975, dvrr_stack+1382848);
 tmp = dvrr_stack + 1431375;
 target_ptr = Libderiv->deriv2_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+416760, dvrr_stack+18607, dvrr_stack+647640);
 tmp = dvrr_stack + 416760;
 target_ptr = Libderiv->deriv2_classes[10][5][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+1435005, dvrr_stack+831804, dvrr_stack+1411657);
 tmp = dvrr_stack + 1435005;
 target_ptr = Libderiv->deriv2_classes[10][6][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+1436853, dvrr_stack+1442331, dvrr_stack+414780);
 tmp = dvrr_stack + 1436853;
 target_ptr = Libderiv->deriv2_classes[10][7][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+1439229, dvrr_stack+398464, dvrr_stack+619515);
 tmp = dvrr_stack + 1439229;
 target_ptr = Libderiv->deriv2_classes[10][8][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1381991, dvrr_stack+92942, dvrr_stack+435480);
 tmp = dvrr_stack + 1381991;
 target_ptr = Libderiv->deriv2_classes[10][9][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+92743, dvrr_stack+1564638, dvrr_stack+1427745);
 tmp = dvrr_stack + 92743;
 target_ptr = Libderiv->deriv2_classes[10][10][1];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+1442199, dvrr_stack+464210, dvrr_stack+946410);
 tmp = dvrr_stack + 1442199;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+1442640, dvrr_stack+418146, dvrr_stack+3730);
 tmp = dvrr_stack + 1442640;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+1443228, dvrr_stack+10051, dvrr_stack+6859);
 tmp = dvrr_stack + 1443228;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1443984, dvrr_stack+438505, dvrr_stack+12118);
 tmp = dvrr_stack + 1443984;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+1411217, dvrr_stack+31432, dvrr_stack+22927);
 tmp = dvrr_stack + 1411217;
 target_ptr = Libderiv->deriv2_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+831006, dvrr_stack+4591, dvrr_stack+36382);
 tmp = dvrr_stack + 831006;
 target_ptr = Libderiv->deriv2_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+117646, dvrr_stack+53755, dvrr_stack+53314);
 tmp = dvrr_stack + 117646;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+1412372, dvrr_stack+1359162, dvrr_stack+117058);
 tmp = dvrr_stack + 1412372;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+832392, dvrr_stack+237876, dvrr_stack+118654);
 tmp = dvrr_stack + 832392;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+398391, dvrr_stack+66670, dvrr_stack+11059);
 tmp = dvrr_stack + 398391;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+11059, dvrr_stack+47176, dvrr_stack+133535);
 tmp = dvrr_stack + 11059;
 target_ptr = Libderiv->deriv2_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+399651, dvrr_stack+0, dvrr_stack+147395);
 tmp = dvrr_stack + 399651;
 target_ptr = Libderiv->deriv2_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+118234, dvrr_stack+1360170, dvrr_stack+464210);
 tmp = dvrr_stack + 118234;
 target_ptr = Libderiv->deriv2_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+242140, dvrr_stack+358163, dvrr_stack+418146);
 tmp = dvrr_stack + 242140;
 target_ptr = Libderiv->deriv2_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+147251, dvrr_stack+163606, dvrr_stack+10051);
 tmp = dvrr_stack + 147251;
 target_ptr = Libderiv->deriv2_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+6439, dvrr_stack+1569786, dvrr_stack+438505);
 tmp = dvrr_stack + 6439;
 target_ptr = Libderiv->deriv2_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+8059, dvrr_stack+1571811, dvrr_stack+31432);
 tmp = dvrr_stack + 8059;
 target_ptr = Libderiv->deriv2_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1427670, dvrr_stack+1574286, dvrr_stack+4591);
 tmp = dvrr_stack + 1427670;
 target_ptr = Libderiv->deriv2_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+4591, dvrr_stack+244288, dvrr_stack+53755);
 tmp = dvrr_stack + 4591;
 target_ptr = Libderiv->deriv2_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+133358, dvrr_stack+275056, dvrr_stack+1359162);
 tmp = dvrr_stack + 133358;
 target_ptr = Libderiv->deriv2_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+1564566, dvrr_stack+297701, dvrr_stack+237876);
 tmp = dvrr_stack + 1564566;
 target_ptr = Libderiv->deriv2_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1566186, dvrr_stack+121202, dvrr_stack+66670);
 tmp = dvrr_stack + 1566186;
 target_ptr = Libderiv->deriv2_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+68878, dvrr_stack+1577256, dvrr_stack+47176);
 tmp = dvrr_stack + 68878;
 target_ptr = Libderiv->deriv2_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1491474, dvrr_stack+1580281, dvrr_stack+0);
 tmp = dvrr_stack + 1491474;
 target_ptr = Libderiv->deriv2_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+0, dvrr_stack+144920, dvrr_stack+1360170);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[9][5][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+47008, dvrr_stack+131510, dvrr_stack+358163);
 tmp = dvrr_stack + 47008;
 target_ptr = Libderiv->deriv2_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+131286, dvrr_stack+1353314, dvrr_stack+163606);
 tmp = dvrr_stack + 131286;
 target_ptr = Libderiv->deriv2_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1352967, dvrr_stack+469259, dvrr_stack+1569786);
 tmp = dvrr_stack + 1352967;
 target_ptr = Libderiv->deriv2_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+467768, dvrr_stack+255412, dvrr_stack+1571811);
 tmp = dvrr_stack + 467768;
 target_ptr = Libderiv->deriv2_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+470793, dvrr_stack+1413197, dvrr_stack+1574286);
 tmp = dvrr_stack + 470793;
 target_ptr = Libderiv->deriv2_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+1413156, dvrr_stack+294071, dvrr_stack+244288);
 tmp = dvrr_stack + 1413156;
 target_ptr = Libderiv->deriv2_classes[10][5][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+1414542, dvrr_stack+680585, dvrr_stack+275056);
 tmp = dvrr_stack + 1414542;
 target_ptr = Libderiv->deriv2_classes[10][6][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+1568211, dvrr_stack+682769, dvrr_stack+297701);
 tmp = dvrr_stack + 1568211;
 target_ptr = Libderiv->deriv2_classes[10][7][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+1570587, dvrr_stack+584320, dvrr_stack+121202);
 tmp = dvrr_stack + 1570587;
 target_ptr = Libderiv->deriv2_classes[10][8][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+1573557, dvrr_stack+839849, dvrr_stack+1577256);
 tmp = dvrr_stack + 1573557;
 target_ptr = Libderiv->deriv2_classes[10][9][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+839780, dvrr_stack+1557290, dvrr_stack+1580281);
 tmp = dvrr_stack + 839780;
 target_ptr = Libderiv->deriv2_classes[10][10][0];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];


}

