/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gfii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|ii) integrals */

void d1hrr_order_gfii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[4][12][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5985;
 Libderiv->deriv_classes[5][7][11] = int_stack + 6573;
 Libderiv->deriv_classes[5][8][11] = int_stack + 7329;
 Libderiv->deriv_classes[5][9][11] = int_stack + 8274;
 Libderiv->deriv_classes[5][10][11] = int_stack + 9429;
 Libderiv->deriv_classes[5][11][11] = int_stack + 10815;
 Libderiv->deriv_classes[5][12][11] = int_stack + 12453;
 Libderiv->deriv_classes[6][6][11] = int_stack + 14364;
 Libderiv->deriv_classes[6][7][11] = int_stack + 15148;
 Libderiv->deriv_classes[6][8][11] = int_stack + 16156;
 Libderiv->deriv_classes[6][9][11] = int_stack + 17416;
 Libderiv->deriv_classes[6][10][11] = int_stack + 18956;
 Libderiv->deriv_classes[6][11][11] = int_stack + 20804;
 Libderiv->deriv_classes[6][12][11] = int_stack + 22988;
 Libderiv->deriv_classes[7][6][11] = int_stack + 25536;
 Libderiv->deriv_classes[7][7][11] = int_stack + 26544;
 Libderiv->deriv_classes[7][8][11] = int_stack + 27840;
 Libderiv->deriv_classes[7][9][11] = int_stack + 29460;
 Libderiv->deriv_classes[7][10][11] = int_stack + 31440;
 Libderiv->deriv_classes[7][11][11] = int_stack + 33816;
 Libderiv->deriv_classes[7][12][11] = int_stack + 36624;
 Libderiv->deriv_classes[4][6][10] = int_stack + 39900;
 Libderiv->deriv_classes[4][7][10] = int_stack + 40320;
 Libderiv->deriv_classes[4][8][10] = int_stack + 40860;
 Libderiv->deriv_classes[4][9][10] = int_stack + 41535;
 Libderiv->deriv_classes[4][10][10] = int_stack + 42360;
 Libderiv->deriv_classes[4][11][10] = int_stack + 43350;
 Libderiv->deriv_classes[4][12][10] = int_stack + 44520;
 Libderiv->deriv_classes[5][6][10] = int_stack + 45885;
 Libderiv->deriv_classes[5][7][10] = int_stack + 46473;
 Libderiv->deriv_classes[5][8][10] = int_stack + 47229;
 Libderiv->deriv_classes[5][9][10] = int_stack + 48174;
 Libderiv->deriv_classes[5][10][10] = int_stack + 49329;
 Libderiv->deriv_classes[5][11][10] = int_stack + 50715;
 Libderiv->deriv_classes[5][12][10] = int_stack + 52353;
 Libderiv->deriv_classes[6][6][10] = int_stack + 54264;
 Libderiv->deriv_classes[6][7][10] = int_stack + 55048;
 Libderiv->deriv_classes[6][8][10] = int_stack + 56056;
 Libderiv->deriv_classes[6][9][10] = int_stack + 57316;
 Libderiv->deriv_classes[6][10][10] = int_stack + 58856;
 Libderiv->deriv_classes[6][11][10] = int_stack + 60704;
 Libderiv->deriv_classes[6][12][10] = int_stack + 62888;
 Libderiv->deriv_classes[7][6][10] = int_stack + 65436;
 Libderiv->deriv_classes[7][7][10] = int_stack + 66444;
 Libderiv->deriv_classes[7][8][10] = int_stack + 67740;
 Libderiv->deriv_classes[7][9][10] = int_stack + 69360;
 Libderiv->deriv_classes[7][10][10] = int_stack + 71340;
 Libderiv->deriv_classes[7][11][10] = int_stack + 73716;
 Libderiv->deriv_classes[7][12][10] = int_stack + 76524;
 Libderiv->deriv_classes[4][6][9] = int_stack + 79800;
 Libderiv->deriv_classes[4][7][9] = int_stack + 80220;
 Libderiv->deriv_classes[4][8][9] = int_stack + 80760;
 Libderiv->deriv_classes[4][9][9] = int_stack + 81435;
 Libderiv->deriv_classes[4][10][9] = int_stack + 82260;
 Libderiv->deriv_classes[4][11][9] = int_stack + 83250;
 Libderiv->deriv_classes[4][12][9] = int_stack + 84420;
 Libderiv->deriv_classes[5][6][9] = int_stack + 85785;
 Libderiv->deriv_classes[5][7][9] = int_stack + 86373;
 Libderiv->deriv_classes[5][8][9] = int_stack + 87129;
 Libderiv->deriv_classes[5][9][9] = int_stack + 88074;
 Libderiv->deriv_classes[5][10][9] = int_stack + 89229;
 Libderiv->deriv_classes[5][11][9] = int_stack + 90615;
 Libderiv->deriv_classes[5][12][9] = int_stack + 92253;
 Libderiv->deriv_classes[6][6][9] = int_stack + 94164;
 Libderiv->deriv_classes[6][7][9] = int_stack + 94948;
 Libderiv->deriv_classes[6][8][9] = int_stack + 95956;
 Libderiv->deriv_classes[6][9][9] = int_stack + 97216;
 Libderiv->deriv_classes[6][10][9] = int_stack + 98756;
 Libderiv->deriv_classes[6][11][9] = int_stack + 100604;
 Libderiv->deriv_classes[6][12][9] = int_stack + 102788;
 Libderiv->deriv_classes[7][6][9] = int_stack + 105336;
 Libderiv->deriv_classes[7][7][9] = int_stack + 106344;
 Libderiv->deriv_classes[7][8][9] = int_stack + 107640;
 Libderiv->deriv_classes[7][9][9] = int_stack + 109260;
 Libderiv->deriv_classes[7][10][9] = int_stack + 111240;
 Libderiv->deriv_classes[7][11][9] = int_stack + 113616;
 Libderiv->deriv_classes[7][12][9] = int_stack + 116424;
 Libderiv->deriv_classes[4][6][8] = int_stack + 119700;
 Libderiv->deriv_classes[4][7][8] = int_stack + 120120;
 Libderiv->deriv_classes[4][8][8] = int_stack + 120660;
 Libderiv->deriv_classes[4][9][8] = int_stack + 121335;
 Libderiv->deriv_classes[4][10][8] = int_stack + 122160;
 Libderiv->deriv_classes[4][11][8] = int_stack + 123150;
 Libderiv->deriv_classes[4][12][8] = int_stack + 124320;
 Libderiv->deriv_classes[5][6][8] = int_stack + 125685;
 Libderiv->deriv_classes[5][7][8] = int_stack + 126273;
 Libderiv->deriv_classes[5][8][8] = int_stack + 127029;
 Libderiv->deriv_classes[5][9][8] = int_stack + 127974;
 Libderiv->deriv_classes[5][10][8] = int_stack + 129129;
 Libderiv->deriv_classes[5][11][8] = int_stack + 130515;
 Libderiv->deriv_classes[5][12][8] = int_stack + 132153;
 Libderiv->deriv_classes[6][6][8] = int_stack + 134064;
 Libderiv->deriv_classes[6][7][8] = int_stack + 134848;
 Libderiv->deriv_classes[6][8][8] = int_stack + 135856;
 Libderiv->deriv_classes[6][9][8] = int_stack + 137116;
 Libderiv->deriv_classes[6][10][8] = int_stack + 138656;
 Libderiv->deriv_classes[6][11][8] = int_stack + 140504;
 Libderiv->deriv_classes[6][12][8] = int_stack + 142688;
 Libderiv->deriv_classes[7][6][8] = int_stack + 145236;
 Libderiv->deriv_classes[7][7][8] = int_stack + 146244;
 Libderiv->deriv_classes[7][8][8] = int_stack + 147540;
 Libderiv->deriv_classes[7][9][8] = int_stack + 149160;
 Libderiv->deriv_classes[7][10][8] = int_stack + 151140;
 Libderiv->deriv_classes[7][11][8] = int_stack + 153516;
 Libderiv->deriv_classes[7][12][8] = int_stack + 156324;
 Libderiv->deriv_classes[4][6][7] = int_stack + 159600;
 Libderiv->deriv_classes[4][7][7] = int_stack + 160020;
 Libderiv->deriv_classes[4][8][7] = int_stack + 160560;
 Libderiv->deriv_classes[4][9][7] = int_stack + 161235;
 Libderiv->deriv_classes[4][10][7] = int_stack + 162060;
 Libderiv->deriv_classes[4][11][7] = int_stack + 163050;
 Libderiv->deriv_classes[4][12][7] = int_stack + 164220;
 Libderiv->deriv_classes[5][6][7] = int_stack + 165585;
 Libderiv->deriv_classes[5][7][7] = int_stack + 166173;
 Libderiv->deriv_classes[5][8][7] = int_stack + 166929;
 Libderiv->deriv_classes[5][9][7] = int_stack + 167874;
 Libderiv->deriv_classes[5][10][7] = int_stack + 169029;
 Libderiv->deriv_classes[5][11][7] = int_stack + 170415;
 Libderiv->deriv_classes[5][12][7] = int_stack + 172053;
 Libderiv->deriv_classes[6][6][7] = int_stack + 173964;
 Libderiv->deriv_classes[6][7][7] = int_stack + 174748;
 Libderiv->deriv_classes[6][8][7] = int_stack + 175756;
 Libderiv->deriv_classes[6][9][7] = int_stack + 177016;
 Libderiv->deriv_classes[6][10][7] = int_stack + 178556;
 Libderiv->deriv_classes[6][11][7] = int_stack + 180404;
 Libderiv->deriv_classes[6][12][7] = int_stack + 182588;
 Libderiv->deriv_classes[7][6][7] = int_stack + 185136;
 Libderiv->deriv_classes[7][7][7] = int_stack + 186144;
 Libderiv->deriv_classes[7][8][7] = int_stack + 187440;
 Libderiv->deriv_classes[7][9][7] = int_stack + 189060;
 Libderiv->deriv_classes[7][10][7] = int_stack + 191040;
 Libderiv->deriv_classes[7][11][7] = int_stack + 193416;
 Libderiv->deriv_classes[7][12][7] = int_stack + 196224;
 Libderiv->deriv_classes[4][6][6] = int_stack + 199500;
 Libderiv->deriv_classes[4][7][6] = int_stack + 199920;
 Libderiv->deriv_classes[4][8][6] = int_stack + 200460;
 Libderiv->deriv_classes[4][9][6] = int_stack + 201135;
 Libderiv->deriv_classes[4][10][6] = int_stack + 201960;
 Libderiv->deriv_classes[4][11][6] = int_stack + 202950;
 Libderiv->deriv_classes[4][12][6] = int_stack + 204120;
 Libderiv->deriv_classes[5][6][6] = int_stack + 205485;
 Libderiv->deriv_classes[5][7][6] = int_stack + 206073;
 Libderiv->deriv_classes[5][8][6] = int_stack + 206829;
 Libderiv->deriv_classes[5][9][6] = int_stack + 207774;
 Libderiv->deriv_classes[5][10][6] = int_stack + 208929;
 Libderiv->deriv_classes[5][11][6] = int_stack + 210315;
 Libderiv->deriv_classes[5][12][6] = int_stack + 211953;
 Libderiv->deriv_classes[6][6][6] = int_stack + 213864;
 Libderiv->deriv_classes[6][7][6] = int_stack + 214648;
 Libderiv->deriv_classes[6][8][6] = int_stack + 215656;
 Libderiv->deriv_classes[6][9][6] = int_stack + 216916;
 Libderiv->deriv_classes[6][10][6] = int_stack + 218456;
 Libderiv->deriv_classes[6][11][6] = int_stack + 220304;
 Libderiv->deriv_classes[6][12][6] = int_stack + 222488;
 Libderiv->dvrr_classes[7][6] = int_stack + 225036;
 Libderiv->deriv_classes[7][6][6] = int_stack + 226044;
 Libderiv->dvrr_classes[7][7] = int_stack + 227052;
 Libderiv->deriv_classes[7][7][6] = int_stack + 228348;
 Libderiv->dvrr_classes[7][8] = int_stack + 229644;
 Libderiv->deriv_classes[7][8][6] = int_stack + 231264;
 Libderiv->dvrr_classes[7][9] = int_stack + 232884;
 Libderiv->deriv_classes[7][9][6] = int_stack + 234864;
 Libderiv->dvrr_classes[7][10] = int_stack + 236844;
 Libderiv->deriv_classes[7][10][6] = int_stack + 239220;
 Libderiv->dvrr_classes[7][11] = int_stack + 241596;
 Libderiv->deriv_classes[7][11][6] = int_stack + 244404;
 Libderiv->deriv_classes[7][12][6] = int_stack + 247212;
 Libderiv->deriv_classes[4][6][2] = int_stack + 250488;
 Libderiv->deriv_classes[4][7][2] = int_stack + 250908;
 Libderiv->deriv_classes[4][8][2] = int_stack + 251448;
 Libderiv->deriv_classes[4][9][2] = int_stack + 252123;
 Libderiv->deriv_classes[4][10][2] = int_stack + 252948;
 Libderiv->deriv_classes[4][11][2] = int_stack + 253938;
 Libderiv->deriv_classes[4][12][2] = int_stack + 255108;
 Libderiv->deriv_classes[5][6][2] = int_stack + 256473;
 Libderiv->deriv_classes[5][7][2] = int_stack + 257061;
 Libderiv->deriv_classes[5][8][2] = int_stack + 257817;
 Libderiv->deriv_classes[5][9][2] = int_stack + 258762;
 Libderiv->deriv_classes[5][10][2] = int_stack + 259917;
 Libderiv->deriv_classes[5][11][2] = int_stack + 261303;
 Libderiv->deriv_classes[5][12][2] = int_stack + 262941;
 Libderiv->deriv_classes[6][6][2] = int_stack + 264852;
 Libderiv->deriv_classes[6][7][2] = int_stack + 265636;
 Libderiv->deriv_classes[6][8][2] = int_stack + 266644;
 Libderiv->deriv_classes[6][9][2] = int_stack + 267904;
 Libderiv->deriv_classes[6][10][2] = int_stack + 269444;
 Libderiv->deriv_classes[6][11][2] = int_stack + 271292;
 Libderiv->deriv_classes[6][12][2] = int_stack + 273476;
 Libderiv->deriv_classes[7][6][2] = int_stack + 276024;
 Libderiv->deriv_classes[7][7][2] = int_stack + 277032;
 Libderiv->deriv_classes[7][8][2] = int_stack + 278328;
 Libderiv->deriv_classes[7][9][2] = int_stack + 279948;
 Libderiv->deriv_classes[7][10][2] = int_stack + 281928;
 Libderiv->deriv_classes[7][11][2] = int_stack + 284304;
 Libderiv->deriv_classes[7][12][2] = int_stack + 287112;
 Libderiv->deriv_classes[4][6][1] = int_stack + 290388;
 Libderiv->deriv_classes[4][7][1] = int_stack + 290808;
 Libderiv->deriv_classes[4][8][1] = int_stack + 291348;
 Libderiv->deriv_classes[4][9][1] = int_stack + 292023;
 Libderiv->deriv_classes[4][10][1] = int_stack + 292848;
 Libderiv->deriv_classes[4][11][1] = int_stack + 293838;
 Libderiv->deriv_classes[4][12][1] = int_stack + 295008;
 Libderiv->deriv_classes[5][6][1] = int_stack + 296373;
 Libderiv->deriv_classes[5][7][1] = int_stack + 296961;
 Libderiv->deriv_classes[5][8][1] = int_stack + 297717;
 Libderiv->deriv_classes[5][9][1] = int_stack + 298662;
 Libderiv->deriv_classes[5][10][1] = int_stack + 299817;
 Libderiv->deriv_classes[5][11][1] = int_stack + 301203;
 Libderiv->deriv_classes[5][12][1] = int_stack + 302841;
 Libderiv->deriv_classes[6][6][1] = int_stack + 304752;
 Libderiv->deriv_classes[6][7][1] = int_stack + 305536;
 Libderiv->deriv_classes[6][8][1] = int_stack + 306544;
 Libderiv->deriv_classes[6][9][1] = int_stack + 307804;
 Libderiv->deriv_classes[6][10][1] = int_stack + 309344;
 Libderiv->deriv_classes[6][11][1] = int_stack + 311192;
 Libderiv->deriv_classes[6][12][1] = int_stack + 313376;
 Libderiv->deriv_classes[7][6][1] = int_stack + 315924;
 Libderiv->deriv_classes[7][7][1] = int_stack + 316932;
 Libderiv->deriv_classes[7][8][1] = int_stack + 318228;
 Libderiv->deriv_classes[7][9][1] = int_stack + 319848;
 Libderiv->deriv_classes[7][10][1] = int_stack + 321828;
 Libderiv->deriv_classes[7][11][1] = int_stack + 324204;
 Libderiv->deriv_classes[7][12][1] = int_stack + 327012;
 Libderiv->dvrr_classes[4][6] = int_stack + 330288;
 Libderiv->dvrr_classes[4][7] = int_stack + 330708;
 Libderiv->dvrr_classes[4][8] = int_stack + 331248;
 Libderiv->dvrr_classes[4][9] = int_stack + 331923;
 Libderiv->dvrr_classes[4][10] = int_stack + 332748;
 Libderiv->dvrr_classes[4][11] = int_stack + 333738;
 Libderiv->dvrr_classes[4][12] = int_stack + 334908;
 Libderiv->deriv_classes[4][6][0] = int_stack + 336273;
 Libderiv->deriv_classes[4][7][0] = int_stack + 336693;
 Libderiv->deriv_classes[4][8][0] = int_stack + 337233;
 Libderiv->deriv_classes[4][9][0] = int_stack + 337908;
 Libderiv->deriv_classes[4][10][0] = int_stack + 338733;
 Libderiv->deriv_classes[4][11][0] = int_stack + 339723;
 Libderiv->deriv_classes[4][12][0] = int_stack + 340893;
 Libderiv->dvrr_classes[5][6] = int_stack + 342258;
 Libderiv->dvrr_classes[5][7] = int_stack + 342846;
 Libderiv->dvrr_classes[5][8] = int_stack + 343602;
 Libderiv->dvrr_classes[5][9] = int_stack + 344547;
 Libderiv->dvrr_classes[5][10] = int_stack + 345702;
 Libderiv->dvrr_classes[5][11] = int_stack + 347088;
 Libderiv->dvrr_classes[5][12] = int_stack + 348726;
 Libderiv->deriv_classes[5][6][0] = int_stack + 350637;
 Libderiv->deriv_classes[5][7][0] = int_stack + 351225;
 Libderiv->deriv_classes[5][8][0] = int_stack + 351981;
 Libderiv->deriv_classes[5][9][0] = int_stack + 352926;
 Libderiv->deriv_classes[5][10][0] = int_stack + 354081;
 Libderiv->deriv_classes[5][11][0] = int_stack + 355467;
 Libderiv->deriv_classes[5][12][0] = int_stack + 357105;
 Libderiv->dvrr_classes[6][6] = int_stack + 359016;
 Libderiv->dvrr_classes[6][7] = int_stack + 359800;
 Libderiv->dvrr_classes[6][8] = int_stack + 360808;
 Libderiv->dvrr_classes[6][9] = int_stack + 362068;
 Libderiv->dvrr_classes[6][10] = int_stack + 363608;
 Libderiv->dvrr_classes[6][11] = int_stack + 365456;
 Libderiv->dvrr_classes[6][12] = int_stack + 367640;
 Libderiv->deriv_classes[6][6][0] = int_stack + 370188;
 Libderiv->deriv_classes[6][7][0] = int_stack + 370972;
 Libderiv->deriv_classes[6][8][0] = int_stack + 371980;
 Libderiv->deriv_classes[6][9][0] = int_stack + 373240;
 Libderiv->deriv_classes[6][10][0] = int_stack + 374780;
 Libderiv->deriv_classes[6][11][0] = int_stack + 376628;
 Libderiv->deriv_classes[6][12][0] = int_stack + 378812;
 Libderiv->deriv_classes[7][6][0] = int_stack + 381360;
 Libderiv->deriv_classes[7][7][0] = int_stack + 382368;
 Libderiv->deriv_classes[7][8][0] = int_stack + 383664;
 Libderiv->deriv_classes[7][9][0] = int_stack + 385284;
 Libderiv->deriv_classes[7][10][0] = int_stack + 387264;
 Libderiv->deriv_classes[7][11][0] = int_stack + 389640;
 Libderiv->deriv_classes[7][12][0] = int_stack + 392448;
 memset(int_stack,0,3165792);

 Libderiv->dvrr_stack = int_stack + 2241172;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gfii(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+395724,int_stack+330708,int_stack+330288,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+396984,int_stack+331248,int_stack+330708,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+398604,int_stack+396984,int_stack+395724,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+401124,int_stack+331923,int_stack+331248,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+403149,int_stack+401124,int_stack+396984,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+406389,int_stack+403149,int_stack+398604,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+410589,int_stack+332748,int_stack+331923,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+413064,int_stack+410589,int_stack+401124,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+417114,int_stack+413064,int_stack+403149,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+422514,int_stack+417114,int_stack+406389,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+428814,int_stack+333738,int_stack+332748,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+431784,int_stack+428814,int_stack+410589,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+436734,int_stack+431784,int_stack+413064,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+443484,int_stack+436734,int_stack+417114,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+451584,int_stack+443484,int_stack+422514,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+460404,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330288,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+461664,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330708,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+463284,int_stack+461664,int_stack+460404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395724,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+465804,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331248,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+467829,int_stack+465804,int_stack+461664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396984,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+471069,int_stack+467829,int_stack+463284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398604,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+460404,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331923,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+475269,int_stack+460404,int_stack+465804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401124,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+479319,int_stack+475269,int_stack+467829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403149,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+462879,int_stack+479319,int_stack+471069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406389,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+469179,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332748,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+484719,int_stack+469179,int_stack+460404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410589,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+489669,int_stack+484719,int_stack+475269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413064,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+496419,int_stack+489669,int_stack+479319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417114,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+472149,int_stack+496419,int_stack+462879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422514,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+460404,int_stack+4620,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333738,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+460404,int_stack+469179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428814,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+460404,int_stack+0,int_stack+484719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431784,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+504519,int_stack+460404,int_stack+489669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436734,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+460404,int_stack+504519,int_stack+496419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443484,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+480969,int_stack+460404,int_stack+472149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451584,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+460404,int_stack+342846,int_stack+342258,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+462168,int_stack+343602,int_stack+342846,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+464436,int_stack+462168,int_stack+460404,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+467964,int_stack+344547,int_stack+343602,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+470799,int_stack+467964,int_stack+462168,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+470799,int_stack+464436,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+475335,int_stack+345702,int_stack+344547,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+492729,int_stack+475335,int_stack+467964,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+498399,int_stack+492729,int_stack+470799,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+505959,int_stack+498399,int_stack+0,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+514779,int_stack+347088,int_stack+345702,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+518937,int_stack+514779,int_stack+475335,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+525867,int_stack+518937,int_stack+492729,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+535317,int_stack+525867,int_stack+498399,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+546657,int_stack+535317,int_stack+505959,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+478800,int_stack+6573,int_stack+5985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342258,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+559005,int_stack+7329,int_stack+6573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342846,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+561273,int_stack+559005,int_stack+478800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460404,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+564801,int_stack+8274,int_stack+7329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343602,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+567636,int_stack+564801,int_stack+559005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462168,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+572172,int_stack+567636,int_stack+561273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464436,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+559005,int_stack+9429,int_stack+8274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344547,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+578052,int_stack+559005,int_stack+564801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467964,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+583722,int_stack+578052,int_stack+567636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470799,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+562470,int_stack+583722,int_stack+572172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+571290,int_stack+10815,int_stack+9429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345702,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+591282,int_stack+571290,int_stack+559005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475335,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+598212,int_stack+591282,int_stack+578052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492729,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+607662,int_stack+598212,int_stack+583722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498399,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+575448,int_stack+607662,int_stack+562470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505959,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+559005,int_stack+12453,int_stack+10815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347088,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+5880,int_stack+559005,int_stack+571290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+514779,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+559005,int_stack+5880,int_stack+591282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518937,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+619002,int_stack+559005,int_stack+598212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525867,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+559005,int_stack+619002,int_stack+607662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535317,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+587796,int_stack+559005,int_stack+575448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546657,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+604260,int_stack+587796,int_stack+480969,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+559005,int_stack+359800,int_stack+359016,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+561357,int_stack+360808,int_stack+359800,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+564381,int_stack+561357,int_stack+559005,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+569085,int_stack+362068,int_stack+360808,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+572865,int_stack+569085,int_stack+561357,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+578913,int_stack+572865,int_stack+564381,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5880,int_stack+363608,int_stack+362068,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+478800,int_stack+5880,int_stack+569085,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+639540,int_stack+478800,int_stack+572865,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+649620,int_stack+639540,int_stack+578913,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+486360,int_stack+365456,int_stack+363608,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+661380,int_stack+486360,int_stack+5880,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+670620,int_stack+661380,int_stack+478800,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+683220,int_stack+670620,int_stack+639540,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+698340,int_stack+683220,int_stack+649620,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+15148,int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359016,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+714804,int_stack+16156,int_stack+15148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359800,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+717828,int_stack+714804,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559005,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10500,int_stack+17416,int_stack+16156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360808,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+722532,int_stack+10500,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561357,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+728580,int_stack+722532,int_stack+717828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564381,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+18956,int_stack+17416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362068,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+736420,int_stack+714804,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569085,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+743980,int_stack+736420,int_stack+722532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+572865,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+754060,int_stack+743980,int_stack+728580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578913,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+10500,int_stack+20804,int_stack+18956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363608,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+719424,int_stack+10500,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+765820,int_stack+719424,int_stack+736420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478800,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+728664,int_stack+765820,int_stack+743980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639540,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+778420,int_stack+728664,int_stack+754060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649620,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+743784,int_stack+22988,int_stack+20804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365456,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+750336,int_stack+743784,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486360,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+794884,int_stack+750336,int_stack+719424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+661380,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+743784,int_stack+794884,int_stack+765820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670620,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+794884,int_stack+743784,int_stack+728664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+683220,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+714804,int_stack+794884,int_stack+778420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+698340,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+736756,int_stack+714804,int_stack+587796,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+786148,int_stack+736756,int_stack+604260,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+227052,int_stack+225036,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13524,int_stack+229644,int_stack+227052,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+17412,int_stack+13524,int_stack+10500,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+586753,int_stack+232884,int_stack+229644,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+591613,int_stack+586753,int_stack+13524,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+599389,int_stack+591613,int_stack+17412,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+609469,int_stack+236844,int_stack+232884,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+615409,int_stack+609469,int_stack+586753,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+625129,int_stack+615409,int_stack+591613,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+856708,int_stack+625129,int_stack+599389,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+871828,int_stack+241596,int_stack+236844,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+878956,int_stack+871828,int_stack+609469,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+890836,int_stack+878956,int_stack+615409,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+907036,int_stack+890836,int_stack+625129,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+926476,int_stack+907036,int_stack+856708,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+947644,int_stack+26544,int_stack+25536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225036,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+950668,int_stack+27840,int_stack+26544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227052,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+954556,int_stack+950668,int_stack+947644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+960604,int_stack+29460,int_stack+27840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229644,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+965464,int_stack+960604,int_stack+950668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+973240,int_stack+965464,int_stack+954556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+947644,int_stack+31440,int_stack+29460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232884,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+983320,int_stack+947644,int_stack+960604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586753,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+993040,int_stack+983320,int_stack+965464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591613,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+953584,int_stack+993040,int_stack+973240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599389,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+968704,int_stack+33816,int_stack+31440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236844,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1006000,int_stack+968704,int_stack+947644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609469,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1017880,int_stack+1006000,int_stack+983320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615409,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1034080,int_stack+1017880,int_stack+993040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625129,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+975832,int_stack+1034080,int_stack+953584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+856708,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+947644,int_stack+36624,int_stack+33816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241596,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+23460,int_stack+947644,int_stack+968704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871828,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+947644,int_stack+23460,int_stack+1006000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878956,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1053520,int_stack+947644,int_stack+1017880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890836,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+947644,int_stack+1053520,int_stack+1034080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+907036,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+997000,int_stack+947644,int_stack+975832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+926476,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1025224,int_stack+997000,int_stack+714804,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1091080,int_stack+1025224,int_stack+736756,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+40320,int_stack+39900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330288, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716064,int_stack+40860,int_stack+40320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330708, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+717684,int_stack+716064,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395724, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+720204,int_stack+41535,int_stack+40860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331248, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+722229,int_stack+720204,int_stack+716064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396984, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725469,int_stack+722229,int_stack+717684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398604, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+42360,int_stack+41535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331923, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+729669,int_stack+714804,int_stack+720204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401124, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+733719,int_stack+729669,int_stack+722229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403149, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+717279,int_stack+733719,int_stack+725469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406389, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+723579,int_stack+43350,int_stack+42360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332748, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+739119,int_stack+723579,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410589, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+744069,int_stack+739119,int_stack+729669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413064, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+750819,int_stack+744069,int_stack+733719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417114, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+726549,int_stack+750819,int_stack+717279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422514, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+44520,int_stack+43350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333738, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+758919,int_stack+714804,int_stack+723579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428814, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+758919,int_stack+739119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431784, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+758919,int_stack+714804,int_stack+744069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436734, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+758919,int_stack+750819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443484, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+735369,int_stack+714804,int_stack+726549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451584, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+46473,int_stack+45885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342258, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716568,int_stack+47229,int_stack+46473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342846, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+718836,int_stack+716568,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460404, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+722364,int_stack+48174,int_stack+47229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343602, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+725199,int_stack+722364,int_stack+716568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462168, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+747129,int_stack+725199,int_stack+718836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464436, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+49329,int_stack+48174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344547, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+753009,int_stack+714804,int_stack+722364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467964, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+758679,int_stack+753009,int_stack+725199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470799, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+718269,int_stack+758679,int_stack+747129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+747129,int_stack+50715,int_stack+49329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345702, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+727089,int_stack+747129,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475335, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+766239,int_stack+727089,int_stack+753009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492729, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+947644,int_stack+766239,int_stack+758679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498399, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+751287,int_stack+947644,int_stack+718269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505959, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+52353,int_stack+50715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347088, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+775689,int_stack+714804,int_stack+747129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+514779, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+775689,int_stack+727089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518937, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+958984,int_stack+714804,int_stack+766239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525867, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+958984,int_stack+947644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535317, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+947644,int_stack+714804,int_stack+751287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546657, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+964108,int_stack+947644,int_stack+735369,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+55048,int_stack+54264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359016, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+717156,int_stack+56056,int_stack+55048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359800, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+720180,int_stack+717156,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559005, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+724884,int_stack+57316,int_stack+56056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360808, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728664,int_stack+724884,int_stack+717156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561357, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+734712,int_stack+728664,int_stack+720180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564381, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+58856,int_stack+57316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362068, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+742552,int_stack+714804,int_stack+724884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569085, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+750112,int_stack+742552,int_stack+728664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+572865, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+719424,int_stack+750112,int_stack+734712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578913, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+731184,int_stack+60704,int_stack+58856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363608, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+760192,int_stack+731184,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+769432,int_stack+760192,int_stack+742552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478800, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+999388,int_stack+769432,int_stack+750112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639540, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+736728,int_stack+999388,int_stack+719424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649620, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+62888,int_stack+60704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365456, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1014508,int_stack+714804,int_stack+731184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486360, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+1014508,int_stack+760192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+661380, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1014508,int_stack+714804,int_stack+769432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670620, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+1014508,int_stack+999388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+683220, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+999388,int_stack+714804,int_stack+736728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+698340, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+714804,int_stack+999388,int_stack+947644,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1189864,int_stack+714804,int_stack+964108,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+947644,int_stack+66444,int_stack+65436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225036, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+950668,int_stack+67740,int_stack+66444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227052, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+954556,int_stack+950668,int_stack+947644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+960604,int_stack+69360,int_stack+67740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229644, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+965464,int_stack+960604,int_stack+950668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+973240,int_stack+965464,int_stack+954556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+947644,int_stack+71340,int_stack+69360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232884, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+983320,int_stack+947644,int_stack+960604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586753, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+764196,int_stack+983320,int_stack+965464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591613, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+953584,int_stack+764196,int_stack+973240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599389, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+968704,int_stack+73716,int_stack+71340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236844, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1021340,int_stack+968704,int_stack+947644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609469, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1033220,int_stack+1021340,int_stack+983320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615409, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+975832,int_stack+1033220,int_stack+764196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625129, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+764196,int_stack+975832,int_stack+953584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+856708, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+947644,int_stack+76524,int_stack+73716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241596, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1049420,int_stack+947644,int_stack+968704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871828, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+947644,int_stack+1049420,int_stack+1021340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878956, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1049420,int_stack+947644,int_stack+1033220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890836, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+947644,int_stack+1049420,int_stack+975832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+907036, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1021340,int_stack+947644,int_stack+764196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+926476, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1260424,int_stack+1021340,int_stack+999388,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+947644,int_stack+1260424,int_stack+714804,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+80220,int_stack+79800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330288, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716064,int_stack+80760,int_stack+80220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330708, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+717684,int_stack+716064,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395724, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+720204,int_stack+81435,int_stack+80760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331248, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+722229,int_stack+720204,int_stack+716064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396984, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725469,int_stack+722229,int_stack+717684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398604, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+82260,int_stack+81435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331923, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+729669,int_stack+714804,int_stack+720204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401124, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+733719,int_stack+729669,int_stack+722229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403149, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+717279,int_stack+733719,int_stack+725469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406389, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+723579,int_stack+83250,int_stack+82260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332748, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+739119,int_stack+723579,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410589, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+744069,int_stack+739119,int_stack+729669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413064, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+750819,int_stack+744069,int_stack+733719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417114, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+726549,int_stack+750819,int_stack+717279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422514, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+84420,int_stack+83250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333738, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+758919,int_stack+714804,int_stack+723579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428814, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+758919,int_stack+739119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431784, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+758919,int_stack+714804,int_stack+744069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436734, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+758919,int_stack+750819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443484, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+735369,int_stack+714804,int_stack+726549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451584, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+86373,int_stack+85785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342258, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716568,int_stack+87129,int_stack+86373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342846, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+718836,int_stack+716568,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460404, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+722364,int_stack+88074,int_stack+87129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343602, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+725199,int_stack+722364,int_stack+716568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462168, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+747129,int_stack+725199,int_stack+718836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464436, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+89229,int_stack+88074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344547, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+753009,int_stack+714804,int_stack+722364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467964, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+758679,int_stack+753009,int_stack+725199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470799, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+718269,int_stack+758679,int_stack+747129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+747129,int_stack+90615,int_stack+89229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345702, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+727089,int_stack+747129,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475335, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+766239,int_stack+727089,int_stack+753009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492729, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1260424,int_stack+766239,int_stack+758679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498399, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+751287,int_stack+1260424,int_stack+718269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505959, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+92253,int_stack+90615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347088, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+775689,int_stack+714804,int_stack+747129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+514779, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+775689,int_stack+727089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518937, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1271764,int_stack+714804,int_stack+766239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525867, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+1271764,int_stack+1260424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535317, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1260424,int_stack+714804,int_stack+751287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546657, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1276888,int_stack+1260424,int_stack+735369,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+94948,int_stack+94164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359016, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+717156,int_stack+95956,int_stack+94948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359800, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+720180,int_stack+717156,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559005, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+724884,int_stack+97216,int_stack+95956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728664,int_stack+724884,int_stack+717156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561357, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+734712,int_stack+728664,int_stack+720180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564381, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+98756,int_stack+97216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362068, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+742552,int_stack+714804,int_stack+724884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569085, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+750112,int_stack+742552,int_stack+728664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+572865, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+719424,int_stack+750112,int_stack+734712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578913, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+731184,int_stack+100604,int_stack+98756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+760192,int_stack+731184,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+769432,int_stack+760192,int_stack+742552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478800, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1046428,int_stack+769432,int_stack+750112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639540, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+736728,int_stack+1046428,int_stack+719424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649620, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+102788,int_stack+100604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365456, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1312168,int_stack+714804,int_stack+731184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486360, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+1312168,int_stack+760192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+661380, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1061548,int_stack+714804,int_stack+769432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670620, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+1061548,int_stack+1046428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+683220, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1046428,int_stack+714804,int_stack+736728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+698340, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+714804,int_stack+1046428,int_stack+1260424,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+23460,int_stack+714804,int_stack+1276888,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260424,int_stack+106344,int_stack+105336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225036, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1263448,int_stack+107640,int_stack+106344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227052, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1267336,int_stack+1263448,int_stack+1260424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1273384,int_stack+109260,int_stack+107640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229644, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1278244,int_stack+1273384,int_stack+1263448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1286020,int_stack+1278244,int_stack+1267336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260424,int_stack+111240,int_stack+109260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232884, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1296100,int_stack+1260424,int_stack+1273384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586753, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1305820,int_stack+1296100,int_stack+1278244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591613, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1266364,int_stack+1305820,int_stack+1286020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599389, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1281484,int_stack+113616,int_stack+111240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236844, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+764196,int_stack+1281484,int_stack+1260424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609469, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1068380,int_stack+764196,int_stack+1296100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615409, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+94020,int_stack+1068380,int_stack+1305820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625129, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1288612,int_stack+94020,int_stack+1266364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+116424,int_stack+113616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241596, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1309780,int_stack+1260424,int_stack+1281484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871828, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1260424,int_stack+1309780,int_stack+764196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878956, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1309780,int_stack+1260424,int_stack+1068380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890836, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+1309780,int_stack+94020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+907036, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1309780,int_stack+1260424,int_stack+1288612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+926476, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1338004,int_stack+1309780,int_stack+1046428,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1403860,int_stack+1338004,int_stack+714804,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+120120,int_stack+119700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716064,int_stack+120660,int_stack+120120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+717684,int_stack+716064,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+720204,int_stack+121335,int_stack+120660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+722229,int_stack+720204,int_stack+716064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725469,int_stack+722229,int_stack+717684, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+122160,int_stack+121335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+729669,int_stack+714804,int_stack+720204, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+733719,int_stack+729669,int_stack+722229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+717279,int_stack+733719,int_stack+725469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+723579,int_stack+123150,int_stack+122160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+739119,int_stack+723579,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+744069,int_stack+739119,int_stack+729669, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+750819,int_stack+744069,int_stack+733719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+726549,int_stack+750819,int_stack+717279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+124320,int_stack+123150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+758919,int_stack+714804,int_stack+723579, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+758919,int_stack+739119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+758919,int_stack+714804,int_stack+744069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+758919,int_stack+750819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+735369,int_stack+714804,int_stack+726549, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+126273,int_stack+125685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716568,int_stack+127029,int_stack+126273, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+718836,int_stack+716568,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+722364,int_stack+127974,int_stack+127029, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+725199,int_stack+722364,int_stack+716568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+747129,int_stack+725199,int_stack+718836, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+129129,int_stack+127974, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+753009,int_stack+714804,int_stack+722364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+758679,int_stack+753009,int_stack+725199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+718269,int_stack+758679,int_stack+747129, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+747129,int_stack+130515,int_stack+129129, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+727089,int_stack+747129,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+766239,int_stack+727089,int_stack+753009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1046428,int_stack+766239,int_stack+758679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+751287,int_stack+1046428,int_stack+718269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+132153,int_stack+130515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+775689,int_stack+714804,int_stack+747129, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+514779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+714804,int_stack+775689,int_stack+727089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1057768,int_stack+714804,int_stack+766239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+714804,int_stack+1057768,int_stack+1046428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1046428,int_stack+714804,int_stack+751287, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+747129,int_stack+1046428,int_stack+735369,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+134848,int_stack+134064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+717156,int_stack+135856,int_stack+134848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+720180,int_stack+717156,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+724884,int_stack+137116,int_stack+135856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728664,int_stack+724884,int_stack+717156, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+734712,int_stack+728664,int_stack+720180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+138656,int_stack+137116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1062892,int_stack+714804,int_stack+724884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1070452,int_stack+1062892,int_stack+728664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+572865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+719424,int_stack+1070452,int_stack+734712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+731184,int_stack+140504,int_stack+138656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+736728,int_stack+731184,int_stack+714804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1260424,int_stack+736728,int_stack+1062892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1273024,int_stack+1260424,int_stack+1070452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1062892,int_stack+1273024,int_stack+719424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1079356,int_stack+142688,int_stack+140504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+714804,int_stack+1079356,int_stack+731184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1288144,int_stack+714804,int_stack+736728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+661380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+714804,int_stack+1288144,int_stack+1260424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1288144,int_stack+714804,int_stack+1273024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+683220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+714804,int_stack+1288144,int_stack+1062892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+698340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1260424,int_stack+714804,int_stack+1046428,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1309816,int_stack+1260424,int_stack+747129,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1046428,int_stack+146244,int_stack+145236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1049452,int_stack+147540,int_stack+146244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1053340,int_stack+1049452,int_stack+1046428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1059388,int_stack+149160,int_stack+147540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1064248,int_stack+1059388,int_stack+1049452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1072024,int_stack+1064248,int_stack+1053340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1046428,int_stack+151140,int_stack+149160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+736756,int_stack+1046428,int_stack+1059388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+746476,int_stack+736756,int_stack+1064248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1052368,int_stack+746476,int_stack+1072024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1067488,int_stack+153516,int_stack+151140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1074616,int_stack+1067488,int_stack+1046428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+759436,int_stack+1074616,int_stack+736756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1380376,int_stack+759436,int_stack+746476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+736756,int_stack+1380376,int_stack+1052368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1046428,int_stack+156324,int_stack+153516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+94020,int_stack+1046428,int_stack+1067488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1046428,int_stack+94020,int_stack+1074616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+94020,int_stack+1046428,int_stack+759436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1046428,int_stack+94020,int_stack+1380376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+907036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+757924,int_stack+1046428,int_stack+736756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+926476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1502644,int_stack+757924,int_stack+714804,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1568500,int_stack+1502644,int_stack+1260424,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260424,int_stack+160020,int_stack+159600, 0.0, zero_stack, 1.0, int_stack+330288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1261684,int_stack+160560,int_stack+160020, 0.0, zero_stack, 1.0, int_stack+330708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1263304,int_stack+1261684,int_stack+1260424, 0.0, zero_stack, 1.0, int_stack+395724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1265824,int_stack+161235,int_stack+160560, 0.0, zero_stack, 1.0, int_stack+331248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1267849,int_stack+1265824,int_stack+1261684, 0.0, zero_stack, 1.0, int_stack+396984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1271089,int_stack+1267849,int_stack+1263304, 0.0, zero_stack, 1.0, int_stack+398604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260424,int_stack+162060,int_stack+161235, 0.0, zero_stack, 1.0, int_stack+331923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1275289,int_stack+1260424,int_stack+1265824, 0.0, zero_stack, 1.0, int_stack+401124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1279339,int_stack+1275289,int_stack+1267849, 0.0, zero_stack, 1.0, int_stack+403149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1262899,int_stack+1279339,int_stack+1271089, 0.0, zero_stack, 1.0, int_stack+406389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1269199,int_stack+163050,int_stack+162060, 0.0, zero_stack, 1.0, int_stack+332748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1284739,int_stack+1269199,int_stack+1260424, 0.0, zero_stack, 1.0, int_stack+410589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1289689,int_stack+1284739,int_stack+1275289, 0.0, zero_stack, 1.0, int_stack+413064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1296439,int_stack+1289689,int_stack+1279339, 0.0, zero_stack, 1.0, int_stack+417114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1272169,int_stack+1296439,int_stack+1262899, 0.0, zero_stack, 1.0, int_stack+422514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+164220,int_stack+163050, 0.0, zero_stack, 1.0, int_stack+333738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1502644,int_stack+1260424,int_stack+1269199, 0.0, zero_stack, 1.0, int_stack+428814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1260424,int_stack+1502644,int_stack+1284739, 0.0, zero_stack, 1.0, int_stack+431784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1502644,int_stack+1260424,int_stack+1289689, 0.0, zero_stack, 1.0, int_stack+436734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+1502644,int_stack+1296439, 0.0, zero_stack, 1.0, int_stack+443484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1502644,int_stack+1260424,int_stack+1272169, 0.0, zero_stack, 1.0, int_stack+451584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260424,int_stack+166173,int_stack+165585, 0.0, zero_stack, 1.0, int_stack+342258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1262188,int_stack+166929,int_stack+166173, 0.0, zero_stack, 1.0, int_stack+342846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1264456,int_stack+1262188,int_stack+1260424, 0.0, zero_stack, 1.0, int_stack+460404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1267984,int_stack+167874,int_stack+166929, 0.0, zero_stack, 1.0, int_stack+343602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1270819,int_stack+1267984,int_stack+1262188, 0.0, zero_stack, 1.0, int_stack+462168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1275355,int_stack+1270819,int_stack+1264456, 0.0, zero_stack, 1.0, int_stack+464436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260424,int_stack+169029,int_stack+167874, 0.0, zero_stack, 1.0, int_stack+344547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1281235,int_stack+1260424,int_stack+1267984, 0.0, zero_stack, 1.0, int_stack+467964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1286905,int_stack+1281235,int_stack+1270819, 0.0, zero_stack, 1.0, int_stack+470799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1263889,int_stack+1286905,int_stack+1275355, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1272709,int_stack+170415,int_stack+169029, 0.0, zero_stack, 1.0, int_stack+345702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1294465,int_stack+1272709,int_stack+1260424, 0.0, zero_stack, 1.0, int_stack+475335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1514404,int_stack+1294465,int_stack+1281235, 0.0, zero_stack, 1.0, int_stack+492729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1523854,int_stack+1514404,int_stack+1286905, 0.0, zero_stack, 1.0, int_stack+498399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1276867,int_stack+1523854,int_stack+1263889, 0.0, zero_stack, 1.0, int_stack+505959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+172053,int_stack+170415, 0.0, zero_stack, 1.0, int_stack+347088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1301395,int_stack+1260424,int_stack+1272709, 0.0, zero_stack, 1.0, int_stack+514779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1260424,int_stack+1301395,int_stack+1294465, 0.0, zero_stack, 1.0, int_stack+518937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1289215,int_stack+1260424,int_stack+1514404, 0.0, zero_stack, 1.0, int_stack+525867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+1289215,int_stack+1523854, 0.0, zero_stack, 1.0, int_stack+535317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1289215,int_stack+1260424,int_stack+1276867, 0.0, zero_stack, 1.0, int_stack+546657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1514404,int_stack+1289215,int_stack+1502644,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1502644,int_stack+174748,int_stack+173964, 0.0, zero_stack, 1.0, int_stack+359016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1504996,int_stack+175756,int_stack+174748, 0.0, zero_stack, 1.0, int_stack+359800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1508020,int_stack+1504996,int_stack+1502644, 0.0, zero_stack, 1.0, int_stack+559005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1260424,int_stack+177016,int_stack+175756, 0.0, zero_stack, 1.0, int_stack+360808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1264204,int_stack+1260424,int_stack+1504996, 0.0, zero_stack, 1.0, int_stack+561357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1270252,int_stack+1264204,int_stack+1508020, 0.0, zero_stack, 1.0, int_stack+564381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1502644,int_stack+178556,int_stack+177016, 0.0, zero_stack, 1.0, int_stack+362068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1278092,int_stack+1502644,int_stack+1260424, 0.0, zero_stack, 1.0, int_stack+569085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1549684,int_stack+1278092,int_stack+1264204, 0.0, zero_stack, 1.0, int_stack+572865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+714804,int_stack+1549684,int_stack+1270252, 0.0, zero_stack, 1.0, int_stack+578913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1260424,int_stack+180404,int_stack+178556, 0.0, zero_stack, 1.0, int_stack+363608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1265968,int_stack+1260424,int_stack+1502644, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+726564,int_stack+1265968,int_stack+1278092, 0.0, zero_stack, 1.0, int_stack+478800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+739164,int_stack+726564,int_stack+1549684, 0.0, zero_stack, 1.0, int_stack+639540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1549684,int_stack+739164,int_stack+714804, 0.0, zero_stack, 1.0, int_stack+649620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+182588,int_stack+180404, 0.0, zero_stack, 1.0, int_stack+365456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1502644,int_stack+714804,int_stack+1260424, 0.0, zero_stack, 1.0, int_stack+486360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+754284,int_stack+1502644,int_stack+1265968, 0.0, zero_stack, 1.0, int_stack+661380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1260424,int_stack+754284,int_stack+726564, 0.0, zero_stack, 1.0, int_stack+670620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+754284,int_stack+1260424,int_stack+739164, 0.0, zero_stack, 1.0, int_stack+683220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1260424,int_stack+754284,int_stack+1549684, 0.0, zero_stack, 1.0, int_stack+698340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+714804,int_stack+1260424,int_stack+1289215,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+94020,int_stack+714804,int_stack+1514404,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1282376,int_stack+186144,int_stack+185136, 0.0, zero_stack, 1.0, int_stack+225036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1285400,int_stack+187440,int_stack+186144, 0.0, zero_stack, 1.0, int_stack+227052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1289288,int_stack+1285400,int_stack+1282376, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1295336,int_stack+189060,int_stack+187440, 0.0, zero_stack, 1.0, int_stack+229644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1300196,int_stack+1295336,int_stack+1285400, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1502644,int_stack+1300196,int_stack+1289288, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1282376,int_stack+191040,int_stack+189060, 0.0, zero_stack, 1.0, int_stack+232884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1512724,int_stack+1282376,int_stack+1295336, 0.0, zero_stack, 1.0, int_stack+586753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1522444,int_stack+1512724,int_stack+1300196, 0.0, zero_stack, 1.0, int_stack+591613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1288316,int_stack+1522444,int_stack+1502644, 0.0, zero_stack, 1.0, int_stack+599389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1502644,int_stack+193416,int_stack+191040, 0.0, zero_stack, 1.0, int_stack+236844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1535404,int_stack+1502644,int_stack+1282376, 0.0, zero_stack, 1.0, int_stack+609469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1547284,int_stack+1535404,int_stack+1512724, 0.0, zero_stack, 1.0, int_stack+615409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+764196,int_stack+1547284,int_stack+1522444, 0.0, zero_stack, 1.0, int_stack+625129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1509772,int_stack+764196,int_stack+1288316, 0.0, zero_stack, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1282376,int_stack+196224,int_stack+193416, 0.0, zero_stack, 1.0, int_stack+241596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1290800,int_stack+1282376,int_stack+1502644, 0.0, zero_stack, 1.0, int_stack+871828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1046428,int_stack+1290800,int_stack+1535404, 0.0, zero_stack, 1.0, int_stack+878956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1282376,int_stack+1046428,int_stack+1547284, 0.0, zero_stack, 1.0, int_stack+890836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1046428,int_stack+1282376,int_stack+764196, 0.0, zero_stack, 1.0, int_stack+907036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1530940,int_stack+1046428,int_stack+1509772, 0.0, zero_stack, 1.0, int_stack+926476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1667284,int_stack+1530940,int_stack+1260424,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1733140,int_stack+1667284,int_stack+714804,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+199920,int_stack+199500, 1.0, int_stack+330288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716064,int_stack+200460,int_stack+199920, 1.0, int_stack+330708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+717684,int_stack+716064,int_stack+714804, 1.0, int_stack+395724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+720204,int_stack+201135,int_stack+200460, 1.0, int_stack+331248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+722229,int_stack+720204,int_stack+716064, 1.0, int_stack+396984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725469,int_stack+722229,int_stack+717684, 1.0, int_stack+398604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+395724,int_stack+201960,int_stack+201135, 1.0, int_stack+331923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+714804,int_stack+395724,int_stack+720204, 1.0, int_stack+401124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+729669,int_stack+714804,int_stack+722229, 1.0, int_stack+403149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+398199,int_stack+729669,int_stack+725469, 1.0, int_stack+406389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+404499,int_stack+202950,int_stack+201960, 1.0, int_stack+332748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+718854,int_stack+404499,int_stack+395724, 1.0, int_stack+410589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+735069,int_stack+718854,int_stack+714804, 1.0, int_stack+413064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+407469,int_stack+735069,int_stack+729669, 1.0, int_stack+417114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+723804,int_stack+407469,int_stack+398199, 1.0, int_stack+422514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+204120,int_stack+202950, 1.0, int_stack+333738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+395724,int_stack+714804,int_stack+404499, 1.0, int_stack+428814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+415569,int_stack+395724,int_stack+718854, 1.0, int_stack+431784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+395724,int_stack+415569,int_stack+735069, 1.0, int_stack+436734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+415569,int_stack+395724,int_stack+407469, 1.0, int_stack+443484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+395724,int_stack+415569,int_stack+723804, 1.0, int_stack+451584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+407484,int_stack+206073,int_stack+205485, 1.0, int_stack+342258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+409248,int_stack+206829,int_stack+206073, 1.0, int_stack+342846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+411516,int_stack+409248,int_stack+407484, 1.0, int_stack+460404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+415044,int_stack+207774,int_stack+206829, 1.0, int_stack+343602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+417879,int_stack+415044,int_stack+409248, 1.0, int_stack+462168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+422415,int_stack+417879,int_stack+411516, 1.0, int_stack+464436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+460404,int_stack+208929,int_stack+207774, 1.0, int_stack+344547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+407484,int_stack+460404,int_stack+415044, 1.0, int_stack+467964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+714804,int_stack+407484,int_stack+417879, 1.0, int_stack+470799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+463869,int_stack+714804,int_stack+422415, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+210315,int_stack+208929, 1.0, int_stack+345702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+413154,int_stack+0,int_stack+460404, 1.0, int_stack+475335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+722364,int_stack+413154,int_stack+407484, 1.0, int_stack+492729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+731814,int_stack+722364,int_stack+714804, 1.0, int_stack+498399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+743154,int_stack+731814,int_stack+463869, 1.0, int_stack+505959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+714804,int_stack+211953,int_stack+210315, 1.0, int_stack+347088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+460404,int_stack+714804,int_stack+0, 1.0, int_stack+514779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+755502,int_stack+460404,int_stack+413154, 1.0, int_stack+518937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+460404,int_stack+755502,int_stack+722364, 1.0, int_stack+525867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+755502,int_stack+460404,int_stack+731814, 1.0, int_stack+535317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+460404,int_stack+755502,int_stack+743154, 1.0, int_stack+546657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+714804,int_stack+460404,int_stack+395724,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+395724,int_stack+214648,int_stack+213864, 1.0, int_stack+359016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+398076,int_stack+215656,int_stack+214648, 1.0, int_stack+359800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+401100,int_stack+398076,int_stack+395724, 1.0, int_stack+559005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+405804,int_stack+216916,int_stack+215656, 1.0, int_stack+360808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+409584,int_stack+405804,int_stack+398076, 1.0, int_stack+561357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+415632,int_stack+409584,int_stack+401100, 1.0, int_stack+564381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+559005,int_stack+218456,int_stack+216916, 1.0, int_stack+362068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+395724,int_stack+559005,int_stack+405804, 1.0, int_stack+569085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+750084,int_stack+395724,int_stack+409584, 1.0, int_stack+572865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+563625,int_stack+750084,int_stack+415632, 1.0, int_stack+578913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+575385,int_stack+220304,int_stack+218456, 1.0, int_stack+363608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+403284,int_stack+575385,int_stack+559005, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+412524,int_stack+403284,int_stack+395724, 1.0, int_stack+478800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+760164,int_stack+412524,int_stack+750084, 1.0, int_stack+639540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1667284,int_stack+760164,int_stack+563625, 1.0, int_stack+649620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+750084,int_stack+222488,int_stack+220304, 1.0, int_stack+365456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+559005,int_stack+750084,int_stack+575385, 1.0, int_stack+486360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+570093,int_stack+559005,int_stack+403284, 1.0, int_stack+661380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1683748,int_stack+570093,int_stack+412524, 1.0, int_stack+670620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+559005,int_stack+1683748,int_stack+760164, 1.0, int_stack+683220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1683748,int_stack+559005,int_stack+1667284, 1.0, int_stack+698340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1260424,int_stack+1683748,int_stack+460404,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1831924,int_stack+1260424,int_stack+714804,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+714804,int_stack+228348,int_stack+226044, 1.0, int_stack+225036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+717828,int_stack+231264,int_stack+228348, 1.0, int_stack+227052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+721716,int_stack+717828,int_stack+714804, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+727764,int_stack+234864,int_stack+231264, 1.0, int_stack+229644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+732624,int_stack+727764,int_stack+717828, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+740400,int_stack+732624,int_stack+721716, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714804,int_stack+239220,int_stack+234864, 1.0, int_stack+232884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+750480,int_stack+714804,int_stack+727764, 1.0, int_stack+586753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+760200,int_stack+750480,int_stack+732624, 1.0, int_stack+591613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+720744,int_stack+760200,int_stack+740400, 1.0, int_stack+599389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+735864,int_stack+244404,int_stack+239220, 1.0, int_stack+236844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+773160,int_stack+735864,int_stack+714804, 1.0, int_stack+609469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+460404,int_stack+773160,int_stack+750480, 1.0, int_stack+615409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+559005,int_stack+460404,int_stack+760200, 1.0, int_stack+625129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+742992,int_stack+559005,int_stack+720744, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+856708,int_stack+247212,int_stack+244404, 1.0, int_stack+241596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+714804,int_stack+856708,int_stack+735864, 1.0, int_stack+871828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+856708,int_stack+714804,int_stack+773160, 1.0, int_stack+878956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+714804,int_stack+856708,int_stack+460404, 1.0, int_stack+890836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+856708,int_stack+714804,int_stack+559005, 1.0, int_stack+907036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+559005,int_stack+856708,int_stack+742992, 1.0, int_stack+926476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1502644,int_stack+559005,int_stack+1683748,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+559005,int_stack+1502644,int_stack+1260424,784);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+334908,int_stack+333738,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1263934,int_stack+1260424,int_stack+428814,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1269874,int_stack+1263934,int_stack+431784,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1278124,int_stack+1269874,int_stack+436734,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+1278124,int_stack+443484,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1271764,int_stack+1260424,int_stack+451584,15);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+348726,int_stack+347088,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1283524,int_stack+1260424,int_stack+514779,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1291840,int_stack+1283524,int_stack+518937,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1502644,int_stack+1291840,int_stack+525867,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1283524,int_stack+1502644,int_stack+535317,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1502644,int_stack+1283524,int_stack+546657,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1519108,int_stack+1502644,int_stack+1271764,784);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1283524,int_stack+367640,int_stack+365456,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1290076,int_stack+1283524,int_stack+486360,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+856708,int_stack+1290076,int_stack+661380,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1283524,int_stack+856708,int_stack+670620,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+856708,int_stack+1283524,int_stack+683220,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1283524,int_stack+856708,int_stack+698340,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+856708,int_stack+1283524,int_stack+1502644,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+657789,int_stack+856708,int_stack+1519108,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+906100,int_stack+250908,int_stack+250488,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+907360,int_stack+251448,int_stack+250908,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+908980,int_stack+907360,int_stack+906100,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+911500,int_stack+252123,int_stack+251448,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+913525,int_stack+911500,int_stack+907360,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+916765,int_stack+913525,int_stack+908980,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+906100,int_stack+252948,int_stack+252123,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+920965,int_stack+906100,int_stack+911500,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+925015,int_stack+920965,int_stack+913525,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+908575,int_stack+925015,int_stack+916765,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+914875,int_stack+253938,int_stack+252948,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+930415,int_stack+914875,int_stack+906100,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+935365,int_stack+930415,int_stack+920965,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1554388,int_stack+935365,int_stack+925015,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+917845,int_stack+1554388,int_stack+908575,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+906100,int_stack+255108,int_stack+253938,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1562488,int_stack+906100,int_stack+914875,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+906100,int_stack+1562488,int_stack+930415,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1260424,int_stack+906100,int_stack+935365,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+906100,int_stack+1260424,int_stack+1554388,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1554388,int_stack+906100,int_stack+917845,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+906100,int_stack+257061,int_stack+256473,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+907864,int_stack+257817,int_stack+257061,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+910132,int_stack+907864,int_stack+906100,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+913660,int_stack+258762,int_stack+257817,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+916495,int_stack+913660,int_stack+907864,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+921031,int_stack+916495,int_stack+910132,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+906100,int_stack+259917,int_stack+258762,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+926911,int_stack+906100,int_stack+913660,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+932581,int_stack+926911,int_stack+916495,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+909565,int_stack+932581,int_stack+921031,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+918385,int_stack+261303,int_stack+259917,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+940141,int_stack+918385,int_stack+906100,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1260424,int_stack+940141,int_stack+926911,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+728349,int_stack+1260424,int_stack+932581,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+922543,int_stack+728349,int_stack+909565,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+906100,int_stack+262941,int_stack+261303,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+739689,int_stack+906100,int_stack+918385,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+906100,int_stack+739689,int_stack+940141,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+739689,int_stack+906100,int_stack+1260424,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+906100,int_stack+739689,int_stack+728349,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+728349,int_stack+906100,int_stack+922543,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+906100,int_stack+728349,int_stack+1554388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1554388,int_stack+265636,int_stack+264852,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1556740,int_stack+266644,int_stack+265636,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1559764,int_stack+1556740,int_stack+1554388,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1564468,int_stack+267904,int_stack+266644,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+941380,int_stack+1564468,int_stack+1556740,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+744813,int_stack+941380,int_stack+1559764,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1554388,int_stack+269444,int_stack+267904,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+752653,int_stack+1554388,int_stack+1564468,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+760213,int_stack+752653,int_stack+941380,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+770293,int_stack+760213,int_stack+744813,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+744813,int_stack+271292,int_stack+269444,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1559008,int_stack+744813,int_stack+1554388,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1667284,int_stack+1559008,int_stack+752653,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1679884,int_stack+1667284,int_stack+760213,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+750357,int_stack+1679884,int_stack+770293,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+766821,int_stack+273476,int_stack+271292,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+773373,int_stack+766821,int_stack+744813,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1695004,int_stack+773373,int_stack+1559008,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+766821,int_stack+1695004,int_stack+1667284,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1695004,int_stack+766821,int_stack+1679884,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1667284,int_stack+1695004,int_stack+750357,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+395724,int_stack+1667284,int_stack+728349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1502644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+445116,int_stack+395724,int_stack+906100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1519108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+906100,int_stack+277032,int_stack+276024,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+909124,int_stack+278328,int_stack+277032,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+913012,int_stack+909124,int_stack+906100,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+919060,int_stack+279948,int_stack+278328,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+923920,int_stack+919060,int_stack+909124,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+931696,int_stack+923920,int_stack+913012,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+906100,int_stack+281928,int_stack+279948,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+728349,int_stack+906100,int_stack+919060,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+738069,int_stack+728349,int_stack+923920,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+912040,int_stack+738069,int_stack+931696,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+927160,int_stack+284304,int_stack+281928,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+934288,int_stack+927160,int_stack+906100,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+751029,int_stack+934288,int_stack+728349,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1689236,int_stack+751029,int_stack+738069,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+728349,int_stack+1689236,int_stack+912040,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+906100,int_stack+287112,int_stack+284304,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+767229,int_stack+906100,int_stack+927160,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+906100,int_stack+767229,int_stack+934288,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1708676,int_stack+906100,int_stack+751029,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+906100,int_stack+1708676,int_stack+1689236,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1689236,int_stack+906100,int_stack+728349,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+164580,int_stack+1689236,int_stack+1667284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hd|ii) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1902484,int_stack+164580,int_stack+395724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+395724,int_stack+290808,int_stack+290388,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+396984,int_stack+291348,int_stack+290808,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+398604,int_stack+396984,int_stack+395724,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+401124,int_stack+292023,int_stack+291348,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+403149,int_stack+401124,int_stack+396984,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+406389,int_stack+403149,int_stack+398604,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+395724,int_stack+292848,int_stack+292023,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+410589,int_stack+395724,int_stack+401124,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+414639,int_stack+410589,int_stack+403149,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+398199,int_stack+414639,int_stack+406389,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+404499,int_stack+293838,int_stack+292848,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+420039,int_stack+404499,int_stack+395724,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+424989,int_stack+420039,int_stack+410589,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+431739,int_stack+424989,int_stack+414639,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+407469,int_stack+431739,int_stack+398199,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+395724,int_stack+295008,int_stack+293838,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+164580,int_stack+395724,int_stack+404499,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+395724,int_stack+164580,int_stack+420039,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+164580,int_stack+395724,int_stack+424989,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+164580,int_stack+431739,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+164580,int_stack+1260424,int_stack+407469,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1260424,int_stack+296961,int_stack+296373,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1262188,int_stack+297717,int_stack+296961,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1264456,int_stack+1262188,int_stack+1260424,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1267984,int_stack+298662,int_stack+297717,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+176340,int_stack+1267984,int_stack+1262188,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+180876,int_stack+176340,int_stack+1264456,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1260424,int_stack+299817,int_stack+298662,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+186756,int_stack+1260424,int_stack+1267984,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1263889,int_stack+186756,int_stack+176340,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+192426,int_stack+1263889,int_stack+180876,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+176340,int_stack+301203,int_stack+299817,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+201246,int_stack+176340,int_stack+1260424,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+208176,int_stack+201246,int_stack+186756,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+180498,int_stack+208176,int_stack+1263889,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+217626,int_stack+180498,int_stack+192426,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+302841,int_stack+301203,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+191838,int_stack+1260424,int_stack+176340,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+229974,int_stack+191838,int_stack+201246,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+191838,int_stack+229974,int_stack+208176,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+229974,int_stack+191838,int_stack+180498,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+245850,int_stack+229974,int_stack+217626,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+262314,int_stack+245850,int_stack+164580, 0.0, zero_stack, 1.0, int_stack+1271764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+164580,int_stack+305536,int_stack+304752,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+166932,int_stack+306544,int_stack+305536,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+169956,int_stack+166932,int_stack+164580,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+174660,int_stack+307804,int_stack+306544,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+178440,int_stack+174660,int_stack+166932,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+184488,int_stack+178440,int_stack+169956,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+164580,int_stack+309344,int_stack+307804,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+192328,int_stack+164580,int_stack+174660,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+199888,int_stack+192328,int_stack+178440,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+169200,int_stack+199888,int_stack+184488,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+180960,int_stack+311192,int_stack+309344,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+209968,int_stack+180960,int_stack+164580,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+219208,int_stack+209968,int_stack+192328,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+395724,int_stack+219208,int_stack+199888,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+186504,int_stack+395724,int_stack+169200,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+164580,int_stack+313376,int_stack+311192,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+231808,int_stack+164580,int_stack+180960,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+164580,int_stack+231808,int_stack+209968,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+410844,int_stack+164580,int_stack+219208,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+164580,int_stack+410844,int_stack+395724,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+395724,int_stack+164580,int_stack+186504,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+164580,int_stack+395724,int_stack+245850, 0.0, zero_stack, 1.0, int_stack+1502644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2001268,int_stack+164580,int_stack+262314, 0.0, zero_stack, 1.0, int_stack+1519108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+213972,int_stack+316932,int_stack+315924,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+216996,int_stack+318228,int_stack+316932,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+220884,int_stack+216996,int_stack+213972,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+226932,int_stack+319848,int_stack+318228,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+231792,int_stack+226932,int_stack+216996,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+239568,int_stack+231792,int_stack+220884,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+213972,int_stack+321828,int_stack+319848,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+249648,int_stack+213972,int_stack+226932,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+259368,int_stack+249648,int_stack+231792,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+219912,int_stack+259368,int_stack+239568,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+235032,int_stack+324204,int_stack+321828,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+272328,int_stack+235032,int_stack+213972,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+284208,int_stack+272328,int_stack+249648,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+300408,int_stack+284208,int_stack+259368,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+242160,int_stack+300408,int_stack+219912,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+213972,int_stack+327012,int_stack+324204,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+319848,int_stack+213972,int_stack+235032,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+213972,int_stack+319848,int_stack+272328,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+417676,int_stack+213972,int_stack+284208,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+213972,int_stack+417676,int_stack+300408,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+263328,int_stack+213972,int_stack+242160,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1667284,int_stack+263328,int_stack+395724, 0.0, zero_stack, 1.0, int_stack+1283524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hd|ii) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+213972,int_stack+1667284,int_stack+164580, 0.0, zero_stack, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+164580,int_stack+336693,int_stack+336273,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+165840,int_stack+337233,int_stack+336693,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+167460,int_stack+165840,int_stack+164580,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+169980,int_stack+337908,int_stack+337233,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+172005,int_stack+169980,int_stack+165840,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+175245,int_stack+172005,int_stack+167460,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+164580,int_stack+338733,int_stack+337908,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+179445,int_stack+164580,int_stack+169980,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+183495,int_stack+179445,int_stack+172005,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+167055,int_stack+183495,int_stack+175245,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+173355,int_stack+339723,int_stack+338733,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+188895,int_stack+173355,int_stack+164580,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+193845,int_stack+188895,int_stack+179445,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+200595,int_stack+193845,int_stack+183495,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+176325,int_stack+200595,int_stack+167055,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+164580,int_stack+340893,int_stack+339723,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1667284,int_stack+164580,int_stack+173355,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+164580,int_stack+1667284,int_stack+188895,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1667284,int_stack+164580,int_stack+193845,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+1667284,int_stack+200595,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1667284,int_stack+1260424,int_stack+176325,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1260424,int_stack+351225,int_stack+350637,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1262188,int_stack+351981,int_stack+351225,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1264456,int_stack+1262188,int_stack+1260424,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1267984,int_stack+352926,int_stack+351981,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1679044,int_stack+1267984,int_stack+1262188,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1683580,int_stack+1679044,int_stack+1264456,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1260424,int_stack+354081,int_stack+352926,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1689460,int_stack+1260424,int_stack+1267984,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1263889,int_stack+1689460,int_stack+1679044,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1695130,int_stack+1263889,int_stack+1683580,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1679044,int_stack+355467,int_stack+354081,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1703950,int_stack+1679044,int_stack+1260424,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1710880,int_stack+1703950,int_stack+1689460,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1683202,int_stack+1710880,int_stack+1263889,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1720330,int_stack+1683202,int_stack+1695130,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1260424,int_stack+357105,int_stack+355467,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1694542,int_stack+1260424,int_stack+1679044,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+164580,int_stack+1694542,int_stack+1703950,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1694542,int_stack+164580,int_stack+1710880,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+164580,int_stack+1694542,int_stack+1683202,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+180456,int_stack+164580,int_stack+1720330,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1679044,int_stack+180456,int_stack+1667284, 1.0, int_stack+1271764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1667284,int_stack+370972,int_stack+370188,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1669636,int_stack+371980,int_stack+370972,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1672660,int_stack+1669636,int_stack+1667284,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+164580,int_stack+373240,int_stack+371980,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+168360,int_stack+164580,int_stack+1669636,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+196920,int_stack+168360,int_stack+1672660,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1667284,int_stack+374780,int_stack+373240,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+204760,int_stack+1667284,int_stack+164580,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1714324,int_stack+204760,int_stack+168360,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+164580,int_stack+1714324,int_stack+196920,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+196920,int_stack+376628,int_stack+374780,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1260424,int_stack+196920,int_stack+1667284,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1269664,int_stack+1260424,int_stack+204760,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+395724,int_stack+1269664,int_stack+1714324,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1714324,int_stack+395724,int_stack+164580,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+164580,int_stack+378812,int_stack+376628,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1667284,int_stack+164580,int_stack+196920,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+196920,int_stack+1667284,int_stack+1260424,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+410844,int_stack+196920,int_stack+1269664,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1260424,int_stack+410844,int_stack+395724,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+395724,int_stack+1260424,int_stack+1714324,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+312756,int_stack+395724,int_stack+180456, 1.0, int_stack+1502644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2071828,int_stack+312756,int_stack+1679044, 1.0, int_stack+1519108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1502644,int_stack+382368,int_stack+381360,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1505668,int_stack+383664,int_stack+382368,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1509556,int_stack+1505668,int_stack+1502644,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1515604,int_stack+385284,int_stack+383664,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1520464,int_stack+1515604,int_stack+1505668,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1528240,int_stack+1520464,int_stack+1509556,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1502644,int_stack+387264,int_stack+385284,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1538320,int_stack+1502644,int_stack+1515604,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1548040,int_stack+1538320,int_stack+1520464,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1508584,int_stack+1548040,int_stack+1528240,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1523704,int_stack+389640,int_stack+387264,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1260424,int_stack+1523704,int_stack+1502644,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+417676,int_stack+1260424,int_stack+1538320,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1667284,int_stack+417676,int_stack+1548040,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1530832,int_stack+1667284,int_stack+1508584,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1502644,int_stack+392448,int_stack+389640,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1552000,int_stack+1502644,int_stack+1523704,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1502644,int_stack+1552000,int_stack+1260424,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1686724,int_stack+1502644,int_stack+417676,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+417676,int_stack+1686724,int_stack+1667284,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1667284,int_stack+417676,int_stack+1530832,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1502644,int_stack+1667284,int_stack+395724, 1.0, int_stack+1283524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hd|ii) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2142388,int_stack+1502644,int_stack+312756, 1.0, int_stack+856708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+312756,int_stack+1091080,int_stack+786148,784);
     Libderiv->ABCD[11] = int_stack + 312756;
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+728349,int_stack+947644,int_stack+1189864,784);
     Libderiv->ABCD[10] = int_stack + 728349;
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+845949,int_stack+1403860,int_stack+23460,784);
     Libderiv->ABCD[9] = int_stack + 845949;
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+963549,int_stack+1568500,int_stack+1309816,784);
     Libderiv->ABCD[8] = int_stack + 963549;
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1081149,int_stack+1733140,int_stack+94020,784);
     Libderiv->ABCD[7] = int_stack + 1081149;
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1198749,int_stack+559005,int_stack+1831924,784);
     Libderiv->ABCD[6] = int_stack + 1198749;
 /*--- compute (gf|ii) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1316349,int_stack+1902484,int_stack+445116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[2] = int_stack + 1316349;
 /*--- compute (gf|ii) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+430356,int_stack+213972,int_stack+2001268, 0.0, zero_stack, 1.0, int_stack+657789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[1] = int_stack + 430356;
 /*--- compute (gf|ii) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1433949,int_stack+2142388,int_stack+2071828, 1.0, int_stack+657789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[0] = int_stack + 1433949;

}
