/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hh|ii) integrals */

void d1vrr_order_hhii(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+0, dvrr_stack+3, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+0);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+52, dvrr_stack+49, dvrr_stack+12, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+58, dvrr_stack+52, dvrr_stack+15, dvrr_stack+49, dvrr_stack+12, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+71, dvrr_stack+3, dvrr_stack+68, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+77, dvrr_stack+6, dvrr_stack+71, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+87, dvrr_stack+39, dvrr_stack+77, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+117, dvrr_stack+58, dvrr_stack+39, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+147, dvrr_stack+117, dvrr_stack+87, dvrr_stack+58, dvrr_stack+39, dvrr_stack+21);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+39, dvrr_stack+77, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+58, dvrr_stack+39, dvrr_stack+52, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+237, dvrr_stack+222, dvrr_stack+207, NULL, NULL, dvrr_stack+39);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+282, dvrr_stack+49, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+291, dvrr_stack+285, dvrr_stack+52, dvrr_stack+282, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+301, dvrr_stack+291, dvrr_stack+58, dvrr_stack+285, dvrr_stack+52, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+316, dvrr_stack+301, dvrr_stack+222, NULL, NULL, dvrr_stack+58);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+68, dvrr_stack+49, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+71, dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+377, dvrr_stack+77, dvrr_stack+367, dvrr_stack+6, dvrr_stack+71, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+392, dvrr_stack+207, dvrr_stack+377, NULL, NULL, dvrr_stack+77);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+437, dvrr_stack+237, dvrr_stack+392, dvrr_stack+222, dvrr_stack+207, dvrr_stack+87);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+527, dvrr_stack+316, dvrr_stack+237, dvrr_stack+301, dvrr_stack+222, dvrr_stack+117);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+617, dvrr_stack+527, dvrr_stack+437, dvrr_stack+316, dvrr_stack+237, dvrr_stack+147);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+767, dvrr_stack+222, dvrr_stack+207, dvrr_stack+58, dvrr_stack+39, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+788, dvrr_stack+301, dvrr_stack+222, dvrr_stack+291, dvrr_stack+58, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+809, dvrr_stack+207, dvrr_stack+377, dvrr_stack+39, dvrr_stack+77, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+830, dvrr_stack+767, dvrr_stack+809, NULL, NULL, dvrr_stack+207);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+893, dvrr_stack+788, dvrr_stack+767, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+956, dvrr_stack+893, dvrr_stack+830, dvrr_stack+788, dvrr_stack+767, dvrr_stack+237);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1082, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1085, dvrr_stack+1082, dvrr_stack+282, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1091, dvrr_stack+1085, dvrr_stack+285, dvrr_stack+1082, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1101, dvrr_stack+1091, dvrr_stack+291, dvrr_stack+1085, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1116, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+1091, dvrr_stack+291, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1137, dvrr_stack+1116, dvrr_stack+788, NULL, NULL, dvrr_stack+301);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1200, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+316);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+49, dvrr_stack+282, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+361, dvrr_stack+285, dvrr_stack+68, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+71, dvrr_stack+361, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1351, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+77, dvrr_stack+367, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1372, dvrr_stack+809, dvrr_stack+1351, NULL, NULL, dvrr_stack+377);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1435, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+767, dvrr_stack+809, dvrr_stack+392);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1561, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+893, dvrr_stack+830, dvrr_stack+437);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1771, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+527);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+1981, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+617);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+809, dvrr_stack+222, dvrr_stack+207, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2324, dvrr_stack+788, dvrr_stack+767, dvrr_stack+301, dvrr_stack+222, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2352, dvrr_stack+2324, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2436, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+1101, dvrr_stack+301, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2464, dvrr_stack+2436, dvrr_stack+2324, NULL, NULL, dvrr_stack+788);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2548, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+207, dvrr_stack+377, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2576, dvrr_stack+2296, dvrr_stack+2548, NULL, NULL, dvrr_stack+809);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2660, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+830);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2828, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+893);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2996, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+956);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+893, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+896, dvrr_stack+893, dvrr_stack+1082, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+902, dvrr_stack+896, dvrr_stack+1085, dvrr_stack+893, dvrr_stack+1082, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+902, dvrr_stack+1091, dvrr_stack+896, dvrr_stack+1085, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+912, dvrr_stack+222, dvrr_stack+1101, dvrr_stack+902, dvrr_stack+1091, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+222, dvrr_stack+1101, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3304, dvrr_stack+3276, dvrr_stack+2436, NULL, NULL, dvrr_stack+1116);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3388, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+1137);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+3556, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+1200);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3304, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3307, dvrr_stack+282, dvrr_stack+3304, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3313, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+49, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+361, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+367, dvrr_stack+1326, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3344, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+377, dvrr_stack+1336, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3836, dvrr_stack+2548, dvrr_stack+3344, NULL, NULL, dvrr_stack+1351);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3920, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+1372);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4088, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+1435);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4368, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+1561);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4788, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+1771);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+5208, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+1981);
 tmp = dvrr_stack + 5208;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+767, dvrr_stack+809, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3408, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+788, dvrr_stack+767, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+3408, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3552, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+1116, dvrr_stack+788, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3588, dvrr_stack+3552, dvrr_stack+3408, NULL, NULL, dvrr_stack+2324);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+809, dvrr_stack+1351, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3696, dvrr_stack+3372, dvrr_stack+767, NULL, NULL, dvrr_stack+2548);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2576);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6012, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2352);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6228, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+2660);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2352, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+912, dvrr_stack+1116, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+2352, dvrr_stack+3552, NULL, NULL, dvrr_stack+2436);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+2464);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6912, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2828);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+803, dvrr_stack+3304, dvrr_stack+2828, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2831, dvrr_stack+3307, dvrr_stack+803, dvrr_stack+282, dvrr_stack+3304, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2841, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+285, dvrr_stack+3307, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+1326, dvrr_stack+3313, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+222, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+1351, dvrr_stack+3323, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+767, dvrr_stack+2905, NULL, NULL, dvrr_stack+3344);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+3836);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7488, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3920);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7848, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+4088);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8388, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+2996);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8928, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+4368);
 tmp = dvrr_stack + 8928;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+9684,dvrr_stack+8928,dvrr_stack+5208,21);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+2296, dvrr_stack+2548, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6741, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2324, dvrr_stack+2296, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+6741, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6921, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2436, dvrr_stack+2324, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6966, dvrr_stack+6921, dvrr_stack+6741, NULL, NULL, dvrr_stack+3408);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+2548, dvrr_stack+3344, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7101, dvrr_stack+6696, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3696);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11718, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3444);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11988, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+5796);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+3276, dvrr_stack+2436, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+3444, dvrr_stack+6921, NULL, NULL, dvrr_stack+3552);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+3588);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12708, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+6012);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6012, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6015, dvrr_stack+2828, dvrr_stack+6012, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6021, dvrr_stack+803, dvrr_stack+6015, dvrr_stack+3304, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6031, dvrr_stack+2831, dvrr_stack+6021, dvrr_stack+3307, dvrr_stack+803, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6046, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+3313, dvrr_stack+2831, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+222, dvrr_stack+2841, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7236, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+2856, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+3344, dvrr_stack+2877, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+2296, dvrr_stack+6067, NULL, NULL, dvrr_stack+2905);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13158, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+6588);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13428, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+7272);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13878, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+7488);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14553, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+6228);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15228, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+7848);
 tmp = dvrr_stack + 15228;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+16173,dvrr_stack+15228,dvrr_stack+8928,21);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+3372, dvrr_stack+767, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3408, dvrr_stack+3372, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+6696);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12658, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3552, dvrr_stack+3408, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12713, dvrr_stack+12658, dvrr_stack+12438, NULL, NULL, dvrr_stack+6741);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12878, dvrr_stack+2941, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+7101);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18771, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6786);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+11448);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+2352, dvrr_stack+3552, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+6786, dvrr_stack+12658, NULL, NULL, dvrr_stack+6921);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+6966);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+11718);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+11718, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+11721, dvrr_stack+6012, dvrr_stack+11718, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+11727, dvrr_stack+6015, dvrr_stack+11721, dvrr_stack+2828, dvrr_stack+6012, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+11737, dvrr_stack+6021, dvrr_stack+11727, dvrr_stack+803, dvrr_stack+6015, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+11752, dvrr_stack+6031, dvrr_stack+11737, dvrr_stack+2831, dvrr_stack+6021, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11773, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+2841, dvrr_stack+6031, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+2856, dvrr_stack+6046, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11837, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+3276, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+2905, dvrr_stack+7236, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+3372, dvrr_stack+11882, NULL, NULL, dvrr_stack+6067);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20531, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+2388);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20861, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+13158);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21411, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+13428);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22236, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+11988);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23061, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+13878);
 tmp = dvrr_stack + 23061;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+24216,dvrr_stack+23061,dvrr_stack+15228,21);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+6696, dvrr_stack+2296, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19717, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+6741, dvrr_stack+6696, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+19717, dvrr_stack+19651, NULL, NULL, dvrr_stack+2941);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6921, dvrr_stack+6741, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20047, dvrr_stack+19981, dvrr_stack+19717, NULL, NULL, dvrr_stack+12438);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+2296, dvrr_stack+6067, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20245, dvrr_stack+19651, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12878);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27447, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12493);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27843, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+18441);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+3444, dvrr_stack+6921, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+12493, dvrr_stack+19981, NULL, NULL, dvrr_stack+12658);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+12713);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28899, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+18771);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+18771, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18774, dvrr_stack+11718, dvrr_stack+18771, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18780, dvrr_stack+11721, dvrr_stack+18774, dvrr_stack+6012, dvrr_stack+11718, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18790, dvrr_stack+11727, dvrr_stack+18780, dvrr_stack+6015, dvrr_stack+11721, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18805, dvrr_stack+11737, dvrr_stack+18790, dvrr_stack+6021, dvrr_stack+11727, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+18826, dvrr_stack+11752, dvrr_stack+18805, dvrr_stack+6031, dvrr_stack+11737, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18854, dvrr_stack+11773, dvrr_stack+18826, dvrr_stack+6046, dvrr_stack+11752, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18890, dvrr_stack+11801, dvrr_stack+18854, dvrr_stack+3276, dvrr_stack+11773, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18935, dvrr_stack+11837, dvrr_stack+18890, dvrr_stack+7236, dvrr_stack+11801, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18990, dvrr_stack+11882, dvrr_stack+18935, dvrr_stack+6067, dvrr_stack+11837, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+6696, dvrr_stack+18990, NULL, NULL, dvrr_stack+11882);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29559, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+3489);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29955, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+20531);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30615, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20861);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31605, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+19101);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32595, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+21411);
 tmp = dvrr_stack + 32595;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+33981,dvrr_stack+32595,dvrr_stack+23061,21);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+2941, dvrr_stack+3372, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28581, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+28581, dvrr_stack+28503, NULL, NULL, dvrr_stack+19651);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28893, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12658, dvrr_stack+12438, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28971, dvrr_stack+28893, dvrr_stack+28581, NULL, NULL, dvrr_stack+19717);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29205, dvrr_stack+6696, dvrr_stack+18990, dvrr_stack+3372, dvrr_stack+11882, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29283, dvrr_stack+28503, dvrr_stack+29205, NULL, NULL, dvrr_stack+6696);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+28659, dvrr_stack+29283, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+20245);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37914, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19783);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38382, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+27051);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+6786, dvrr_stack+12658, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12559, dvrr_stack+19783, dvrr_stack+28893, NULL, NULL, dvrr_stack+19981);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+12559, dvrr_stack+28971, dvrr_stack+19783, dvrr_stack+28893, dvrr_stack+20047);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39630, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+12559, dvrr_stack+28971, dvrr_stack+27447);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6012, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+27447, dvrr_stack+18771, dvrr_stack+6012, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+27453, dvrr_stack+18774, dvrr_stack+27447, dvrr_stack+11718, dvrr_stack+18771, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+27463, dvrr_stack+18780, dvrr_stack+27453, dvrr_stack+11721, dvrr_stack+18774, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+27478, dvrr_stack+18790, dvrr_stack+27463, dvrr_stack+11727, dvrr_stack+18780, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+27499, dvrr_stack+18805, dvrr_stack+27478, dvrr_stack+11737, dvrr_stack+18790, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27527, dvrr_stack+18826, dvrr_stack+27499, dvrr_stack+11752, dvrr_stack+18805, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19056, dvrr_stack+18854, dvrr_stack+27527, dvrr_stack+11773, dvrr_stack+18826, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+18890, dvrr_stack+19056, dvrr_stack+11801, dvrr_stack+18854, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27563, dvrr_stack+18935, dvrr_stack+12438, dvrr_stack+11837, dvrr_stack+18890, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27629, dvrr_stack+18990, dvrr_stack+27563, dvrr_stack+11882, dvrr_stack+18935, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12559, dvrr_stack+29205, dvrr_stack+27629, NULL, NULL, dvrr_stack+18990);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40410, dvrr_stack+29283, dvrr_stack+12559, dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+6841);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40878, dvrr_stack+37446, dvrr_stack+40410, dvrr_stack+28659, dvrr_stack+29283, dvrr_stack+29559);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+41658, dvrr_stack+38382, dvrr_stack+40878, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+29955);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42828, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+27843);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43998, dvrr_stack+42828, dvrr_stack+41658, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+30615);
 tmp = dvrr_stack + 43998;
 target_ptr = Libderiv->dvrr_classes[5][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+45636,dvrr_stack+43998,dvrr_stack+32595,21);


 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+19651, dvrr_stack+6696, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39253, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+19717, dvrr_stack+19651, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39344, dvrr_stack+39253, dvrr_stack+39162, NULL, NULL, dvrr_stack+28503);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39617, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19981, dvrr_stack+19717, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39708, dvrr_stack+39617, dvrr_stack+39253, NULL, NULL, dvrr_stack+28581);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+29205, dvrr_stack+27629, dvrr_stack+6696, dvrr_stack+18990, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39981, dvrr_stack+39162, dvrr_stack+19651, NULL, NULL, dvrr_stack+29205);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+39344, dvrr_stack+39981, dvrr_stack+39253, dvrr_stack+39162, dvrr_stack+29283);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50340, dvrr_stack+39708, dvrr_stack+39344, dvrr_stack+39617, dvrr_stack+39253, dvrr_stack+28659);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50886, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+39708, dvrr_stack+39344, dvrr_stack+37446);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+19783, dvrr_stack+28893, dvrr_stack+12493, dvrr_stack+19981, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19861, dvrr_stack+28659, dvrr_stack+39617, NULL, NULL, dvrr_stack+28893);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51796, dvrr_stack+19861, dvrr_stack+39708, dvrr_stack+28659, dvrr_stack+39617, dvrr_stack+28971);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+52342, dvrr_stack+51796, dvrr_stack+50340, dvrr_stack+19861, dvrr_stack+39708, dvrr_stack+37914);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+37914, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+37917, dvrr_stack+6012, dvrr_stack+37914, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+37923, dvrr_stack+27447, dvrr_stack+37917, dvrr_stack+18771, dvrr_stack+6012, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+37933, dvrr_stack+27453, dvrr_stack+37923, dvrr_stack+18774, dvrr_stack+27447, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+37948, dvrr_stack+27463, dvrr_stack+37933, dvrr_stack+18780, dvrr_stack+27453, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+37969, dvrr_stack+27478, dvrr_stack+37948, dvrr_stack+18790, dvrr_stack+27463, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37997, dvrr_stack+27499, dvrr_stack+37969, dvrr_stack+18805, dvrr_stack+27478, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38033, dvrr_stack+27527, dvrr_stack+37997, dvrr_stack+18826, dvrr_stack+27499, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+19056, dvrr_stack+38033, dvrr_stack+18854, dvrr_stack+27527, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+18890, dvrr_stack+19056, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38078, dvrr_stack+27563, dvrr_stack+12493, dvrr_stack+18935, dvrr_stack+12438, NULL);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+38156, dvrr_stack+27629, dvrr_stack+38078, dvrr_stack+18990, dvrr_stack+27563, NULL);

 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19861, dvrr_stack+19651, dvrr_stack+38156, NULL, NULL, dvrr_stack+27629);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+53252, dvrr_stack+39981, dvrr_stack+19861, dvrr_stack+39162, dvrr_stack+19651, dvrr_stack+12559);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+53798, dvrr_stack+49794, dvrr_stack+53252, dvrr_stack+39344, dvrr_stack+39981, dvrr_stack+40410);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+54708, dvrr_stack+50886, dvrr_stack+53798, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+40878);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+56073, dvrr_stack+52342, dvrr_stack+50886, dvrr_stack+51796, dvrr_stack+50340, dvrr_stack+38382);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57438, dvrr_stack+56073, dvrr_stack+54708, dvrr_stack+52342, dvrr_stack+50886, dvrr_stack+41658);
 tmp = dvrr_stack + 57438;
 target_ptr = Libderiv->dvrr_classes[5][12];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+59349,dvrr_stack+57438,dvrr_stack+43998,21);


 /* compute (0 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51796, dvrr_stack+39162, dvrr_stack+19651, dvrr_stack+28503, dvrr_stack+29205, NULL);

 /* compute (0 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51901, dvrr_stack+39253, dvrr_stack+39162, dvrr_stack+28581, dvrr_stack+28503, NULL);

 /* compute (1 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52006, dvrr_stack+51901, dvrr_stack+51796, NULL, NULL, dvrr_stack+39162);

 /* compute (0 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52321, dvrr_stack+39617, dvrr_stack+39253, dvrr_stack+28893, dvrr_stack+28581, NULL);

 /* compute (1 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52426, dvrr_stack+52321, dvrr_stack+51901, NULL, NULL, dvrr_stack+39253);

 /* compute (0 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+19651, dvrr_stack+38156, dvrr_stack+29205, dvrr_stack+27629, NULL);

 /* compute (1 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52741, dvrr_stack+51796, dvrr_stack+39162, NULL, NULL, dvrr_stack+19651);

 /* compute (2 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+52006, dvrr_stack+52741, dvrr_stack+51901, dvrr_stack+51796, dvrr_stack+39981);

 /* compute (2 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64893, dvrr_stack+52426, dvrr_stack+52006, dvrr_stack+52321, dvrr_stack+51901, dvrr_stack+39344);

 /* compute (3 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+65523, dvrr_stack+64893, dvrr_stack+64263, dvrr_stack+52426, dvrr_stack+52006, dvrr_stack+49794);

 /* compute (0 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51901, dvrr_stack+28659, dvrr_stack+39617, dvrr_stack+19783, dvrr_stack+28893, NULL);

 /* compute (1 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39267, dvrr_stack+51901, dvrr_stack+52321, NULL, NULL, dvrr_stack+39617);

 /* compute (2 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+39267, dvrr_stack+52426, dvrr_stack+51901, dvrr_stack+52321, dvrr_stack+39708);

 /* compute (3 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+66573, dvrr_stack+28503, dvrr_stack+64893, dvrr_stack+39267, dvrr_stack+52426, dvrr_stack+50340);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+50340, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50343, dvrr_stack+37914, dvrr_stack+50340, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+50349, dvrr_stack+37917, dvrr_stack+50343, dvrr_stack+6012, dvrr_stack+37914, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50359, dvrr_stack+37923, dvrr_stack+50349, dvrr_stack+27447, dvrr_stack+37917, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+50374, dvrr_stack+37933, dvrr_stack+50359, dvrr_stack+27453, dvrr_stack+37923, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+50395, dvrr_stack+37948, dvrr_stack+50374, dvrr_stack+27463, dvrr_stack+37933, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+50423, dvrr_stack+37969, dvrr_stack+50395, dvrr_stack+27478, dvrr_stack+37948, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+50459, dvrr_stack+37997, dvrr_stack+50423, dvrr_stack+27499, dvrr_stack+37969, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+50504, dvrr_stack+38033, dvrr_stack+50459, dvrr_stack+27527, dvrr_stack+37997, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50559, dvrr_stack+2941, dvrr_stack+50504, dvrr_stack+19056, dvrr_stack+38033, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50625, dvrr_stack+12493, dvrr_stack+50559, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50703, dvrr_stack+38078, dvrr_stack+50625, dvrr_stack+27563, dvrr_stack+12493, NULL);

 /* compute (0 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51901, dvrr_stack+38156, dvrr_stack+50703, dvrr_stack+27629, dvrr_stack+38078, NULL);

 /* compute (1 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39267, dvrr_stack+39162, dvrr_stack+51901, NULL, NULL, dvrr_stack+38156);

 /* compute (2 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+67623, dvrr_stack+52741, dvrr_stack+39267, dvrr_stack+51796, dvrr_stack+39162, dvrr_stack+19861);

 /* compute (3 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+68253, dvrr_stack+64263, dvrr_stack+67623, dvrr_stack+52006, dvrr_stack+52741, dvrr_stack+53252);

 /* compute (4 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+69303, dvrr_stack+65523, dvrr_stack+68253, dvrr_stack+64893, dvrr_stack+64263, dvrr_stack+53798);

 /* compute (4 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+70878, dvrr_stack+66573, dvrr_stack+65523, dvrr_stack+28503, dvrr_stack+64893, dvrr_stack+50886);

 /* compute (5 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+72453, dvrr_stack+70878, dvrr_stack+69303, dvrr_stack+66573, dvrr_stack+65523, dvrr_stack+54708);

 /* compute (5 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+74658,dvrr_stack+72453,dvrr_stack+57438,21);


 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+11718, dvrr_stack+0, dvrr_stack+3, NULL, NULL, Data->F+6);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+66573, dvrr_stack+6, dvrr_stack+71, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+66591, dvrr_stack+21, dvrr_stack+66573, dvrr_stack+15, dvrr_stack+6, dvrr_stack+11718);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+66627, dvrr_stack+77, dvrr_stack+367, NULL, NULL, dvrr_stack+71);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+66657, dvrr_stack+87, dvrr_stack+66627, dvrr_stack+39, dvrr_stack+77, dvrr_stack+66573);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+66717, dvrr_stack+147, dvrr_stack+66657, dvrr_stack+117, dvrr_stack+87, dvrr_stack+66591);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+66817, dvrr_stack+377, dvrr_stack+1336, NULL, NULL, dvrr_stack+367);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+66862, dvrr_stack+392, dvrr_stack+66817, dvrr_stack+207, dvrr_stack+377, dvrr_stack+66627);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+66952, dvrr_stack+437, dvrr_stack+66862, dvrr_stack+237, dvrr_stack+392, dvrr_stack+66657);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+67102, dvrr_stack+617, dvrr_stack+66952, dvrr_stack+527, dvrr_stack+437, dvrr_stack+66717);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+67327, dvrr_stack+1351, dvrr_stack+3323, NULL, NULL, dvrr_stack+1336);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+67390, dvrr_stack+1372, dvrr_stack+67327, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+66817);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+64893, dvrr_stack+1435, dvrr_stack+67390, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+66862);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+65103, dvrr_stack+1561, dvrr_stack+64893, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+66952);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+28503, dvrr_stack+1981, dvrr_stack+65103, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+67102);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+809, dvrr_stack+3344, dvrr_stack+2877, NULL, NULL, dvrr_stack+3323);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+67327);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+52006, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+67390);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+52286, dvrr_stack+4088, dvrr_stack+52006, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+64893);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+80391, dvrr_stack+4368, dvrr_stack+52286, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+65103);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+80979, dvrr_stack+5208, dvrr_stack+80391, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+28503);
 tmp = dvrr_stack + 80979;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2996, dvrr_stack+2905, dvrr_stack+7236, NULL, NULL, dvrr_stack+2877);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28944, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+809);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39582, dvrr_stack+7272, dvrr_stack+28944, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+81763, dvrr_stack+7488, dvrr_stack+39582, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+52006);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+82303, dvrr_stack+7848, dvrr_stack+81763, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+52286);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+83059, dvrr_stack+8928, dvrr_stack+82303, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+80391);
 tmp = dvrr_stack + 83059;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+84067,dvrr_stack+83059,dvrr_stack+80979,28);


 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38247, dvrr_stack+6067, dvrr_stack+11837, NULL, NULL, dvrr_stack+7236);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+2388, dvrr_stack+38247, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+2996);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86419, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+28944);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86869, dvrr_stack+13428, dvrr_stack+86419, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+39582);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+87544, dvrr_stack+13878, dvrr_stack+86869, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+81763);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+88489, dvrr_stack+15228, dvrr_stack+87544, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+82303);
 tmp = dvrr_stack + 88489;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+89749,dvrr_stack+88489,dvrr_stack+83059,28);


 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+11882, dvrr_stack+18935, NULL, NULL, dvrr_stack+11837);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+38247);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+92773, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+6112);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+93323, dvrr_stack+20861, dvrr_stack+92773, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+86419);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+94148, dvrr_stack+21411, dvrr_stack+93323, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+86869);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+95303, dvrr_stack+23061, dvrr_stack+94148, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+87544);
 tmp = dvrr_stack + 95303;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+96843,dvrr_stack+95303,dvrr_stack+88489,28);


 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+18990, dvrr_stack+27563, NULL, NULL, dvrr_stack+18935);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+100623, dvrr_stack+6841, dvrr_stack+19101, dvrr_stack+6696, dvrr_stack+18990, dvrr_stack+11448);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+101019, dvrr_stack+29559, dvrr_stack+100623, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+11937);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+101679, dvrr_stack+29955, dvrr_stack+101019, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+92773);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+102669, dvrr_stack+30615, dvrr_stack+101679, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+93323);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+104055, dvrr_stack+32595, dvrr_stack+102669, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+94148);
 tmp = dvrr_stack + 104055;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+105903,dvrr_stack+104055,dvrr_stack+95303,28);


 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+27629, dvrr_stack+38078, NULL, NULL, dvrr_stack+27563);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27707, dvrr_stack+12559, dvrr_stack+27051, dvrr_stack+29205, dvrr_stack+27629, dvrr_stack+19101);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+110523, dvrr_stack+40410, dvrr_stack+27707, dvrr_stack+29283, dvrr_stack+12559, dvrr_stack+100623);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+111303, dvrr_stack+40878, dvrr_stack+110523, dvrr_stack+37446, dvrr_stack+40410, dvrr_stack+101019);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+112473, dvrr_stack+41658, dvrr_stack+111303, dvrr_stack+38382, dvrr_stack+40878, dvrr_stack+101679);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+114111, dvrr_stack+43998, dvrr_stack+112473, dvrr_stack+42828, dvrr_stack+41658, dvrr_stack+102669);
 tmp = dvrr_stack + 114111;
 target_ptr = Libderiv->dvrr_classes[6][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+116295,dvrr_stack+114111,dvrr_stack+104055,28);


 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+38382, dvrr_stack+38156, dvrr_stack+50703, NULL, NULL, dvrr_stack+38078);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+121839, dvrr_stack+19861, dvrr_stack+38382, dvrr_stack+19651, dvrr_stack+38156, dvrr_stack+27051);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+122385, dvrr_stack+53252, dvrr_stack+121839, dvrr_stack+39981, dvrr_stack+19861, dvrr_stack+27707);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+123295, dvrr_stack+53798, dvrr_stack+122385, dvrr_stack+49794, dvrr_stack+53252, dvrr_stack+110523);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+124660, dvrr_stack+54708, dvrr_stack+123295, dvrr_stack+50886, dvrr_stack+53798, dvrr_stack+111303);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+126571, dvrr_stack+57438, dvrr_stack+124660, dvrr_stack+56073, dvrr_stack+54708, dvrr_stack+112473);
 tmp = dvrr_stack + 126571;
 target_ptr = Libderiv->dvrr_classes[6][12];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+129119,dvrr_stack+126571,dvrr_stack+114111,28);


 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49794, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+49797, dvrr_stack+50340, dvrr_stack+49794, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+50343, dvrr_stack+49797, dvrr_stack+37914, dvrr_stack+50340, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+50349, dvrr_stack+39, dvrr_stack+37917, dvrr_stack+50343, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+49803, dvrr_stack+50359, dvrr_stack+207, dvrr_stack+37923, dvrr_stack+50349, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+49824, dvrr_stack+50374, dvrr_stack+49803, dvrr_stack+37933, dvrr_stack+50359, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+50395, dvrr_stack+49824, dvrr_stack+37948, dvrr_stack+50374, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+237, dvrr_stack+50423, dvrr_stack+767, dvrr_stack+37969, dvrr_stack+50395, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+49852, dvrr_stack+50459, dvrr_stack+237, dvrr_stack+37997, dvrr_stack+50423, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49907, dvrr_stack+50504, dvrr_stack+49852, dvrr_stack+38033, dvrr_stack+50459, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49973, dvrr_stack+50559, dvrr_stack+49907, dvrr_stack+2941, dvrr_stack+50504, NULL);

 /* compute (0 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50051, dvrr_stack+50625, dvrr_stack+49973, dvrr_stack+12493, dvrr_stack+50559, NULL);

 /* compute (0 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+11613, dvrr_stack+50703, dvrr_stack+50051, dvrr_stack+38078, dvrr_stack+50625, NULL);

 /* compute (1 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+38655, dvrr_stack+51901, dvrr_stack+11613, NULL, NULL, dvrr_stack+50703);

 /* compute (2 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+50794, dvrr_stack+39267, dvrr_stack+38655, dvrr_stack+39162, dvrr_stack+51901, dvrr_stack+38382);

 /* compute (3 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+135671, dvrr_stack+67623, dvrr_stack+50794, dvrr_stack+52741, dvrr_stack+39267, dvrr_stack+121839);

 /* compute (4 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+136721, dvrr_stack+68253, dvrr_stack+135671, dvrr_stack+64263, dvrr_stack+67623, dvrr_stack+122385);

 /* compute (5 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+138296, dvrr_stack+69303, dvrr_stack+136721, dvrr_stack+65523, dvrr_stack+68253, dvrr_stack+123295);

 /* compute (6 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+140501, dvrr_stack+72453, dvrr_stack+138296, dvrr_stack+70878, dvrr_stack+69303, dvrr_stack+124660);

 /* compute (6 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+143441,dvrr_stack+140501,dvrr_stack+126571,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+70878, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+70881, dvrr_stack+3, dvrr_stack+68, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+70890, dvrr_stack+11718, dvrr_stack+70881, dvrr_stack+0, dvrr_stack+3, dvrr_stack+70878);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+70908, dvrr_stack+71, dvrr_stack+361, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+70926, dvrr_stack+66573, dvrr_stack+70908, dvrr_stack+6, dvrr_stack+71, dvrr_stack+70881);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+70962, dvrr_stack+66591, dvrr_stack+70926, dvrr_stack+21, dvrr_stack+66573, dvrr_stack+70890);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71022, dvrr_stack+367, dvrr_stack+1326, NULL, NULL, dvrr_stack+361);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+71052, dvrr_stack+66627, dvrr_stack+71022, dvrr_stack+77, dvrr_stack+367, dvrr_stack+70908);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+71112, dvrr_stack+66657, dvrr_stack+71052, dvrr_stack+87, dvrr_stack+66627, dvrr_stack+70926);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+71212, dvrr_stack+66717, dvrr_stack+71112, dvrr_stack+147, dvrr_stack+66657, dvrr_stack+70962);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+71362, dvrr_stack+1336, dvrr_stack+222, NULL, NULL, dvrr_stack+1326);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+71407, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+71022);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+71497, dvrr_stack+66862, dvrr_stack+71407, dvrr_stack+392, dvrr_stack+66817, dvrr_stack+71052);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+71647, dvrr_stack+66952, dvrr_stack+71497, dvrr_stack+437, dvrr_stack+66862, dvrr_stack+71112);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+71872, dvrr_stack+67102, dvrr_stack+71647, dvrr_stack+617, dvrr_stack+66952, dvrr_stack+71212);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+377, dvrr_stack+3323, dvrr_stack+2856, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+72187, dvrr_stack+67327, dvrr_stack+377, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+71362);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+64263, dvrr_stack+67390, dvrr_stack+72187, dvrr_stack+1372, dvrr_stack+67327, dvrr_stack+71407);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+64473, dvrr_stack+64893, dvrr_stack+64263, dvrr_stack+1435, dvrr_stack+67390, dvrr_stack+71497);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+37446, dvrr_stack+65103, dvrr_stack+64473, dvrr_stack+1561, dvrr_stack+64893, dvrr_stack+71647);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+65418, dvrr_stack+28503, dvrr_stack+37446, dvrr_stack+1981, dvrr_stack+65103, dvrr_stack+71872);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1351, dvrr_stack+2877, dvrr_stack+3276, NULL, NULL, dvrr_stack+2856);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1435, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+377);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+38970, dvrr_stack+933, dvrr_stack+1435, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+72187);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+19299, dvrr_stack+52006, dvrr_stack+38970, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+64263);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+151085, dvrr_stack+52286, dvrr_stack+19299, dvrr_stack+4088, dvrr_stack+52006, dvrr_stack+64473);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+151673, dvrr_stack+80391, dvrr_stack+151085, dvrr_stack+4368, dvrr_stack+52286, dvrr_stack+37446);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+3654, dvrr_stack+80979, dvrr_stack+151673, dvrr_stack+5208, dvrr_stack+80391, dvrr_stack+65418);
 tmp = dvrr_stack + 3654;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3344, dvrr_stack+7236, dvrr_stack+11801, NULL, NULL, dvrr_stack+3276);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+1351);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66006, dvrr_stack+28944, dvrr_stack+18441, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+1435);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+52706, dvrr_stack+39582, dvrr_stack+66006, dvrr_stack+7272, dvrr_stack+28944, dvrr_stack+38970);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+152457, dvrr_stack+81763, dvrr_stack+52706, dvrr_stack+7488, dvrr_stack+39582, dvrr_stack+19299);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+153213, dvrr_stack+82303, dvrr_stack+152457, dvrr_stack+7848, dvrr_stack+81763, dvrr_stack+151085);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+154221, dvrr_stack+83059, dvrr_stack+153213, dvrr_stack+8928, dvrr_stack+82303, dvrr_stack+151673);
 tmp = dvrr_stack + 154221;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+155517,dvrr_stack+154221,dvrr_stack+3654,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+11837, dvrr_stack+18890, NULL, NULL, dvrr_stack+11801);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7407, dvrr_stack+38247, dvrr_stack+7272, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+3344);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7677, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+2388, dvrr_stack+38247, dvrr_stack+18441);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+158541, dvrr_stack+86419, dvrr_stack+7677, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+66006);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+159216, dvrr_stack+86869, dvrr_stack+158541, dvrr_stack+13428, dvrr_stack+86419, dvrr_stack+52706);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+160161, dvrr_stack+87544, dvrr_stack+159216, dvrr_stack+13878, dvrr_stack+86869, dvrr_stack+152457);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12793, dvrr_stack+88489, dvrr_stack+160161, dvrr_stack+15228, dvrr_stack+87544, dvrr_stack+153213);
 tmp = dvrr_stack + 12793;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+161421,dvrr_stack+12793,dvrr_stack+154221,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8127, dvrr_stack+18935, dvrr_stack+12438, NULL, NULL, dvrr_stack+18890);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+11448, dvrr_stack+8127, dvrr_stack+11882, dvrr_stack+18935, dvrr_stack+7272);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+165309, dvrr_stack+11937, dvrr_stack+2296, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+7407);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+165859, dvrr_stack+92773, dvrr_stack+165309, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+7677);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+166684, dvrr_stack+93323, dvrr_stack+165859, dvrr_stack+20861, dvrr_stack+92773, dvrr_stack+158541);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+167839, dvrr_stack+94148, dvrr_stack+166684, dvrr_stack+21411, dvrr_stack+93323, dvrr_stack+159216);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20134, dvrr_stack+95303, dvrr_stack+167839, dvrr_stack+23061, dvrr_stack+94148, dvrr_stack+160161);
 tmp = dvrr_stack + 20134;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+169379,dvrr_stack+20134,dvrr_stack+12793,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50142, dvrr_stack+27563, dvrr_stack+12493, NULL, NULL, dvrr_stack+12438);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29160, dvrr_stack+19101, dvrr_stack+50142, dvrr_stack+18990, dvrr_stack+27563, dvrr_stack+8127);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+174239, dvrr_stack+100623, dvrr_stack+29160, dvrr_stack+6841, dvrr_stack+19101, dvrr_stack+2296);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+174899, dvrr_stack+101019, dvrr_stack+174239, dvrr_stack+29559, dvrr_stack+100623, dvrr_stack+165309);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+175889, dvrr_stack+101679, dvrr_stack+174899, dvrr_stack+29955, dvrr_stack+101019, dvrr_stack+165859);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+177275, dvrr_stack+102669, dvrr_stack+175889, dvrr_stack+30615, dvrr_stack+101679, dvrr_stack+166684);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+179123, dvrr_stack+104055, dvrr_stack+177275, dvrr_stack+32595, dvrr_stack+102669, dvrr_stack+167839);
 tmp = dvrr_stack + 179123;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+181499,dvrr_stack+179123,dvrr_stack+20134,36);


 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29556, dvrr_stack+38078, dvrr_stack+50625, NULL, NULL, dvrr_stack+12493);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39942, dvrr_stack+27051, dvrr_stack+29556, dvrr_stack+27629, dvrr_stack+38078, dvrr_stack+50142);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29790, dvrr_stack+27707, dvrr_stack+39942, dvrr_stack+12559, dvrr_stack+27051, dvrr_stack+29160);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+187439, dvrr_stack+110523, dvrr_stack+29790, dvrr_stack+40410, dvrr_stack+27707, dvrr_stack+174239);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+188609, dvrr_stack+111303, dvrr_stack+187439, dvrr_stack+40878, dvrr_stack+110523, dvrr_stack+174899);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+190247, dvrr_stack+112473, dvrr_stack+188609, dvrr_stack+41658, dvrr_stack+111303, dvrr_stack+175889);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+192431, dvrr_stack+114111, dvrr_stack+190247, dvrr_stack+43998, dvrr_stack+112473, dvrr_stack+177275);
 tmp = dvrr_stack + 192431;
 target_ptr = Libderiv->dvrr_classes[7][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+195239,dvrr_stack+192431,dvrr_stack+179123,36);


 /* compute (1 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+40410, dvrr_stack+50703, dvrr_stack+50051, NULL, NULL, dvrr_stack+50625);

 /* compute (2 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+40683, dvrr_stack+38382, dvrr_stack+40410, dvrr_stack+38156, dvrr_stack+50703, dvrr_stack+29556);

 /* compute (3 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+41229, dvrr_stack+121839, dvrr_stack+40683, dvrr_stack+19861, dvrr_stack+38382, dvrr_stack+39942);

 /* compute (4 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+202367, dvrr_stack+122385, dvrr_stack+41229, dvrr_stack+53252, dvrr_stack+121839, dvrr_stack+29790);

 /* compute (5 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+203732, dvrr_stack+123295, dvrr_stack+202367, dvrr_stack+53798, dvrr_stack+122385, dvrr_stack+187439);

 /* compute (6 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+205643, dvrr_stack+124660, dvrr_stack+203732, dvrr_stack+54708, dvrr_stack+123295, dvrr_stack+188609);

 /* compute (7 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+208191, dvrr_stack+126571, dvrr_stack+205643, dvrr_stack+57438, dvrr_stack+124660, dvrr_stack+190247);
 tmp = dvrr_stack + 208191;
 target_ptr = Libderiv->dvrr_classes[7][12];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+211467,dvrr_stack+208191,dvrr_stack+192431,36);


 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+38156, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+49794, dvrr_stack+38156, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+38159, dvrr_stack+49797, dvrr_stack+6, dvrr_stack+50340, dvrr_stack+49794, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+38169, dvrr_stack+39, dvrr_stack+38159, dvrr_stack+50343, dvrr_stack+49797, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+38184, dvrr_stack+207, dvrr_stack+38169, dvrr_stack+50349, dvrr_stack+39, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+38205, dvrr_stack+49803, dvrr_stack+38184, dvrr_stack+50359, dvrr_stack+207, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+49824, dvrr_stack+38205, dvrr_stack+50374, dvrr_stack+49803, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+50395, dvrr_stack+49824, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+237, dvrr_stack+6067, dvrr_stack+50423, dvrr_stack+767, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18990, dvrr_stack+49852, dvrr_stack+11882, dvrr_stack+50459, dvrr_stack+237, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27629, dvrr_stack+49907, dvrr_stack+18990, dvrr_stack+50504, dvrr_stack+49852, NULL);

 /* compute (0 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+42139, dvrr_stack+49973, dvrr_stack+27629, dvrr_stack+50559, dvrr_stack+49907, NULL);

 /* compute (0 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64788, dvrr_stack+50051, dvrr_stack+42139, dvrr_stack+50625, dvrr_stack+49973, NULL);

 /* compute (1 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+42230, dvrr_stack+11613, dvrr_stack+64788, NULL, NULL, dvrr_stack+50051);

 /* compute (2 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+30570, dvrr_stack+38655, dvrr_stack+42230, dvrr_stack+51901, dvrr_stack+11613, dvrr_stack+40410);

 /* compute (3 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+53246, dvrr_stack+50794, dvrr_stack+30570, dvrr_stack+39267, dvrr_stack+38655, dvrr_stack+40683);

 /* compute (4 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+54296, dvrr_stack+135671, dvrr_stack+53246, dvrr_stack+67623, dvrr_stack+50794, dvrr_stack+41229);

 /* compute (5 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+219891, dvrr_stack+136721, dvrr_stack+54296, dvrr_stack+68253, dvrr_stack+135671, dvrr_stack+202367);

 /* compute (6 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+222096, dvrr_stack+138296, dvrr_stack+219891, dvrr_stack+69303, dvrr_stack+136721, dvrr_stack+203732);

 /* compute (7 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+225036, dvrr_stack+140501, dvrr_stack+222096, dvrr_stack+72453, dvrr_stack+138296, dvrr_stack+205643);

 /* compute (7 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+228816,dvrr_stack+225036,dvrr_stack+208191,36);


 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+50340, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+50343, dvrr_stack+70878, dvrr_stack+50340, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+50349, dvrr_stack+68, dvrr_stack+49, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+50358, dvrr_stack+70881, dvrr_stack+50349, dvrr_stack+3, dvrr_stack+68, dvrr_stack+50340);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+50376, dvrr_stack+70890, dvrr_stack+50358, dvrr_stack+11718, dvrr_stack+70881, dvrr_stack+50343);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+42545, dvrr_stack+361, dvrr_stack+285, NULL, NULL, dvrr_stack+49);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+42563, dvrr_stack+70908, dvrr_stack+42545, dvrr_stack+71, dvrr_stack+361, dvrr_stack+50349);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+42599, dvrr_stack+70926, dvrr_stack+42563, dvrr_stack+66573, dvrr_stack+70908, dvrr_stack+50358);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+42659, dvrr_stack+70962, dvrr_stack+42599, dvrr_stack+66591, dvrr_stack+70926, dvrr_stack+50376);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71, dvrr_stack+1326, dvrr_stack+3313, NULL, NULL, dvrr_stack+285);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+42749, dvrr_stack+71022, dvrr_stack+71, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+42545);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+12559, dvrr_stack+71052, dvrr_stack+42749, dvrr_stack+66627, dvrr_stack+71022, dvrr_stack+42563);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+3452, dvrr_stack+71112, dvrr_stack+12559, dvrr_stack+66657, dvrr_stack+71052, dvrr_stack+42599);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+39250, dvrr_stack+71212, dvrr_stack+3452, dvrr_stack+66717, dvrr_stack+71112, dvrr_stack+42659);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+66627, dvrr_stack+222, dvrr_stack+2841, NULL, NULL, dvrr_stack+3313);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+12659, dvrr_stack+71362, dvrr_stack+66627, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+71);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1603, dvrr_stack+71407, dvrr_stack+12659, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+42749);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+66366, dvrr_stack+71497, dvrr_stack+1603, dvrr_stack+66862, dvrr_stack+71407, dvrr_stack+12559);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+19719, dvrr_stack+71647, dvrr_stack+66366, dvrr_stack+66952, dvrr_stack+71497, dvrr_stack+3452);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+67516, dvrr_stack+71872, dvrr_stack+19719, dvrr_stack+67102, dvrr_stack+71647, dvrr_stack+39250);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+66817, dvrr_stack+2856, dvrr_stack+6046, NULL, NULL, dvrr_stack+2841);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+377, dvrr_stack+66817, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+66627);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+66880, dvrr_stack+72187, dvrr_stack+4662, dvrr_stack+67327, dvrr_stack+377, dvrr_stack+12659);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+67936, dvrr_stack+64263, dvrr_stack+66880, dvrr_stack+67390, dvrr_stack+72187, dvrr_stack+1603);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+68251, dvrr_stack+64473, dvrr_stack+67936, dvrr_stack+64893, dvrr_stack+64263, dvrr_stack+66366);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+68692, dvrr_stack+37446, dvrr_stack+68251, dvrr_stack+65103, dvrr_stack+64473, dvrr_stack+19719);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+69280, dvrr_stack+65418, dvrr_stack+68692, dvrr_stack+28503, dvrr_stack+37446, dvrr_stack+67516);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+64893, dvrr_stack+3276, dvrr_stack+11773, NULL, NULL, dvrr_stack+6046);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+64977, dvrr_stack+1351, dvrr_stack+64893, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+66817);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+70036, dvrr_stack+1435, dvrr_stack+64977, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+4662);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+70316, dvrr_stack+38970, dvrr_stack+70036, dvrr_stack+933, dvrr_stack+1435, dvrr_stack+66880);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+6382, dvrr_stack+19299, dvrr_stack+70316, dvrr_stack+52006, dvrr_stack+38970, dvrr_stack+67936);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+51424, dvrr_stack+151085, dvrr_stack+6382, dvrr_stack+52286, dvrr_stack+19299, dvrr_stack+68251);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+238644, dvrr_stack+151673, dvrr_stack+51424, dvrr_stack+80391, dvrr_stack+151085, dvrr_stack+68692);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+239652, dvrr_stack+3654, dvrr_stack+238644, dvrr_stack+80979, dvrr_stack+151673, dvrr_stack+69280);
 tmp = dvrr_stack + 239652;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+80391, dvrr_stack+11801, dvrr_stack+18854, NULL, NULL, dvrr_stack+11773);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+80499, dvrr_stack+3344, dvrr_stack+80391, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+64893);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31200, dvrr_stack+18441, dvrr_stack+80499, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+64977);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+240912, dvrr_stack+66006, dvrr_stack+31200, dvrr_stack+28944, dvrr_stack+18441, dvrr_stack+70036);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+241452, dvrr_stack+52706, dvrr_stack+240912, dvrr_stack+39582, dvrr_stack+66006, dvrr_stack+70316);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+242208, dvrr_stack+152457, dvrr_stack+241452, dvrr_stack+81763, dvrr_stack+52706, dvrr_stack+6382);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+243216, dvrr_stack+153213, dvrr_stack+242208, dvrr_stack+82303, dvrr_stack+152457, dvrr_stack+51424);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+244512, dvrr_stack+154221, dvrr_stack+243216, dvrr_stack+83059, dvrr_stack+153213, dvrr_stack+238644);
 tmp = dvrr_stack + 244512;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+246132,dvrr_stack+244512,dvrr_stack+239652,45);


 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+81763, dvrr_stack+18890, dvrr_stack+19056, NULL, NULL, dvrr_stack+18854);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+81898, dvrr_stack+7272, dvrr_stack+81763, dvrr_stack+11837, dvrr_stack+18890, dvrr_stack+80391);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+82168, dvrr_stack+7407, dvrr_stack+81898, dvrr_stack+38247, dvrr_stack+7272, dvrr_stack+80499);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+249912, dvrr_stack+7677, dvrr_stack+82168, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+31200);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+250587, dvrr_stack+158541, dvrr_stack+249912, dvrr_stack+86419, dvrr_stack+7677, dvrr_stack+240912);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+251532, dvrr_stack+159216, dvrr_stack+250587, dvrr_stack+86869, dvrr_stack+158541, dvrr_stack+241452);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+252792, dvrr_stack+160161, dvrr_stack+251532, dvrr_stack+87544, dvrr_stack+159216, dvrr_stack+242208);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86419, dvrr_stack+12793, dvrr_stack+252792, dvrr_stack+88489, dvrr_stack+160161, dvrr_stack+243216);
 tmp = dvrr_stack + 86419;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+254412,dvrr_stack+86419,dvrr_stack+244512,45);


 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+19056);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82618, dvrr_stack+8127, dvrr_stack+6112, dvrr_stack+18935, dvrr_stack+12438, dvrr_stack+81763);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+259272, dvrr_stack+2296, dvrr_stack+82618, dvrr_stack+11448, dvrr_stack+8127, dvrr_stack+81898);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+259822, dvrr_stack+165309, dvrr_stack+259272, dvrr_stack+11937, dvrr_stack+2296, dvrr_stack+82168);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+260647, dvrr_stack+165859, dvrr_stack+259822, dvrr_stack+92773, dvrr_stack+165309, dvrr_stack+249912);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+261802, dvrr_stack+166684, dvrr_stack+260647, dvrr_stack+93323, dvrr_stack+165859, dvrr_stack+250587);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+263342, dvrr_stack+167839, dvrr_stack+261802, dvrr_stack+94148, dvrr_stack+166684, dvrr_stack+251532);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+92773, dvrr_stack+20134, dvrr_stack+263342, dvrr_stack+95303, dvrr_stack+167839, dvrr_stack+252792);
 tmp = dvrr_stack + 92773;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+265322,dvrr_stack+92773,dvrr_stack+86419,45);


 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+12493, dvrr_stack+50559, NULL, NULL, dvrr_stack+2941);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+39460, dvrr_stack+50142, dvrr_stack+11937, dvrr_stack+27563, dvrr_stack+12493, dvrr_stack+6112);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+271397, dvrr_stack+29160, dvrr_stack+39460, dvrr_stack+19101, dvrr_stack+50142, dvrr_stack+82618);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+272057, dvrr_stack+174239, dvrr_stack+271397, dvrr_stack+100623, dvrr_stack+29160, dvrr_stack+259272);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+273047, dvrr_stack+174899, dvrr_stack+272057, dvrr_stack+101019, dvrr_stack+174239, dvrr_stack+259822);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+274433, dvrr_stack+175889, dvrr_stack+273047, dvrr_stack+101679, dvrr_stack+174899, dvrr_stack+260647);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+276281, dvrr_stack+177275, dvrr_stack+274433, dvrr_stack+102669, dvrr_stack+175889, dvrr_stack+261802);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+100623, dvrr_stack+179123, dvrr_stack+276281, dvrr_stack+104055, dvrr_stack+177275, dvrr_stack+263342);
 tmp = dvrr_stack + 100623;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+278657,dvrr_stack+100623,dvrr_stack+92773,45);


 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+103593, dvrr_stack+50625, dvrr_stack+49973, NULL, NULL, dvrr_stack+50559);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+52208, dvrr_stack+29556, dvrr_stack+103593, dvrr_stack+38078, dvrr_stack+50625, dvrr_stack+11937);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+286082, dvrr_stack+39942, dvrr_stack+52208, dvrr_stack+27051, dvrr_stack+29556, dvrr_stack+39460);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+286862, dvrr_stack+29790, dvrr_stack+286082, dvrr_stack+27707, dvrr_stack+39942, dvrr_stack+271397);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+288032, dvrr_stack+187439, dvrr_stack+286862, dvrr_stack+110523, dvrr_stack+29790, dvrr_stack+272057);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+289670, dvrr_stack+188609, dvrr_stack+288032, dvrr_stack+111303, dvrr_stack+187439, dvrr_stack+273047);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+291854, dvrr_stack+190247, dvrr_stack+289670, dvrr_stack+112473, dvrr_stack+188609, dvrr_stack+274433);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+110523, dvrr_stack+192431, dvrr_stack+291854, dvrr_stack+114111, dvrr_stack+190247, dvrr_stack+276281);
 tmp = dvrr_stack + 110523;
 target_ptr = Libderiv->dvrr_classes[8][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+294662,dvrr_stack+110523,dvrr_stack+100623,45);


 /* compute (1 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+65145, dvrr_stack+50051, dvrr_stack+42139, NULL, NULL, dvrr_stack+49973);

 /* compute (2 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+27707, dvrr_stack+40410, dvrr_stack+65145, dvrr_stack+50703, dvrr_stack+50051, dvrr_stack+103593);

 /* compute (3 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+303572, dvrr_stack+40683, dvrr_stack+27707, dvrr_stack+38382, dvrr_stack+40410, dvrr_stack+52208);

 /* compute (4 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+304482, dvrr_stack+41229, dvrr_stack+303572, dvrr_stack+121839, dvrr_stack+40683, dvrr_stack+286082);

 /* compute (5 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+305847, dvrr_stack+202367, dvrr_stack+304482, dvrr_stack+122385, dvrr_stack+41229, dvrr_stack+286862);

 /* compute (6 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+307758, dvrr_stack+203732, dvrr_stack+305847, dvrr_stack+123295, dvrr_stack+202367, dvrr_stack+288032);

 /* compute (7 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+310306, dvrr_stack+205643, dvrr_stack+307758, dvrr_stack+124660, dvrr_stack+203732, dvrr_stack+289670);

 /* compute (8 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+121839, dvrr_stack+208191, dvrr_stack+310306, dvrr_stack+126571, dvrr_stack+205643, dvrr_stack+291854);
 tmp = dvrr_stack + 121839;
 target_ptr = Libderiv->dvrr_classes[8][12];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+313582,dvrr_stack+121839,dvrr_stack+110523,45);


 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+125934, dvrr_stack+38156, dvrr_stack+3, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+6, dvrr_stack+125934, dvrr_stack+49794, dvrr_stack+38156, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+38159, dvrr_stack+367, dvrr_stack+49797, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+38169, dvrr_stack+1336, dvrr_stack+39, dvrr_stack+38159, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+38184, dvrr_stack+3323, dvrr_stack+207, dvrr_stack+38169, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+125940, dvrr_stack+38205, dvrr_stack+2877, dvrr_stack+49803, dvrr_stack+38184, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+88444, dvrr_stack+2905, dvrr_stack+125940, dvrr_stack+49824, dvrr_stack+38205, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+95248, dvrr_stack+6067, dvrr_stack+88444, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27563, dvrr_stack+11882, dvrr_stack+95248, dvrr_stack+237, dvrr_stack+6067, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+114033, dvrr_stack+18990, dvrr_stack+27563, dvrr_stack+49852, dvrr_stack+11882, NULL);

 /* compute (0 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50703, dvrr_stack+27629, dvrr_stack+114033, dvrr_stack+49907, dvrr_stack+18990, NULL);

 /* compute (0 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+6277, dvrr_stack+42139, dvrr_stack+50703, dvrr_stack+49973, dvrr_stack+27629, NULL);

 /* compute (1 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+125976, dvrr_stack+64788, dvrr_stack+6277, NULL, NULL, dvrr_stack+42139);

 /* compute (2 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+324112, dvrr_stack+42230, dvrr_stack+125976, dvrr_stack+11613, dvrr_stack+64788, dvrr_stack+65145);

 /* compute (3 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+324742, dvrr_stack+30570, dvrr_stack+324112, dvrr_stack+38655, dvrr_stack+42230, dvrr_stack+27707);

 /* compute (4 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+325792, dvrr_stack+53246, dvrr_stack+324742, dvrr_stack+50794, dvrr_stack+30570, dvrr_stack+303572);

 /* compute (5 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+327367, dvrr_stack+54296, dvrr_stack+325792, dvrr_stack+135671, dvrr_stack+53246, dvrr_stack+304482);

 /* compute (6 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+329572, dvrr_stack+219891, dvrr_stack+327367, dvrr_stack+136721, dvrr_stack+54296, dvrr_stack+305847);

 /* compute (7 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+332512, dvrr_stack+222096, dvrr_stack+329572, dvrr_stack+138296, dvrr_stack+219891, dvrr_stack+307758);

 /* compute (8 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+135671, dvrr_stack+225036, dvrr_stack+332512, dvrr_stack+140501, dvrr_stack+222096, dvrr_stack+310306);

 /* compute (8 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+336292,dvrr_stack+135671,dvrr_stack+121839,45);


 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+140396, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+140399, dvrr_stack+50340, dvrr_stack+140396, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+39, dvrr_stack+50343, dvrr_stack+140399, dvrr_stack+70878, dvrr_stack+50340, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+140405, dvrr_stack+49, dvrr_stack+282, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1753, dvrr_stack+50349, dvrr_stack+140405, dvrr_stack+68, dvrr_stack+49, dvrr_stack+140396);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+52676, dvrr_stack+50358, dvrr_stack+1753, dvrr_stack+70881, dvrr_stack+50349, dvrr_stack+140399);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+11837, dvrr_stack+50376, dvrr_stack+52676, dvrr_stack+70890, dvrr_stack+50358, dvrr_stack+39);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+140414, dvrr_stack+285, dvrr_stack+3307, NULL, NULL, dvrr_stack+282);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+767, dvrr_stack+42545, dvrr_stack+140414, dvrr_stack+361, dvrr_stack+285, dvrr_stack+140405);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+140432, dvrr_stack+42563, dvrr_stack+767, dvrr_stack+70908, dvrr_stack+42545, dvrr_stack+1753);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+50794, dvrr_stack+42599, dvrr_stack+140432, dvrr_stack+70926, dvrr_stack+42563, dvrr_stack+52676);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+50884, dvrr_stack+42659, dvrr_stack+50794, dvrr_stack+70962, dvrr_stack+42599, dvrr_stack+11837);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+70908, dvrr_stack+3313, dvrr_stack+2831, NULL, NULL, dvrr_stack+3307);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+51010, dvrr_stack+71, dvrr_stack+70908, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+140414);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+20034, dvrr_stack+42749, dvrr_stack+51010, dvrr_stack+71022, dvrr_stack+71, dvrr_stack+767);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+51070, dvrr_stack+12559, dvrr_stack+20034, dvrr_stack+71052, dvrr_stack+42749, dvrr_stack+140432);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+126291, dvrr_stack+3452, dvrr_stack+51070, dvrr_stack+71112, dvrr_stack+12559, dvrr_stack+50794);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2996, dvrr_stack+39250, dvrr_stack+126291, dvrr_stack+71212, dvrr_stack+3452, dvrr_stack+50884);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+66672, dvrr_stack+2841, dvrr_stack+6031, NULL, NULL, dvrr_stack+2831);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+71022, dvrr_stack+66627, dvrr_stack+66672, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+70908);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+51220, dvrr_stack+12659, dvrr_stack+71022, dvrr_stack+71362, dvrr_stack+66627, dvrr_stack+51010);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+28253, dvrr_stack+1603, dvrr_stack+51220, dvrr_stack+71407, dvrr_stack+12659, dvrr_stack+20034);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+27051, dvrr_stack+66366, dvrr_stack+28253, dvrr_stack+71497, dvrr_stack+1603, dvrr_stack+51070);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+38233, dvrr_stack+19719, dvrr_stack+27051, dvrr_stack+71647, dvrr_stack+66366, dvrr_stack+126291);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+348577, dvrr_stack+67516, dvrr_stack+38233, dvrr_stack+71872, dvrr_stack+19719, dvrr_stack+2996);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+71362, dvrr_stack+6046, dvrr_stack+11752, NULL, NULL, dvrr_stack+6031);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+71425, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+66672);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+71551, dvrr_stack+4662, dvrr_stack+71425, dvrr_stack+377, dvrr_stack+66817, dvrr_stack+71022);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+38653, dvrr_stack+66880, dvrr_stack+71551, dvrr_stack+72187, dvrr_stack+4662, dvrr_stack+51220);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+349117, dvrr_stack+67936, dvrr_stack+38653, dvrr_stack+64263, dvrr_stack+66880, dvrr_stack+28253);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+349558, dvrr_stack+68251, dvrr_stack+349117, dvrr_stack+64473, dvrr_stack+67936, dvrr_stack+27051);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+350146, dvrr_stack+68692, dvrr_stack+349558, dvrr_stack+37446, dvrr_stack+68251, dvrr_stack+38233);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+350902, dvrr_stack+69280, dvrr_stack+350146, dvrr_stack+65418, dvrr_stack+68692, dvrr_stack+348577);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+37446, dvrr_stack+11773, dvrr_stack+18826, NULL, NULL, dvrr_stack+11752);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+64893, dvrr_stack+37446, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+71362);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+37530, dvrr_stack+64977, dvrr_stack+933, dvrr_stack+1351, dvrr_stack+64893, dvrr_stack+71425);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+64263, dvrr_stack+70036, dvrr_stack+37530, dvrr_stack+1435, dvrr_stack+64977, dvrr_stack+71551);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+351847, dvrr_stack+70316, dvrr_stack+64263, dvrr_stack+38970, dvrr_stack+70036, dvrr_stack+38653);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+352435, dvrr_stack+6382, dvrr_stack+351847, dvrr_stack+19299, dvrr_stack+70316, dvrr_stack+349117);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+353219, dvrr_stack+51424, dvrr_stack+352435, dvrr_stack+151085, dvrr_stack+6382, dvrr_stack+349558);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+354227, dvrr_stack+238644, dvrr_stack+353219, dvrr_stack+151673, dvrr_stack+51424, dvrr_stack+350146);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+355487, dvrr_stack+239652, dvrr_stack+354227, dvrr_stack+3654, dvrr_stack+238644, dvrr_stack+350902);
 tmp = dvrr_stack + 355487;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+151085, dvrr_stack+18854, dvrr_stack+27527, NULL, NULL, dvrr_stack+18826);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28944, dvrr_stack+80391, dvrr_stack+151085, dvrr_stack+11801, dvrr_stack+18854, dvrr_stack+37446);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+151193, dvrr_stack+80499, dvrr_stack+28944, dvrr_stack+3344, dvrr_stack+80391, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+151553, dvrr_stack+31200, dvrr_stack+151193, dvrr_stack+18441, dvrr_stack+80499, dvrr_stack+37530);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+357027, dvrr_stack+240912, dvrr_stack+151553, dvrr_stack+66006, dvrr_stack+31200, dvrr_stack+64263);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+357783, dvrr_stack+241452, dvrr_stack+357027, dvrr_stack+52706, dvrr_stack+240912, dvrr_stack+351847);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+358791, dvrr_stack+242208, dvrr_stack+357783, dvrr_stack+152457, dvrr_stack+241452, dvrr_stack+352435);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+360087, dvrr_stack+243216, dvrr_stack+358791, dvrr_stack+153213, dvrr_stack+242208, dvrr_stack+353219);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+152093, dvrr_stack+244512, dvrr_stack+360087, dvrr_stack+154221, dvrr_stack+243216, dvrr_stack+354227);
 tmp = dvrr_stack + 152093;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+361707,dvrr_stack+152093,dvrr_stack+355487,55);


 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+52706, dvrr_stack+19056, dvrr_stack+38033, NULL, NULL, dvrr_stack+27527);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+81763, dvrr_stack+52706, dvrr_stack+18890, dvrr_stack+19056, dvrr_stack+151085);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+81898, dvrr_stack+11448, dvrr_stack+7272, dvrr_stack+81763, dvrr_stack+28944);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+366327, dvrr_stack+82168, dvrr_stack+19101, dvrr_stack+7407, dvrr_stack+81898, dvrr_stack+151193);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+367002, dvrr_stack+249912, dvrr_stack+366327, dvrr_stack+7677, dvrr_stack+82168, dvrr_stack+151553);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+367947, dvrr_stack+250587, dvrr_stack+367002, dvrr_stack+158541, dvrr_stack+249912, dvrr_stack+357027);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+369207, dvrr_stack+251532, dvrr_stack+367947, dvrr_stack+159216, dvrr_stack+250587, dvrr_stack+357783);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+370827, dvrr_stack+252792, dvrr_stack+369207, dvrr_stack+160161, dvrr_stack+251532, dvrr_stack+358791);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+158541, dvrr_stack+86419, dvrr_stack+370827, dvrr_stack+12793, dvrr_stack+252792, dvrr_stack+360087);
 tmp = dvrr_stack + 158541;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+372852,dvrr_stack+158541,dvrr_stack+152093,55);


 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+161016, dvrr_stack+2941, dvrr_stack+50504, NULL, NULL, dvrr_stack+38033);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52841, dvrr_stack+6112, dvrr_stack+161016, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+52706);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6970, dvrr_stack+82618, dvrr_stack+52841, dvrr_stack+8127, dvrr_stack+6112, dvrr_stack+11448);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7520, dvrr_stack+259272, dvrr_stack+6970, dvrr_stack+2296, dvrr_stack+82618, dvrr_stack+19101);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+378792, dvrr_stack+259822, dvrr_stack+7520, dvrr_stack+165309, dvrr_stack+259272, dvrr_stack+366327);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+379947, dvrr_stack+260647, dvrr_stack+378792, dvrr_stack+165859, dvrr_stack+259822, dvrr_stack+367002);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+381487, dvrr_stack+261802, dvrr_stack+379947, dvrr_stack+166684, dvrr_stack+260647, dvrr_stack+367947);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+165309, dvrr_stack+263342, dvrr_stack+381487, dvrr_stack+167839, dvrr_stack+261802, dvrr_stack+369207);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+383467, dvrr_stack+92773, dvrr_stack+165309, dvrr_stack+20134, dvrr_stack+263342, dvrr_stack+370827);
 tmp = dvrr_stack + 383467;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+386492,dvrr_stack+383467,dvrr_stack+158541,55);


 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+167784, dvrr_stack+50559, dvrr_stack+49907, NULL, NULL, dvrr_stack+50504);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+167982, dvrr_stack+11937, dvrr_stack+167784, dvrr_stack+12493, dvrr_stack+50559, dvrr_stack+161016);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+168378, dvrr_stack+39460, dvrr_stack+167982, dvrr_stack+50142, dvrr_stack+11937, dvrr_stack+52841);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+393917, dvrr_stack+271397, dvrr_stack+168378, dvrr_stack+29160, dvrr_stack+39460, dvrr_stack+6970);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+394907, dvrr_stack+272057, dvrr_stack+393917, dvrr_stack+174239, dvrr_stack+271397, dvrr_stack+7520);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+396293, dvrr_stack+273047, dvrr_stack+394907, dvrr_stack+174899, dvrr_stack+272057, dvrr_stack+378792);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+398141, dvrr_stack+274433, dvrr_stack+396293, dvrr_stack+175889, dvrr_stack+273047, dvrr_stack+379947);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+174239, dvrr_stack+276281, dvrr_stack+398141, dvrr_stack+177275, dvrr_stack+274433, dvrr_stack+381487);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+400517, dvrr_stack+100623, dvrr_stack+174239, dvrr_stack+179123, dvrr_stack+276281, dvrr_stack+165309);
 tmp = dvrr_stack + 400517;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+404147,dvrr_stack+400517,dvrr_stack+383467,55);


 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+177209, dvrr_stack+49973, dvrr_stack+27629, NULL, NULL, dvrr_stack+49907);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+177443, dvrr_stack+103593, dvrr_stack+177209, dvrr_stack+50625, dvrr_stack+49973, dvrr_stack+167784);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+177911, dvrr_stack+52208, dvrr_stack+177443, dvrr_stack+29556, dvrr_stack+103593, dvrr_stack+167982);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+413222, dvrr_stack+286082, dvrr_stack+177911, dvrr_stack+39942, dvrr_stack+52208, dvrr_stack+168378);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+414392, dvrr_stack+286862, dvrr_stack+413222, dvrr_stack+29790, dvrr_stack+286082, dvrr_stack+393917);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+416030, dvrr_stack+288032, dvrr_stack+414392, dvrr_stack+187439, dvrr_stack+286862, dvrr_stack+394907);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+418214, dvrr_stack+289670, dvrr_stack+416030, dvrr_stack+188609, dvrr_stack+288032, dvrr_stack+396293);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+421022, dvrr_stack+291854, dvrr_stack+418214, dvrr_stack+190247, dvrr_stack+289670, dvrr_stack+398141);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+187439, dvrr_stack+110523, dvrr_stack+421022, dvrr_stack+192431, dvrr_stack+291854, dvrr_stack+174239);
 tmp = dvrr_stack + 187439;
 target_ptr = Libderiv->dvrr_classes[9][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+424532,dvrr_stack+187439,dvrr_stack+400517,55);


 /* compute (1 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+191729, dvrr_stack+42139, dvrr_stack+50703, NULL, NULL, dvrr_stack+27629);

 /* compute (2 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+29160, dvrr_stack+65145, dvrr_stack+191729, dvrr_stack+50051, dvrr_stack+42139, dvrr_stack+177209);

 /* compute (3 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+435422, dvrr_stack+27707, dvrr_stack+29160, dvrr_stack+40410, dvrr_stack+65145, dvrr_stack+177443);

 /* compute (4 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+436332, dvrr_stack+303572, dvrr_stack+435422, dvrr_stack+40683, dvrr_stack+27707, dvrr_stack+177911);

 /* compute (5 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+437697, dvrr_stack+304482, dvrr_stack+436332, dvrr_stack+41229, dvrr_stack+303572, dvrr_stack+413222);

 /* compute (6 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+439608, dvrr_stack+305847, dvrr_stack+437697, dvrr_stack+202367, dvrr_stack+304482, dvrr_stack+414392);

 /* compute (7 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+442156, dvrr_stack+307758, dvrr_stack+439608, dvrr_stack+203732, dvrr_stack+305847, dvrr_stack+416030);

 /* compute (8 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+445432, dvrr_stack+310306, dvrr_stack+442156, dvrr_stack+205643, dvrr_stack+307758, dvrr_stack+418214);

 /* compute (9 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+202367, dvrr_stack+121839, dvrr_stack+445432, dvrr_stack+208191, dvrr_stack+310306, dvrr_stack+421022);
 tmp = dvrr_stack + 202367;
 target_ptr = Libderiv->dvrr_classes[9][12];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+449527,dvrr_stack+202367,dvrr_stack+187439,55);


 /* compute (0 0 | 1 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+21, Data->F+22, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, Data->F+20, Data->F+21, NULL);

 /* compute (0 0 | 3 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+125934, dvrr_stack+361, dvrr_stack+38156, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207372, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+6, dvrr_stack+125934, NULL);

 /* compute (0 0 | 5 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+207372, dvrr_stack+38159, dvrr_stack+367, NULL);

 /* compute (0 0 | 6 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+38169, dvrr_stack+1336, NULL);

 /* compute (0 0 | 7 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+38184, dvrr_stack+3323, NULL);

 /* compute (0 0 | 8 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+31560, dvrr_stack+125940, dvrr_stack+11801, dvrr_stack+38205, dvrr_stack+2877, NULL);

 /* compute (0 0 | 9 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+207387, dvrr_stack+88444, dvrr_stack+31560, dvrr_stack+2905, dvrr_stack+125940, NULL);

 /* compute (0 0 | 10 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+207442, dvrr_stack+95248, dvrr_stack+207387, dvrr_stack+6067, dvrr_stack+88444, NULL);

 /* compute (0 0 | 11 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50625, dvrr_stack+27563, dvrr_stack+207442, dvrr_stack+11882, dvrr_stack+95248, NULL);

 /* compute (0 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+207508, dvrr_stack+114033, dvrr_stack+50625, dvrr_stack+18990, dvrr_stack+27563, NULL);

 /* compute (0 0 | 13 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64683, dvrr_stack+50703, dvrr_stack+207508, dvrr_stack+27629, dvrr_stack+114033, NULL);

 /* compute (1 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+207599, dvrr_stack+6277, dvrr_stack+64683, NULL, NULL, dvrr_stack+50703);

 /* compute (2 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+29706, dvrr_stack+125976, dvrr_stack+207599, dvrr_stack+64788, dvrr_stack+6277, dvrr_stack+191729);

 /* compute (3 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39856, dvrr_stack+324112, dvrr_stack+29706, dvrr_stack+42230, dvrr_stack+125976, dvrr_stack+29160);

 /* compute (4 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+462397, dvrr_stack+324742, dvrr_stack+39856, dvrr_stack+30570, dvrr_stack+324112, dvrr_stack+435422);

 /* compute (5 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+463972, dvrr_stack+325792, dvrr_stack+462397, dvrr_stack+53246, dvrr_stack+324742, dvrr_stack+436332);

 /* compute (6 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+466177, dvrr_stack+327367, dvrr_stack+463972, dvrr_stack+54296, dvrr_stack+325792, dvrr_stack+437697);

 /* compute (7 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+469117, dvrr_stack+329572, dvrr_stack+466177, dvrr_stack+219891, dvrr_stack+327367, dvrr_stack+439608);

 /* compute (8 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+472897, dvrr_stack+332512, dvrr_stack+469117, dvrr_stack+222096, dvrr_stack+329572, dvrr_stack+442156);

 /* compute (9 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+477622, dvrr_stack+135671, dvrr_stack+472897, dvrr_stack+225036, dvrr_stack+332512, dvrr_stack+445432);

 /* compute (9 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+483397,dvrr_stack+477622,dvrr_stack+202367,55);


 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+219891, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+6, dvrr_stack+140396, dvrr_stack+219891, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+219894, dvrr_stack+140399, dvrr_stack+6, dvrr_stack+50340, dvrr_stack+140396, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+219904, dvrr_stack+39, dvrr_stack+219894, dvrr_stack+50343, dvrr_stack+140399, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+70881, dvrr_stack+282, dvrr_stack+3304, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+219919, dvrr_stack+140405, dvrr_stack+70881, dvrr_stack+49, dvrr_stack+282, dvrr_stack+219891);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+207, dvrr_stack+1753, dvrr_stack+219919, dvrr_stack+50349, dvrr_stack+140405, dvrr_stack+6);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+6067, dvrr_stack+52676, dvrr_stack+207, dvrr_stack+50358, dvrr_stack+1753, dvrr_stack+219894);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+219937, dvrr_stack+11837, dvrr_stack+6067, dvrr_stack+50376, dvrr_stack+52676, dvrr_stack+219904);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+50349, dvrr_stack+3307, dvrr_stack+803, NULL, NULL, dvrr_stack+3304);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+2905, dvrr_stack+140414, dvrr_stack+50349, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+70881);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+220000, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+42545, dvrr_stack+140414, dvrr_stack+219919);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+220060, dvrr_stack+140432, dvrr_stack+220000, dvrr_stack+42563, dvrr_stack+767, dvrr_stack+207);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+220150, dvrr_stack+50794, dvrr_stack+220060, dvrr_stack+42599, dvrr_stack+140432, dvrr_stack+6067);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+19551, dvrr_stack+50884, dvrr_stack+220150, dvrr_stack+42659, dvrr_stack+50794, dvrr_stack+219937);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+220276, dvrr_stack+2831, dvrr_stack+6021, NULL, NULL, dvrr_stack+803);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+220306, dvrr_stack+70908, dvrr_stack+220276, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+50349);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+18890, dvrr_stack+51010, dvrr_stack+220306, dvrr_stack+71, dvrr_stack+70908, dvrr_stack+2905);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+377, dvrr_stack+20034, dvrr_stack+18890, dvrr_stack+42749, dvrr_stack+51010, dvrr_stack+220000);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+220366, dvrr_stack+51070, dvrr_stack+377, dvrr_stack+12559, dvrr_stack+20034, dvrr_stack+220060);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+220576, dvrr_stack+126291, dvrr_stack+220366, dvrr_stack+3452, dvrr_stack+51070, dvrr_stack+220150);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+66006, dvrr_stack+2996, dvrr_stack+220576, dvrr_stack+39250, dvrr_stack+126291, dvrr_stack+19551);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+42749, dvrr_stack+6031, dvrr_stack+11737, NULL, NULL, dvrr_stack+6021);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+220856, dvrr_stack+66672, dvrr_stack+42749, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+220276);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+220946, dvrr_stack+71022, dvrr_stack+220856, dvrr_stack+66627, dvrr_stack+66672, dvrr_stack+220306);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+221096, dvrr_stack+51220, dvrr_stack+220946, dvrr_stack+12659, dvrr_stack+71022, dvrr_stack+18890);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+221321, dvrr_stack+28253, dvrr_stack+221096, dvrr_stack+1603, dvrr_stack+51220, dvrr_stack+377);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+221636, dvrr_stack+27051, dvrr_stack+221321, dvrr_stack+66366, dvrr_stack+28253, dvrr_stack+220366);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+222056, dvrr_stack+38233, dvrr_stack+221636, dvrr_stack+19719, dvrr_stack+27051, dvrr_stack+220576);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+222596, dvrr_stack+348577, dvrr_stack+222056, dvrr_stack+67516, dvrr_stack+38233, dvrr_stack+66006);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+19719, dvrr_stack+11752, dvrr_stack+18805, NULL, NULL, dvrr_stack+11737);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+19782, dvrr_stack+71362, dvrr_stack+19719, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+42749);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+66366, dvrr_stack+71425, dvrr_stack+19782, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+220856);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+223271, dvrr_stack+71551, dvrr_stack+66366, dvrr_stack+4662, dvrr_stack+71425, dvrr_stack+220946);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+223586, dvrr_stack+38653, dvrr_stack+223271, dvrr_stack+66880, dvrr_stack+71551, dvrr_stack+221096);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+224027, dvrr_stack+349117, dvrr_stack+223586, dvrr_stack+67936, dvrr_stack+38653, dvrr_stack+221321);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+30336, dvrr_stack+349558, dvrr_stack+224027, dvrr_stack+68251, dvrr_stack+349117, dvrr_stack+221636);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+53171, dvrr_stack+350146, dvrr_stack+30336, dvrr_stack+68692, dvrr_stack+349558, dvrr_stack+222056);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+67936, dvrr_stack+350902, dvrr_stack+53171, dvrr_stack+69280, dvrr_stack+350146, dvrr_stack+222596);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+69091, dvrr_stack+18826, dvrr_stack+27499, NULL, NULL, dvrr_stack+18805);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+66817, dvrr_stack+37446, dvrr_stack+69091, dvrr_stack+11773, dvrr_stack+18826, dvrr_stack+19719);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+224615, dvrr_stack+933, dvrr_stack+66817, dvrr_stack+64893, dvrr_stack+37446, dvrr_stack+19782);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+42230, dvrr_stack+37530, dvrr_stack+224615, dvrr_stack+64977, dvrr_stack+933, dvrr_stack+66366);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+54116, dvrr_stack+64263, dvrr_stack+42230, dvrr_stack+70036, dvrr_stack+37530, dvrr_stack+223271);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+54704, dvrr_stack+351847, dvrr_stack+54116, dvrr_stack+70316, dvrr_stack+64263, dvrr_stack+223586);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+40906, dvrr_stack+352435, dvrr_stack+54704, dvrr_stack+6382, dvrr_stack+351847, dvrr_stack+224027);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+498412, dvrr_stack+353219, dvrr_stack+40906, dvrr_stack+51424, dvrr_stack+352435, dvrr_stack+30336);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+499672, dvrr_stack+354227, dvrr_stack+498412, dvrr_stack+238644, dvrr_stack+353219, dvrr_stack+53171);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+501212, dvrr_stack+355487, dvrr_stack+499672, dvrr_stack+239652, dvrr_stack+354227, dvrr_stack+67936);
 tmp = dvrr_stack + 501212;
 target_ptr = Libderiv->dvrr_classes[10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31092, dvrr_stack+27527, dvrr_stack+37997, NULL, NULL, dvrr_stack+27499);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238644, dvrr_stack+151085, dvrr_stack+31092, dvrr_stack+18854, dvrr_stack+27527, dvrr_stack+69091);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238860, dvrr_stack+28944, dvrr_stack+238644, dvrr_stack+80391, dvrr_stack+151085, dvrr_stack+66817);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6382, dvrr_stack+151193, dvrr_stack+238860, dvrr_stack+80499, dvrr_stack+28944, dvrr_stack+224615);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+70036, dvrr_stack+151553, dvrr_stack+6382, dvrr_stack+31200, dvrr_stack+151193, dvrr_stack+42230);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+503060, dvrr_stack+357027, dvrr_stack+70036, dvrr_stack+240912, dvrr_stack+151553, dvrr_stack+54116);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+504068, dvrr_stack+357783, dvrr_stack+503060, dvrr_stack+241452, dvrr_stack+357027, dvrr_stack+54704);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+505364, dvrr_stack+358791, dvrr_stack+504068, dvrr_stack+242208, dvrr_stack+357783, dvrr_stack+40906);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+240912, dvrr_stack+360087, dvrr_stack+505364, dvrr_stack+243216, dvrr_stack+358791, dvrr_stack+498412);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+506984, dvrr_stack+152093, dvrr_stack+240912, dvrr_stack+244512, dvrr_stack+360087, dvrr_stack+499672);
 tmp = dvrr_stack + 506984;
 target_ptr = Libderiv->dvrr_classes[10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+509360,dvrr_stack+506984,dvrr_stack+501212,66);


 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242892, dvrr_stack+38033, dvrr_stack+50459, NULL, NULL, dvrr_stack+37997);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+243027, dvrr_stack+52706, dvrr_stack+242892, dvrr_stack+19056, dvrr_stack+38033, dvrr_stack+31092);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+243297, dvrr_stack+11448, dvrr_stack+243027, dvrr_stack+81763, dvrr_stack+52706, dvrr_stack+238644);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+243747, dvrr_stack+19101, dvrr_stack+243297, dvrr_stack+81898, dvrr_stack+11448, dvrr_stack+238860);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+514904, dvrr_stack+366327, dvrr_stack+243747, dvrr_stack+82168, dvrr_stack+19101, dvrr_stack+6382);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+515849, dvrr_stack+367002, dvrr_stack+514904, dvrr_stack+249912, dvrr_stack+366327, dvrr_stack+70036);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+517109, dvrr_stack+367947, dvrr_stack+515849, dvrr_stack+250587, dvrr_stack+367002, dvrr_stack+503060);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+518729, dvrr_stack+369207, dvrr_stack+517109, dvrr_stack+251532, dvrr_stack+367947, dvrr_stack+504068);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+249912, dvrr_stack+370827, dvrr_stack+518729, dvrr_stack+252792, dvrr_stack+369207, dvrr_stack+505364);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+520754, dvrr_stack+158541, dvrr_stack+249912, dvrr_stack+86419, dvrr_stack+370827, dvrr_stack+240912);
 tmp = dvrr_stack + 520754;
 target_ptr = Libderiv->dvrr_classes[10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+523724,dvrr_stack+520754,dvrr_stack+506984,66);


 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+252387, dvrr_stack+50504, dvrr_stack+49852, NULL, NULL, dvrr_stack+50459);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+252552, dvrr_stack+161016, dvrr_stack+252387, dvrr_stack+2941, dvrr_stack+50504, dvrr_stack+242892);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+252882, dvrr_stack+52841, dvrr_stack+252552, dvrr_stack+6112, dvrr_stack+161016, dvrr_stack+243027);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+253432, dvrr_stack+6970, dvrr_stack+252882, dvrr_stack+82618, dvrr_stack+52841, dvrr_stack+243297);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+81763, dvrr_stack+7520, dvrr_stack+253432, dvrr_stack+259272, dvrr_stack+6970, dvrr_stack+243747);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+530852, dvrr_stack+378792, dvrr_stack+81763, dvrr_stack+259822, dvrr_stack+7520, dvrr_stack+514904);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+532392, dvrr_stack+379947, dvrr_stack+530852, dvrr_stack+260647, dvrr_stack+378792, dvrr_stack+515849);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+259272, dvrr_stack+381487, dvrr_stack+532392, dvrr_stack+261802, dvrr_stack+379947, dvrr_stack+517109);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+534372, dvrr_stack+165309, dvrr_stack+259272, dvrr_stack+263342, dvrr_stack+381487, dvrr_stack+518729);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+537397, dvrr_stack+383467, dvrr_stack+534372, dvrr_stack+92773, dvrr_stack+165309, dvrr_stack+249912);
 tmp = dvrr_stack + 537397;
 target_ptr = Libderiv->dvrr_classes[10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+541027,dvrr_stack+537397,dvrr_stack+520754,66);


 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+261747, dvrr_stack+49907, dvrr_stack+18990, NULL, NULL, dvrr_stack+49852);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+261945, dvrr_stack+167784, dvrr_stack+261747, dvrr_stack+50559, dvrr_stack+49907, dvrr_stack+252387);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+262341, dvrr_stack+167982, dvrr_stack+261945, dvrr_stack+11937, dvrr_stack+167784, dvrr_stack+252552);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+263001, dvrr_stack+168378, dvrr_stack+262341, dvrr_stack+39460, dvrr_stack+167982, dvrr_stack+252882);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+549937, dvrr_stack+393917, dvrr_stack+263001, dvrr_stack+271397, dvrr_stack+168378, dvrr_stack+253432);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+551323, dvrr_stack+394907, dvrr_stack+549937, dvrr_stack+272057, dvrr_stack+393917, dvrr_stack+81763);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+553171, dvrr_stack+396293, dvrr_stack+551323, dvrr_stack+273047, dvrr_stack+394907, dvrr_stack+530852);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+271397, dvrr_stack+398141, dvrr_stack+553171, dvrr_stack+274433, dvrr_stack+396293, dvrr_stack+532392);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+555547, dvrr_stack+174239, dvrr_stack+271397, dvrr_stack+276281, dvrr_stack+398141, dvrr_stack+259272);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+559177, dvrr_stack+400517, dvrr_stack+555547, dvrr_stack+100623, dvrr_stack+174239, dvrr_stack+534372);
 tmp = dvrr_stack + 559177;
 target_ptr = Libderiv->dvrr_classes[10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+563533,dvrr_stack+559177,dvrr_stack+537397,66);


 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+274367, dvrr_stack+27629, dvrr_stack+114033, NULL, NULL, dvrr_stack+18990);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+274601, dvrr_stack+177209, dvrr_stack+274367, dvrr_stack+49973, dvrr_stack+27629, dvrr_stack+261747);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+275069, dvrr_stack+177443, dvrr_stack+274601, dvrr_stack+103593, dvrr_stack+177209, dvrr_stack+261945);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+275849, dvrr_stack+177911, dvrr_stack+275069, dvrr_stack+52208, dvrr_stack+177443, dvrr_stack+262341);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+277019, dvrr_stack+413222, dvrr_stack+275849, dvrr_stack+286082, dvrr_stack+177911, dvrr_stack+263001);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+574423, dvrr_stack+414392, dvrr_stack+277019, dvrr_stack+286862, dvrr_stack+413222, dvrr_stack+549937);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+576607, dvrr_stack+416030, dvrr_stack+574423, dvrr_stack+288032, dvrr_stack+414392, dvrr_stack+551323);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+286082, dvrr_stack+418214, dvrr_stack+576607, dvrr_stack+289670, dvrr_stack+416030, dvrr_stack+553171);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+579415, dvrr_stack+421022, dvrr_stack+286082, dvrr_stack+291854, dvrr_stack+418214, dvrr_stack+271397);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+583705, dvrr_stack+187439, dvrr_stack+579415, dvrr_stack+110523, dvrr_stack+421022, dvrr_stack+555547);
 tmp = dvrr_stack + 583705;
 target_ptr = Libderiv->dvrr_classes[10][11];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+588853,dvrr_stack+583705,dvrr_stack+559177,66);


 /* compute (1 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+289592, dvrr_stack+50703, dvrr_stack+207508, NULL, NULL, dvrr_stack+114033);

 /* compute (2 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+289865, dvrr_stack+191729, dvrr_stack+289592, dvrr_stack+42139, dvrr_stack+50703, dvrr_stack+274367);

 /* compute (3 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+290411, dvrr_stack+29160, dvrr_stack+289865, dvrr_stack+65145, dvrr_stack+191729, dvrr_stack+274601);

 /* compute (4 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+291321, dvrr_stack+435422, dvrr_stack+290411, dvrr_stack+27707, dvrr_stack+29160, dvrr_stack+275069);

 /* compute (5 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+292686, dvrr_stack+436332, dvrr_stack+291321, dvrr_stack+303572, dvrr_stack+435422, dvrr_stack+275849);

 /* compute (6 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+601921, dvrr_stack+437697, dvrr_stack+292686, dvrr_stack+304482, dvrr_stack+436332, dvrr_stack+277019);

 /* compute (7 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+604469, dvrr_stack+439608, dvrr_stack+601921, dvrr_stack+305847, dvrr_stack+437697, dvrr_stack+574423);

 /* compute (8 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+303572, dvrr_stack+442156, dvrr_stack+604469, dvrr_stack+307758, dvrr_stack+439608, dvrr_stack+576607);

 /* compute (9 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+607745, dvrr_stack+445432, dvrr_stack+303572, dvrr_stack+310306, dvrr_stack+442156, dvrr_stack+286082);

 /* compute (10 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+612750, dvrr_stack+202367, dvrr_stack+607745, dvrr_stack+121839, dvrr_stack+445432, dvrr_stack+579415);

 /* compute (10 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+618756,dvrr_stack+612750,dvrr_stack+583705,66);


 /* compute (0 0 | 1 0) m=22 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+22, Data->F+23, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+68, dvrr_stack+49, Data->F+21, Data->F+22, NULL);

 /* compute (0 0 | 3 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3313, dvrr_stack+361, dvrr_stack+285, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+66576, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+125934, dvrr_stack+361, NULL);

 /* compute (0 0 | 5 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6046, dvrr_stack+207372, dvrr_stack+66576, dvrr_stack+367, dvrr_stack+1326, NULL);

 /* compute (0 0 | 6 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11773, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+1336, dvrr_stack+207372, NULL);

 /* compute (0 0 | 7 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18854, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+3323, dvrr_stack+2856, NULL);

 /* compute (0 0 | 8 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19056, dvrr_stack+11801, dvrr_stack+18854, dvrr_stack+2877, dvrr_stack+3276, NULL);

 /* compute (0 0 | 9 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+31560, dvrr_stack+19056, dvrr_stack+125940, dvrr_stack+11801, NULL);

 /* compute (0 0 | 10 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50559, dvrr_stack+207387, dvrr_stack+2941, dvrr_stack+88444, dvrr_stack+31560, NULL);

 /* compute (0 0 | 11 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1326, dvrr_stack+207442, dvrr_stack+50559, dvrr_stack+95248, dvrr_stack+207387, NULL);

 /* compute (0 0 | 12 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+1404, dvrr_stack+50625, dvrr_stack+1326, dvrr_stack+27563, dvrr_stack+207442, NULL);

 /* compute (0 0 | 13 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+69175, dvrr_stack+207508, dvrr_stack+1404, dvrr_stack+114033, dvrr_stack+50625, NULL);

 /* compute (1 0 | 13 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+3313, dvrr_stack+64683, dvrr_stack+69175, NULL, NULL, dvrr_stack+207508);

 /* compute (2 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64788, dvrr_stack+207599, dvrr_stack+3313, dvrr_stack+6277, dvrr_stack+64683, dvrr_stack+289592);

 /* compute (3 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+307667, dvrr_stack+29706, dvrr_stack+64788, dvrr_stack+125976, dvrr_stack+207599, dvrr_stack+289865);

 /* compute (4 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+308717, dvrr_stack+39856, dvrr_stack+307667, dvrr_stack+324112, dvrr_stack+29706, dvrr_stack+290411);

 /* compute (5 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+310292, dvrr_stack+462397, dvrr_stack+308717, dvrr_stack+324742, dvrr_stack+39856, dvrr_stack+291321);

 /* compute (6 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+634200, dvrr_stack+463972, dvrr_stack+310292, dvrr_stack+325792, dvrr_stack+462397, dvrr_stack+292686);

 /* compute (7 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+307667, dvrr_stack+466177, dvrr_stack+634200, dvrr_stack+327367, dvrr_stack+463972, dvrr_stack+601921);

 /* compute (8 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+324112, dvrr_stack+469117, dvrr_stack+307667, dvrr_stack+329572, dvrr_stack+466177, dvrr_stack+604469);

 /* compute (9 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+307667, dvrr_stack+472897, dvrr_stack+324112, dvrr_stack+332512, dvrr_stack+469117, dvrr_stack+303572);

 /* compute (10 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+324112, dvrr_stack+477622, dvrr_stack+307667, dvrr_stack+135671, dvrr_stack+472897, dvrr_stack+607745);

 /* compute (10 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+634200,dvrr_stack+324112,dvrr_stack+612750,66);


 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+50367, dvrr_stack+12, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+307667, dvrr_stack+52, dvrr_stack+15, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+18854, dvrr_stack+307667, dvrr_stack+21, dvrr_stack+52, dvrr_stack+15, dvrr_stack+50367);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+307685, dvrr_stack+291, dvrr_stack+58, NULL, NULL, dvrr_stack+52);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+307715, dvrr_stack+307685, dvrr_stack+117, dvrr_stack+291, dvrr_stack+58, dvrr_stack+307667);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+71112, dvrr_stack+307715, dvrr_stack+147, dvrr_stack+307685, dvrr_stack+117, dvrr_stack+18854);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+88444, dvrr_stack+1101, dvrr_stack+301, NULL, NULL, dvrr_stack+291);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+244422, dvrr_stack+88444, dvrr_stack+316, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+307685);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+307775, dvrr_stack+244422, dvrr_stack+527, dvrr_stack+88444, dvrr_stack+316, dvrr_stack+307715);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+307925, dvrr_stack+307775, dvrr_stack+617, dvrr_stack+244422, dvrr_stack+527, dvrr_stack+71112);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+527, dvrr_stack+912, dvrr_stack+1116, NULL, NULL, dvrr_stack+1101);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+527, dvrr_stack+1137, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+88444);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+308150, dvrr_stack+4662, dvrr_stack+1200, dvrr_stack+527, dvrr_stack+1137, dvrr_stack+244422);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+308360, dvrr_stack+308150, dvrr_stack+1771, dvrr_stack+4662, dvrr_stack+1200, dvrr_stack+307775);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+308675, dvrr_stack+308360, dvrr_stack+1981, dvrr_stack+308150, dvrr_stack+1771, dvrr_stack+307925);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1771, dvrr_stack+50367, dvrr_stack+11718, dvrr_stack+12, dvrr_stack+0, dvrr_stack+3);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1789, dvrr_stack+18854, dvrr_stack+66591, dvrr_stack+307667, dvrr_stack+21, dvrr_stack+1771);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+308150, dvrr_stack+71112, dvrr_stack+66717, dvrr_stack+307715, dvrr_stack+147, dvrr_stack+1789);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+309116, dvrr_stack+307925, dvrr_stack+67102, dvrr_stack+307775, dvrr_stack+617, dvrr_stack+308150);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+80391, dvrr_stack+308675, dvrr_stack+28503, dvrr_stack+308360, dvrr_stack+1981, dvrr_stack+309116);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+307667, dvrr_stack+3, dvrr_stack+70878, Data->F+5, Data->F+6, NULL);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+307673, dvrr_stack+1771, dvrr_stack+70890, dvrr_stack+50367, dvrr_stack+11718, dvrr_stack+307667);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+244422, dvrr_stack+1789, dvrr_stack+70962, dvrr_stack+18854, dvrr_stack+66591, dvrr_stack+307673);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+307703, dvrr_stack+308150, dvrr_stack+71212, dvrr_stack+71112, dvrr_stack+66717, dvrr_stack+244422);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+1849, dvrr_stack+309116, dvrr_stack+71872, dvrr_stack+307925, dvrr_stack+67102, dvrr_stack+307703);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+309431, dvrr_stack+80391, dvrr_stack+65418, dvrr_stack+308675, dvrr_stack+28503, dvrr_stack+1849);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+66717, dvrr_stack+307667, dvrr_stack+50343, dvrr_stack+3, dvrr_stack+70878, NULL);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+88444, dvrr_stack+307673, dvrr_stack+50376, dvrr_stack+1771, dvrr_stack+70890, dvrr_stack+66717);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+4662, dvrr_stack+244422, dvrr_stack+42659, dvrr_stack+1789, dvrr_stack+70962, dvrr_stack+88444);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2269, dvrr_stack+307703, dvrr_stack+39250, dvrr_stack+308150, dvrr_stack+71212, dvrr_stack+4662);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+307913, dvrr_stack+1849, dvrr_stack+67516, dvrr_stack+309116, dvrr_stack+71872, dvrr_stack+2269);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+310187, dvrr_stack+309431, dvrr_stack+69280, dvrr_stack+80391, dvrr_stack+65418, dvrr_stack+307913);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+309116, dvrr_stack+66717, dvrr_stack+39, dvrr_stack+307667, dvrr_stack+50343, NULL);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+309131, dvrr_stack+88444, dvrr_stack+11837, dvrr_stack+307673, dvrr_stack+50376, dvrr_stack+309116);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+309194, dvrr_stack+4662, dvrr_stack+50884, dvrr_stack+244422, dvrr_stack+42659, dvrr_stack+309131);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+311132, dvrr_stack+2269, dvrr_stack+2996, dvrr_stack+307703, dvrr_stack+39250, dvrr_stack+309194);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+311492, dvrr_stack+307913, dvrr_stack+348577, dvrr_stack+1849, dvrr_stack+67516, dvrr_stack+311132);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+312167, dvrr_stack+310187, dvrr_stack+350902, dvrr_stack+309431, dvrr_stack+69280, dvrr_stack+311492);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+6046, dvrr_stack+309116, dvrr_stack+219904, dvrr_stack+66717, dvrr_stack+39, NULL);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+70938, dvrr_stack+309131, dvrr_stack+219937, dvrr_stack+88444, dvrr_stack+11837, dvrr_stack+6046);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+307667, dvrr_stack+309194, dvrr_stack+19551, dvrr_stack+4662, dvrr_stack+50884, dvrr_stack+70938);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+1771, dvrr_stack+311132, dvrr_stack+66006, dvrr_stack+2269, dvrr_stack+2996, dvrr_stack+307667);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+331042, dvrr_stack+311492, dvrr_stack+222596, dvrr_stack+307913, dvrr_stack+348577, dvrr_stack+1771);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+331867, dvrr_stack+312167, dvrr_stack+67936, dvrr_stack+310187, dvrr_stack+350902, dvrr_stack+331042);

 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+331042, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+0, dvrr_stack+219891, dvrr_stack+331042, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+331045, dvrr_stack+6, dvrr_stack+0, dvrr_stack+140396, dvrr_stack+219891, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+331055, dvrr_stack+219894, dvrr_stack+331045, dvrr_stack+140399, dvrr_stack+6, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+6046, dvrr_stack+219904, dvrr_stack+331055, dvrr_stack+39, dvrr_stack+219894, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+140396, dvrr_stack+3304, dvrr_stack+2828, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+70890, dvrr_stack+70881, dvrr_stack+140396, dvrr_stack+282, dvrr_stack+3304, dvrr_stack+331042);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+282, dvrr_stack+219919, dvrr_stack+70890, dvrr_stack+140405, dvrr_stack+70881, dvrr_stack+0);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+88444, dvrr_stack+207, dvrr_stack+282, dvrr_stack+1753, dvrr_stack+219919, dvrr_stack+331045);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+0, dvrr_stack+6067, dvrr_stack+88444, dvrr_stack+52676, dvrr_stack+207, dvrr_stack+331055);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+70938, dvrr_stack+219937, dvrr_stack+0, dvrr_stack+11837, dvrr_stack+6067, dvrr_stack+6046);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+6046, dvrr_stack+803, dvrr_stack+6015, NULL, NULL, dvrr_stack+2828);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+18854, dvrr_stack+50349, dvrr_stack+6046, dvrr_stack+3307, dvrr_stack+803, dvrr_stack+140396);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+803, dvrr_stack+2905, dvrr_stack+18854, dvrr_stack+140414, dvrr_stack+50349, dvrr_stack+70890);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+244422, dvrr_stack+220000, dvrr_stack+803, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+282);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+4662, dvrr_stack+220060, dvrr_stack+244422, dvrr_stack+140432, dvrr_stack+220000, dvrr_stack+88444);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+6064, dvrr_stack+220150, dvrr_stack+4662, dvrr_stack+50794, dvrr_stack+220060, dvrr_stack+0);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+19551, dvrr_stack+6064, dvrr_stack+50884, dvrr_stack+220150, dvrr_stack+70938);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+70938, dvrr_stack+6021, dvrr_stack+11727, NULL, NULL, dvrr_stack+6015);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+19551, dvrr_stack+220276, dvrr_stack+70938, dvrr_stack+2831, dvrr_stack+6021, dvrr_stack+6046);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+66717, dvrr_stack+220306, dvrr_stack+19551, dvrr_stack+70908, dvrr_stack+220276, dvrr_stack+18854);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+6232, dvrr_stack+18890, dvrr_stack+66717, dvrr_stack+51010, dvrr_stack+220306, dvrr_stack+803);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+50794, dvrr_stack+377, dvrr_stack+6232, dvrr_stack+20034, dvrr_stack+18890, dvrr_stack+244422);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+331042, dvrr_stack+220366, dvrr_stack+50794, dvrr_stack+51070, dvrr_stack+377, dvrr_stack+4662);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+282, dvrr_stack+220576, dvrr_stack+331042, dvrr_stack+126291, dvrr_stack+220366, dvrr_stack+6064);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+49973, dvrr_stack+66006, dvrr_stack+282, dvrr_stack+2996, dvrr_stack+220576, dvrr_stack+0);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+88444, dvrr_stack+11737, dvrr_stack+18790, NULL, NULL, dvrr_stack+11727);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+244422, dvrr_stack+42749, dvrr_stack+88444, dvrr_stack+6031, dvrr_stack+11737, dvrr_stack+70938);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+0, dvrr_stack+220856, dvrr_stack+244422, dvrr_stack+66672, dvrr_stack+42749, dvrr_stack+19551);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+642, dvrr_stack+220946, dvrr_stack+0, dvrr_stack+71022, dvrr_stack+220856, dvrr_stack+66717);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+309116, dvrr_stack+221096, dvrr_stack+642, dvrr_stack+51220, dvrr_stack+220946, dvrr_stack+6232);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+51004, dvrr_stack+221321, dvrr_stack+309116, dvrr_stack+28253, dvrr_stack+221096, dvrr_stack+50794);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+51424, dvrr_stack+221636, dvrr_stack+51004, dvrr_stack+27051, dvrr_stack+221321, dvrr_stack+331042);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+331042, dvrr_stack+222056, dvrr_stack+51424, dvrr_stack+38233, dvrr_stack+221636, dvrr_stack+282);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+219891, dvrr_stack+222596, dvrr_stack+331042, dvrr_stack+348577, dvrr_stack+222056, dvrr_stack+49973);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+49973, dvrr_stack+18805, dvrr_stack+27478, NULL, NULL, dvrr_stack+18790);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+19719, dvrr_stack+49973, dvrr_stack+11752, dvrr_stack+18805, dvrr_stack+88444);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+50794, dvrr_stack+19782, dvrr_stack+4662, dvrr_stack+71362, dvrr_stack+19719, dvrr_stack+244422);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+50036, dvrr_stack+66366, dvrr_stack+50794, dvrr_stack+71425, dvrr_stack+19782, dvrr_stack+0);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+348577, dvrr_stack+223271, dvrr_stack+50036, dvrr_stack+71551, dvrr_stack+66366, dvrr_stack+642);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+282, dvrr_stack+223586, dvrr_stack+348577, dvrr_stack+38653, dvrr_stack+223271, dvrr_stack+309116);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+220716, dvrr_stack+224027, dvrr_stack+282, dvrr_stack+349117, dvrr_stack+223586, dvrr_stack+51004);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+221472, dvrr_stack+30336, dvrr_stack+220716, dvrr_stack+349558, dvrr_stack+224027, dvrr_stack+51424);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+51004, dvrr_stack+53171, dvrr_stack+221472, dvrr_stack+350146, dvrr_stack+30336, dvrr_stack+331042);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+29706, dvrr_stack+67936, dvrr_stack+51004, dvrr_stack+350902, dvrr_stack+53171, dvrr_stack+219891);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+219891, dvrr_stack+27499, dvrr_stack+37969, NULL, NULL, dvrr_stack+27478);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+219975, dvrr_stack+69091, dvrr_stack+219891, dvrr_stack+18826, dvrr_stack+27499, dvrr_stack+49973);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+220143, dvrr_stack+66817, dvrr_stack+219975, dvrr_stack+37446, dvrr_stack+69091, dvrr_stack+4662);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+53171, dvrr_stack+224615, dvrr_stack+220143, dvrr_stack+933, dvrr_stack+66817, dvrr_stack+50794);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+331042, dvrr_stack+42230, dvrr_stack+53171, dvrr_stack+37530, dvrr_stack+224615, dvrr_stack+50036);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+349018, dvrr_stack+54116, dvrr_stack+331042, dvrr_stack+64263, dvrr_stack+42230, dvrr_stack+348577);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+307667, dvrr_stack+54704, dvrr_stack+349018, dvrr_stack+351847, dvrr_stack+54116, dvrr_stack+282);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+40906, dvrr_stack+307667, dvrr_stack+352435, dvrr_stack+54704, dvrr_stack+220716);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+65523, dvrr_stack+498412, dvrr_stack+64263, dvrr_stack+353219, dvrr_stack+40906, dvrr_stack+221472);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+67063, dvrr_stack+499672, dvrr_stack+65523, dvrr_stack+354227, dvrr_stack+498412, dvrr_stack+51004);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+220423, dvrr_stack+501212, dvrr_stack+67063, dvrr_stack+355487, dvrr_stack+499672, dvrr_stack+29706);

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29706, dvrr_stack+37997, dvrr_stack+50423, NULL, NULL, dvrr_stack+37969);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29814, dvrr_stack+31092, dvrr_stack+29706, dvrr_stack+27527, dvrr_stack+37997, dvrr_stack+219891);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30030, dvrr_stack+238644, dvrr_stack+29814, dvrr_stack+151085, dvrr_stack+31092, dvrr_stack+219975);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30390, dvrr_stack+238860, dvrr_stack+30030, dvrr_stack+28944, dvrr_stack+238644, dvrr_stack+220143);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+498412, dvrr_stack+6382, dvrr_stack+30390, dvrr_stack+151193, dvrr_stack+238860, dvrr_stack+53171);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238644, dvrr_stack+70036, dvrr_stack+498412, dvrr_stack+151553, dvrr_stack+6382, dvrr_stack+331042);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53171, dvrr_stack+503060, dvrr_stack+238644, dvrr_stack+357027, dvrr_stack+70036, dvrr_stack+349018);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+499168, dvrr_stack+504068, dvrr_stack+53171, dvrr_stack+357783, dvrr_stack+503060, dvrr_stack+307667);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+348577, dvrr_stack+505364, dvrr_stack+499168, dvrr_stack+358791, dvrr_stack+504068, dvrr_stack+64263);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+357027, dvrr_stack+240912, dvrr_stack+348577, dvrr_stack+360087, dvrr_stack+505364, dvrr_stack+65523);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+503060, dvrr_stack+506984, dvrr_stack+357027, dvrr_stack+152093, dvrr_stack+240912, dvrr_stack+67063);

 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+240912, dvrr_stack+50459, dvrr_stack+237, NULL, NULL, dvrr_stack+50423);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+241047, dvrr_stack+242892, dvrr_stack+240912, dvrr_stack+38033, dvrr_stack+50459, dvrr_stack+29706);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+241317, dvrr_stack+243027, dvrr_stack+241047, dvrr_stack+52706, dvrr_stack+242892, dvrr_stack+29814);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30930, dvrr_stack+243297, dvrr_stack+241317, dvrr_stack+11448, dvrr_stack+243027, dvrr_stack+30030);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+241767, dvrr_stack+243747, dvrr_stack+30930, dvrr_stack+19101, dvrr_stack+243297, dvrr_stack+30390);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+514904, dvrr_stack+241767, dvrr_stack+366327, dvrr_stack+243747, dvrr_stack+498412);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242712, dvrr_stack+515849, dvrr_stack+64263, dvrr_stack+367002, dvrr_stack+514904, dvrr_stack+238644);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+65523, dvrr_stack+517109, dvrr_stack+242712, dvrr_stack+367947, dvrr_stack+515849, dvrr_stack+53171);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+53171, dvrr_stack+518729, dvrr_stack+65523, dvrr_stack+369207, dvrr_stack+517109, dvrr_stack+499168);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+514904, dvrr_stack+249912, dvrr_stack+53171, dvrr_stack+370827, dvrr_stack+518729, dvrr_stack+348577);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+348577, dvrr_stack+520754, dvrr_stack+514904, dvrr_stack+158541, dvrr_stack+249912, dvrr_stack+357027);

 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+357027, dvrr_stack+49852, dvrr_stack+11882, NULL, NULL, dvrr_stack+237);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+357192, dvrr_stack+252387, dvrr_stack+357027, dvrr_stack+50504, dvrr_stack+49852, dvrr_stack+240912);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+357522, dvrr_stack+252552, dvrr_stack+357192, dvrr_stack+161016, dvrr_stack+252387, dvrr_stack+241047);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+331042, dvrr_stack+252882, dvrr_stack+357522, dvrr_stack+52841, dvrr_stack+252552, dvrr_stack+241317);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+358072, dvrr_stack+253432, dvrr_stack+331042, dvrr_stack+6970, dvrr_stack+252882, dvrr_stack+30930);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+359227, dvrr_stack+81763, dvrr_stack+358072, dvrr_stack+7520, dvrr_stack+253432, dvrr_stack+241767);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+249912, dvrr_stack+530852, dvrr_stack+359227, dvrr_stack+378792, dvrr_stack+81763, dvrr_stack+64263);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+251892, dvrr_stack+532392, dvrr_stack+249912, dvrr_stack+379947, dvrr_stack+530852, dvrr_stack+242712);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+240912, dvrr_stack+259272, dvrr_stack+251892, dvrr_stack+381487, dvrr_stack+532392, dvrr_stack+65523);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+534372, dvrr_stack+240912, dvrr_stack+165309, dvrr_stack+259272, dvrr_stack+53171);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67893, dvrr_stack+537397, dvrr_stack+64263, dvrr_stack+383467, dvrr_stack+534372, dvrr_stack+514904);

 /* compute (1 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+514904, dvrr_stack+18990, dvrr_stack+27563, NULL, NULL, dvrr_stack+11882);

 /* compute (2 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+515102, dvrr_stack+261747, dvrr_stack+514904, dvrr_stack+49907, dvrr_stack+18990, dvrr_stack+357027);

 /* compute (3 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+515498, dvrr_stack+261945, dvrr_stack+515102, dvrr_stack+167784, dvrr_stack+261747, dvrr_stack+357192);

 /* compute (4 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+516158, dvrr_stack+262341, dvrr_stack+515498, dvrr_stack+167982, dvrr_stack+261945, dvrr_stack+357522);

 /* compute (5 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+517148, dvrr_stack+263001, dvrr_stack+516158, dvrr_stack+168378, dvrr_stack+262341, dvrr_stack+331042);

 /* compute (6 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+518534, dvrr_stack+549937, dvrr_stack+517148, dvrr_stack+393917, dvrr_stack+263001, dvrr_stack+358072);

 /* compute (7 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+259272, dvrr_stack+551323, dvrr_stack+518534, dvrr_stack+394907, dvrr_stack+549937, dvrr_stack+359227);

 /* compute (8 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+357027, dvrr_stack+553171, dvrr_stack+259272, dvrr_stack+396293, dvrr_stack+551323, dvrr_stack+249912);

 /* compute (9 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+393917, dvrr_stack+271397, dvrr_stack+357027, dvrr_stack+398141, dvrr_stack+553171, dvrr_stack+251892);

 /* compute (10 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+249912, dvrr_stack+555547, dvrr_stack+393917, dvrr_stack+174239, dvrr_stack+271397, dvrr_stack+240912);

 /* compute (11 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+549937, dvrr_stack+559177, dvrr_stack+249912, dvrr_stack+400517, dvrr_stack+555547, dvrr_stack+64263);

 /* compute (1 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+114033, dvrr_stack+50625, NULL, NULL, dvrr_stack+27563);

 /* compute (2 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+64497, dvrr_stack+274367, dvrr_stack+64263, dvrr_stack+27629, dvrr_stack+114033, dvrr_stack+514904);

 /* compute (3 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+64965, dvrr_stack+274601, dvrr_stack+64497, dvrr_stack+177209, dvrr_stack+274367, dvrr_stack+515102);

 /* compute (4 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+65745, dvrr_stack+275069, dvrr_stack+64965, dvrr_stack+177443, dvrr_stack+274601, dvrr_stack+515498);

 /* compute (5 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+240912, dvrr_stack+275849, dvrr_stack+65745, dvrr_stack+177911, dvrr_stack+275069, dvrr_stack+516158);

 /* compute (6 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+514904, dvrr_stack+277019, dvrr_stack+240912, dvrr_stack+413222, dvrr_stack+275849, dvrr_stack+517148);

 /* compute (7 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+271397, dvrr_stack+574423, dvrr_stack+514904, dvrr_stack+414392, dvrr_stack+277019, dvrr_stack+518534);

 /* compute (8 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+517088, dvrr_stack+576607, dvrr_stack+271397, dvrr_stack+416030, dvrr_stack+574423, dvrr_stack+259272);

 /* compute (9 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+259272, dvrr_stack+286082, dvrr_stack+517088, dvrr_stack+418214, dvrr_stack+576607, dvrr_stack+357027);

 /* compute (10 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+413222, dvrr_stack+579415, dvrr_stack+259272, dvrr_stack+421022, dvrr_stack+286082, dvrr_stack+393917);

 /* compute (11 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+393917, dvrr_stack+583705, dvrr_stack+413222, dvrr_stack+187439, dvrr_stack+579415, dvrr_stack+249912);

 /* compute (1 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+249912, dvrr_stack+207508, dvrr_stack+1404, NULL, NULL, dvrr_stack+50625);

 /* compute (2 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+250185, dvrr_stack+289592, dvrr_stack+249912, dvrr_stack+50703, dvrr_stack+207508, dvrr_stack+64263);

 /* compute (3 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+250731, dvrr_stack+289865, dvrr_stack+250185, dvrr_stack+191729, dvrr_stack+289592, dvrr_stack+64497);

 /* compute (4 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+251641, dvrr_stack+290411, dvrr_stack+250731, dvrr_stack+29160, dvrr_stack+289865, dvrr_stack+64965);

 /* compute (5 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+286082, dvrr_stack+291321, dvrr_stack+251641, dvrr_stack+435422, dvrr_stack+290411, dvrr_stack+65745);

 /* compute (6 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+292686, dvrr_stack+286082, dvrr_stack+436332, dvrr_stack+291321, dvrr_stack+240912);

 /* compute (7 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+240912, dvrr_stack+601921, dvrr_stack+64263, dvrr_stack+437697, dvrr_stack+292686, dvrr_stack+514904);

 /* compute (8 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+286082, dvrr_stack+604469, dvrr_stack+240912, dvrr_stack+439608, dvrr_stack+601921, dvrr_stack+271397);

 /* compute (9 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+271397, dvrr_stack+303572, dvrr_stack+286082, dvrr_stack+442156, dvrr_stack+604469, dvrr_stack+517088);

 /* compute (10 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+286082, dvrr_stack+607745, dvrr_stack+271397, dvrr_stack+445432, dvrr_stack+303572, dvrr_stack+259272);

 /* compute (11 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+271397, dvrr_stack+612750, dvrr_stack+286082, dvrr_stack+202367, dvrr_stack+607745, dvrr_stack+413222);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+413222, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 413222;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+413810, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 413810;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+414566, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 414566;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+415511, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 415511;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+416666, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 416666;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+418052, dvrr_stack+59349, NULL);
 tmp = dvrr_stack + 418052;
 target_ptr = Libderiv->deriv_classes[5][11][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1911,dvrr_stack+419690, dvrr_stack+74658, NULL);
 tmp = dvrr_stack + 419690;
 target_ptr = Libderiv->deriv_classes[5][12][11];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+421601, dvrr_stack+84067, NULL);
 tmp = dvrr_stack + 421601;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+238644, dvrr_stack+89749, NULL);
 tmp = dvrr_stack + 238644;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+422385, dvrr_stack+96843, NULL);
 tmp = dvrr_stack + 422385;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+286082, dvrr_stack+105903, NULL);
 tmp = dvrr_stack + 286082;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+287622, dvrr_stack+116295, NULL);
 tmp = dvrr_stack + 287622;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+289470, dvrr_stack+129119, NULL);
 tmp = dvrr_stack + 289470;
 target_ptr = Libderiv->deriv_classes[6][11][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2548,dvrr_stack+291654, dvrr_stack+143441, NULL);
 tmp = dvrr_stack + 291654;
 target_ptr = Libderiv->deriv_classes[6][12][11];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+151085, dvrr_stack+155517, NULL);
 tmp = dvrr_stack + 151085;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+81763, dvrr_stack+161421, NULL);
 tmp = dvrr_stack + 81763;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+259272, dvrr_stack+169379, NULL);
 tmp = dvrr_stack + 259272;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+260892, dvrr_stack+181499, NULL);
 tmp = dvrr_stack + 260892;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+262872, dvrr_stack+195239, NULL);
 tmp = dvrr_stack + 262872;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+303572, dvrr_stack+211467, NULL);
 tmp = dvrr_stack + 303572;
 target_ptr = Libderiv->deriv_classes[7][11][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3276,dvrr_stack+601921, dvrr_stack+228816, NULL);
 tmp = dvrr_stack + 601921;
 target_ptr = Libderiv->deriv_classes[7][12][11];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+306380, dvrr_stack+246132, NULL);
 tmp = dvrr_stack + 306380;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+605197, dvrr_stack+254412, NULL);
 tmp = dvrr_stack + 605197;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+606817, dvrr_stack+265322, NULL);
 tmp = dvrr_stack + 606817;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+608842, dvrr_stack+278657, NULL);
 tmp = dvrr_stack + 608842;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+240912, dvrr_stack+294662, NULL);
 tmp = dvrr_stack + 240912;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+514904, dvrr_stack+313582, NULL);
 tmp = dvrr_stack + 514904;
 target_ptr = Libderiv->deriv_classes[8][11][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4095,dvrr_stack+435422, dvrr_stack+336292, NULL);
 tmp = dvrr_stack + 435422;
 target_ptr = Libderiv->deriv_classes[8][12][11];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+518414, dvrr_stack+361707, NULL);
 tmp = dvrr_stack + 518414;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+64263, dvrr_stack+372852, NULL);
 tmp = dvrr_stack + 64263;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+439517, dvrr_stack+386492, NULL);
 tmp = dvrr_stack + 439517;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+441992, dvrr_stack+404147, NULL);
 tmp = dvrr_stack + 441992;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+445017, dvrr_stack+424532, NULL);
 tmp = dvrr_stack + 445017;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+249912, dvrr_stack+449527, NULL);
 tmp = dvrr_stack + 249912;
 target_ptr = Libderiv->deriv_classes[9][11][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5005,dvrr_stack+574423, dvrr_stack+483397, NULL);
 tmp = dvrr_stack + 574423;
 target_ptr = Libderiv->deriv_classes[9][12][11];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+357027, dvrr_stack+509360, NULL);
 tmp = dvrr_stack + 357027;
 target_ptr = Libderiv->deriv_classes[10][6][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+358875, dvrr_stack+523724, NULL);
 tmp = dvrr_stack + 358875;
 target_ptr = Libderiv->deriv_classes[10][7][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+579428, dvrr_stack+541027, NULL);
 tmp = dvrr_stack + 579428;
 target_ptr = Libderiv->deriv_classes[10][8][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+174239, dvrr_stack+563533, NULL);
 tmp = dvrr_stack + 174239;
 target_ptr = Libderiv->deriv_classes[10][9][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+530852, dvrr_stack+588853, NULL);
 tmp = dvrr_stack + 530852;
 target_ptr = Libderiv->deriv_classes[10][10][11];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5148,dvrr_stack+366327, dvrr_stack+618756, NULL);
 tmp = dvrr_stack + 366327;
 target_ptr = Libderiv->deriv_classes[10][11][11];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,6006,dvrr_stack+462397, dvrr_stack+634200, NULL);
 tmp = dvrr_stack + 462397;
 target_ptr = Libderiv->deriv_classes[10][12][11];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+423645, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 423645;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+307640, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 307640;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+611317, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 611317;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+66243, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 66243;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+555085, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 555085;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+556471, dvrr_stack+59349, NULL);
 tmp = dvrr_stack + 556471;
 target_ptr = Libderiv->deriv_classes[5][11][10];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1911,dvrr_stack+165309, dvrr_stack+74658, NULL);
 tmp = dvrr_stack + 165309;
 target_ptr = Libderiv->deriv_classes[5][12][10];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+519954, dvrr_stack+84067, NULL);
 tmp = dvrr_stack + 519954;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+582398, dvrr_stack+89749, NULL);
 tmp = dvrr_stack + 582398;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+167220, dvrr_stack+96843, NULL);
 tmp = dvrr_stack + 167220;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+535208, dvrr_stack+105903, NULL);
 tmp = dvrr_stack + 535208;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+378792, dvrr_stack+116295, NULL);
 tmp = dvrr_stack + 378792;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+380640, dvrr_stack+129119, NULL);
 tmp = dvrr_stack + 380640;
 target_ptr = Libderiv->deriv_classes[6][11][10];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2548,dvrr_stack+352087, dvrr_stack+143441, NULL);
 tmp = dvrr_stack + 352087;
 target_ptr = Libderiv->deriv_classes[6][12][10];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+177869, dvrr_stack+155517, NULL);
 tmp = dvrr_stack + 177869;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+498412, dvrr_stack+161421, NULL);
 tmp = dvrr_stack + 498412;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+37446, dvrr_stack+169379, NULL);
 tmp = dvrr_stack + 37446;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+39066, dvrr_stack+181499, NULL);
 tmp = dvrr_stack + 39066;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+222607, dvrr_stack+195239, NULL);
 tmp = dvrr_stack + 222607;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+0, dvrr_stack+211467, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[7][11][10];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3276,dvrr_stack+27051, dvrr_stack+228816, NULL);
 tmp = dvrr_stack + 27051;
 target_ptr = Libderiv->deriv_classes[7][12][10];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+499708, dvrr_stack+246132, NULL);
 tmp = dvrr_stack + 499708;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+41046, dvrr_stack+254412, NULL);
 tmp = dvrr_stack + 41046;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+333253, dvrr_stack+265322, NULL);
 tmp = dvrr_stack + 333253;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+468403, dvrr_stack+278657, NULL);
 tmp = dvrr_stack + 468403;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+470878, dvrr_stack+294662, NULL);
 tmp = dvrr_stack + 470878;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+473848, dvrr_stack+313582, NULL);
 tmp = dvrr_stack + 473848;
 target_ptr = Libderiv->deriv_classes[8][11][10];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4095,dvrr_stack+49794, dvrr_stack+336292, NULL);
 tmp = dvrr_stack + 49794;
 target_ptr = Libderiv->deriv_classes[8][12][10];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+18441, dvrr_stack+361707, NULL);
 tmp = dvrr_stack + 18441;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+53889, dvrr_stack+372852, NULL);
 tmp = dvrr_stack + 53889;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+5796, dvrr_stack+386492, NULL);
 tmp = dvrr_stack + 5796;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+652218, dvrr_stack+404147, NULL);
 tmp = dvrr_stack + 652218;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+655243, dvrr_stack+424532, NULL);
 tmp = dvrr_stack + 655243;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+658873, dvrr_stack+449527, NULL);
 tmp = dvrr_stack + 658873;
 target_ptr = Libderiv->deriv_classes[9][11][10];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5005,dvrr_stack+663163, dvrr_stack+483397, NULL);
 tmp = dvrr_stack + 663163;
 target_ptr = Libderiv->deriv_classes[9][12][10];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+668168, dvrr_stack+509360, NULL);
 tmp = dvrr_stack + 668168;
 target_ptr = Libderiv->deriv_classes[10][6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+670016, dvrr_stack+523724, NULL);
 tmp = dvrr_stack + 670016;
 target_ptr = Libderiv->deriv_classes[10][7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+672392, dvrr_stack+541027, NULL);
 tmp = dvrr_stack + 672392;
 target_ptr = Libderiv->deriv_classes[10][8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+675362, dvrr_stack+563533, NULL);
 tmp = dvrr_stack + 675362;
 target_ptr = Libderiv->deriv_classes[10][9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+678992, dvrr_stack+588853, NULL);
 tmp = dvrr_stack + 678992;
 target_ptr = Libderiv->deriv_classes[10][10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5148,dvrr_stack+683348, dvrr_stack+618756, NULL);
 tmp = dvrr_stack + 683348;
 target_ptr = Libderiv->deriv_classes[10][11][10];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,6006,dvrr_stack+688496, dvrr_stack+634200, NULL);
 tmp = dvrr_stack + 688496;
 target_ptr = Libderiv->deriv_classes[10][12][10];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+243882, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 243882;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+9684, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 9684;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+16173, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 16173;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+24216, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 24216;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+33981, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 33981;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+45636, dvrr_stack+59349, NULL);
 tmp = dvrr_stack + 45636;
 target_ptr = Libderiv->deriv_classes[5][11][9];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1911,dvrr_stack+59349, dvrr_stack+74658, NULL);
 tmp = dvrr_stack + 59349;
 target_ptr = Libderiv->deriv_classes[5][12][9];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+74658, dvrr_stack+84067, NULL);
 tmp = dvrr_stack + 74658;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+84067, dvrr_stack+89749, NULL);
 tmp = dvrr_stack + 84067;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+89749, dvrr_stack+96843, NULL);
 tmp = dvrr_stack + 89749;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+96843, dvrr_stack+105903, NULL);
 tmp = dvrr_stack + 96843;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+105903, dvrr_stack+116295, NULL);
 tmp = dvrr_stack + 105903;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+116295, dvrr_stack+129119, NULL);
 tmp = dvrr_stack + 116295;
 target_ptr = Libderiv->deriv_classes[6][11][9];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2548,dvrr_stack+129119, dvrr_stack+143441, NULL);
 tmp = dvrr_stack + 129119;
 target_ptr = Libderiv->deriv_classes[6][12][9];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+143441, dvrr_stack+155517, NULL);
 tmp = dvrr_stack + 143441;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+155517, dvrr_stack+161421, NULL);
 tmp = dvrr_stack + 155517;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+156813, dvrr_stack+169379, NULL);
 tmp = dvrr_stack + 156813;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+144449, dvrr_stack+181499, NULL);
 tmp = dvrr_stack + 144449;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+181499, dvrr_stack+195239, NULL);
 tmp = dvrr_stack + 181499;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+195239, dvrr_stack+211467, NULL);
 tmp = dvrr_stack + 195239;
 target_ptr = Libderiv->deriv_classes[7][11][9];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3276,dvrr_stack+211467, dvrr_stack+228816, NULL);
 tmp = dvrr_stack + 211467;
 target_ptr = Libderiv->deriv_classes[7][12][9];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+228816, dvrr_stack+246132, NULL);
 tmp = dvrr_stack + 228816;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+246132, dvrr_stack+254412, NULL);
 tmp = dvrr_stack + 246132;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+247752, dvrr_stack+265322, NULL);
 tmp = dvrr_stack + 247752;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+230076, dvrr_stack+278657, NULL);
 tmp = dvrr_stack + 230076;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+232551, dvrr_stack+294662, NULL);
 tmp = dvrr_stack + 232551;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+214743, dvrr_stack+313582, NULL);
 tmp = dvrr_stack + 214743;
 target_ptr = Libderiv->deriv_classes[8][11][9];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4095,dvrr_stack+198047, dvrr_stack+336292, NULL);
 tmp = dvrr_stack + 198047;
 target_ptr = Libderiv->deriv_classes[8][12][9];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+235521, dvrr_stack+361707, NULL);
 tmp = dvrr_stack + 235521;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+218253, dvrr_stack+372852, NULL);
 tmp = dvrr_stack + 218253;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+183875, dvrr_stack+386492, NULL);
 tmp = dvrr_stack + 183875;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+386492, dvrr_stack+404147, NULL);
 tmp = dvrr_stack + 386492;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+404147, dvrr_stack+424532, NULL);
 tmp = dvrr_stack + 404147;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+407777, dvrr_stack+449527, NULL);
 tmp = dvrr_stack + 407777;
 target_ptr = Libderiv->deriv_classes[9][11][9];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5005,dvrr_stack+424233, dvrr_stack+483397, NULL);
 tmp = dvrr_stack + 424233;
 target_ptr = Libderiv->deriv_classes[9][12][9];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+483397, dvrr_stack+509360, NULL);
 tmp = dvrr_stack + 483397;
 target_ptr = Libderiv->deriv_classes[10][6][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+509360, dvrr_stack+523724, NULL);
 tmp = dvrr_stack + 509360;
 target_ptr = Libderiv->deriv_classes[10][7][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+523724, dvrr_stack+541027, NULL);
 tmp = dvrr_stack + 523724;
 target_ptr = Libderiv->deriv_classes[10][8][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+541027, dvrr_stack+563533, NULL);
 tmp = dvrr_stack + 541027;
 target_ptr = Libderiv->deriv_classes[10][9][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+563533, dvrr_stack+588853, NULL);
 tmp = dvrr_stack + 563533;
 target_ptr = Libderiv->deriv_classes[10][10][9];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5148,dvrr_stack+588853, dvrr_stack+618756, NULL);
 tmp = dvrr_stack + 588853;
 target_ptr = Libderiv->deriv_classes[10][11][9];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,6006,dvrr_stack+618756, dvrr_stack+634200, NULL);
 tmp = dvrr_stack + 618756;
 target_ptr = Libderiv->deriv_classes[10][12][9];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+624762, dvrr_stack+8928, dvrr_stack+308675);
 tmp = dvrr_stack + 624762;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+625350, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 625350;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+626106, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 626106;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+412067, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 412067;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+627051, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 627051;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,21,1,dvrr_stack+628437, dvrr_stack+57438, dvrr_stack+32595);
 tmp = dvrr_stack + 628437;
 target_ptr = Libderiv->deriv_classes[5][11][8];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,21,1,dvrr_stack+630075, dvrr_stack+72453, dvrr_stack+43998);
 tmp = dvrr_stack + 630075;
 target_ptr = Libderiv->deriv_classes[5][12][8];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+631986, dvrr_stack+83059, dvrr_stack+80391);
 tmp = dvrr_stack + 631986;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+632770, dvrr_stack+88489, dvrr_stack+80979);
 tmp = dvrr_stack + 632770;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+633778, dvrr_stack+95303, dvrr_stack+83059);
 tmp = dvrr_stack + 633778;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+635038, dvrr_stack+104055, dvrr_stack+88489);
 tmp = dvrr_stack + 635038;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+636578, dvrr_stack+114111, dvrr_stack+95303);
 tmp = dvrr_stack + 636578;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,28,1,dvrr_stack+638426, dvrr_stack+126571, dvrr_stack+104055);
 tmp = dvrr_stack + 638426;
 target_ptr = Libderiv->deriv_classes[6][11][8];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,28,1,dvrr_stack+640610, dvrr_stack+140501, dvrr_stack+114111);
 tmp = dvrr_stack + 640610;
 target_ptr = Libderiv->deriv_classes[6][12][8];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+643158, dvrr_stack+154221, dvrr_stack+309431);
 tmp = dvrr_stack + 643158;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+644166, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 644166;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+645462, dvrr_stack+20134, dvrr_stack+154221);
 tmp = dvrr_stack + 645462;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+647082, dvrr_stack+179123, dvrr_stack+12793);
 tmp = dvrr_stack + 647082;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+649062, dvrr_stack+192431, dvrr_stack+20134);
 tmp = dvrr_stack + 649062;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,36,1,dvrr_stack+594001, dvrr_stack+208191, dvrr_stack+179123);
 tmp = dvrr_stack + 594001;
 target_ptr = Libderiv->deriv_classes[7][11][8];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,36,1,dvrr_stack+596809, dvrr_stack+225036, dvrr_stack+192431);
 tmp = dvrr_stack + 596809;
 target_ptr = Libderiv->deriv_classes[7][12][8];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+600085, dvrr_stack+244512, dvrr_stack+310187);
 tmp = dvrr_stack + 600085;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+567889, dvrr_stack+86419, dvrr_stack+239652);
 tmp = dvrr_stack + 567889;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+569509, dvrr_stack+92773, dvrr_stack+244512);
 tmp = dvrr_stack + 569509;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+571534, dvrr_stack+100623, dvrr_stack+86419);
 tmp = dvrr_stack + 571534;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+544657, dvrr_stack+110523, dvrr_stack+92773);
 tmp = dvrr_stack + 544657;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,45,1,dvrr_stack+526694, dvrr_stack+121839, dvrr_stack+100623);
 tmp = dvrr_stack + 526694;
 target_ptr = Libderiv->deriv_classes[8][11][8];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,45,1,dvrr_stack+485245, dvrr_stack+135671, dvrr_stack+110523);
 tmp = dvrr_stack + 485245;
 target_ptr = Libderiv->deriv_classes[8][12][8];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+547627, dvrr_stack+152093, dvrr_stack+312167);
 tmp = dvrr_stack + 547627;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+511736, dvrr_stack+158541, dvrr_stack+355487);
 tmp = dvrr_stack + 511736;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+489340, dvrr_stack+383467, dvrr_stack+152093);
 tmp = dvrr_stack + 489340;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+491815, dvrr_stack+400517, dvrr_stack+158541);
 tmp = dvrr_stack + 491815;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+389517, dvrr_stack+187439, dvrr_stack+383467);
 tmp = dvrr_stack + 389517;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,55,1,dvrr_stack+146429, dvrr_stack+202367, dvrr_stack+400517);
 tmp = dvrr_stack + 146429;
 target_ptr = Libderiv->deriv_classes[9][11][8];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,55,1,dvrr_stack+429238, dvrr_stack+477622, dvrr_stack+187439);
 tmp = dvrr_stack + 429238;
 target_ptr = Libderiv->deriv_classes[9][12][8];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+494840, dvrr_stack+506984, dvrr_stack+331867);
 tmp = dvrr_stack + 494840;
 target_ptr = Libderiv->deriv_classes[10][6][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+131667, dvrr_stack+520754, dvrr_stack+501212);
 tmp = dvrr_stack + 131667;
 target_ptr = Libderiv->deriv_classes[10][7][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+118479, dvrr_stack+537397, dvrr_stack+506984);
 tmp = dvrr_stack + 118479;
 target_ptr = Libderiv->deriv_classes[10][8][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+75442, dvrr_stack+559177, dvrr_stack+520754);
 tmp = dvrr_stack + 75442;
 target_ptr = Libderiv->deriv_classes[10][9][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+294202, dvrr_stack+583705, dvrr_stack+537397);
 tmp = dvrr_stack + 294202;
 target_ptr = Libderiv->deriv_classes[10][10][8];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,66,1,dvrr_stack+265248, dvrr_stack+612750, dvrr_stack+559177);
 tmp = dvrr_stack + 265248;
 target_ptr = Libderiv->deriv_classes[10][11][8];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,66,1,dvrr_stack+278495, dvrr_stack+324112, dvrr_stack+583705);
 tmp = dvrr_stack + 278495;
 target_ptr = Libderiv->deriv_classes[10][12][8];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+651438, dvrr_stack+8928, dvrr_stack+308675);
 tmp = dvrr_stack + 651438;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+549167, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 549167;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+513716, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 513716;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+496688, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 496688;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+237061, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 237061;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,21,1,dvrr_stack+107751, dvrr_stack+57438, dvrr_stack+32595);
 tmp = dvrr_stack + 107751;
 target_ptr = Libderiv->deriv_classes[5][11][7];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,21,1,dvrr_stack+98383, dvrr_stack+72453, dvrr_stack+43998);
 tmp = dvrr_stack + 98383;
 target_ptr = Libderiv->deriv_classes[5][12][7];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+186350, dvrr_stack+83059, dvrr_stack+80391);
 tmp = dvrr_stack + 186350;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+134043, dvrr_stack+88489, dvrr_stack+80979);
 tmp = dvrr_stack + 134043;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+91009, dvrr_stack+95303, dvrr_stack+83059);
 tmp = dvrr_stack + 91009;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+61260, dvrr_stack+104055, dvrr_stack+88489);
 tmp = dvrr_stack + 61260;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+47274, dvrr_stack+114111, dvrr_stack+95303);
 tmp = dvrr_stack + 47274;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,28,1,dvrr_stack+10440, dvrr_stack+126571, dvrr_stack+104055);
 tmp = dvrr_stack + 10440;
 target_ptr = Libderiv->deriv_classes[6][11][7];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,28,1,dvrr_stack+298558, dvrr_stack+140501, dvrr_stack+114111);
 tmp = dvrr_stack + 298558;
 target_ptr = Libderiv->deriv_classes[6][12][7];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+109389, dvrr_stack+154221, dvrr_stack+309431);
 tmp = dvrr_stack + 109389;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+85075, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 85075;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+35367, dvrr_stack+20134, dvrr_stack+154221);
 tmp = dvrr_stack + 35367;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+301106, dvrr_stack+179123, dvrr_stack+12793);
 tmp = dvrr_stack + 301106;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+448647, dvrr_stack+192431, dvrr_stack+20134);
 tmp = dvrr_stack + 448647;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,36,1,dvrr_stack+451023, dvrr_stack+208191, dvrr_stack+179123);
 tmp = dvrr_stack + 451023;
 target_ptr = Libderiv->deriv_classes[7][11][7];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,36,1,dvrr_stack+453831, dvrr_stack+225036, dvrr_stack+192431);
 tmp = dvrr_stack + 453831;
 target_ptr = Libderiv->deriv_classes[7][12][7];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+79072, dvrr_stack+244512, dvrr_stack+310187);
 tmp = dvrr_stack + 79072;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+25371, dvrr_stack+86419, dvrr_stack+239652);
 tmp = dvrr_stack + 25371;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+457107, dvrr_stack+92773, dvrr_stack+244512);
 tmp = dvrr_stack + 457107;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+459132, dvrr_stack+100623, dvrr_stack+86419);
 tmp = dvrr_stack + 459132;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+254202, dvrr_stack+110523, dvrr_stack+92773);
 tmp = dvrr_stack + 254202;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,45,1,dvrr_stack+361251, dvrr_stack+121839, dvrr_stack+100623);
 tmp = dvrr_stack + 361251;
 target_ptr = Libderiv->deriv_classes[8][11][7];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,45,1,dvrr_stack+168480, dvrr_stack+135671, dvrr_stack+110523);
 tmp = dvrr_stack + 168480;
 target_ptr = Libderiv->deriv_classes[8][12][7];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+284501, dvrr_stack+152093, dvrr_stack+312167);
 tmp = dvrr_stack + 284501;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+257172, dvrr_stack+158541, dvrr_stack+355487);
 tmp = dvrr_stack + 257172;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+161016, dvrr_stack+383467, dvrr_stack+152093);
 tmp = dvrr_stack + 161016;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+371475, dvrr_stack+400517, dvrr_stack+158541);
 tmp = dvrr_stack + 371475;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+374500, dvrr_stack+187439, dvrr_stack+383467);
 tmp = dvrr_stack + 374500;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,55,1,dvrr_stack+313322, dvrr_stack+202367, dvrr_stack+400517);
 tmp = dvrr_stack + 313322;
 target_ptr = Libderiv->deriv_classes[9][11][7];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,55,1,dvrr_stack+317612, dvrr_stack+477622, dvrr_stack+187439);
 tmp = dvrr_stack + 317612;
 target_ptr = Libderiv->deriv_classes[9][12][7];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+335278, dvrr_stack+506984, dvrr_stack+331867);
 tmp = dvrr_stack + 335278;
 target_ptr = Libderiv->deriv_classes[10][6][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+337126, dvrr_stack+520754, dvrr_stack+501212);
 tmp = dvrr_stack + 337126;
 target_ptr = Libderiv->deriv_classes[10][7][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+339502, dvrr_stack+537397, dvrr_stack+506984);
 tmp = dvrr_stack + 339502;
 target_ptr = Libderiv->deriv_classes[10][8][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+342472, dvrr_stack+559177, dvrr_stack+520754);
 tmp = dvrr_stack + 342472;
 target_ptr = Libderiv->deriv_classes[10][9][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+694502, dvrr_stack+583705, dvrr_stack+537397);
 tmp = dvrr_stack + 694502;
 target_ptr = Libderiv->deriv_classes[10][10][7];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,66,1,dvrr_stack+698858, dvrr_stack+612750, dvrr_stack+559177);
 tmp = dvrr_stack + 698858;
 target_ptr = Libderiv->deriv_classes[10][11][7];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,66,1,dvrr_stack+704006, dvrr_stack+324112, dvrr_stack+583705);
 tmp = dvrr_stack + 704006;
 target_ptr = Libderiv->deriv_classes[10][12][7];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+530204, dvrr_stack+8928, dvrr_stack+308675);
 tmp = dvrr_stack + 530204;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+393147, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 393147;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+62800, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 62800;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+17118, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 17118;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+364761, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 364761;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,21,1,dvrr_stack+172575, dvrr_stack+57438, dvrr_stack+32595);
 tmp = dvrr_stack + 172575;
 target_ptr = Libderiv->deriv_classes[5][11][6];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,21,1,dvrr_stack+346102, dvrr_stack+72453, dvrr_stack+43998);
 tmp = dvrr_stack + 346102;
 target_ptr = Libderiv->deriv_classes[5][12][6];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+434243, dvrr_stack+83059, dvrr_stack+80391);
 tmp = dvrr_stack + 434243;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+308396, dvrr_stack+88489, dvrr_stack+80979);
 tmp = dvrr_stack + 308396;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+72183, dvrr_stack+95303, dvrr_stack+83059);
 tmp = dvrr_stack + 72183;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+163491, dvrr_stack+104055, dvrr_stack+88489);
 tmp = dvrr_stack + 163491;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+710012, dvrr_stack+114111, dvrr_stack+95303);
 tmp = dvrr_stack + 710012;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,28,1,dvrr_stack+711860, dvrr_stack+126571, dvrr_stack+104055);
 tmp = dvrr_stack + 711860;
 target_ptr = Libderiv->deriv_classes[6][11][6];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,28,1,dvrr_stack+714044, dvrr_stack+140501, dvrr_stack+114111);
 tmp = dvrr_stack + 714044;
 target_ptr = Libderiv->deriv_classes[6][12][6];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+558109, dvrr_stack+154221, dvrr_stack+309431);
 tmp = dvrr_stack + 558109;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+140396, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 140396;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+141692, dvrr_stack+20134, dvrr_stack+154221);
 tmp = dvrr_stack + 141692;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+716592, dvrr_stack+179123, dvrr_stack+12793);
 tmp = dvrr_stack + 716592;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+718572, dvrr_stack+192431, dvrr_stack+20134);
 tmp = dvrr_stack + 718572;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,36,1,dvrr_stack+720948, dvrr_stack+208191, dvrr_stack+179123);
 tmp = dvrr_stack + 720948;
 target_ptr = Libderiv->deriv_classes[7][11][6];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,36,1,dvrr_stack+723756, dvrr_stack+225036, dvrr_stack+192431);
 tmp = dvrr_stack + 723756;
 target_ptr = Libderiv->deriv_classes[7][12][6];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+224983, dvrr_stack+244512, dvrr_stack+310187);
 tmp = dvrr_stack + 224983;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+309404, dvrr_stack+86419, dvrr_stack+239652);
 tmp = dvrr_stack + 309404;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+226243, dvrr_stack+92773, dvrr_stack+244512);
 tmp = dvrr_stack + 226243;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+727032, dvrr_stack+100623, dvrr_stack+86419);
 tmp = dvrr_stack + 727032;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+729507, dvrr_stack+110523, dvrr_stack+92773);
 tmp = dvrr_stack + 729507;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,45,1,dvrr_stack+732477, dvrr_stack+121839, dvrr_stack+100623);
 tmp = dvrr_stack + 732477;
 target_ptr = Libderiv->deriv_classes[8][11][6];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,45,1,dvrr_stack+735987, dvrr_stack+135671, dvrr_stack+110523);
 tmp = dvrr_stack + 735987;
 target_ptr = Libderiv->deriv_classes[8][12][6];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+135051, dvrr_stack+152093, dvrr_stack+312167);
 tmp = dvrr_stack + 135051;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+136591, dvrr_stack+158541, dvrr_stack+355487);
 tmp = dvrr_stack + 136591;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+740082, dvrr_stack+383467, dvrr_stack+152093);
 tmp = dvrr_stack + 740082;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+742557, dvrr_stack+400517, dvrr_stack+158541);
 tmp = dvrr_stack + 742557;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+745582, dvrr_stack+187439, dvrr_stack+383467);
 tmp = dvrr_stack + 745582;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,55,1,dvrr_stack+749212, dvrr_stack+202367, dvrr_stack+400517);
 tmp = dvrr_stack + 749212;
 target_ptr = Libderiv->deriv_classes[9][11][6];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,55,1,dvrr_stack+753502, dvrr_stack+477622, dvrr_stack+187439);
 tmp = dvrr_stack + 753502;
 target_ptr = Libderiv->deriv_classes[9][12][6];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+311024, dvrr_stack+506984, dvrr_stack+331867);
 tmp = dvrr_stack + 311024;
 target_ptr = Libderiv->deriv_classes[10][6][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+477358, dvrr_stack+520754, dvrr_stack+501212);
 tmp = dvrr_stack + 477358;
 target_ptr = Libderiv->deriv_classes[10][7][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+479734, dvrr_stack+537397, dvrr_stack+506984);
 tmp = dvrr_stack + 479734;
 target_ptr = Libderiv->deriv_classes[10][8][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+758507, dvrr_stack+559177, dvrr_stack+520754);
 tmp = dvrr_stack + 758507;
 target_ptr = Libderiv->deriv_classes[10][9][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+762137, dvrr_stack+583705, dvrr_stack+537397);
 tmp = dvrr_stack + 762137;
 target_ptr = Libderiv->deriv_classes[10][10][6];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,66,1,dvrr_stack+766493, dvrr_stack+612750, dvrr_stack+559177);
 tmp = dvrr_stack + 766493;
 target_ptr = Libderiv->deriv_classes[10][11][6];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,66,1,dvrr_stack+771641, dvrr_stack+324112, dvrr_stack+583705);
 tmp = dvrr_stack + 771641;
 target_ptr = Libderiv->deriv_classes[10][12][6];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+138571, dvrr_stack+80979, dvrr_stack+4788);
 tmp = dvrr_stack + 138571;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+139159, dvrr_stack+83059, dvrr_stack+8388);
 tmp = dvrr_stack + 139159;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+270396, dvrr_stack+88489, dvrr_stack+14553);
 tmp = dvrr_stack + 270396;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+73443, dvrr_stack+95303, dvrr_stack+22236);
 tmp = dvrr_stack + 73443;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+322617, dvrr_stack+104055, dvrr_stack+31605);
 tmp = dvrr_stack + 322617;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,78,dvrr_stack+324003, dvrr_stack+114111, dvrr_stack+42828);
 tmp = dvrr_stack + 324003;
 target_ptr = Libderiv->deriv_classes[5][11][2];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,91,dvrr_stack+325641, dvrr_stack+126571, dvrr_stack+56073);
 tmp = dvrr_stack + 325641;
 target_ptr = Libderiv->deriv_classes[5][12][2];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+461607, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 461607;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+505868, dvrr_stack+154221, dvrr_stack+8928);
 tmp = dvrr_stack + 505868;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+30327, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 30327;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+327552, dvrr_stack+20134, dvrr_stack+23061);
 tmp = dvrr_stack + 327552;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+329092, dvrr_stack+179123, dvrr_stack+32595);
 tmp = dvrr_stack + 329092;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,78,dvrr_stack+330940, dvrr_stack+192431, dvrr_stack+43998);
 tmp = dvrr_stack + 330940;
 target_ptr = Libderiv->deriv_classes[6][11][2];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,91,dvrr_stack+777647, dvrr_stack+208191, dvrr_stack+57438);
 tmp = dvrr_stack + 777647;
 target_ptr = Libderiv->deriv_classes[6][12][2];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+780195, dvrr_stack+239652, dvrr_stack+80979);
 tmp = dvrr_stack + 780195;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+781203, dvrr_stack+244512, dvrr_stack+83059);
 tmp = dvrr_stack + 781203;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+782499, dvrr_stack+86419, dvrr_stack+88489);
 tmp = dvrr_stack + 782499;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+784119, dvrr_stack+92773, dvrr_stack+95303);
 tmp = dvrr_stack + 784119;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+786099, dvrr_stack+100623, dvrr_stack+104055);
 tmp = dvrr_stack + 786099;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,78,dvrr_stack+788475, dvrr_stack+110523, dvrr_stack+114111);
 tmp = dvrr_stack + 788475;
 target_ptr = Libderiv->deriv_classes[7][11][2];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,91,dvrr_stack+791283, dvrr_stack+121839, dvrr_stack+126571);
 tmp = dvrr_stack + 791283;
 target_ptr = Libderiv->deriv_classes[7][12][2];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+794559, dvrr_stack+355487, dvrr_stack+3654);
 tmp = dvrr_stack + 794559;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+795819, dvrr_stack+152093, dvrr_stack+154221);
 tmp = dvrr_stack + 795819;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+797439, dvrr_stack+158541, dvrr_stack+12793);
 tmp = dvrr_stack + 797439;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+799464, dvrr_stack+383467, dvrr_stack+20134);
 tmp = dvrr_stack + 799464;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+801939, dvrr_stack+400517, dvrr_stack+179123);
 tmp = dvrr_stack + 801939;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,78,dvrr_stack+804909, dvrr_stack+187439, dvrr_stack+192431);
 tmp = dvrr_stack + 804909;
 target_ptr = Libderiv->deriv_classes[8][11][2];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,91,dvrr_stack+808419, dvrr_stack+202367, dvrr_stack+208191);
 tmp = dvrr_stack + 808419;
 target_ptr = Libderiv->deriv_classes[8][12][2];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+812514, dvrr_stack+501212, dvrr_stack+239652);
 tmp = dvrr_stack + 812514;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+814054, dvrr_stack+506984, dvrr_stack+244512);
 tmp = dvrr_stack + 814054;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+816034, dvrr_stack+520754, dvrr_stack+86419);
 tmp = dvrr_stack + 816034;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+818509, dvrr_stack+537397, dvrr_stack+92773);
 tmp = dvrr_stack + 818509;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+821534, dvrr_stack+559177, dvrr_stack+100623);
 tmp = dvrr_stack + 821534;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,78,dvrr_stack+825164, dvrr_stack+583705, dvrr_stack+110523);
 tmp = dvrr_stack + 825164;
 target_ptr = Libderiv->deriv_classes[9][11][2];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,91,dvrr_stack+829454, dvrr_stack+612750, dvrr_stack+121839);
 tmp = dvrr_stack + 829454;
 target_ptr = Libderiv->deriv_classes[9][12][2];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+834459, dvrr_stack+220423, dvrr_stack+355487);
 tmp = dvrr_stack + 834459;
 target_ptr = Libderiv->deriv_classes[10][6][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+836307, dvrr_stack+503060, dvrr_stack+152093);
 tmp = dvrr_stack + 836307;
 target_ptr = Libderiv->deriv_classes[10][7][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+838683, dvrr_stack+348577, dvrr_stack+158541);
 tmp = dvrr_stack + 838683;
 target_ptr = Libderiv->deriv_classes[10][8][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+841653, dvrr_stack+67893, dvrr_stack+383467);
 tmp = dvrr_stack + 841653;
 target_ptr = Libderiv->deriv_classes[10][9][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+845283, dvrr_stack+549937, dvrr_stack+400517);
 tmp = dvrr_stack + 845283;
 target_ptr = Libderiv->deriv_classes[10][10][2];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,78,dvrr_stack+849639, dvrr_stack+393917, dvrr_stack+187439);
 tmp = dvrr_stack + 849639;
 target_ptr = Libderiv->deriv_classes[10][11][2];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,91,dvrr_stack+854787, dvrr_stack+271397, dvrr_stack+202367);
 tmp = dvrr_stack + 854787;
 target_ptr = Libderiv->deriv_classes[10][12][2];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+80332, dvrr_stack+80979, dvrr_stack+4788);
 tmp = dvrr_stack + 80332;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+354635, dvrr_stack+83059, dvrr_stack+8388);
 tmp = dvrr_stack + 354635;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+860793, dvrr_stack+88489, dvrr_stack+14553);
 tmp = dvrr_stack + 860793;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+861738, dvrr_stack+95303, dvrr_stack+22236);
 tmp = dvrr_stack + 861738;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+862893, dvrr_stack+104055, dvrr_stack+31605);
 tmp = dvrr_stack + 862893;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,78,dvrr_stack+864279, dvrr_stack+114111, dvrr_stack+42828);
 tmp = dvrr_stack + 864279;
 target_ptr = Libderiv->deriv_classes[5][11][1];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,91,dvrr_stack+865917, dvrr_stack+126571, dvrr_stack+56073);
 tmp = dvrr_stack + 865917;
 target_ptr = Libderiv->deriv_classes[5][12][1];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2808, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 2808;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+867828, dvrr_stack+154221, dvrr_stack+8928);
 tmp = dvrr_stack + 867828;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+868836, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 868836;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+870096, dvrr_stack+20134, dvrr_stack+23061);
 tmp = dvrr_stack + 870096;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+871636, dvrr_stack+179123, dvrr_stack+32595);
 tmp = dvrr_stack + 871636;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,78,dvrr_stack+873484, dvrr_stack+192431, dvrr_stack+43998);
 tmp = dvrr_stack + 873484;
 target_ptr = Libderiv->deriv_classes[6][11][1];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,91,dvrr_stack+875668, dvrr_stack+208191, dvrr_stack+57438);
 tmp = dvrr_stack + 875668;
 target_ptr = Libderiv->deriv_classes[6][12][1];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+878216, dvrr_stack+239652, dvrr_stack+80979);
 tmp = dvrr_stack + 878216;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+879224, dvrr_stack+244512, dvrr_stack+83059);
 tmp = dvrr_stack + 879224;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+880520, dvrr_stack+86419, dvrr_stack+88489);
 tmp = dvrr_stack + 880520;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+882140, dvrr_stack+92773, dvrr_stack+95303);
 tmp = dvrr_stack + 882140;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+884120, dvrr_stack+100623, dvrr_stack+104055);
 tmp = dvrr_stack + 884120;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,78,dvrr_stack+886496, dvrr_stack+110523, dvrr_stack+114111);
 tmp = dvrr_stack + 886496;
 target_ptr = Libderiv->deriv_classes[7][11][1];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,91,dvrr_stack+889304, dvrr_stack+121839, dvrr_stack+126571);
 tmp = dvrr_stack + 889304;
 target_ptr = Libderiv->deriv_classes[7][12][1];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+892580, dvrr_stack+355487, dvrr_stack+3654);
 tmp = dvrr_stack + 892580;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+893840, dvrr_stack+152093, dvrr_stack+154221);
 tmp = dvrr_stack + 893840;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+895460, dvrr_stack+158541, dvrr_stack+12793);
 tmp = dvrr_stack + 895460;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+897485, dvrr_stack+383467, dvrr_stack+20134);
 tmp = dvrr_stack + 897485;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+899960, dvrr_stack+400517, dvrr_stack+179123);
 tmp = dvrr_stack + 899960;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,78,dvrr_stack+902930, dvrr_stack+187439, dvrr_stack+192431);
 tmp = dvrr_stack + 902930;
 target_ptr = Libderiv->deriv_classes[8][11][1];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,91,dvrr_stack+906440, dvrr_stack+202367, dvrr_stack+208191);
 tmp = dvrr_stack + 906440;
 target_ptr = Libderiv->deriv_classes[8][12][1];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+910535, dvrr_stack+501212, dvrr_stack+239652);
 tmp = dvrr_stack + 910535;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+912075, dvrr_stack+506984, dvrr_stack+244512);
 tmp = dvrr_stack + 912075;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+914055, dvrr_stack+520754, dvrr_stack+86419);
 tmp = dvrr_stack + 914055;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+916530, dvrr_stack+537397, dvrr_stack+92773);
 tmp = dvrr_stack + 916530;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+919555, dvrr_stack+559177, dvrr_stack+100623);
 tmp = dvrr_stack + 919555;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,78,dvrr_stack+923185, dvrr_stack+583705, dvrr_stack+110523);
 tmp = dvrr_stack + 923185;
 target_ptr = Libderiv->deriv_classes[9][11][1];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,91,dvrr_stack+927475, dvrr_stack+612750, dvrr_stack+121839);
 tmp = dvrr_stack + 927475;
 target_ptr = Libderiv->deriv_classes[9][12][1];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+932480, dvrr_stack+220423, dvrr_stack+355487);
 tmp = dvrr_stack + 932480;
 target_ptr = Libderiv->deriv_classes[10][6][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+934328, dvrr_stack+503060, dvrr_stack+152093);
 tmp = dvrr_stack + 934328;
 target_ptr = Libderiv->deriv_classes[10][7][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+936704, dvrr_stack+348577, dvrr_stack+158541);
 tmp = dvrr_stack + 936704;
 target_ptr = Libderiv->deriv_classes[10][8][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+939674, dvrr_stack+67893, dvrr_stack+383467);
 tmp = dvrr_stack + 939674;
 target_ptr = Libderiv->deriv_classes[10][9][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+943304, dvrr_stack+549937, dvrr_stack+400517);
 tmp = dvrr_stack + 943304;
 target_ptr = Libderiv->deriv_classes[10][10][1];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,78,dvrr_stack+947660, dvrr_stack+393917, dvrr_stack+187439);
 tmp = dvrr_stack + 947660;
 target_ptr = Libderiv->deriv_classes[10][11][1];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,91,dvrr_stack+952808, dvrr_stack+271397, dvrr_stack+202367);
 tmp = dvrr_stack + 952808;
 target_ptr = Libderiv->deriv_classes[10][12][1];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+49122, dvrr_stack+80979, dvrr_stack+4788);
 tmp = dvrr_stack + 49122;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+207372, dvrr_stack+83059, dvrr_stack+8388);
 tmp = dvrr_stack + 207372;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+958814, dvrr_stack+88489, dvrr_stack+14553);
 tmp = dvrr_stack + 958814;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+959759, dvrr_stack+95303, dvrr_stack+22236);
 tmp = dvrr_stack + 959759;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+960914, dvrr_stack+104055, dvrr_stack+31605);
 tmp = dvrr_stack + 960914;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,78,dvrr_stack+962300, dvrr_stack+114111, dvrr_stack+42828);
 tmp = dvrr_stack + 962300;
 target_ptr = Libderiv->deriv_classes[5][11][0];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,91,dvrr_stack+963938, dvrr_stack+126571, dvrr_stack+56073);
 tmp = dvrr_stack + 963938;
 target_ptr = Libderiv->deriv_classes[5][12][0];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+42666, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 42666;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+31587, dvrr_stack+154221, dvrr_stack+8928);
 tmp = dvrr_stack + 31587;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+55869, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 55869;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+14413, dvrr_stack+20134, dvrr_stack+23061);
 tmp = dvrr_stack + 14413;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+22114, dvrr_stack+179123, dvrr_stack+32595);
 tmp = dvrr_stack + 22114;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,78,dvrr_stack+965849, dvrr_stack+192431, dvrr_stack+43998);
 tmp = dvrr_stack + 965849;
 target_ptr = Libderiv->deriv_classes[6][11][0];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,91,dvrr_stack+968033, dvrr_stack+208191, dvrr_stack+57438);
 tmp = dvrr_stack + 968033;
 target_ptr = Libderiv->deriv_classes[6][12][0];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+32595, dvrr_stack+239652, dvrr_stack+80979);
 tmp = dvrr_stack + 32595;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+43450, dvrr_stack+244512, dvrr_stack+83059);
 tmp = dvrr_stack + 43450;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+57129, dvrr_stack+86419, dvrr_stack+88489);
 tmp = dvrr_stack + 57129;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+970581, dvrr_stack+92773, dvrr_stack+95303);
 tmp = dvrr_stack + 970581;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+972561, dvrr_stack+100623, dvrr_stack+104055);
 tmp = dvrr_stack + 972561;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,78,dvrr_stack+974937, dvrr_stack+110523, dvrr_stack+114111);
 tmp = dvrr_stack + 974937;
 target_ptr = Libderiv->deriv_classes[7][11][0];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,91,dvrr_stack+977745, dvrr_stack+121839, dvrr_stack+126571);
 tmp = dvrr_stack + 977745;
 target_ptr = Libderiv->deriv_classes[7][12][0];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+114033, dvrr_stack+355487, dvrr_stack+3654);
 tmp = dvrr_stack + 114033;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+3592, dvrr_stack+152093, dvrr_stack+154221);
 tmp = dvrr_stack + 3592;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+125934, dvrr_stack+158541, dvrr_stack+12793);
 tmp = dvrr_stack + 125934;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+981021, dvrr_stack+383467, dvrr_stack+20134);
 tmp = dvrr_stack + 981021;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+983496, dvrr_stack+400517, dvrr_stack+179123);
 tmp = dvrr_stack + 983496;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,78,dvrr_stack+986466, dvrr_stack+187439, dvrr_stack+192431);
 tmp = dvrr_stack + 986466;
 target_ptr = Libderiv->deriv_classes[8][11][0];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,91,dvrr_stack+989976, dvrr_stack+202367, dvrr_stack+208191);
 tmp = dvrr_stack + 989976;
 target_ptr = Libderiv->deriv_classes[8][12][0];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+12624, dvrr_stack+501212, dvrr_stack+239652);
 tmp = dvrr_stack + 12624;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+191729, dvrr_stack+506984, dvrr_stack+244512);
 tmp = dvrr_stack + 191729;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+178877, dvrr_stack+520754, dvrr_stack+86419);
 tmp = dvrr_stack + 178877;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+86371, dvrr_stack+537397, dvrr_stack+92773);
 tmp = dvrr_stack + 86371;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+92269, dvrr_stack+559177, dvrr_stack+100623);
 tmp = dvrr_stack + 92269;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,78,dvrr_stack+100294, dvrr_stack+583705, dvrr_stack+110523);
 tmp = dvrr_stack + 100294;
 target_ptr = Libderiv->deriv_classes[9][11][0];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,91,dvrr_stack+583406, dvrr_stack+612750, dvrr_stack+121839);
 tmp = dvrr_stack + 583406;
 target_ptr = Libderiv->deriv_classes[9][12][0];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+121449, dvrr_stack+220423, dvrr_stack+355487);
 tmp = dvrr_stack + 121449;
 target_ptr = Libderiv->deriv_classes[10][6][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+123297, dvrr_stack+503060, dvrr_stack+152093);
 tmp = dvrr_stack + 123297;
 target_ptr = Libderiv->deriv_classes[10][7][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+152093, dvrr_stack+348577, dvrr_stack+158541);
 tmp = dvrr_stack + 152093;
 target_ptr = Libderiv->deriv_classes[10][8][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+110397, dvrr_stack+67893, dvrr_stack+383467);
 tmp = dvrr_stack + 110397;
 target_ptr = Libderiv->deriv_classes[10][9][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+612262, dvrr_stack+549937, dvrr_stack+400517);
 tmp = dvrr_stack + 612262;
 target_ptr = Libderiv->deriv_classes[10][10][0];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,78,dvrr_stack+549923, dvrr_stack+393917, dvrr_stack+187439);
 tmp = dvrr_stack + 549923;
 target_ptr = Libderiv->deriv_classes[10][11][0];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,91,dvrr_stack+393903, dvrr_stack+271397, dvrr_stack+202367);
 tmp = dvrr_stack + 393903;
 target_ptr = Libderiv->deriv_classes[10][12][0];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];


}

